h3[data-v-32964697]{cursor:default}.module-card[data-v-32964697]{margin-bottom:20px;line-height:1;white-space:nowrap}.unloaded[data-v-32964697]{color:gray;font-style:oblique}.el-button i[data-v-32964697]{margin-right:8px}.header-container[data-v-32964697]{display:flex;justify-content:space-between;align-items:center}.filter-container[data-v-32964697]{display:flex;flex-wrap:wrap;gap:20px;margin-bottom:20px}.filter-item[data-v-32964697]{flex:1 1 0;min-width:200px}.pagination-wrapper[data-v-32964697]{overflow-x:auto;-webkit-overflow-scrolling:touch;white-space:nowrap;width:100%}.help-code[data-v-32964697]{font-family:Consolas,Noto Sans Mono,Courier New,Courier,monospace}
