import{Q as u,ac as c,U as h,j as p,cg as v,W as C,c as r,h as t,x as n,b as g,n as o,O as a,a0 as l,e as i,t as f,H as S,a4 as b}from"./index-Xuk4tRmH.js";const m=u({header:{type:String,default:""},footer:{type:String,default:""},bodyStyle:{type:c([String,Object,Array]),default:""},headerClass:String,bodyClass:String,footerClass:String,shadow:{type:String,values:["always","hover","never"],default:void 0}}),w=p({name:"ElCard"}),$=p({...w,props:m,setup(E){const y=v("card"),s=C("card");return(e,N)=>{var d;return t(),r("div",{class:o([a(s).b(),a(s).is(`${e.shadow||((d=a(y))==null?void 0:d.shadow)||"always"}-shadow`)])},[e.$slots.header||e.header?(t(),r("div",{key:0,class:o([a(s).e("header"),e.headerClass])},[l(e.$slots,"header",{},()=>[i(f(e.header),1)])],2)):n("v-if",!0),g("div",{class:o([a(s).e("body"),e.bodyClass]),style:S(e.bodyStyle)},[l(e.$slots,"default")],6),e.$slots.footer||e.footer?(t(),r("div",{key:1,class:o([a(s).e("footer"),e.footerClass])},[l(e.$slots,"footer",{},()=>[i(f(e.footer),1)])],2)):n("v-if",!0)],2)}}});var k=h($,[["__file","card.vue"]]);const P=b(k);export{P as E};
