import{Q as h,ab as o,ac as u,U as $,j as b,q as g,s as c,W as N,ap as f,bx as _,l as x,h as j,w as C,a0 as O,H as v,n as E,O as p,a1 as w,a4 as S}from"./index-Xuk4tRmH.js";const K=h({tag:{type:String,default:"div"},span:{type:Number,default:24},offset:{type:Number,default:0},pull:{type:Number,default:0},push:{type:Number,default:0},xs:{type:u([Number,Object]),default:()=>o({})},sm:{type:u([Number,Object]),default:()=>o({})},md:{type:u([Number,Object]),default:()=>o({})},lg:{type:u([Number,Object]),default:()=>o({})},xl:{type:u([Number,Object]),default:()=>o({})}}),k=Symbol("rowContextKey"),B=b({name:"ElCol"}),P=b({...B,props:K,setup(m){const t=m,{gutter:n}=g(k,{gutter:c(()=>0)}),a=N("col"),d=c(()=>{const e={};return n.value&&(e.paddingLeft=e.paddingRight=`${n.value/2}px`),e}),i=c(()=>{const e=[];return["span","offset","pull","push"].forEach(s=>{const l=t[s];f(l)&&(s==="span"?e.push(a.b(`${t[s]}`)):l>0&&e.push(a.b(`${s}-${t[s]}`)))}),["xs","sm","md","lg","xl"].forEach(s=>{f(t[s])?e.push(a.b(`${s}-${t[s]}`)):_(t[s])&&Object.entries(t[s]).forEach(([l,r])=>{e.push(l!=="span"?a.b(`${s}-${l}-${r}`):a.b(`${s}-${r}`))})}),n.value&&e.push(a.is("guttered")),[a.b(),e]});return(e,y)=>(j(),x(w(e.tag),{class:E(p(i)),style:v(p(d))},{default:C(()=>[O(e.$slots,"default")]),_:3},8,["class","style"]))}});var q=$(P,[["__file","col.vue"]]);const I=S(q);export{I as E,k as r};
