h3[data-v-885d018a]{cursor:default}.sql-console[data-v-885d018a] .el-card__body{display:flex;flex-direction:column;gap:16px;height:100%}.button-toolbar[data-v-885d018a]{flex-wrap:wrap}.button-toolbar .el-button i[data-v-885d018a]{margin-right:8px}.editor-area[data-v-885d018a]{display:flex;gap:16px;height:200px}.sql-input[data-v-885d018a]{flex:1;min-height:100px;height:100%}.sql-input[data-v-885d018a] .el-textarea__inner{font-family:Consolas,Noto Sans Mono,Courier New,Courier,monospace;font-size:14px;line-height:1.5}.history-area[data-v-885d018a]{flex:1;height:198px;display:flex;background-color:var(--el-fill-color-blank);flex-direction:column}.history-area span[data-v-885d018a]{cursor:default}.history[data-v-885d018a]{overflow-y:auto;height:80px;display:flex;flex-direction:column;gap:8px}.history-item[data-v-885d018a]{padding:8px 12px;border-radius:8px;background-color:var(--el-fill-color-light);cursor:pointer;word-break:break-word;font-family:Consolas,Noto Sans Mono,Courier New,Courier,monospace;font-size:14px;line-height:1.5}@media (max-width: 384px){.editor-area[data-v-885d018a]{flex-direction:column;height:400px}.sql-input[data-v-885d018a],.history-area[data-v-885d018a]{width:100%;height:200px}}.affected-rows[data-v-885d018a]{margin-bottom:10px;color:#606266}.error[data-v-885d018a]{margin-bottom:10px;color:red}.result-card[data-v-885d018a]{min-height:300px;height:calc(100vh - 450px)}.result-area[data-v-885d018a]{padding-bottom:40px;height:100%;overflow-y:auto}.pagination-wrapper[data-v-885d018a]{overflow-x:auto;-webkit-overflow-scrolling:touch;white-space:nowrap;width:100%}h3[data-v-dfadf935]{cursor:default}.data-models[data-v-dfadf935] .el-card__body{min-height:300px;height:calc(100vh - 150px);display:flex;flex-direction:column}.models[data-v-dfadf935]{flex:1;overflow-y:auto;display:block}h3[data-v-c9596b30]{cursor:default}@media (max-width: 768px){.el-row[data-v-c9596b30]{row-gap:16px}}
