h3[data-v-0ad1536f]{cursor:default}.el-card[data-v-0ad1536f]{margin-bottom:20px;line-height:1;white-space:nowrap}.card-header[data-v-0ad1536f]{display:flex;justify-content:space-between;align-items:center;margin-bottom:10px}.time-range-select[data-v-0ad1536f]{width:150px}.statistics-content[data-v-0ad1536f]{display:flex;justify-content:center;align-items:center;gap:20px}.data-group[data-v-0ad1536f]{display:flex;flex-direction:column;align-items:center;text-align:center}.data-title[data-v-0ad1536f],.data-text[data-v-0ad1536f]{display:inline-block}.data-title[data-v-0ad1536f]{flex:1 1 100%;margin-bottom:4px;color:#333;cursor:default}.dark .data-title[data-v-0ad1536f]{color:#fff}.data-text[data-v-0ad1536f]{flex:1 1 100%;color:#666;text-overflow:ellipsis}.dark .data-text[data-v-0ad1536f]{color:#ccc}.positive[data-v-0ad1536f]{color:#228b22}.negative[data-v-0ad1536f]{color:red}.chart-container[data-v-0ad1536f]{height:250px;width:100%}.ranking-item[data-v-0ad1536f]{margin-bottom:12px;display:flex;align-items:center}.ranking-label[data-v-0ad1536f]{display:flex;justify-content:space-between;align-items:center;margin-bottom:4px;font-size:14px;width:100%}.ranking-total-label[data-v-0ad1536f]{display:flex;justify-content:space-between;margin-bottom:20px;font-size:14px;width:100%}.proportion-bar[data-v-0ad1536f]{display:flex;height:12px;overflow:hidden;margin-bottom:20px;background-color:var(--el-fill-color-light);border-radius:10px}.proportion-segment[data-v-0ad1536f]{height:100%;transition:width .3s ease}h3[data-v-5356f1c9]{cursor:default}.el-card[data-v-5356f1c9]{margin-bottom:20px;line-height:1}.data-text[data-v-5356f1c9]{color:#666}.dark .data-text[data-v-5356f1c9]{color:#ccc}.data-title[data-v-5356f1c9]{margin-right:3ex;color:#333;cursor:default}.dark .data-title[data-v-5356f1c9]{color:#fff}.percentage-value[data-v-5356f1c9]{display:block;margin-top:10px;font-size:20px}.percentage-label[data-v-5356f1c9]{display:block;margin-top:10px;font-size:14px}.memory-dashboards[data-v-5356f1c9]{display:flex;justify-content:center;overflow-x:auto}.memory-dashboards.centerAlign[data-v-5356f1c9]{justify-content:center}.memory-dashboards.leftAlign[data-v-5356f1c9]{justify-content:flex-start}.el-progress--dashboard[data-v-5356f1c9]{margin:5px}.refresh-button[data-v-05dd6b0c]{position:fixed;bottom:20px;right:20px;z-index:9999;font-size:22px!important}
