import{r as c}from"./col-CaP0LA8w.js";import{Q as p,U as f,j as r,W as g,s as a,l as m,h as y,w as d,a0 as w,H as _,n as v,O as o,a1 as R,G as b,a4 as h}from"./index-Xuk4tRmH.js";const j=["start","center","end","space-around","space-between","space-evenly"],C=["top","middle","bottom"],S=p({tag:{type:String,default:"div"},gutter:{type:Number,default:0},justify:{type:String,values:j,default:"start"},align:{type:String,values:C}}),x=r({name:"ElRow"}),$=r({...x,props:S,setup(n){const t=n,e=g("row"),l=a(()=>t.gutter);b(c,{gutter:l});const i=a(()=>{const s={};return t.gutter&&(s.marginRight=s.marginLeft=`-${t.gutter/2}px`),s}),u=a(()=>[e.b(),e.is(`justify-${t.justify}`,t.justify!=="start"),e.is(`align-${t.align}`,!!t.align)]);return(s,k)=>(y(),m(R(s.tag),{class:v(o(u)),style:_(o(i))},{default:d(()=>[w(s.$slots,"default")]),_:3},8,["class","style"]))}});var E=f($,[["__file","row.vue"]]);const K=h(E);export{K as E};
