.el-button[data-v-9e8d8e9e]{border:none}.container[data-v-9e8d8e9e]{text-align:center}.title[data-v-9e8d8e9e]{font-size:32px;font-weight:700;margin:0}.quote[data-v-9e8d8e9e]{font-style:oblique;color:gray;display:block;margin:16px}.text[data-v-9e8d8e9e]{display:block;margin:16px}.footer-text[data-v-9e8d8e9e]{color:gray;display:block;margin-top:60px;font-size:14px}.python-text.disabled[data-v-9e8d8e9e]{cursor:default;-webkit-user-select:none;user-select:none}.repo-buttons[data-v-9e8d8e9e]{display:flex;justify-content:center;gap:16px;margin-top:24px;margin-bottom:16px}.github-link[data-v-9e8d8e9e]{display:flex;flex-direction:column;align-items:center;gap:2px}.other-links[data-v-9e8d8e9e]{display:flex;justify-content:center;gap:6px}.repo-button i[data-v-9e8d8e9e],.locale-button i[data-v-9e8d8e9e],.sponsor-button i[data-v-9e8d8e9e]{margin-right:8px}.repo-button[data-v-9e8d8e9e]{background-color:#242a31;color:#fff}.repo-button[data-v-9e8d8e9e]:hover{background-color:#474a4f;color:#fff}.locale-button[data-v-9e8d8e9e]{background-color:#419c45;color:#fff}.locale-button[data-v-9e8d8e9e]:hover{background-color:#45b24a;color:#fff}.sponsor-button[data-v-9e8d8e9e]{background-color:#916ae4;color:#fff}.sponsor-button[data-v-9e8d8e9e]:hover{background-color:#a284e3;color:#fff}
