.el-popover{--el-popover-bg-color: var(--el-bg-color-overlay);--el-popover-font-size: var(--el-font-size-base);--el-popover-border-color: var(--el-border-color-lighter);--el-popover-padding: 12px;--el-popover-padding-large: 18px 20px;--el-popover-title-font-size: 16px;--el-popover-title-text-color: var(--el-text-color-primary);--el-popover-border-radius: 4px}.el-popover.el-popper{background:var(--el-popover-bg-color);min-width:150px;border-radius:var(--el-popover-border-radius);border:1px solid var(--el-popover-border-color);padding:var(--el-popover-padding);z-index:var(--el-index-popper);color:var(--el-text-color-regular);line-height:1.4;font-size:var(--el-popover-font-size);box-shadow:var(--el-box-shadow-light);overflow-wrap:break-word;box-sizing:border-box}.el-popover.el-popper--plain{padding:var(--el-popover-padding-large)}.el-popover__title{color:var(--el-popover-title-text-color);font-size:var(--el-popover-title-font-size);line-height:1;margin-bottom:12px}.el-popover__reference:focus:not(.focusing),.el-popover__reference:focus:hover{outline-width:0}.el-popover.el-popper.is-dark{--el-popover-bg-color: var(--el-text-color-primary);--el-popover-border-color: var(--el-text-color-primary);--el-popover-title-text-color: var(--el-bg-color);color:var(--el-bg-color)}.el-popover.el-popper:focus:active,.el-popover.el-popper:focus{outline-width:0}
