import{_ as f,u as w,r as p,L as m,I as C,o as S,a as T,c as y,b as t,d as I,t as e,e as i,f as l,w as u,E as B,n as M,g as b,h as $}from"./index-Xuk4tRmH.js";const D={class:"container"},E={class:"quote"},A={class:"repo-buttons"},N={class:"github-link"},R=["title"],O={class:"github-link"},V=["title"],L={class:"other-links"},U={class:"footer-text"},j={__name:"about",setup(q){const{t:r}=w(),a=p(0),d=p(m.getItem("showDevelopMode")==="true"&&!C),c=p(""),h=()=>{if(d.value){b.info(r("setting.develop_mode.message.info.already"));return}a.value++;const s=7-a.value;s>0&&s<6&&b.info(r("setting.develop_mode.message.info.remain",{remain:s})),a.value>=7&&(m.setItem("showDevelopMode","true"),d.value=!0,b.success(r("setting.develop_mode.message.success")),a.value=0)},g=()=>window.open("https://github.com/Teahouse-Studios/akari-bot","_blank"),k=()=>window.open("https://github.com/Teahouse-Studios/akari-bot-webui","_blank"),v=()=>window.open("https://crowdin.com/project/akari-bot","_blank"),_=()=>window.open("https://afdian.com/a/teahouse","_blank");return S(()=>{}),T(()=>{c.value=""}),(s,o)=>{const n=B;return $(),y("div",D,[o[6]||(o[6]=t("img",{width:"300",src:I,alt:"Akaribot"},null,-1)),o[7]||(o[7]=t("h1",{class:"title"},"小可 · AkariBot",-1)),t("span",E,e(s.$t("about.slogan")),1),o[8]||(o[8]=t("span",{class:"text"},[i(" By "),t("a",{href:"https://github.com/OasisAkari"},"OasisAkari"),i(" via "),t("a",{href:"https://teahouse.team"},"Teahouse Studios")],-1)),t("div",A,[t("div",N,[l(n,{class:"repo-button",onClick:g},{default:u(()=>[o[0]||(o[0]=t("i",{class:"mdi mdi-github"},null,-1)),t("span",null,e(s.$t("about.button.repo.main")),1)]),_:1}),t("img",{src:"https://img.shields.io/github/stars/Teahouse-Studios/akari-bot?style=social",alt:"Repo Stars",title:s.$t("about.star.tooltip")},null,8,R)]),t("div",O,[l(n,{class:"repo-button",onClick:k},{default:u(()=>[o[1]||(o[1]=t("i",{class:"mdi mdi-github"},null,-1)),t("span",null,e(s.$t("about.button.repo.webui")),1)]),_:1}),t("img",{src:"https://img.shields.io/github/stars/Teahouse-Studios/akari-bot-webui?style=social",alt:"Repo Stars",title:s.$t("about.star.tooltip")},null,8,V)])]),t("div",L,[l(n,{class:"locale-button",onClick:v},{default:u(()=>[o[2]||(o[2]=t("i",{class:"mdi mdi-translate"},null,-1)),t("span",null,e(s.$t("about.button.locale")),1)]),_:1}),l(n,{class:"sponsor-button",onClick:_},{default:u(()=>[o[3]||(o[3]=t("i",{class:"mdi mdi-heart-outline"},null,-1)),t("span",null,e(s.$t("about.button.sponsor")),1)]),_:1})]),t("span",U,[o[4]||(o[4]=i(" Made with love❤️ and ",-1)),t("span",{class:M(["python-text",{disabled:!d.value}]),onClick:h}," Python🐍 ",2),o[5]||(o[5]=i(". ",-1))])])}}},z=f(j,[["__scopeId","data-v-9e8d8e9e"]]);export{z as default};
