import{_ as dh,u as zg,r as Wt,o as ph,a as gh,l as Ar,h as Jt,w as Ot,f as Bt,A as ma,aw as Hg,b as N,e as Sn,t as J,n as Vg,c as si,F as Iv,y as Pv,H as Rv,ay as hs,g as Gg,N as qu,m as Fi,L as Wg,J as f1,E as h1}from"./index-Xuk4tRmH.js";import{E as Ug}from"./row-A7ID7Bts.js";import{E as v1}from"./empty-BL6aLORj.js";import{E as c1,a as d1,b as p1}from"./select-CquTMhG_.js";import{E as Yg}from"./col-CaP0LA8w.js";import{E as Zg}from"./card-C1DHVaI1.js";import{E as g1}from"./progress-7zvDqfBc.js";/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */var Ku=function(r,t){return Ku=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,n){e.__proto__=n}||function(e,n){for(var i in n)Object.prototype.hasOwnProperty.call(n,i)&&(e[i]=n[i])},Ku(r,t)};function z(r,t){if(typeof t!="function"&&t!==null)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");Ku(r,t);function e(){this.constructor=r}r.prototype=t===null?Object.create(t):(e.prototype=t.prototype,new e)}var mh=12,m1="sans-serif",Br=mh+"px "+m1,y1=20,_1=100,S1="007LLmW'55;N0500LLLLLLLLLL00NNNLzWW\\\\WQb\\0FWLg\\bWb\\WQ\\WrWWQ000CL5LLFLL0LL**F*gLLLL5F0LF\\FFF5.5N";function b1(r){var t={};if(typeof JSON>"u")return t;for(var e=0;e<r.length;e++){var n=String.fromCharCode(e+32),i=(r.charCodeAt(e)-y1)/_1;t[n]=i}return t}var w1=b1(S1),fr={createCanvas:function(){return typeof document<"u"&&document.createElement("canvas")},measureText:(function(){var r,t;return function(e,n){if(!r){var i=fr.createCanvas();r=i&&i.getContext("2d")}if(r)return t!==n&&(t=r.font=n||Br),r.measureText(e);e=e||"",n=n||Br;var a=/((?:\d+)?\.?\d*)px/.exec(n),o=a&&+a[1]||mh,s=0;if(n.indexOf("mono")>=0)s=o*e.length;else for(var l=0;l<e.length;l++){var u=w1[e[l]];s+=u==null?o:u*o}return{width:s}}})(),loadImage:function(r,t,e){var n=new Image;return n.onload=t,n.onerror=e,n.src=r,n}},Xg=Ei(["Function","RegExp","Date","Error","CanvasGradient","CanvasPattern","Image","Canvas"],function(r,t){return r["[object "+t+"]"]=!0,r},{}),$g=Ei(["Int8","Uint8","Uint8Clamped","Int16","Uint16","Int32","Uint32","Float32","Float64"],function(r,t){return r["[object "+t+"Array]"]=!0,r},{}),Ri=Object.prototype.toString,js=Array.prototype,x1=js.forEach,T1=js.filter,yh=js.slice,M1=js.map,Ev=(function(){}).constructor,ao=Ev?Ev.prototype:null,_h="__proto__",C1=2311;function qg(){return C1++}function Sh(){for(var r=[],t=0;t<arguments.length;t++)r[t]=arguments[t];typeof console<"u"&&console.error.apply(console,r)}function st(r){if(r==null||typeof r!="object")return r;var t=r,e=Ri.call(r);if(e==="[object Array]"){if(!ya(r)){t=[];for(var n=0,i=r.length;n<i;n++)t[n]=st(r[n])}}else if($g[e]){if(!ya(r)){var a=r.constructor;if(a.from)t=a.from(r);else{t=new a(r.length);for(var n=0,i=r.length;n<i;n++)t[n]=r[n]}}}else if(!Xg[e]&&!ya(r)&&!Ia(r)){t={};for(var o in r)r.hasOwnProperty(o)&&o!==_h&&(t[o]=st(r[o]))}return t}function vt(r,t,e){if(!X(t)||!X(r))return e?st(t):r;for(var n in t)if(t.hasOwnProperty(n)&&n!==_h){var i=r[n],a=t[n];X(a)&&X(i)&&!H(a)&&!H(i)&&!Ia(a)&&!Ia(i)&&!kv(a)&&!kv(i)&&!ya(a)&&!ya(i)?vt(i,a,e):(e||!(n in r))&&(r[n]=st(t[n]))}return r}function O(r,t){if(Object.assign)Object.assign(r,t);else for(var e in t)t.hasOwnProperty(e)&&e!==_h&&(r[e]=t[e]);return r}function at(r,t,e){for(var n=St(t),i=0,a=n.length;i<a;i++){var o=n[i];r[o]==null&&(r[o]=t[o])}return r}function ft(r,t){if(r){if(r.indexOf)return r.indexOf(t);for(var e=0,n=r.length;e<n;e++)if(r[e]===t)return e}return-1}function D1(r,t){var e=r.prototype;function n(){}n.prototype=t.prototype,r.prototype=new n;for(var i in e)e.hasOwnProperty(i)&&(r.prototype[i]=e[i]);r.prototype.constructor=r,r.superClass=t}function Qe(r,t,e){if(r="prototype"in r?r.prototype:r,t="prototype"in t?t.prototype:t,Object.getOwnPropertyNames)for(var n=Object.getOwnPropertyNames(t),i=0;i<n.length;i++){var a=n[i];a!=="constructor"&&r[a]==null&&(r[a]=t[a])}else at(r,t)}function Qt(r){return!r||typeof r=="string"?!1:typeof r.length=="number"}function D(r,t,e){if(r&&t)if(r.forEach&&r.forEach===x1)r.forEach(t,e);else if(r.length===+r.length)for(var n=0,i=r.length;n<i;n++)t.call(e,r[n],n,r);else for(var a in r)r.hasOwnProperty(a)&&t.call(e,r[a],a,r)}function $(r,t,e){if(!r)return[];if(!t)return bh(r);if(r.map&&r.map===M1)return r.map(t,e);for(var n=[],i=0,a=r.length;i<a;i++)n.push(t.call(e,r[i],i,r));return n}function Ei(r,t,e,n){if(r&&t){for(var i=0,a=r.length;i<a;i++)e=t.call(n,e,r[i],i,r);return e}}function wt(r,t,e){if(!r)return[];if(!t)return bh(r);if(r.filter&&r.filter===T1)return r.filter(t,e);for(var n=[],i=0,a=r.length;i<a;i++)t.call(e,r[i],i,r)&&n.push(r[i]);return n}function A1(r,t,e){if(r&&t){for(var n=0,i=r.length;n<i;n++)if(t.call(e,r[n],n,r))return r[n]}}function St(r){if(!r)return[];if(Object.keys)return Object.keys(r);var t=[];for(var e in r)r.hasOwnProperty(e)&&t.push(e);return t}function L1(r,t){for(var e=[],n=2;n<arguments.length;n++)e[n-2]=arguments[n];return function(){return r.apply(t,e.concat(yh.call(arguments)))}}var Q=ao&&et(ao.bind)?ao.call.bind(ao.bind):L1;function ie(r){for(var t=[],e=1;e<arguments.length;e++)t[e-1]=arguments[e];return function(){return r.apply(this,t.concat(yh.call(arguments)))}}function H(r){return Array.isArray?Array.isArray(r):Ri.call(r)==="[object Array]"}function et(r){return typeof r=="function"}function W(r){return typeof r=="string"}function Qu(r){return Ri.call(r)==="[object String]"}function mt(r){return typeof r=="number"}function X(r){var t=typeof r;return t==="function"||!!r&&t==="object"}function kv(r){return!!Xg[Ri.call(r)]}function ae(r){return!!$g[Ri.call(r)]}function Ia(r){return typeof r=="object"&&typeof r.nodeType=="number"&&typeof r.ownerDocument=="object"}function Js(r){return r.colorStops!=null}function I1(r){return r.image!=null}function P1(r){return Ri.call(r)==="[object RegExp]"}function Pa(r){return r!==r}function vs(){for(var r=[],t=0;t<arguments.length;t++)r[t]=arguments[t];for(var e=0,n=r.length;e<n;e++)if(r[e]!=null)return r[e]}function q(r,t){return r??t}function _i(r,t,e){return r??t??e}function bh(r){for(var t=[],e=1;e<arguments.length;e++)t[e-1]=arguments[e];return yh.apply(r,t)}function wh(r){if(typeof r=="number")return[r,r,r,r];var t=r.length;return t===2?[r[0],r[1],r[0],r[1]]:t===3?[r[0],r[1],r[2],r[1]]:r}function hr(r,t){if(!r)throw new Error(t)}function We(r){return r==null?null:typeof r.trim=="function"?r.trim():r.replace(/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g,"")}var Kg="__ec_primitive__";function cs(r){r[Kg]=!0}function ya(r){return r[Kg]}var R1=(function(){function r(){this.data={}}return r.prototype.delete=function(t){var e=this.has(t);return e&&delete this.data[t],e},r.prototype.has=function(t){return this.data.hasOwnProperty(t)},r.prototype.get=function(t){return this.data[t]},r.prototype.set=function(t,e){return this.data[t]=e,this},r.prototype.keys=function(){return St(this.data)},r.prototype.forEach=function(t){var e=this.data;for(var n in e)e.hasOwnProperty(n)&&t(e[n],n)},r})(),Qg=typeof Map=="function";function E1(){return Qg?new Map:new R1}var k1=(function(){function r(t){var e=H(t);this.data=E1();var n=this;t instanceof r?t.each(i):t&&D(t,i);function i(a,o){e?n.set(a,o):n.set(o,a)}}return r.prototype.hasKey=function(t){return this.data.has(t)},r.prototype.get=function(t){return this.data.get(t)},r.prototype.set=function(t,e){return this.data.set(t,e),e},r.prototype.each=function(t,e){this.data.forEach(function(n,i){t.call(e,n,i)})},r.prototype.keys=function(){var t=this.data.keys();return Qg?Array.from(t):t},r.prototype.removeKey=function(t){this.data.delete(t)},r})();function K(r){return new k1(r)}function O1(r,t){for(var e=new r.constructor(r.length+t.length),n=0;n<r.length;n++)e[n]=r[n];for(var i=r.length,n=0;n<t.length;n++)e[n+i]=t[n];return e}function tl(r,t){var e;if(Object.create)e=Object.create(r);else{var n=function(){};n.prototype=r,e=new n}return t&&O(e,t),e}function jg(r){var t=r.style;t.webkitUserSelect="none",t.userSelect="none",t.webkitTapHighlightColor="rgba(0,0,0,0)",t["-webkit-touch-callout"]="none"}function ve(r,t){return r.hasOwnProperty(t)}function Kt(){}var B1=180/Math.PI,N1=(function(){function r(){this.firefox=!1,this.ie=!1,this.edge=!1,this.newEdge=!1,this.weChat=!1}return r})(),F1=(function(){function r(){this.browser=new N1,this.node=!1,this.wxa=!1,this.worker=!1,this.svgSupported=!1,this.touchEventsSupported=!1,this.pointerEventsSupported=!1,this.domSupported=!1,this.transformSupported=!1,this.transform3dSupported=!1,this.hasGlobalWindow=typeof window<"u"}return r})(),nt=new F1;typeof wx=="object"&&typeof wx.getSystemInfoSync=="function"?(nt.wxa=!0,nt.touchEventsSupported=!0):typeof document>"u"&&typeof self<"u"?nt.worker=!0:!nt.hasGlobalWindow||"Deno"in window||typeof navigator<"u"&&typeof navigator.userAgent=="string"&&navigator.userAgent.indexOf("Node.js")>-1?(nt.node=!0,nt.svgSupported=!0):z1(navigator.userAgent,nt);function z1(r,t){var e=t.browser,n=r.match(/Firefox\/([\d.]+)/),i=r.match(/MSIE\s([\d.]+)/)||r.match(/Trident\/.+?rv:(([\d.]+))/),a=r.match(/Edge?\/([\d.]+)/),o=/micromessenger/i.test(r);n&&(e.firefox=!0,e.version=n[1]),i&&(e.ie=!0,e.version=i[1]),a&&(e.edge=!0,e.version=a[1],e.newEdge=+a[1].split(".")[0]>18),o&&(e.weChat=!0),t.svgSupported=typeof SVGRect<"u",t.touchEventsSupported="ontouchstart"in window&&!e.ie&&!e.edge,t.pointerEventsSupported="onpointerdown"in window&&(e.edge||e.ie&&+e.version>=11);var s=t.domSupported=typeof document<"u";if(s){var l=document.documentElement.style;t.transform3dSupported=(e.ie&&"transition"in l||e.edge||"WebKitCSSMatrix"in window&&"m11"in new WebKitCSSMatrix||"MozPerspective"in l)&&!("OTransition"in l),t.transformSupported=t.transform3dSupported||e.ie&&+e.version>=9}}var H1=".",Zr="___EC__COMPONENT__CONTAINER___",Jg="___EC__EXTENDED_CLASS___";function Ue(r){var t={main:"",sub:""};if(r){var e=r.split(H1);t.main=e[0]||"",t.sub=e[1]||""}return t}function V1(r){hr(/^[a-zA-Z0-9_]+([.][a-zA-Z0-9_]+)?$/.test(r),'componentType "'+r+'" illegal')}function G1(r){return!!(r&&r[Jg])}function xh(r,t){r.$constructor=r,r.extend=function(e){var n=this,i;return W1(n)?i=(function(a){z(o,a);function o(){return a.apply(this,arguments)||this}return o})(n):(i=function(){(e.$constructor||n).apply(this,arguments)},D1(i,this)),O(i.prototype,e),i[Jg]=!0,i.extend=this.extend,i.superCall=Z1,i.superApply=X1,i.superClass=n,i}}function W1(r){return et(r)&&/^class\s/.test(Function.prototype.toString.call(r))}function tm(r,t){r.extend=t.extend}var U1=Math.round(Math.random()*10);function Y1(r){var t=["__\0is_clz",U1++].join("_");r.prototype[t]=!0,r.isInstance=function(e){return!!(e&&e[t])}}function Z1(r,t){for(var e=[],n=2;n<arguments.length;n++)e[n-2]=arguments[n];return this.superClass.prototype[t].apply(r,e)}function X1(r,t,e){return this.superClass.prototype[t].apply(r,e)}function el(r){var t={};r.registerClass=function(n){var i=n.type||n.prototype.type;if(i){V1(i),n.prototype.type=i;var a=Ue(i);if(!a.sub)t[a.main]=n;else if(a.sub!==Zr){var o=e(a);o[a.sub]=n}}return n},r.getClass=function(n,i,a){var o=t[n];if(o&&o[Zr]&&(o=i?o[i]:null),a&&!o)throw new Error(i?"Component "+n+"."+(i||"")+" is used but not imported.":n+".type should be specified.");return o},r.getClassesByMainType=function(n){var i=Ue(n),a=[],o=t[i.main];return o&&o[Zr]?D(o,function(s,l){l!==Zr&&a.push(s)}):a.push(o),a},r.hasClass=function(n){var i=Ue(n);return!!t[i.main]},r.getAllClassMainTypes=function(){var n=[];return D(t,function(i,a){n.push(a)}),n},r.hasSubTypes=function(n){var i=Ue(n),a=t[i.main];return a&&a[Zr]};function e(n){var i=t[n.main];return(!i||!i[Zr])&&(i=t[n.main]={},i[Zr]=!0),i}}function Ra(r,t){for(var e=0;e<r.length;e++)r[e][1]||(r[e][1]=r[e][0]);return t=t||!1,function(n,i,a){for(var o={},s=0;s<r.length;s++){var l=r[s][1];if(!(i&&ft(i,l)>=0||a&&ft(a,l)<0)){var u=n.getShallow(l,t);u!=null&&(o[r[s][0]]=u)}}return o}}var $1=[["fill","color"],["shadowBlur"],["shadowOffsetX"],["shadowOffsetY"],["opacity"],["shadowColor"]],q1=Ra($1),K1=(function(){function r(){}return r.prototype.getAreaStyle=function(t,e){return q1(this,t,e)},r})(),em=(function(){function r(t){this.value=t}return r})(),Q1=(function(){function r(){this._len=0}return r.prototype.insert=function(t){var e=new em(t);return this.insertEntry(e),e},r.prototype.insertEntry=function(t){this.head?(this.tail.next=t,t.prev=this.tail,t.next=null,this.tail=t):this.head=this.tail=t,this._len++},r.prototype.remove=function(t){var e=t.prev,n=t.next;e?e.next=n:this.head=n,n?n.prev=e:this.tail=e,t.next=t.prev=null,this._len--},r.prototype.len=function(){return this._len},r.prototype.clear=function(){this.head=this.tail=null,this._len=0},r})(),Ti=(function(){function r(t){this._list=new Q1,this._maxSize=10,this._map={},this._maxSize=t}return r.prototype.put=function(t,e){var n=this._list,i=this._map,a=null;if(i[t]==null){var o=n.len(),s=this._lastRemovedEntry;if(o>=this._maxSize&&o>0){var l=n.head;n.remove(l),delete i[l.key],a=l.value,this._lastRemovedEntry=l}s?s.value=e:s=new em(e),s.key=t,n.insertEntry(s),i[t]=s}return a},r.prototype.get=function(t){var e=this._map[t],n=this._list;if(e!=null)return e!==n.tail&&(n.remove(e),n.insertEntry(e)),e.value},r.prototype.clear=function(){this._list.clear(),this._map={}},r.prototype.len=function(){return this._list.len()},r})(),ju=new Ti(50);function j1(r){if(typeof r=="string"){var t=ju.get(r);return t&&t.image}else return r}function rm(r,t,e,n,i){if(r)if(typeof r=="string"){if(t&&t.__zrImageSrc===r||!e)return t;var a=ju.get(r),o={hostEl:e,cb:n,cbPayload:i};return a?(t=a.image,!rl(t)&&a.pending.push(o)):(t=fr.loadImage(r,Ov,Ov),t.__zrImageSrc=r,ju.put(r,t.__cachedImgObj={image:t,pending:[o]})),t}else return r;else return t}function Ov(){var r=this.__cachedImgObj;this.onload=this.onerror=this.__cachedImgObj=null;for(var t=0;t<r.pending.length;t++){var e=r.pending[t],n=e.cb;n&&n(this,e.cbPayload),e.hostEl.dirty()}r.pending.length=0}function rl(r){return r&&r.width&&r.height}function lr(){return[1,0,0,1,0,0]}function Th(r){return r[0]=1,r[1]=0,r[2]=0,r[3]=1,r[4]=0,r[5]=0,r}function nm(r,t){return r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=t[3],r[4]=t[4],r[5]=t[5],r}function _a(r,t,e){var n=t[0]*e[0]+t[2]*e[1],i=t[1]*e[0]+t[3]*e[1],a=t[0]*e[2]+t[2]*e[3],o=t[1]*e[2]+t[3]*e[3],s=t[0]*e[4]+t[2]*e[5]+t[4],l=t[1]*e[4]+t[3]*e[5]+t[5];return r[0]=n,r[1]=i,r[2]=a,r[3]=o,r[4]=s,r[5]=l,r}function Ju(r,t,e){return r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=t[3],r[4]=t[4]+e[0],r[5]=t[5]+e[1],r}function Mh(r,t,e,n){n===void 0&&(n=[0,0]);var i=t[0],a=t[2],o=t[4],s=t[1],l=t[3],u=t[5],f=Math.sin(e),h=Math.cos(e);return r[0]=i*h+s*f,r[1]=-i*f+s*h,r[2]=a*h+l*f,r[3]=-a*f+h*l,r[4]=h*(o-n[0])+f*(u-n[1])+n[0],r[5]=h*(u-n[1])-f*(o-n[0])+n[1],r}function J1(r,t,e){var n=e[0],i=e[1];return r[0]=t[0]*n,r[1]=t[1]*i,r[2]=t[2]*n,r[3]=t[3]*i,r[4]=t[4]*n,r[5]=t[5]*i,r}function ki(r,t){var e=t[0],n=t[2],i=t[4],a=t[1],o=t[3],s=t[5],l=e*o-a*n;return l?(l=1/l,r[0]=o*l,r[1]=-a*l,r[2]=-n*l,r[3]=e*l,r[4]=(n*s-o*i)*l,r[5]=(a*i-e*s)*l,r):null}var tt=(function(){function r(t,e){this.x=t||0,this.y=e||0}return r.prototype.copy=function(t){return this.x=t.x,this.y=t.y,this},r.prototype.clone=function(){return new r(this.x,this.y)},r.prototype.set=function(t,e){return this.x=t,this.y=e,this},r.prototype.equal=function(t){return t.x===this.x&&t.y===this.y},r.prototype.add=function(t){return this.x+=t.x,this.y+=t.y,this},r.prototype.scale=function(t){this.x*=t,this.y*=t},r.prototype.scaleAndAdd=function(t,e){this.x+=t.x*e,this.y+=t.y*e},r.prototype.sub=function(t){return this.x-=t.x,this.y-=t.y,this},r.prototype.dot=function(t){return this.x*t.x+this.y*t.y},r.prototype.len=function(){return Math.sqrt(this.x*this.x+this.y*this.y)},r.prototype.lenSquare=function(){return this.x*this.x+this.y*this.y},r.prototype.normalize=function(){var t=this.len();return this.x/=t,this.y/=t,this},r.prototype.distance=function(t){var e=this.x-t.x,n=this.y-t.y;return Math.sqrt(e*e+n*n)},r.prototype.distanceSquare=function(t){var e=this.x-t.x,n=this.y-t.y;return e*e+n*n},r.prototype.negate=function(){return this.x=-this.x,this.y=-this.y,this},r.prototype.transform=function(t){if(t){var e=this.x,n=this.y;return this.x=t[0]*e+t[2]*n+t[4],this.y=t[1]*e+t[3]*n+t[5],this}},r.prototype.toArray=function(t){return t[0]=this.x,t[1]=this.y,t},r.prototype.fromArray=function(t){this.x=t[0],this.y=t[1]},r.set=function(t,e,n){t.x=e,t.y=n},r.copy=function(t,e){t.x=e.x,t.y=e.y},r.len=function(t){return Math.sqrt(t.x*t.x+t.y*t.y)},r.lenSquare=function(t){return t.x*t.x+t.y*t.y},r.dot=function(t,e){return t.x*e.x+t.y*e.y},r.add=function(t,e,n){t.x=e.x+n.x,t.y=e.y+n.y},r.sub=function(t,e,n){t.x=e.x-n.x,t.y=e.y-n.y},r.scale=function(t,e,n){t.x=e.x*n,t.y=e.y*n},r.scaleAndAdd=function(t,e,n,i){t.x=e.x+n.x*i,t.y=e.y+n.y*i},r.lerp=function(t,e,n,i){var a=1-i;t.x=a*e.x+i*n.x,t.y=a*e.y+i*n.y},r})(),wn=Math.min,fi=Math.max,tf=Math.abs,Bv=["x","y"],tS=["width","height"],Xr=new tt,$r=new tt,qr=new tt,Kr=new tt,ue=im(),ua=ue.minTv,ef=ue.maxTv,Sa=[0,0],it=(function(){function r(t,e,n,i){r.set(this,t,e,n,i)}return r.set=function(t,e,n,i,a){return i<0&&(e=e+i,i=-i),a<0&&(n=n+a,a=-a),t.x=e,t.y=n,t.width=i,t.height=a,t},r.prototype.union=function(t){var e=wn(t.x,this.x),n=wn(t.y,this.y);isFinite(this.x)&&isFinite(this.width)?this.width=fi(t.x+t.width,this.x+this.width)-e:this.width=t.width,isFinite(this.y)&&isFinite(this.height)?this.height=fi(t.y+t.height,this.y+this.height)-n:this.height=t.height,this.x=e,this.y=n},r.prototype.applyTransform=function(t){r.applyTransform(this,this,t)},r.prototype.calculateTransform=function(t){var e=this,n=t.width/e.width,i=t.height/e.height,a=lr();return Ju(a,a,[-e.x,-e.y]),J1(a,a,[n,i]),Ju(a,a,[t.x,t.y]),a},r.prototype.intersect=function(t,e,n){return r.intersect(this,t,e,n)},r.intersect=function(t,e,n,i){n&&tt.set(n,0,0);var a=i&&i.outIntersectRect||null,o=i&&i.clamp;if(a&&(a.x=a.y=a.width=a.height=NaN),!t||!e)return!1;t instanceof r||(t=r.set(eS,t.x,t.y,t.width,t.height)),e instanceof r||(e=r.set(rS,e.x,e.y,e.width,e.height));var s=!!n;ue.reset(i,s);var l=ue.touchThreshold,u=t.x+l,f=t.x+t.width-l,h=t.y+l,c=t.y+t.height-l,v=e.x+l,d=e.x+e.width-l,p=e.y+l,g=e.y+e.height-l;if(u>f||h>c||v>d||p>g)return!1;var m=!(f<v||d<u||c<p||g<h);return(s||a)&&(Sa[0]=1/0,Sa[1]=0,Nv(u,f,v,d,0,s,a,o),Nv(h,c,p,g,1,s,a,o),s&&tt.copy(n,m?ue.useDir?ue.dirMinTv:ua:ef)),m},r.contain=function(t,e,n){return e>=t.x&&e<=t.x+t.width&&n>=t.y&&n<=t.y+t.height},r.prototype.contain=function(t,e){return r.contain(this,t,e)},r.prototype.clone=function(){return new r(this.x,this.y,this.width,this.height)},r.prototype.copy=function(t){r.copy(this,t)},r.prototype.plain=function(){return{x:this.x,y:this.y,width:this.width,height:this.height}},r.prototype.isFinite=function(){return isFinite(this.x)&&isFinite(this.y)&&isFinite(this.width)&&isFinite(this.height)},r.prototype.isZero=function(){return this.width===0||this.height===0},r.create=function(t){return new r(t.x,t.y,t.width,t.height)},r.copy=function(t,e){return t.x=e.x,t.y=e.y,t.width=e.width,t.height=e.height,t},r.applyTransform=function(t,e,n){if(!n){t!==e&&r.copy(t,e);return}if(n[1]<1e-5&&n[1]>-1e-5&&n[2]<1e-5&&n[2]>-1e-5){var i=n[0],a=n[3],o=n[4],s=n[5];t.x=e.x*i+o,t.y=e.y*a+s,t.width=e.width*i,t.height=e.height*a,t.width<0&&(t.x+=t.width,t.width=-t.width),t.height<0&&(t.y+=t.height,t.height=-t.height);return}Xr.x=qr.x=e.x,Xr.y=Kr.y=e.y,$r.x=Kr.x=e.x+e.width,$r.y=qr.y=e.y+e.height,Xr.transform(n),Kr.transform(n),$r.transform(n),qr.transform(n),t.x=wn(Xr.x,$r.x,qr.x,Kr.x),t.y=wn(Xr.y,$r.y,qr.y,Kr.y);var l=fi(Xr.x,$r.x,qr.x,Kr.x),u=fi(Xr.y,$r.y,qr.y,Kr.y);t.width=l-t.x,t.height=u-t.y},r})(),eS=new it(0,0,0,0),rS=new it(0,0,0,0);function Nv(r,t,e,n,i,a,o,s){var l=tf(t-e),u=tf(n-r),f=wn(l,u),h=Bv[i],c=Bv[1-i],v=tS[i];t<e||n<r?l<u?(a&&(ef[h]=-l),s&&(o[h]=t,o[v]=0)):(a&&(ef[h]=u),s&&(o[h]=r,o[v]=0)):(o&&(o[h]=fi(r,e),o[v]=wn(t,n)-o[h]),a&&(f<Sa[0]||ue.useDir)&&(Sa[0]=wn(f,Sa[0]),(l<u||!ue.bidirectional)&&(ua[h]=l,ua[c]=0,ue.useDir&&ue.calcDirMTV()),(l>=u||!ue.bidirectional)&&(ua[h]=-u,ua[c]=0,ue.useDir&&ue.calcDirMTV())))}function im(){var r=0,t=new tt,e=new tt,n={minTv:new tt,maxTv:new tt,useDir:!1,dirMinTv:new tt,touchThreshold:0,bidirectional:!0,negativeSize:!1,reset:function(a,o){n.touchThreshold=0,a&&a.touchThreshold!=null&&(n.touchThreshold=fi(0,a.touchThreshold)),n.negativeSize=!1,o&&(n.minTv.set(1/0,1/0),n.maxTv.set(0,0),n.useDir=!1,a&&a.direction!=null&&(n.useDir=!0,n.dirMinTv.copy(n.minTv),e.copy(n.minTv),r=a.direction,n.bidirectional=a.bidirectional==null||!!a.bidirectional,n.bidirectional||t.set(Math.cos(r),Math.sin(r))))},calcDirMTV:function(){var a=n.minTv,o=n.dirMinTv,s=a.y*a.y+a.x*a.x,l=Math.sin(r),u=Math.cos(r),f=l*a.y+u*a.x;if(i(f)){i(a.x)&&i(a.y)&&o.set(0,0);return}if(e.x=s*u/f,e.y=s*l/f,i(e.x)&&i(e.y)){o.set(0,0);return}(n.bidirectional||t.dot(e)>0)&&e.len()<o.len()&&o.copy(e)}};function i(a){return tf(a)<1e-10}return n}function Ze(r){oo||(oo=new Ti(100)),r=r||Br;var t=oo.get(r);return t||(t={font:r,strWidthCache:new Ti(500),asciiWidthMap:null,asciiWidthMapTried:!1,stWideCharWidth:fr.measureText("国",r).width,asciiCharWidth:fr.measureText("a",r).width},oo.put(r,t)),t}var oo;function nS(r){if(!(wl>=Fv)){r=r||Br;for(var t=[],e=+new Date,n=0;n<=127;n++)t[n]=fr.measureText(String.fromCharCode(n),r).width;var i=+new Date-e;return i>16?wl=Fv:i>2&&wl++,t}}var wl=0,Fv=5;function am(r,t){return r.asciiWidthMapTried||(r.asciiWidthMap=nS(r.font),r.asciiWidthMapTried=!0),0<=t&&t<=127?r.asciiWidthMap!=null?r.asciiWidthMap[t]:r.asciiCharWidth:r.stWideCharWidth}function Xe(r,t){var e=r.strWidthCache,n=e.get(t);return n==null&&(n=fr.measureText(t,r.font).width,e.put(t,n)),n}function zv(r,t,e,n){var i=Xe(Ze(t),r),a=nl(t),o=Mi(0,i,e),s=Dn(0,a,n),l=new it(o,s,i,a);return l}function om(r,t,e,n){var i=((r||"")+"").split(`
`),a=i.length;if(a===1)return zv(i[0],t,e,n);for(var o=new it(0,0,0,0),s=0;s<i.length;s++){var l=zv(i[s],t,e,n);s===0?o.copy(l):o.union(l)}return o}function Mi(r,t,e,n){return e==="right"?n?r+=t:r-=t:e==="center"&&(n?r+=t/2:r-=t/2),r}function Dn(r,t,e,n){return e==="middle"?n?r+=t/2:r-=t/2:e==="bottom"&&(n?r+=t:r-=t),r}function nl(r){return Ze(r).stWideCharWidth}function En(r,t){return typeof r=="string"?r.lastIndexOf("%")>=0?parseFloat(r)/100*t:parseFloat(r):r}function sm(r,t,e){var n=t.position||"inside",i=t.distance!=null?t.distance:5,a=e.height,o=e.width,s=a/2,l=e.x,u=e.y,f="left",h="top";if(n instanceof Array)l+=En(n[0],e.width),u+=En(n[1],e.height),f=null,h=null;else switch(n){case"left":l-=i,u+=s,f="right",h="middle";break;case"right":l+=i+o,u+=s,h="middle";break;case"top":l+=o/2,u-=i,f="center",h="bottom";break;case"bottom":l+=o/2,u+=a+i,f="center";break;case"inside":l+=o/2,u+=s,f="center",h="middle";break;case"insideLeft":l+=i,u+=s,h="middle";break;case"insideRight":l+=o-i,u+=s,f="right",h="middle";break;case"insideTop":l+=o/2,u+=i,f="center";break;case"insideBottom":l+=o/2,u+=a-i,f="center",h="bottom";break;case"insideTopLeft":l+=i,u+=i;break;case"insideTopRight":l+=o-i,u+=i,f="right";break;case"insideBottomLeft":l+=i,u+=a-i,h="bottom";break;case"insideBottomRight":l+=o-i,u+=a-i,f="right",h="bottom";break}return r=r||{},r.x=l,r.y=u,r.align=f,r.verticalAlign=h,r}var xl=/\{([a-zA-Z0-9_]+)\|([^}]*)\}/g;function iS(r,t,e,n,i,a){if(!e){r.text="",r.isTruncated=!1;return}var o=(t+"").split(`
`);a=lm(e,n,i,a);for(var s=!1,l={},u=0,f=o.length;u<f;u++)um(l,o[u],a),o[u]=l.textLine,s=s||l.isTruncated;r.text=o.join(`
`),r.isTruncated=s}function lm(r,t,e,n){n=n||{};var i=O({},n);e=q(e,"..."),i.maxIterations=q(n.maxIterations,2);var a=i.minChar=q(n.minChar,0),o=i.fontMeasureInfo=Ze(t),s=o.asciiCharWidth;i.placeholder=q(n.placeholder,"");for(var l=r=Math.max(0,r-1),u=0;u<a&&l>=s;u++)l-=s;var f=Xe(o,e);return f>l&&(e="",f=0),l=r-f,i.ellipsis=e,i.ellipsisWidth=f,i.contentWidth=l,i.containerWidth=r,i}function um(r,t,e){var n=e.containerWidth,i=e.contentWidth,a=e.fontMeasureInfo;if(!n){r.textLine="",r.isTruncated=!1;return}var o=Xe(a,t);if(o<=n){r.textLine=t,r.isTruncated=!1;return}for(var s=0;;s++){if(o<=i||s>=e.maxIterations){t+=e.ellipsis;break}var l=s===0?aS(t,i,a):o>0?Math.floor(t.length*i/o):0;t=t.substr(0,l),o=Xe(a,t)}t===""&&(t=e.placeholder),r.textLine=t,r.isTruncated=!0}function aS(r,t,e){for(var n=0,i=0,a=r.length;i<a&&n<t;i++)n+=am(e,r.charCodeAt(i));return i}function oS(r,t,e,n){var i=Ch(r),a=t.overflow,o=t.padding,s=o?o[1]+o[3]:0,l=o?o[0]+o[2]:0,u=t.font,f=a==="truncate",h=nl(u),c=q(t.lineHeight,h),v=t.lineOverflow==="truncate",d=!1,p=t.width;p==null&&e!=null&&(p=e-s);var g=t.height;g==null&&n!=null&&(g=n-l);var m;p!=null&&(a==="break"||a==="breakAll")?m=i?fm(i,t.font,p,a==="breakAll",0).lines:[]:m=i?i.split(`
`):[];var y=m.length*c;if(g==null&&(g=y),y>g&&v){var _=Math.floor(g/c);d=d||m.length>_,m=m.slice(0,_),y=m.length*c}if(i&&f&&p!=null)for(var S=lm(p,u,t.ellipsis,{minChar:t.truncateMinChar,placeholder:t.placeholder}),w={},b=0;b<m.length;b++)um(w,m[b],S),m[b]=w.textLine,d=d||w.isTruncated;for(var T=g,C=0,x=Ze(u),b=0;b<m.length;b++)C=Math.max(Xe(x,m[b]),C);p==null&&(p=C);var M=p;return T+=l,M+=s,{lines:m,height:g,outerWidth:M,outerHeight:T,lineHeight:c,calculatedLineHeight:h,contentWidth:C,contentHeight:y,width:p,isTruncated:d}}var sS=(function(){function r(){}return r})(),Hv=(function(){function r(t){this.tokens=[],t&&(this.tokens=t)}return r})(),lS=(function(){function r(){this.width=0,this.height=0,this.contentWidth=0,this.contentHeight=0,this.outerWidth=0,this.outerHeight=0,this.lines=[],this.isTruncated=!1}return r})();function uS(r,t,e,n,i){var a=new lS,o=Ch(r);if(!o)return a;var s=t.padding,l=s?s[1]+s[3]:0,u=s?s[0]+s[2]:0,f=t.width;f==null&&e!=null&&(f=e-l);var h=t.height;h==null&&n!=null&&(h=n-u);for(var c=t.overflow,v=(c==="break"||c==="breakAll")&&f!=null?{width:f,accumWidth:0,breakAll:c==="breakAll"}:null,d=xl.lastIndex=0,p;(p=xl.exec(o))!=null;){var g=p.index;g>d&&Tl(a,o.substring(d,g),t,v),Tl(a,p[2],t,v,p[1]),d=xl.lastIndex}d<o.length&&Tl(a,o.substring(d,o.length),t,v);var m=[],y=0,_=0,S=c==="truncate",w=t.lineOverflow==="truncate",b={};function T(Ht,de,pe){Ht.width=de,Ht.lineHeight=pe,y+=pe,_=Math.max(_,de)}t:for(var C=0;C<a.lines.length;C++){for(var x=a.lines[C],M=0,A=0,P=0;P<x.tokens.length;P++){var L=x.tokens[P],I=L.styleName&&t.rich[L.styleName]||{},R=L.textPadding=I.padding,E=R?R[1]+R[3]:0,V=L.font=I.font||t.font;L.contentHeight=nl(V);var B=q(I.height,L.contentHeight);if(L.innerHeight=B,R&&(B+=R[0]+R[2]),L.height=B,L.lineHeight=_i(I.lineHeight,t.lineHeight,B),L.align=I&&I.align||i,L.verticalAlign=I&&I.verticalAlign||"middle",w&&h!=null&&y+L.lineHeight>h){var k=a.lines.length;P>0?(x.tokens=x.tokens.slice(0,P),T(x,A,M),a.lines=a.lines.slice(0,C+1)):a.lines=a.lines.slice(0,C),a.isTruncated=a.isTruncated||a.lines.length<k;break t}var G=I.width,U=G==null||G==="auto";if(typeof G=="string"&&G.charAt(G.length-1)==="%")L.percentWidth=G,m.push(L),L.contentWidth=Xe(Ze(V),L.text);else{if(U){var Z=I.backgroundColor,j=Z&&Z.image;j&&(j=j1(j),rl(j)&&(L.width=Math.max(L.width,j.width*B/j.height)))}var ot=S&&f!=null?f-A:null;ot!=null&&ot<L.width?!U||ot<E?(L.text="",L.width=L.contentWidth=0):(iS(b,L.text,ot-E,V,t.ellipsis,{minChar:t.truncateMinChar}),L.text=b.text,a.isTruncated=a.isTruncated||b.isTruncated,L.width=L.contentWidth=Xe(Ze(V),L.text)):L.contentWidth=Xe(Ze(V),L.text)}L.width+=E,A+=L.width,I&&(M=Math.max(M,L.lineHeight))}T(x,A,M)}a.outerWidth=a.width=q(f,_),a.outerHeight=a.height=q(h,y),a.contentHeight=y,a.contentWidth=_,a.outerWidth+=l,a.outerHeight+=u;for(var C=0;C<m.length;C++){var L=m[C],yt=L.percentWidth;L.width=parseInt(yt,10)/100*a.width}return a}function Tl(r,t,e,n,i){var a=t==="",o=i&&e.rich[i]||{},s=r.lines,l=o.font||e.font,u=!1,f,h;if(n){var c=o.padding,v=c?c[1]+c[3]:0;if(o.width!=null&&o.width!=="auto"){var d=En(o.width,n.width)+v;s.length>0&&d+n.accumWidth>n.width&&(f=t.split(`
`),u=!0),n.accumWidth=d}else{var p=fm(t,l,n.width,n.breakAll,n.accumWidth);n.accumWidth=p.accumWidth+v,h=p.linesWidths,f=p.lines}}f||(f=t.split(`
`));for(var g=Ze(l),m=0;m<f.length;m++){var y=f[m],_=new sS;if(_.styleName=i,_.text=y,_.isLineHolder=!y&&!a,typeof o.width=="number"?_.width=o.width:_.width=h?h[m]:Xe(g,y),!m&&!u){var S=(s[s.length-1]||(s[0]=new Hv)).tokens,w=S.length;w===1&&S[0].isLineHolder?S[0]=_:(y||!w||a)&&S.push(_)}else s.push(new Hv([_]))}}function fS(r){var t=r.charCodeAt(0);return t>=32&&t<=591||t>=880&&t<=4351||t>=4608&&t<=5119||t>=7680&&t<=8303}var hS=Ei(",&?/;] ".split(""),function(r,t){return r[t]=!0,r},{});function vS(r){return fS(r)?!!hS[r]:!0}function fm(r,t,e,n,i){for(var a=[],o=[],s="",l="",u=0,f=0,h=Ze(t),c=0;c<r.length;c++){var v=r.charAt(c);if(v===`
`){l&&(s+=l,f+=u),a.push(s),o.push(f),s="",l="",u=0,f=0;continue}var d=am(h,v.charCodeAt(0)),p=n?!1:!vS(v);if(a.length?f+d>e:i+f+d>e){f?(s||l)&&(p?(s||(s=l,l="",u=0,f=u),a.push(s),o.push(f-u),l+=v,u+=d,s="",f=u):(l&&(s+=l,l="",u=0),a.push(s),o.push(f),s=v,f=d)):p?(a.push(l),o.push(u),l=v,u=d):(a.push(v),o.push(d));continue}f+=d,p?(l+=v,u+=d):(l&&(s+=l,l="",u=0),s+=v)}return l&&(s+=l),s&&(a.push(s),o.push(f)),a.length===1&&(f+=i),{accumWidth:f,lines:a,linesWidths:o}}function Vv(r,t,e,n,i,a){if(r.baseX=e,r.baseY=n,r.outerWidth=r.outerHeight=null,!!t){var o=t.width*2,s=t.height*2;it.set(Gv,Mi(e,o,i),Dn(n,s,a),o,s),it.intersect(t,Gv,null,Wv);var l=Wv.outIntersectRect;r.outerWidth=l.width,r.outerHeight=l.height,r.baseX=Mi(l.x,l.width,i,!0),r.baseY=Dn(l.y,l.height,a,!0)}}var Gv=new it(0,0,0,0),Wv={outIntersectRect:{},clamp:!0};function Ch(r){return r!=null?r+="":r=""}function cS(r){var t=Ch(r.text),e=r.font,n=Xe(Ze(e),t),i=nl(e);return rf(r,n,i,null)}function rf(r,t,e,n){var i=new it(Mi(r.x||0,t,r.textAlign),Dn(r.y||0,e,r.textBaseline),t,e),a=n??(hm(r)?r.lineWidth:0);return a>0&&(i.x-=a/2,i.y-=a/2,i.width+=a,i.height+=a),i}function hm(r){var t=r.stroke;return t!=null&&t!=="none"&&r.lineWidth>0}function Oi(r,t){return r==null&&(r=0),t==null&&(t=0),[r,t]}function dS(r){return[r[0],r[1]]}function Uv(r,t,e){return r[0]=t[0]+e[0],r[1]=t[1]+e[1],r}function pS(r,t,e){return r[0]=t[0]-e[0],r[1]=t[1]-e[1],r}function gS(r){return Math.sqrt(mS(r))}function mS(r){return r[0]*r[0]+r[1]*r[1]}function Ml(r,t,e){return r[0]=t[0]*e,r[1]=t[1]*e,r}function yS(r,t){var e=gS(t);return e===0?(r[0]=0,r[1]=0):(r[0]=t[0]/e,r[1]=t[1]/e),r}function nf(r,t){return Math.sqrt((r[0]-t[0])*(r[0]-t[0])+(r[1]-t[1])*(r[1]-t[1]))}var af=nf;function _S(r,t){return(r[0]-t[0])*(r[0]-t[0])+(r[1]-t[1])*(r[1]-t[1])}var Si=_S;function $o(r,t,e,n){return r[0]=t[0]+n*(e[0]-t[0]),r[1]=t[1]+n*(e[1]-t[1]),r}function xe(r,t,e){var n=t[0],i=t[1];return r[0]=e[0]*n+e[2]*i+e[4],r[1]=e[1]*n+e[3]*i+e[5],r}function hi(r,t,e){return r[0]=Math.min(t[0],e[0]),r[1]=Math.min(t[1],e[1]),r}function vi(r,t,e){return r[0]=Math.max(t[0],e[0]),r[1]=Math.max(t[1],e[1]),r}var Yv=Th,Zv=5e-5;function Qr(r){return r>Zv||r<-Zv}var jr=[],Gn=[],Cl=lr(),Dl=Math.abs,Qa=(function(){function r(){}return r.prototype.getLocalTransform=function(t){return r.getLocalTransform(this,t)},r.prototype.setPosition=function(t){this.x=t[0],this.y=t[1]},r.prototype.setScale=function(t){this.scaleX=t[0],this.scaleY=t[1]},r.prototype.setSkew=function(t){this.skewX=t[0],this.skewY=t[1]},r.prototype.setOrigin=function(t){this.originX=t[0],this.originY=t[1]},r.prototype.needLocalTransform=function(){return Qr(this.rotation)||Qr(this.x)||Qr(this.y)||Qr(this.scaleX-1)||Qr(this.scaleY-1)||Qr(this.skewX)||Qr(this.skewY)},r.prototype.updateTransform=function(){var t=this.parent&&this.parent.transform,e=this.needLocalTransform(),n=this.transform;if(!(e||t)){n&&(Yv(n),this.invTransform=null);return}n=n||lr(),e?this.getLocalTransform(n):Yv(n),t&&(e?_a(n,t,n):nm(n,t)),this.transform=n,this._resolveGlobalScaleRatio(n)},r.prototype._resolveGlobalScaleRatio=function(t){var e=this.globalScaleRatio;if(e!=null&&e!==1){this.getGlobalScale(jr);var n=jr[0]<0?-1:1,i=jr[1]<0?-1:1,a=((jr[0]-n)*e+n)/jr[0]||0,o=((jr[1]-i)*e+i)/jr[1]||0;t[0]*=a,t[1]*=a,t[2]*=o,t[3]*=o}this.invTransform=this.invTransform||lr(),ki(this.invTransform,t)},r.prototype.getComputedTransform=function(){for(var t=this,e=[];t;)e.push(t),t=t.parent;for(;t=e.pop();)t.updateTransform();return this.transform},r.prototype.setLocalTransform=function(t){if(t){var e=t[0]*t[0]+t[1]*t[1],n=t[2]*t[2]+t[3]*t[3],i=Math.atan2(t[1],t[0]),a=Math.PI/2+i-Math.atan2(t[3],t[2]);n=Math.sqrt(n)*Math.cos(a),e=Math.sqrt(e),this.skewX=a,this.skewY=0,this.rotation=-i,this.x=+t[4],this.y=+t[5],this.scaleX=e,this.scaleY=n,this.originX=0,this.originY=0}},r.prototype.decomposeTransform=function(){if(this.transform){var t=this.parent,e=this.transform;t&&t.transform&&(t.invTransform=t.invTransform||lr(),_a(Gn,t.invTransform,e),e=Gn);var n=this.originX,i=this.originY;(n||i)&&(Cl[4]=n,Cl[5]=i,_a(Gn,e,Cl),Gn[4]-=n,Gn[5]-=i,e=Gn),this.setLocalTransform(e)}},r.prototype.getGlobalScale=function(t){var e=this.transform;return t=t||[],e?(t[0]=Math.sqrt(e[0]*e[0]+e[1]*e[1]),t[1]=Math.sqrt(e[2]*e[2]+e[3]*e[3]),e[0]<0&&(t[0]=-t[0]),e[3]<0&&(t[1]=-t[1]),t):(t[0]=1,t[1]=1,t)},r.prototype.transformCoordToLocal=function(t,e){var n=[t,e],i=this.invTransform;return i&&xe(n,n,i),n},r.prototype.transformCoordToGlobal=function(t,e){var n=[t,e],i=this.transform;return i&&xe(n,n,i),n},r.prototype.getLineScale=function(){var t=this.transform;return t&&Dl(t[0]-1)>1e-10&&Dl(t[3]-1)>1e-10?Math.sqrt(Dl(t[0]*t[3]-t[2]*t[1])):1},r.prototype.copyTransform=function(t){of(this,t)},r.getLocalTransform=function(t,e){e=e||[];var n=t.originX||0,i=t.originY||0,a=t.scaleX,o=t.scaleY,s=t.anchorX,l=t.anchorY,u=t.rotation||0,f=t.x,h=t.y,c=t.skewX?Math.tan(t.skewX):0,v=t.skewY?Math.tan(-t.skewY):0;if(n||i||s||l){var d=n+s,p=i+l;e[4]=-d*a-c*p*o,e[5]=-p*o-v*d*a}else e[4]=e[5]=0;return e[0]=a,e[3]=o,e[1]=v*a,e[2]=c*o,u&&Mh(e,e,u),e[4]+=n+f,e[5]+=i+h,e},r.initDefaultProps=(function(){var t=r.prototype;t.scaleX=t.scaleY=t.globalScaleRatio=1,t.x=t.y=t.originX=t.originY=t.skewX=t.skewY=t.rotation=t.anchorX=t.anchorY=0})(),r})(),Ea=["x","y","originX","originY","anchorX","anchorY","rotation","scaleX","scaleY","skewX","skewY"];function of(r,t){for(var e=0;e<Ea.length;e++){var n=Ea[e];r[n]=t[n]}}var ba={linear:function(r){return r},quadraticIn:function(r){return r*r},quadraticOut:function(r){return r*(2-r)},quadraticInOut:function(r){return(r*=2)<1?.5*r*r:-.5*(--r*(r-2)-1)},cubicIn:function(r){return r*r*r},cubicOut:function(r){return--r*r*r+1},cubicInOut:function(r){return(r*=2)<1?.5*r*r*r:.5*((r-=2)*r*r+2)},quarticIn:function(r){return r*r*r*r},quarticOut:function(r){return 1- --r*r*r*r},quarticInOut:function(r){return(r*=2)<1?.5*r*r*r*r:-.5*((r-=2)*r*r*r-2)},quinticIn:function(r){return r*r*r*r*r},quinticOut:function(r){return--r*r*r*r*r+1},quinticInOut:function(r){return(r*=2)<1?.5*r*r*r*r*r:.5*((r-=2)*r*r*r*r+2)},sinusoidalIn:function(r){return 1-Math.cos(r*Math.PI/2)},sinusoidalOut:function(r){return Math.sin(r*Math.PI/2)},sinusoidalInOut:function(r){return .5*(1-Math.cos(Math.PI*r))},exponentialIn:function(r){return r===0?0:Math.pow(1024,r-1)},exponentialOut:function(r){return r===1?1:1-Math.pow(2,-10*r)},exponentialInOut:function(r){return r===0?0:r===1?1:(r*=2)<1?.5*Math.pow(1024,r-1):.5*(-Math.pow(2,-10*(r-1))+2)},circularIn:function(r){return 1-Math.sqrt(1-r*r)},circularOut:function(r){return Math.sqrt(1- --r*r)},circularInOut:function(r){return(r*=2)<1?-.5*(Math.sqrt(1-r*r)-1):.5*(Math.sqrt(1-(r-=2)*r)+1)},elasticIn:function(r){var t,e=.1,n=.4;return r===0?0:r===1?1:(!e||e<1?(e=1,t=n/4):t=n*Math.asin(1/e)/(2*Math.PI),-(e*Math.pow(2,10*(r-=1))*Math.sin((r-t)*(2*Math.PI)/n)))},elasticOut:function(r){var t,e=.1,n=.4;return r===0?0:r===1?1:(!e||e<1?(e=1,t=n/4):t=n*Math.asin(1/e)/(2*Math.PI),e*Math.pow(2,-10*r)*Math.sin((r-t)*(2*Math.PI)/n)+1)},elasticInOut:function(r){var t,e=.1,n=.4;return r===0?0:r===1?1:(!e||e<1?(e=1,t=n/4):t=n*Math.asin(1/e)/(2*Math.PI),(r*=2)<1?-.5*(e*Math.pow(2,10*(r-=1))*Math.sin((r-t)*(2*Math.PI)/n)):e*Math.pow(2,-10*(r-=1))*Math.sin((r-t)*(2*Math.PI)/n)*.5+1)},backIn:function(r){var t=1.70158;return r*r*((t+1)*r-t)},backOut:function(r){var t=1.70158;return--r*r*((t+1)*r+t)+1},backInOut:function(r){var t=2.5949095;return(r*=2)<1?.5*(r*r*((t+1)*r-t)):.5*((r-=2)*r*((t+1)*r+t)+2)},bounceIn:function(r){return 1-ba.bounceOut(1-r)},bounceOut:function(r){return r<1/2.75?7.5625*r*r:r<2/2.75?7.5625*(r-=1.5/2.75)*r+.75:r<2.5/2.75?7.5625*(r-=2.25/2.75)*r+.9375:7.5625*(r-=2.625/2.75)*r+.984375},bounceInOut:function(r){return r<.5?ba.bounceIn(r*2)*.5:ba.bounceOut(r*2-1)*.5+.5}},so=Math.pow,Rr=Math.sqrt,ds=1e-8,vm=1e-4,Xv=Rr(3),lo=1/3,Ge=Oi(),be=Oi(),bi=Oi();function Lr(r){return r>-ds&&r<ds}function cm(r){return r>ds||r<-ds}function Lt(r,t,e,n,i){var a=1-i;return a*a*(a*r+3*i*t)+i*i*(i*n+3*a*e)}function $v(r,t,e,n,i){var a=1-i;return 3*(((t-r)*a+2*(e-t)*i)*a+(n-e)*i*i)}function ps(r,t,e,n,i,a){var o=n+3*(t-e)-r,s=3*(e-t*2+r),l=3*(t-r),u=r-i,f=s*s-3*o*l,h=s*l-9*o*u,c=l*l-3*s*u,v=0;if(Lr(f)&&Lr(h))if(Lr(s))a[0]=0;else{var d=-l/s;d>=0&&d<=1&&(a[v++]=d)}else{var p=h*h-4*f*c;if(Lr(p)){var g=h/f,d=-s/o+g,m=-g/2;d>=0&&d<=1&&(a[v++]=d),m>=0&&m<=1&&(a[v++]=m)}else if(p>0){var y=Rr(p),_=f*s+1.5*o*(-h+y),S=f*s+1.5*o*(-h-y);_<0?_=-so(-_,lo):_=so(_,lo),S<0?S=-so(-S,lo):S=so(S,lo);var d=(-s-(_+S))/(3*o);d>=0&&d<=1&&(a[v++]=d)}else{var w=(2*f*s-3*o*h)/(2*Rr(f*f*f)),b=Math.acos(w)/3,T=Rr(f),C=Math.cos(b),d=(-s-2*T*C)/(3*o),m=(-s+T*(C+Xv*Math.sin(b)))/(3*o),x=(-s+T*(C-Xv*Math.sin(b)))/(3*o);d>=0&&d<=1&&(a[v++]=d),m>=0&&m<=1&&(a[v++]=m),x>=0&&x<=1&&(a[v++]=x)}}return v}function dm(r,t,e,n,i){var a=6*e-12*t+6*r,o=9*t+3*n-3*r-9*e,s=3*t-3*r,l=0;if(Lr(o)){if(cm(a)){var u=-s/a;u>=0&&u<=1&&(i[l++]=u)}}else{var f=a*a-4*o*s;if(Lr(f))i[0]=-a/(2*o);else if(f>0){var h=Rr(f),u=(-a+h)/(2*o),c=(-a-h)/(2*o);u>=0&&u<=1&&(i[l++]=u),c>=0&&c<=1&&(i[l++]=c)}}return l}function Nr(r,t,e,n,i,a){var o=(t-r)*i+r,s=(e-t)*i+t,l=(n-e)*i+e,u=(s-o)*i+o,f=(l-s)*i+s,h=(f-u)*i+u;a[0]=r,a[1]=o,a[2]=u,a[3]=h,a[4]=h,a[5]=f,a[6]=l,a[7]=n}function pm(r,t,e,n,i,a,o,s,l,u,f){var h,c=.005,v=1/0,d,p,g,m;Ge[0]=l,Ge[1]=u;for(var y=0;y<1;y+=.05)be[0]=Lt(r,e,i,o,y),be[1]=Lt(t,n,a,s,y),g=Si(Ge,be),g<v&&(h=y,v=g);v=1/0;for(var _=0;_<32&&!(c<vm);_++)d=h-c,p=h+c,be[0]=Lt(r,e,i,o,d),be[1]=Lt(t,n,a,s,d),g=Si(be,Ge),d>=0&&g<v?(h=d,v=g):(bi[0]=Lt(r,e,i,o,p),bi[1]=Lt(t,n,a,s,p),m=Si(bi,Ge),p<=1&&m<v?(h=p,v=m):c*=.5);return f&&(f[0]=Lt(r,e,i,o,h),f[1]=Lt(t,n,a,s,h)),Rr(v)}function SS(r,t,e,n,i,a,o,s,l){for(var u=r,f=t,h=0,c=1/l,v=1;v<=l;v++){var d=v*c,p=Lt(r,e,i,o,d),g=Lt(t,n,a,s,d),m=p-u,y=g-f;h+=Math.sqrt(m*m+y*y),u=p,f=g}return h}function Ut(r,t,e,n){var i=1-n;return i*(i*r+2*n*t)+n*n*e}function qv(r,t,e,n){return 2*((1-n)*(t-r)+n*(e-t))}function bS(r,t,e,n,i){var a=r-2*t+e,o=2*(t-r),s=r-n,l=0;if(Lr(a)){if(cm(o)){var u=-s/o;u>=0&&u<=1&&(i[l++]=u)}}else{var f=o*o-4*a*s;if(Lr(f)){var u=-o/(2*a);u>=0&&u<=1&&(i[l++]=u)}else if(f>0){var h=Rr(f),u=(-o+h)/(2*a),c=(-o-h)/(2*a);u>=0&&u<=1&&(i[l++]=u),c>=0&&c<=1&&(i[l++]=c)}}return l}function gm(r,t,e){var n=r+e-2*t;return n===0?.5:(r-t)/n}function gs(r,t,e,n,i){var a=(t-r)*n+r,o=(e-t)*n+t,s=(o-a)*n+a;i[0]=r,i[1]=a,i[2]=s,i[3]=s,i[4]=o,i[5]=e}function mm(r,t,e,n,i,a,o,s,l){var u,f=.005,h=1/0;Ge[0]=o,Ge[1]=s;for(var c=0;c<1;c+=.05){be[0]=Ut(r,e,i,c),be[1]=Ut(t,n,a,c);var v=Si(Ge,be);v<h&&(u=c,h=v)}h=1/0;for(var d=0;d<32&&!(f<vm);d++){var p=u-f,g=u+f;be[0]=Ut(r,e,i,p),be[1]=Ut(t,n,a,p);var v=Si(be,Ge);if(p>=0&&v<h)u=p,h=v;else{bi[0]=Ut(r,e,i,g),bi[1]=Ut(t,n,a,g);var m=Si(bi,Ge);g<=1&&m<h?(u=g,h=m):f*=.5}}return l&&(l[0]=Ut(r,e,i,u),l[1]=Ut(t,n,a,u)),Rr(h)}function wS(r,t,e,n,i,a,o){for(var s=r,l=t,u=0,f=1/o,h=1;h<=o;h++){var c=h*f,v=Ut(r,e,i,c),d=Ut(t,n,a,c),p=v-s,g=d-l;u+=Math.sqrt(p*p+g*g),s=v,l=d}return u}var xS=/cubic-bezier\(([0-9,\.e ]+)\)/;function ym(r){var t=r&&xS.exec(r);if(t){var e=t[1].split(","),n=+We(e[0]),i=+We(e[1]),a=+We(e[2]),o=+We(e[3]);if(isNaN(n+i+a+o))return;var s=[];return function(l){return l<=0?0:l>=1?1:ps(0,n,a,1,l,s)&&Lt(0,i,o,1,s[0])}}}var TS=(function(){function r(t){this._inited=!1,this._startTime=0,this._pausedTime=0,this._paused=!1,this._life=t.life||1e3,this._delay=t.delay||0,this.loop=t.loop||!1,this.onframe=t.onframe||Kt,this.ondestroy=t.ondestroy||Kt,this.onrestart=t.onrestart||Kt,t.easing&&this.setEasing(t.easing)}return r.prototype.step=function(t,e){if(this._inited||(this._startTime=t+this._delay,this._inited=!0),this._paused){this._pausedTime+=e;return}var n=this._life,i=t-this._startTime-this._pausedTime,a=i/n;a<0&&(a=0),a=Math.min(a,1);var o=this.easingFunc,s=o?o(a):a;if(this.onframe(s),a===1)if(this.loop){var l=i%n;this._startTime=t-l,this._pausedTime=0,this.onrestart()}else return!0;return!1},r.prototype.pause=function(){this._paused=!0},r.prototype.resume=function(){this._paused=!1},r.prototype.setEasing=function(t){this.easing=t,this.easingFunc=et(t)?t:ba[t]||ym(t)},r})(),Kv={transparent:[0,0,0,0],aliceblue:[240,248,255,1],antiquewhite:[250,235,215,1],aqua:[0,255,255,1],aquamarine:[127,255,212,1],azure:[240,255,255,1],beige:[245,245,220,1],bisque:[255,228,196,1],black:[0,0,0,1],blanchedalmond:[255,235,205,1],blue:[0,0,255,1],blueviolet:[138,43,226,1],brown:[165,42,42,1],burlywood:[222,184,135,1],cadetblue:[95,158,160,1],chartreuse:[127,255,0,1],chocolate:[210,105,30,1],coral:[255,127,80,1],cornflowerblue:[100,149,237,1],cornsilk:[255,248,220,1],crimson:[220,20,60,1],cyan:[0,255,255,1],darkblue:[0,0,139,1],darkcyan:[0,139,139,1],darkgoldenrod:[184,134,11,1],darkgray:[169,169,169,1],darkgreen:[0,100,0,1],darkgrey:[169,169,169,1],darkkhaki:[189,183,107,1],darkmagenta:[139,0,139,1],darkolivegreen:[85,107,47,1],darkorange:[255,140,0,1],darkorchid:[153,50,204,1],darkred:[139,0,0,1],darksalmon:[233,150,122,1],darkseagreen:[143,188,143,1],darkslateblue:[72,61,139,1],darkslategray:[47,79,79,1],darkslategrey:[47,79,79,1],darkturquoise:[0,206,209,1],darkviolet:[148,0,211,1],deeppink:[255,20,147,1],deepskyblue:[0,191,255,1],dimgray:[105,105,105,1],dimgrey:[105,105,105,1],dodgerblue:[30,144,255,1],firebrick:[178,34,34,1],floralwhite:[255,250,240,1],forestgreen:[34,139,34,1],fuchsia:[255,0,255,1],gainsboro:[220,220,220,1],ghostwhite:[248,248,255,1],gold:[255,215,0,1],goldenrod:[218,165,32,1],gray:[128,128,128,1],green:[0,128,0,1],greenyellow:[173,255,47,1],grey:[128,128,128,1],honeydew:[240,255,240,1],hotpink:[255,105,180,1],indianred:[205,92,92,1],indigo:[75,0,130,1],ivory:[255,255,240,1],khaki:[240,230,140,1],lavender:[230,230,250,1],lavenderblush:[255,240,245,1],lawngreen:[124,252,0,1],lemonchiffon:[255,250,205,1],lightblue:[173,216,230,1],lightcoral:[240,128,128,1],lightcyan:[224,255,255,1],lightgoldenrodyellow:[250,250,210,1],lightgray:[211,211,211,1],lightgreen:[144,238,144,1],lightgrey:[211,211,211,1],lightpink:[255,182,193,1],lightsalmon:[255,160,122,1],lightseagreen:[32,178,170,1],lightskyblue:[135,206,250,1],lightslategray:[119,136,153,1],lightslategrey:[119,136,153,1],lightsteelblue:[176,196,222,1],lightyellow:[255,255,224,1],lime:[0,255,0,1],limegreen:[50,205,50,1],linen:[250,240,230,1],magenta:[255,0,255,1],maroon:[128,0,0,1],mediumaquamarine:[102,205,170,1],mediumblue:[0,0,205,1],mediumorchid:[186,85,211,1],mediumpurple:[147,112,219,1],mediumseagreen:[60,179,113,1],mediumslateblue:[123,104,238,1],mediumspringgreen:[0,250,154,1],mediumturquoise:[72,209,204,1],mediumvioletred:[199,21,133,1],midnightblue:[25,25,112,1],mintcream:[245,255,250,1],mistyrose:[255,228,225,1],moccasin:[255,228,181,1],navajowhite:[255,222,173,1],navy:[0,0,128,1],oldlace:[253,245,230,1],olive:[128,128,0,1],olivedrab:[107,142,35,1],orange:[255,165,0,1],orangered:[255,69,0,1],orchid:[218,112,214,1],palegoldenrod:[238,232,170,1],palegreen:[152,251,152,1],paleturquoise:[175,238,238,1],palevioletred:[219,112,147,1],papayawhip:[255,239,213,1],peachpuff:[255,218,185,1],peru:[205,133,63,1],pink:[255,192,203,1],plum:[221,160,221,1],powderblue:[176,224,230,1],purple:[128,0,128,1],red:[255,0,0,1],rosybrown:[188,143,143,1],royalblue:[65,105,225,1],saddlebrown:[139,69,19,1],salmon:[250,128,114,1],sandybrown:[244,164,96,1],seagreen:[46,139,87,1],seashell:[255,245,238,1],sienna:[160,82,45,1],silver:[192,192,192,1],skyblue:[135,206,235,1],slateblue:[106,90,205,1],slategray:[112,128,144,1],slategrey:[112,128,144,1],snow:[255,250,250,1],springgreen:[0,255,127,1],steelblue:[70,130,180,1],tan:[210,180,140,1],teal:[0,128,128,1],thistle:[216,191,216,1],tomato:[255,99,71,1],turquoise:[64,224,208,1],violet:[238,130,238,1],wheat:[245,222,179,1],white:[255,255,255,1],whitesmoke:[245,245,245,1],yellow:[255,255,0,1],yellowgreen:[154,205,50,1]};function Er(r){return r=Math.round(r),r<0?0:r>255?255:r}function sf(r){return r<0?0:r>1?1:r}function Al(r){var t=r;return t.length&&t.charAt(t.length-1)==="%"?Er(parseFloat(t)/100*255):Er(parseInt(t,10))}function An(r){var t=r;return t.length&&t.charAt(t.length-1)==="%"?sf(parseFloat(t)/100):sf(parseFloat(t))}function Ll(r,t,e){return e<0?e+=1:e>1&&(e-=1),e*6<1?r+(t-r)*e*6:e*2<1?t:e*3<2?r+(t-r)*(2/3-e)*6:r}function uo(r,t,e){return r+(t-r)*e}function me(r,t,e,n,i){return r[0]=t,r[1]=e,r[2]=n,r[3]=i,r}function lf(r,t){return r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=t[3],r}var _m=new Ti(20),fo=null;function Wn(r,t){fo&&lf(fo,t),fo=_m.put(r,fo||t.slice())}function ur(r,t){if(r){t=t||[];var e=_m.get(r);if(e)return lf(t,e);r=r+"";var n=r.replace(/ /g,"").toLowerCase();if(n in Kv)return lf(t,Kv[n]),Wn(r,t),t;var i=n.length;if(n.charAt(0)==="#"){if(i===4||i===5){var a=parseInt(n.slice(1,4),16);if(!(a>=0&&a<=4095)){me(t,0,0,0,1);return}return me(t,(a&3840)>>4|(a&3840)>>8,a&240|(a&240)>>4,a&15|(a&15)<<4,i===5?parseInt(n.slice(4),16)/15:1),Wn(r,t),t}else if(i===7||i===9){var a=parseInt(n.slice(1,7),16);if(!(a>=0&&a<=16777215)){me(t,0,0,0,1);return}return me(t,(a&16711680)>>16,(a&65280)>>8,a&255,i===9?parseInt(n.slice(7),16)/255:1),Wn(r,t),t}return}var o=n.indexOf("("),s=n.indexOf(")");if(o!==-1&&s+1===i){var l=n.substr(0,o),u=n.substr(o+1,s-(o+1)).split(","),f=1;switch(l){case"rgba":if(u.length!==4)return u.length===3?me(t,+u[0],+u[1],+u[2],1):me(t,0,0,0,1);f=An(u.pop());case"rgb":if(u.length>=3)return me(t,Al(u[0]),Al(u[1]),Al(u[2]),u.length===3?f:An(u[3])),Wn(r,t),t;me(t,0,0,0,1);return;case"hsla":if(u.length!==4){me(t,0,0,0,1);return}return u[3]=An(u[3]),uf(u,t),Wn(r,t),t;case"hsl":if(u.length!==3){me(t,0,0,0,1);return}return uf(u,t),Wn(r,t),t;default:return}}me(t,0,0,0,1)}}function uf(r,t){var e=(parseFloat(r[0])%360+360)%360/360,n=An(r[1]),i=An(r[2]),a=i<=.5?i*(n+1):i+n-i*n,o=i*2-a;return t=t||[],me(t,Er(Ll(o,a,e+1/3)*255),Er(Ll(o,a,e)*255),Er(Ll(o,a,e-1/3)*255),1),r.length===4&&(t[3]=r[3]),t}function MS(r){if(r){var t=r[0]/255,e=r[1]/255,n=r[2]/255,i=Math.min(t,e,n),a=Math.max(t,e,n),o=a-i,s=(a+i)/2,l,u;if(o===0)l=0,u=0;else{s<.5?u=o/(a+i):u=o/(2-a-i);var f=((a-t)/6+o/2)/o,h=((a-e)/6+o/2)/o,c=((a-n)/6+o/2)/o;t===a?l=c-h:e===a?l=1/3+f-c:n===a&&(l=2/3+h-f),l<0&&(l+=1),l>1&&(l-=1)}var v=[l*360,u,s];return r[3]!=null&&v.push(r[3]),v}}function Qv(r,t){var e=ur(r);if(e){for(var n=0;n<3;n++)e[n]=e[n]*(1-t)|0,e[n]>255?e[n]=255:e[n]<0&&(e[n]=0);return il(e,e.length===4?"rgba":"rgb")}}function CS(r,t,e){if(!(!(t&&t.length)||!(r>=0&&r<=1))){var n=r*(t.length-1),i=Math.floor(n),a=Math.ceil(n),o=ur(t[i]),s=ur(t[a]),l=n-i,u=il([Er(uo(o[0],s[0],l)),Er(uo(o[1],s[1],l)),Er(uo(o[2],s[2],l)),sf(uo(o[3],s[3],l))],"rgba");return e?{color:u,leftIndex:i,rightIndex:a,value:n}:u}}function ff(r,t,e,n){var i=ur(r);if(r)return i=MS(i),e!=null&&(i[1]=An(et(e)?e(i[1]):e)),n!=null&&(i[2]=An(et(n)?n(i[2]):n)),il(uf(i),"rgba")}function il(r,t){if(!(!r||!r.length)){var e=r[0]+","+r[1]+","+r[2];return(t==="rgba"||t==="hsva"||t==="hsla")&&(e+=","+r[3]),t+"("+e+")"}}function ms(r,t){var e=ur(r);return e?(.299*e[0]+.587*e[1]+.114*e[2])*e[3]/255+(1-e[3])*t:0}var jv=new Ti(100);function Jv(r){if(W(r)){var t=jv.get(r);return t||(t=Qv(r,-.1),jv.put(r,t)),t}else if(Js(r)){var e=O({},r);return e.colorStops=$(r.colorStops,function(n){return{offset:n.offset,color:Qv(n.color,-.1)}}),e}return r}function DS(r){return r.type==="linear"}function AS(r){return r.type==="radial"}(function(){return nt.hasGlobalWindow&&et(window.btoa)?function(r){return window.btoa(unescape(encodeURIComponent(r)))}:typeof Buffer<"u"?function(r){return Buffer.from(r).toString("base64")}:function(r){return null}})();var hf=Array.prototype.slice;function nr(r,t,e){return(t-r)*e+r}function Il(r,t,e,n){for(var i=t.length,a=0;a<i;a++)r[a]=nr(t[a],e[a],n);return r}function LS(r,t,e,n){for(var i=t.length,a=i&&t[0].length,o=0;o<i;o++){r[o]||(r[o]=[]);for(var s=0;s<a;s++)r[o][s]=nr(t[o][s],e[o][s],n)}return r}function ho(r,t,e,n){for(var i=t.length,a=0;a<i;a++)r[a]=t[a]+e[a]*n;return r}function tc(r,t,e,n){for(var i=t.length,a=i&&t[0].length,o=0;o<i;o++){r[o]||(r[o]=[]);for(var s=0;s<a;s++)r[o][s]=t[o][s]+e[o][s]*n}return r}function IS(r,t){for(var e=r.length,n=t.length,i=e>n?t:r,a=Math.min(e,n),o=i[a-1]||{color:[0,0,0,0],offset:0},s=a;s<Math.max(e,n);s++)i.push({offset:o.offset,color:o.color.slice()})}function PS(r,t,e){var n=r,i=t;if(!(!n.push||!i.push)){var a=n.length,o=i.length;if(a!==o){var s=a>o;if(s)n.length=o;else for(var l=a;l<o;l++)n.push(e===1?i[l]:hf.call(i[l]))}for(var u=n[0]&&n[0].length,l=0;l<n.length;l++)if(e===1)isNaN(n[l])&&(n[l]=i[l]);else for(var f=0;f<u;f++)isNaN(n[l][f])&&(n[l][f]=i[l][f])}}function qo(r){if(Qt(r)){var t=r.length;if(Qt(r[0])){for(var e=[],n=0;n<t;n++)e.push(hf.call(r[n]));return e}return hf.call(r)}return r}function Ko(r){return r[0]=Math.floor(r[0])||0,r[1]=Math.floor(r[1])||0,r[2]=Math.floor(r[2])||0,r[3]=r[3]==null?1:r[3],"rgba("+r.join(",")+")"}function RS(r){return Qt(r&&r[0])?2:1}var vo=0,Qo=1,Sm=2,fa=3,vf=4,cf=5,ec=6;function rc(r){return r===vf||r===cf}function co(r){return r===Qo||r===Sm}var zi=[0,0,0,0],ES=(function(){function r(t){this.keyframes=[],this.discrete=!1,this._invalid=!1,this._needsSort=!1,this._lastFr=0,this._lastFrP=0,this.propName=t}return r.prototype.isFinished=function(){return this._finished},r.prototype.setFinished=function(){this._finished=!0,this._additiveTrack&&this._additiveTrack.setFinished()},r.prototype.needsAnimate=function(){return this.keyframes.length>=1},r.prototype.getAdditiveTrack=function(){return this._additiveTrack},r.prototype.addKeyframe=function(t,e,n){this._needsSort=!0;var i=this.keyframes,a=i.length,o=!1,s=ec,l=e;if(Qt(e)){var u=RS(e);s=u,(u===1&&!mt(e[0])||u===2&&!mt(e[0][0]))&&(o=!0)}else if(mt(e)&&!Pa(e))s=vo;else if(W(e))if(!isNaN(+e))s=vo;else{var f=ur(e);f&&(l=f,s=fa)}else if(Js(e)){var h=O({},l);h.colorStops=$(e.colorStops,function(v){return{offset:v.offset,color:ur(v.color)}}),DS(e)?s=vf:AS(e)&&(s=cf),l=h}a===0?this.valType=s:(s!==this.valType||s===ec)&&(o=!0),this.discrete=this.discrete||o;var c={time:t,value:l,rawValue:e,percent:0};return n&&(c.easing=n,c.easingFunc=et(n)?n:ba[n]||ym(n)),i.push(c),c},r.prototype.prepare=function(t,e){var n=this.keyframes;this._needsSort&&n.sort(function(p,g){return p.time-g.time});for(var i=this.valType,a=n.length,o=n[a-1],s=this.discrete,l=co(i),u=rc(i),f=0;f<a;f++){var h=n[f],c=h.value,v=o.value;h.percent=h.time/t,s||(l&&f!==a-1?PS(c,v,i):u&&IS(c.colorStops,v.colorStops))}if(!s&&i!==cf&&e&&this.needsAnimate()&&e.needsAnimate()&&i===e.valType&&!e._finished){this._additiveTrack=e;for(var d=n[0].value,f=0;f<a;f++)i===vo?n[f].additiveValue=n[f].value-d:i===fa?n[f].additiveValue=ho([],n[f].value,d,-1):co(i)&&(n[f].additiveValue=i===Qo?ho([],n[f].value,d,-1):tc([],n[f].value,d,-1))}},r.prototype.step=function(t,e){if(!this._finished){this._additiveTrack&&this._additiveTrack._finished&&(this._additiveTrack=null);var n=this._additiveTrack!=null,i=n?"additiveValue":"value",a=this.valType,o=this.keyframes,s=o.length,l=this.propName,u=a===fa,f,h=this._lastFr,c=Math.min,v,d;if(s===1)v=d=o[0];else{if(e<0)f=0;else if(e<this._lastFrP){var p=c(h+1,s-1);for(f=p;f>=0&&!(o[f].percent<=e);f--);f=c(f,s-2)}else{for(f=h;f<s&&!(o[f].percent>e);f++);f=c(f-1,s-2)}d=o[f+1],v=o[f]}if(v&&d){this._lastFr=f,this._lastFrP=e;var g=d.percent-v.percent,m=g===0?1:c((e-v.percent)/g,1);d.easingFunc&&(m=d.easingFunc(m));var y=n?this._additiveValue:u?zi:t[l];if((co(a)||u)&&!y&&(y=this._additiveValue=[]),this.discrete)t[l]=m<1?v.rawValue:d.rawValue;else if(co(a))a===Qo?Il(y,v[i],d[i],m):LS(y,v[i],d[i],m);else if(rc(a)){var _=v[i],S=d[i],w=a===vf;t[l]={type:w?"linear":"radial",x:nr(_.x,S.x,m),y:nr(_.y,S.y,m),colorStops:$(_.colorStops,function(T,C){var x=S.colorStops[C];return{offset:nr(T.offset,x.offset,m),color:Ko(Il([],T.color,x.color,m))}}),global:S.global},w?(t[l].x2=nr(_.x2,S.x2,m),t[l].y2=nr(_.y2,S.y2,m)):t[l].r=nr(_.r,S.r,m)}else if(u)Il(y,v[i],d[i],m),n||(t[l]=Ko(y));else{var b=nr(v[i],d[i],m);n?this._additiveValue=b:t[l]=b}n&&this._addToTarget(t)}}},r.prototype._addToTarget=function(t){var e=this.valType,n=this.propName,i=this._additiveValue;e===vo?t[n]=t[n]+i:e===fa?(ur(t[n],zi),ho(zi,zi,i,1),t[n]=Ko(zi)):e===Qo?ho(t[n],t[n],i,1):e===Sm&&tc(t[n],t[n],i,1)},r})(),Dh=(function(){function r(t,e,n,i){if(this._tracks={},this._trackKeys=[],this._maxTime=0,this._started=0,this._clip=null,this._target=t,this._loop=e,e&&i){Sh("Can' use additive animation on looped animation.");return}this._additiveAnimators=i,this._allowDiscrete=n}return r.prototype.getMaxTime=function(){return this._maxTime},r.prototype.getDelay=function(){return this._delay},r.prototype.getLoop=function(){return this._loop},r.prototype.getTarget=function(){return this._target},r.prototype.changeTarget=function(t){this._target=t},r.prototype.when=function(t,e,n){return this.whenWithKeys(t,e,St(e),n)},r.prototype.whenWithKeys=function(t,e,n,i){for(var a=this._tracks,o=0;o<n.length;o++){var s=n[o],l=a[s];if(!l){l=a[s]=new ES(s);var u=void 0,f=this._getAdditiveTrack(s);if(f){var h=f.keyframes,c=h[h.length-1];u=c&&c.value,f.valType===fa&&u&&(u=Ko(u))}else u=this._target[s];if(u==null)continue;t>0&&l.addKeyframe(0,qo(u),i),this._trackKeys.push(s)}l.addKeyframe(t,qo(e[s]),i)}return this._maxTime=Math.max(this._maxTime,t),this},r.prototype.pause=function(){this._clip.pause(),this._paused=!0},r.prototype.resume=function(){this._clip.resume(),this._paused=!1},r.prototype.isPaused=function(){return!!this._paused},r.prototype.duration=function(t){return this._maxTime=t,this._force=!0,this},r.prototype._doneCallback=function(){this._setTracksFinished(),this._clip=null;var t=this._doneCbs;if(t)for(var e=t.length,n=0;n<e;n++)t[n].call(this)},r.prototype._abortedCallback=function(){this._setTracksFinished();var t=this.animation,e=this._abortedCbs;if(t&&t.removeClip(this._clip),this._clip=null,e)for(var n=0;n<e.length;n++)e[n].call(this)},r.prototype._setTracksFinished=function(){for(var t=this._tracks,e=this._trackKeys,n=0;n<e.length;n++)t[e[n]].setFinished()},r.prototype._getAdditiveTrack=function(t){var e,n=this._additiveAnimators;if(n)for(var i=0;i<n.length;i++){var a=n[i].getTrack(t);a&&(e=a)}return e},r.prototype.start=function(t){if(!(this._started>0)){this._started=1;for(var e=this,n=[],i=this._maxTime||0,a=0;a<this._trackKeys.length;a++){var o=this._trackKeys[a],s=this._tracks[o],l=this._getAdditiveTrack(o),u=s.keyframes,f=u.length;if(s.prepare(i,l),s.needsAnimate())if(!this._allowDiscrete&&s.discrete){var h=u[f-1];h&&(e._target[s.propName]=h.rawValue),s.setFinished()}else n.push(s)}if(n.length||this._force){var c=new TS({life:i,loop:this._loop,delay:this._delay||0,onframe:function(v){e._started=2;var d=e._additiveAnimators;if(d){for(var p=!1,g=0;g<d.length;g++)if(d[g]._clip){p=!0;break}p||(e._additiveAnimators=null)}for(var g=0;g<n.length;g++)n[g].step(e._target,v);var m=e._onframeCbs;if(m)for(var g=0;g<m.length;g++)m[g](e._target,v)},ondestroy:function(){e._doneCallback()}});this._clip=c,this.animation&&this.animation.addClip(c),t&&c.setEasing(t)}else this._doneCallback();return this}},r.prototype.stop=function(t){if(this._clip){var e=this._clip;t&&e.onframe(1),this._abortedCallback()}},r.prototype.delay=function(t){return this._delay=t,this},r.prototype.during=function(t){return t&&(this._onframeCbs||(this._onframeCbs=[]),this._onframeCbs.push(t)),this},r.prototype.done=function(t){return t&&(this._doneCbs||(this._doneCbs=[]),this._doneCbs.push(t)),this},r.prototype.aborted=function(t){return t&&(this._abortedCbs||(this._abortedCbs=[]),this._abortedCbs.push(t)),this},r.prototype.getClip=function(){return this._clip},r.prototype.getTrack=function(t){return this._tracks[t]},r.prototype.getTracks=function(){var t=this;return $(this._trackKeys,function(e){return t._tracks[e]})},r.prototype.stopTracks=function(t,e){if(!t.length||!this._clip)return!0;for(var n=this._tracks,i=this._trackKeys,a=0;a<t.length;a++){var o=n[t[a]];o&&!o.isFinished()&&(e?o.step(this._target,1):this._started===1&&o.step(this._target,0),o.setFinished())}for(var s=!0,a=0;a<i.length;a++)if(!n[i[a]].isFinished()){s=!1;break}return s&&this._abortedCallback(),s},r.prototype.saveTo=function(t,e,n){if(t){e=e||this._trackKeys;for(var i=0;i<e.length;i++){var a=e[i],o=this._tracks[a];if(!(!o||o.isFinished())){var s=o.keyframes,l=s[n?0:s.length-1];l&&(t[a]=qo(l.rawValue))}}}},r.prototype.__changeFinalValue=function(t,e){e=e||St(t);for(var n=0;n<e.length;n++){var i=e[n],a=this._tracks[i];if(a){var o=a.keyframes;if(o.length>1){var s=o.pop();a.addKeyframe(s.time,t[i]),a.prepare(this._maxTime,a.getAdditiveTrack())}}}},r})(),ke=(function(){function r(t){t&&(this._$eventProcessor=t)}return r.prototype.on=function(t,e,n,i){this._$handlers||(this._$handlers={});var a=this._$handlers;if(typeof e=="function"&&(i=n,n=e,e=null),!n||!t)return this;var o=this._$eventProcessor;e!=null&&o&&o.normalizeQuery&&(e=o.normalizeQuery(e)),a[t]||(a[t]=[]);for(var s=0;s<a[t].length;s++)if(a[t][s].h===n)return this;var l={h:n,query:e,ctx:i||this,callAtLast:n.zrEventfulCallAtLast},u=a[t].length-1,f=a[t][u];return f&&f.callAtLast?a[t].splice(u,0,l):a[t].push(l),this},r.prototype.isSilent=function(t){var e=this._$handlers;return!e||!e[t]||!e[t].length},r.prototype.off=function(t,e){var n=this._$handlers;if(!n)return this;if(!t)return this._$handlers={},this;if(e){if(n[t]){for(var i=[],a=0,o=n[t].length;a<o;a++)n[t][a].h!==e&&i.push(n[t][a]);n[t]=i}n[t]&&n[t].length===0&&delete n[t]}else delete n[t];return this},r.prototype.trigger=function(t){for(var e=[],n=1;n<arguments.length;n++)e[n-1]=arguments[n];if(!this._$handlers)return this;var i=this._$handlers[t],a=this._$eventProcessor;if(i)for(var o=e.length,s=i.length,l=0;l<s;l++){var u=i[l];if(!(a&&a.filter&&u.query!=null&&!a.filter(t,u.query)))switch(o){case 0:u.h.call(u.ctx);break;case 1:u.h.call(u.ctx,e[0]);break;case 2:u.h.call(u.ctx,e[0],e[1]);break;default:u.h.apply(u.ctx,e);break}}return a&&a.afterTrigger&&a.afterTrigger(t),this},r.prototype.triggerWithContext=function(t){for(var e=[],n=1;n<arguments.length;n++)e[n-1]=arguments[n];if(!this._$handlers)return this;var i=this._$handlers[t],a=this._$eventProcessor;if(i)for(var o=e.length,s=e[o-1],l=i.length,u=0;u<l;u++){var f=i[u];if(!(a&&a.filter&&f.query!=null&&!a.filter(t,f.query)))switch(o){case 0:f.h.call(s);break;case 1:f.h.call(s,e[0]);break;case 2:f.h.call(s,e[0],e[1]);break;default:f.h.apply(s,e.slice(1,o-1));break}}return a&&a.afterTrigger&&a.afterTrigger(t),this},r})(),bm=1;nt.hasGlobalWindow&&(bm=Math.max(window.devicePixelRatio||window.screen&&window.screen.deviceXDPI/window.screen.logicalXDPI||1,1));var ys=bm,df=.4,pf="#333",gf="#ccc",kS="#eee",fe=1,ha=2,li=4,Pl="__zr_normal__",Rl=Ea.concat(["ignore"]),OS=Ei(Ea,function(r,t){return r[t]=!0,r},{ignore:!1}),Un={},BS=new it(0,0,0,0),po=[],al=(function(){function r(t){this.id=qg(),this.animators=[],this.currentStates=[],this.states={},this._init(t)}return r.prototype._init=function(t){this.attr(t)},r.prototype.drift=function(t,e,n){switch(this.draggable){case"horizontal":e=0;break;case"vertical":t=0;break}var i=this.transform;i||(i=this.transform=[1,0,0,1,0,0]),i[4]+=t,i[5]+=e,this.decomposeTransform(),this.markRedraw()},r.prototype.beforeUpdate=function(){},r.prototype.afterUpdate=function(){},r.prototype.update=function(){this.updateTransform(),this.__dirty&&this.updateInnerText()},r.prototype.updateInnerText=function(t){var e=this._textContent;if(e&&(!e.ignore||t)){this.textConfig||(this.textConfig={});var n=this.textConfig,i=n.local,a=e.innerTransformable,o=void 0,s=void 0,l=!1;a.parent=i?this:null;var u=!1;a.copyTransform(e);var f=n.position!=null,h=n.autoOverflowArea,c=void 0;if((h||f)&&(c=BS,n.layoutRect?c.copy(n.layoutRect):c.copy(this.getBoundingRect()),i||c.applyTransform(this.transform)),f){this.calculateTextPosition?this.calculateTextPosition(Un,n,c):sm(Un,n,c),a.x=Un.x,a.y=Un.y,o=Un.align,s=Un.verticalAlign;var v=n.origin;if(v&&n.rotation!=null){var d=void 0,p=void 0;v==="center"?(d=c.width*.5,p=c.height*.5):(d=En(v[0],c.width),p=En(v[1],c.height)),u=!0,a.originX=-a.x+d+(i?0:c.x),a.originY=-a.y+p+(i?0:c.y)}}n.rotation!=null&&(a.rotation=n.rotation);var g=n.offset;g&&(a.x+=g[0],a.y+=g[1],u||(a.originX=-g[0],a.originY=-g[1]));var m=this._innerTextDefaultStyle||(this._innerTextDefaultStyle={});if(h){var y=m.overflowRect=m.overflowRect||new it(0,0,0,0);a.getLocalTransform(po),ki(po,po),it.copy(y,c),y.applyTransform(po)}else m.overflowRect=null;var _=n.inside==null?typeof n.position=="string"&&n.position.indexOf("inside")>=0:n.inside,S=void 0,w=void 0,b=void 0;_&&this.canBeInsideText()?(S=n.insideFill,w=n.insideStroke,(S==null||S==="auto")&&(S=this.getInsideTextFill()),(w==null||w==="auto")&&(w=this.getInsideTextStroke(S),b=!0)):(S=n.outsideFill,w=n.outsideStroke,(S==null||S==="auto")&&(S=this.getOutsideFill()),(w==null||w==="auto")&&(w=this.getOutsideStroke(S),b=!0)),S=S||"#000",(S!==m.fill||w!==m.stroke||b!==m.autoStroke||o!==m.align||s!==m.verticalAlign)&&(l=!0,m.fill=S,m.stroke=w,m.autoStroke=b,m.align=o,m.verticalAlign=s,e.setDefaultTextStyle(m)),e.__dirty|=fe,l&&e.dirtyStyle(!0)}},r.prototype.canBeInsideText=function(){return!0},r.prototype.getInsideTextFill=function(){return"#fff"},r.prototype.getInsideTextStroke=function(t){return"#000"},r.prototype.getOutsideFill=function(){return this.__zr&&this.__zr.isDarkMode()?gf:pf},r.prototype.getOutsideStroke=function(t){var e=this.__zr&&this.__zr.getBackgroundColor(),n=typeof e=="string"&&ur(e);n||(n=[255,255,255,1]);for(var i=n[3],a=this.__zr.isDarkMode(),o=0;o<3;o++)n[o]=n[o]*i+(a?0:255)*(1-i);return n[3]=1,il(n,"rgba")},r.prototype.traverse=function(t,e){},r.prototype.attrKV=function(t,e){t==="textConfig"?this.setTextConfig(e):t==="textContent"?this.setTextContent(e):t==="clipPath"?this.setClipPath(e):t==="extra"?(this.extra=this.extra||{},O(this.extra,e)):this[t]=e},r.prototype.hide=function(){this.ignore=!0,this.markRedraw()},r.prototype.show=function(){this.ignore=!1,this.markRedraw()},r.prototype.attr=function(t,e){if(typeof t=="string")this.attrKV(t,e);else if(X(t))for(var n=t,i=St(n),a=0;a<i.length;a++){var o=i[a];this.attrKV(o,t[o])}return this.markRedraw(),this},r.prototype.saveCurrentToNormalState=function(t){this._innerSaveToNormal(t);for(var e=this._normalState,n=0;n<this.animators.length;n++){var i=this.animators[n],a=i.__fromStateTransition;if(!(i.getLoop()||a&&a!==Pl)){var o=i.targetName,s=o?e[o]:e;i.saveTo(s)}}},r.prototype._innerSaveToNormal=function(t){var e=this._normalState;e||(e=this._normalState={}),t.textConfig&&!e.textConfig&&(e.textConfig=this.textConfig),this._savePrimaryToNormal(t,e,Rl)},r.prototype._savePrimaryToNormal=function(t,e,n){for(var i=0;i<n.length;i++){var a=n[i];t[a]!=null&&!(a in e)&&(e[a]=this[a])}},r.prototype.hasState=function(){return this.currentStates.length>0},r.prototype.getState=function(t){return this.states[t]},r.prototype.ensureState=function(t){var e=this.states;return e[t]||(e[t]={}),e[t]},r.prototype.clearStates=function(t){this.useState(Pl,!1,t)},r.prototype.useState=function(t,e,n,i){var a=t===Pl,o=this.hasState();if(!(!o&&a)){var s=this.currentStates,l=this.stateTransition;if(!(ft(s,t)>=0&&(e||s.length===1))){var u;if(this.stateProxy&&!a&&(u=this.stateProxy(t)),u||(u=this.states&&this.states[t]),!u&&!a){Sh("State "+t+" not exists.");return}a||this.saveCurrentToNormalState(u);var f=!!(u&&u.hoverLayer||i);f&&this._toggleHoverLayerFlag(!0),this._applyStateObj(t,u,this._normalState,e,!n&&!this.__inHover&&l&&l.duration>0,l);var h=this._textContent,c=this._textGuide;return h&&h.useState(t,e,n,f),c&&c.useState(t,e,n,f),a?(this.currentStates=[],this._normalState={}):e?this.currentStates.push(t):this.currentStates=[t],this._updateAnimationTargets(),this.markRedraw(),!f&&this.__inHover&&(this._toggleHoverLayerFlag(!1),this.__dirty&=~fe),u}}},r.prototype.useStates=function(t,e,n){if(!t.length)this.clearStates();else{var i=[],a=this.currentStates,o=t.length,s=o===a.length;if(s){for(var l=0;l<o;l++)if(t[l]!==a[l]){s=!1;break}}if(s)return;for(var l=0;l<o;l++){var u=t[l],f=void 0;this.stateProxy&&(f=this.stateProxy(u,t)),f||(f=this.states[u]),f&&i.push(f)}var h=i[o-1],c=!!(h&&h.hoverLayer||n);c&&this._toggleHoverLayerFlag(!0);var v=this._mergeStates(i),d=this.stateTransition;this.saveCurrentToNormalState(v),this._applyStateObj(t.join(","),v,this._normalState,!1,!e&&!this.__inHover&&d&&d.duration>0,d);var p=this._textContent,g=this._textGuide;p&&p.useStates(t,e,c),g&&g.useStates(t,e,c),this._updateAnimationTargets(),this.currentStates=t.slice(),this.markRedraw(),!c&&this.__inHover&&(this._toggleHoverLayerFlag(!1),this.__dirty&=~fe)}},r.prototype.isSilent=function(){for(var t=this;t;){if(t.silent)return!0;var e=t.__hostTarget;t=e?t.ignoreHostSilent?null:e:t.parent}return!1},r.prototype._updateAnimationTargets=function(){for(var t=0;t<this.animators.length;t++){var e=this.animators[t];e.targetName&&e.changeTarget(this[e.targetName])}},r.prototype.removeState=function(t){var e=ft(this.currentStates,t);if(e>=0){var n=this.currentStates.slice();n.splice(e,1),this.useStates(n)}},r.prototype.replaceState=function(t,e,n){var i=this.currentStates.slice(),a=ft(i,t),o=ft(i,e)>=0;a>=0?o?i.splice(a,1):i[a]=e:n&&!o&&i.push(e),this.useStates(i)},r.prototype.toggleState=function(t,e){e?this.useState(t,!0):this.removeState(t)},r.prototype._mergeStates=function(t){for(var e={},n,i=0;i<t.length;i++){var a=t[i];O(e,a),a.textConfig&&(n=n||{},O(n,a.textConfig))}return n&&(e.textConfig=n),e},r.prototype._applyStateObj=function(t,e,n,i,a,o){var s=!(e&&i);e&&e.textConfig?(this.textConfig=O({},i?this.textConfig:n.textConfig),O(this.textConfig,e.textConfig)):s&&n.textConfig&&(this.textConfig=n.textConfig);for(var l={},u=!1,f=0;f<Rl.length;f++){var h=Rl[f],c=a&&OS[h];e&&e[h]!=null?c?(u=!0,l[h]=e[h]):this[h]=e[h]:s&&n[h]!=null&&(c?(u=!0,l[h]=n[h]):this[h]=n[h])}if(!a)for(var f=0;f<this.animators.length;f++){var v=this.animators[f],d=v.targetName;v.getLoop()||v.__changeFinalValue(d?(e||n)[d]:e||n)}u&&this._transitionState(t,l,o)},r.prototype._attachComponent=function(t){if(!(t.__zr&&!t.__hostTarget)&&t!==this){var e=this.__zr;e&&t.addSelfToZr(e),t.__zr=e,t.__hostTarget=this}},r.prototype._detachComponent=function(t){t.__zr&&t.removeSelfFromZr(t.__zr),t.__zr=null,t.__hostTarget=null},r.prototype.getClipPath=function(){return this._clipPath},r.prototype.setClipPath=function(t){this._clipPath&&this._clipPath!==t&&this.removeClipPath(),this._attachComponent(t),this._clipPath=t,this.markRedraw()},r.prototype.removeClipPath=function(){var t=this._clipPath;t&&(this._detachComponent(t),this._clipPath=null,this.markRedraw())},r.prototype.getTextContent=function(){return this._textContent},r.prototype.setTextContent=function(t){var e=this._textContent;e!==t&&(e&&e!==t&&this.removeTextContent(),t.innerTransformable=new Qa,this._attachComponent(t),this._textContent=t,this.markRedraw())},r.prototype.setTextConfig=function(t){this.textConfig||(this.textConfig={}),O(this.textConfig,t),this.markRedraw()},r.prototype.removeTextConfig=function(){this.textConfig=null,this.markRedraw()},r.prototype.removeTextContent=function(){var t=this._textContent;t&&(t.innerTransformable=null,this._detachComponent(t),this._textContent=null,this._innerTextDefaultStyle=null,this.markRedraw())},r.prototype.getTextGuideLine=function(){return this._textGuide},r.prototype.setTextGuideLine=function(t){this._textGuide&&this._textGuide!==t&&this.removeTextGuideLine(),this._attachComponent(t),this._textGuide=t,this.markRedraw()},r.prototype.removeTextGuideLine=function(){var t=this._textGuide;t&&(this._detachComponent(t),this._textGuide=null,this.markRedraw())},r.prototype.markRedraw=function(){this.__dirty|=fe;var t=this.__zr;t&&(this.__inHover?t.refreshHover():t.refresh()),this.__hostTarget&&this.__hostTarget.markRedraw()},r.prototype.dirty=function(){this.markRedraw()},r.prototype._toggleHoverLayerFlag=function(t){this.__inHover=t;var e=this._textContent,n=this._textGuide;e&&(e.__inHover=t),n&&(n.__inHover=t)},r.prototype.addSelfToZr=function(t){if(this.__zr!==t){this.__zr=t;var e=this.animators;if(e)for(var n=0;n<e.length;n++)t.animation.addAnimator(e[n]);this._clipPath&&this._clipPath.addSelfToZr(t),this._textContent&&this._textContent.addSelfToZr(t),this._textGuide&&this._textGuide.addSelfToZr(t)}},r.prototype.removeSelfFromZr=function(t){if(this.__zr){this.__zr=null;var e=this.animators;if(e)for(var n=0;n<e.length;n++)t.animation.removeAnimator(e[n]);this._clipPath&&this._clipPath.removeSelfFromZr(t),this._textContent&&this._textContent.removeSelfFromZr(t),this._textGuide&&this._textGuide.removeSelfFromZr(t)}},r.prototype.animate=function(t,e,n){var i=t?this[t]:this,a=new Dh(i,e,n);return t&&(a.targetName=t),this.addAnimator(a,t),a},r.prototype.addAnimator=function(t,e){var n=this.__zr,i=this;t.during(function(){i.updateDuringAnimation(e)}).done(function(){var a=i.animators,o=ft(a,t);o>=0&&a.splice(o,1)}),this.animators.push(t),n&&n.animation.addAnimator(t),n&&n.wakeUp()},r.prototype.updateDuringAnimation=function(t){this.markRedraw()},r.prototype.stopAnimation=function(t,e){for(var n=this.animators,i=n.length,a=[],o=0;o<i;o++){var s=n[o];!t||t===s.scope?s.stop(e):a.push(s)}return this.animators=a,this},r.prototype.animateTo=function(t,e,n){El(this,t,e,n)},r.prototype.animateFrom=function(t,e,n){El(this,t,e,n,!0)},r.prototype._transitionState=function(t,e,n,i){for(var a=El(this,e,n,i),o=0;o<a.length;o++)a[o].__fromStateTransition=t},r.prototype.getBoundingRect=function(){return null},r.prototype.getPaintRect=function(){return null},r.initDefaultProps=(function(){var t=r.prototype;t.type="element",t.name="",t.ignore=t.silent=t.ignoreHostSilent=t.isGroup=t.draggable=t.dragging=t.ignoreClip=t.__inHover=!1,t.__dirty=fe;function e(n,i,a,o){Object.defineProperty(t,n,{get:function(){if(!this[i]){var l=this[i]=[];s(this,l)}return this[i]},set:function(l){this[a]=l[0],this[o]=l[1],this[i]=l,s(this,l)}});function s(l,u){Object.defineProperty(u,0,{get:function(){return l[a]},set:function(f){l[a]=f}}),Object.defineProperty(u,1,{get:function(){return l[o]},set:function(f){l[o]=f}})}}Object.defineProperty&&(e("position","_legacyPos","x","y"),e("scale","_legacyScale","scaleX","scaleY"),e("origin","_legacyOrigin","originX","originY"))})(),r})();Qe(al,ke);Qe(al,Qa);function El(r,t,e,n,i){e=e||{};var a=[];wm(r,"",r,t,e,n,a,i);var o=a.length,s=!1,l=e.done,u=e.aborted,f=function(){s=!0,o--,o<=0&&(s?l&&l():u&&u())},h=function(){o--,o<=0&&(s?l&&l():u&&u())};o||l&&l(),a.length>0&&e.during&&a[0].during(function(d,p){e.during(p)});for(var c=0;c<a.length;c++){var v=a[c];f&&v.done(f),h&&v.aborted(h),e.force&&v.duration(e.duration),v.start(e.easing)}return a}function kl(r,t,e){for(var n=0;n<e;n++)r[n]=t[n]}function NS(r){return Qt(r[0])}function FS(r,t,e){if(Qt(t[e]))if(Qt(r[e])||(r[e]=[]),ae(t[e])){var n=t[e].length;r[e].length!==n&&(r[e]=new t[e].constructor(n),kl(r[e],t[e],n))}else{var i=t[e],a=r[e],o=i.length;if(NS(i))for(var s=i[0].length,l=0;l<o;l++)a[l]?kl(a[l],i[l],s):a[l]=Array.prototype.slice.call(i[l]);else kl(a,i,o);a.length=i.length}else r[e]=t[e]}function zS(r,t){return r===t||Qt(r)&&Qt(t)&&HS(r,t)}function HS(r,t){var e=r.length;if(e!==t.length)return!1;for(var n=0;n<e;n++)if(r[n]!==t[n])return!1;return!0}function wm(r,t,e,n,i,a,o,s){for(var l=St(n),u=i.duration,f=i.delay,h=i.additive,c=i.setToFinal,v=!X(a),d=r.animators,p=[],g=0;g<l.length;g++){var m=l[g],y=n[m];if(y!=null&&e[m]!=null&&(v||a[m]))if(X(y)&&!Qt(y)&&!Js(y)){if(t){s||(e[m]=y,r.updateDuringAnimation(t));continue}wm(r,m,e[m],y,i,a&&a[m],o,s)}else p.push(m);else s||(e[m]=y,r.updateDuringAnimation(t),p.push(m))}var _=p.length;if(!h&&_)for(var S=0;S<d.length;S++){var w=d[S];if(w.targetName===t){var b=w.stopTracks(p);if(b){var T=ft(d,w);d.splice(T,1)}}}if(i.force||(p=wt(p,function(A){return!zS(n[A],e[A])}),_=p.length),_>0||i.force&&!o.length){var C=void 0,x=void 0,M=void 0;if(s){x={},c&&(C={});for(var S=0;S<_;S++){var m=p[S];x[m]=e[m],c?C[m]=n[m]:e[m]=n[m]}}else if(c){M={};for(var S=0;S<_;S++){var m=p[S];M[m]=qo(e[m]),FS(e,n,m)}}var w=new Dh(e,!1,!1,h?wt(d,function(P){return P.targetName===t}):null);w.targetName=t,i.scope&&(w.scope=i.scope),c&&C&&w.whenWithKeys(0,C,p),M&&w.whenWithKeys(0,M,p),w.whenWithKeys(u??500,s?x:n,p).delay(f||0),r.addAnimator(w,t),o.push(w)}}var mf="__zr_style_"+Math.round(Math.random()*10),Ln={shadowBlur:0,shadowOffsetX:0,shadowOffsetY:0,shadowColor:"#000",opacity:1,blend:"source-over"},ol={style:{shadowBlur:!0,shadowOffsetX:!0,shadowOffsetY:!0,shadowColor:!0,opacity:!0}};Ln[mf]=!0;var nc=["z","z2","invisible"],VS=["invisible"],Bi=(function(r){z(t,r);function t(e){return r.call(this,e)||this}return t.prototype._init=function(e){for(var n=St(e),i=0;i<n.length;i++){var a=n[i];a==="style"?this.useStyle(e[a]):r.prototype.attrKV.call(this,a,e[a])}this.style||this.useStyle({})},t.prototype.beforeBrush=function(){},t.prototype.afterBrush=function(){},t.prototype.innerBeforeBrush=function(){},t.prototype.innerAfterBrush=function(){},t.prototype.shouldBePainted=function(e,n,i,a){var o=this.transform;if(this.ignore||this.invisible||this.style.opacity===0||this.culling&&GS(this,e,n)||o&&!o[0]&&!o[3])return!1;if(i&&this.__clipPaths&&this.__clipPaths.length){for(var s=0;s<this.__clipPaths.length;++s)if(this.__clipPaths[s].isZeroArea())return!1}if(a&&this.parent)for(var l=this.parent;l;){if(l.ignore)return!1;l=l.parent}return!0},t.prototype.contain=function(e,n){return this.rectContain(e,n)},t.prototype.traverse=function(e,n){e.call(n,this)},t.prototype.rectContain=function(e,n){var i=this.transformCoordToLocal(e,n),a=this.getBoundingRect();return a.contain(i[0],i[1])},t.prototype.getPaintRect=function(){var e=this._paintRect;if(!this._paintRect||this.__dirty){var n=this.transform,i=this.getBoundingRect(),a=this.style,o=a.shadowBlur||0,s=a.shadowOffsetX||0,l=a.shadowOffsetY||0;e=this._paintRect||(this._paintRect=new it(0,0,0,0)),n?it.applyTransform(e,i,n):e.copy(i),(o||s||l)&&(e.width+=o*2+Math.abs(s),e.height+=o*2+Math.abs(l),e.x=Math.min(e.x,e.x+s-o),e.y=Math.min(e.y,e.y+l-o));var u=this.dirtyRectTolerance;e.isZero()||(e.x=Math.floor(e.x-u),e.y=Math.floor(e.y-u),e.width=Math.ceil(e.width+1+u*2),e.height=Math.ceil(e.height+1+u*2))}return e},t.prototype.setPrevPaintRect=function(e){e?(this._prevPaintRect=this._prevPaintRect||new it(0,0,0,0),this._prevPaintRect.copy(e)):this._prevPaintRect=null},t.prototype.getPrevPaintRect=function(){return this._prevPaintRect},t.prototype.animateStyle=function(e){return this.animate("style",e)},t.prototype.updateDuringAnimation=function(e){e==="style"?this.dirtyStyle():this.markRedraw()},t.prototype.attrKV=function(e,n){e!=="style"?r.prototype.attrKV.call(this,e,n):this.style?this.setStyle(n):this.useStyle(n)},t.prototype.setStyle=function(e,n){return typeof e=="string"?this.style[e]=n:O(this.style,e),this.dirtyStyle(),this},t.prototype.dirtyStyle=function(e){e||this.markRedraw(),this.__dirty|=ha,this._rect&&(this._rect=null)},t.prototype.dirty=function(){this.dirtyStyle()},t.prototype.styleChanged=function(){return!!(this.__dirty&ha)},t.prototype.styleUpdated=function(){this.__dirty&=~ha},t.prototype.createStyle=function(e){return tl(Ln,e)},t.prototype.useStyle=function(e){e[mf]||(e=this.createStyle(e)),this.__inHover?this.__hoverStyle=e:this.style=e,this.dirtyStyle()},t.prototype.isStyleObject=function(e){return e[mf]},t.prototype._innerSaveToNormal=function(e){r.prototype._innerSaveToNormal.call(this,e);var n=this._normalState;e.style&&!n.style&&(n.style=this._mergeStyle(this.createStyle(),this.style)),this._savePrimaryToNormal(e,n,nc)},t.prototype._applyStateObj=function(e,n,i,a,o,s){r.prototype._applyStateObj.call(this,e,n,i,a,o,s);var l=!(n&&a),u;if(n&&n.style?o?a?u=n.style:(u=this._mergeStyle(this.createStyle(),i.style),this._mergeStyle(u,n.style)):(u=this._mergeStyle(this.createStyle(),a?this.style:i.style),this._mergeStyle(u,n.style)):l&&(u=i.style),u)if(o){var f=this.style;if(this.style=this.createStyle(l?{}:f),l)for(var h=St(f),c=0;c<h.length;c++){var v=h[c];v in u&&(u[v]=u[v],this.style[v]=f[v])}for(var d=St(u),c=0;c<d.length;c++){var v=d[c];this.style[v]=this.style[v]}this._transitionState(e,{style:u},s,this.getAnimationStyleProps())}else this.useStyle(u);for(var p=this.__inHover?VS:nc,c=0;c<p.length;c++){var v=p[c];n&&n[v]!=null?this[v]=n[v]:l&&i[v]!=null&&(this[v]=i[v])}},t.prototype._mergeStates=function(e){for(var n=r.prototype._mergeStates.call(this,e),i,a=0;a<e.length;a++){var o=e[a];o.style&&(i=i||{},this._mergeStyle(i,o.style))}return i&&(n.style=i),n},t.prototype._mergeStyle=function(e,n){return O(e,n),e},t.prototype.getAnimationStyleProps=function(){return ol},t.initDefaultProps=(function(){var e=t.prototype;e.type="displayable",e.invisible=!1,e.z=0,e.z2=0,e.zlevel=0,e.culling=!1,e.cursor="pointer",e.rectHover=!1,e.incremental=!1,e._rect=null,e.dirtyRectTolerance=0,e.__dirty=fe|ha})(),t})(al),Ol=new it(0,0,0,0),Bl=new it(0,0,0,0);function GS(r,t,e){return Ol.copy(r.getBoundingRect()),r.transform&&Ol.applyTransform(r.transform),Bl.width=t,Bl.height=e,!Ol.intersect(Bl)}var te=Math.min,ee=Math.max,Nl=Math.sin,Fl=Math.cos,Jr=Math.PI*2,go=Oi(),mo=Oi(),yo=Oi();function xm(r,t,e){if(r.length!==0){for(var n=r[0],i=n[0],a=n[0],o=n[1],s=n[1],l=1;l<r.length;l++)n=r[l],i=te(i,n[0]),a=ee(a,n[0]),o=te(o,n[1]),s=ee(s,n[1]);t[0]=i,t[1]=o,e[0]=a,e[1]=s}}function ic(r,t,e,n,i,a){i[0]=te(r,e),i[1]=te(t,n),a[0]=ee(r,e),a[1]=ee(t,n)}var ac=[],oc=[];function WS(r,t,e,n,i,a,o,s,l,u){var f=dm,h=Lt,c=f(r,e,i,o,ac);l[0]=1/0,l[1]=1/0,u[0]=-1/0,u[1]=-1/0;for(var v=0;v<c;v++){var d=h(r,e,i,o,ac[v]);l[0]=te(d,l[0]),u[0]=ee(d,u[0])}c=f(t,n,a,s,oc);for(var v=0;v<c;v++){var p=h(t,n,a,s,oc[v]);l[1]=te(p,l[1]),u[1]=ee(p,u[1])}l[0]=te(r,l[0]),u[0]=ee(r,u[0]),l[0]=te(o,l[0]),u[0]=ee(o,u[0]),l[1]=te(t,l[1]),u[1]=ee(t,u[1]),l[1]=te(s,l[1]),u[1]=ee(s,u[1])}function US(r,t,e,n,i,a,o,s){var l=gm,u=Ut,f=ee(te(l(r,e,i),1),0),h=ee(te(l(t,n,a),1),0),c=u(r,e,i,f),v=u(t,n,a,h);o[0]=te(r,i,c),o[1]=te(t,a,v),s[0]=ee(r,i,c),s[1]=ee(t,a,v)}function YS(r,t,e,n,i,a,o,s,l){var u=hi,f=vi,h=Math.abs(i-a);if(h%Jr<1e-4&&h>1e-4){s[0]=r-e,s[1]=t-n,l[0]=r+e,l[1]=t+n;return}if(go[0]=Fl(i)*e+r,go[1]=Nl(i)*n+t,mo[0]=Fl(a)*e+r,mo[1]=Nl(a)*n+t,u(s,go,mo),f(l,go,mo),i=i%Jr,i<0&&(i=i+Jr),a=a%Jr,a<0&&(a=a+Jr),i>a&&!o?a+=Jr:i<a&&o&&(i+=Jr),o){var c=a;a=i,i=c}for(var v=0;v<a;v+=Math.PI/2)v>i&&(yo[0]=Fl(v)*e+r,yo[1]=Nl(v)*n+t,u(s,yo,s),f(l,yo,l))}var ct={M:1,L:2,C:3,Q:4,A:5,Z:6,R:7},tn=[],en=[],Be=[],pr=[],Ne=[],Fe=[],zl=Math.min,Hl=Math.max,rn=Math.cos,nn=Math.sin,Je=Math.abs,yf=Math.PI,Tr=yf*2,Vl=typeof Float32Array<"u",Hi=[];function Gl(r){var t=Math.round(r/yf*1e8)/1e8;return t%2*yf}function ZS(r,t){var e=Gl(r[0]);e<0&&(e+=Tr);var n=e-r[0],i=r[1];i+=n,!t&&i-e>=Tr?i=e+Tr:t&&e-i>=Tr?i=e-Tr:!t&&e>i?i=e+(Tr-Gl(e-i)):t&&e<i&&(i=e-(Tr-Gl(i-e))),r[0]=e,r[1]=i}var vr=(function(){function r(t){this.dpr=1,this._xi=0,this._yi=0,this._x0=0,this._y0=0,this._len=0,t&&(this._saveData=!1),this._saveData&&(this.data=[])}return r.prototype.increaseVersion=function(){this._version++},r.prototype.getVersion=function(){return this._version},r.prototype.setScale=function(t,e,n){n=n||0,n>0&&(this._ux=Je(n/ys/t)||0,this._uy=Je(n/ys/e)||0)},r.prototype.setDPR=function(t){this.dpr=t},r.prototype.setContext=function(t){this._ctx=t},r.prototype.getContext=function(){return this._ctx},r.prototype.beginPath=function(){return this._ctx&&this._ctx.beginPath(),this.reset(),this},r.prototype.reset=function(){this._saveData&&(this._len=0),this._pathSegLen&&(this._pathSegLen=null,this._pathLen=0),this._version++},r.prototype.moveTo=function(t,e){return this._drawPendingPt(),this.addData(ct.M,t,e),this._ctx&&this._ctx.moveTo(t,e),this._x0=t,this._y0=e,this._xi=t,this._yi=e,this},r.prototype.lineTo=function(t,e){var n=Je(t-this._xi),i=Je(e-this._yi),a=n>this._ux||i>this._uy;if(this.addData(ct.L,t,e),this._ctx&&a&&this._ctx.lineTo(t,e),a)this._xi=t,this._yi=e,this._pendingPtDist=0;else{var o=n*n+i*i;o>this._pendingPtDist&&(this._pendingPtX=t,this._pendingPtY=e,this._pendingPtDist=o)}return this},r.prototype.bezierCurveTo=function(t,e,n,i,a,o){return this._drawPendingPt(),this.addData(ct.C,t,e,n,i,a,o),this._ctx&&this._ctx.bezierCurveTo(t,e,n,i,a,o),this._xi=a,this._yi=o,this},r.prototype.quadraticCurveTo=function(t,e,n,i){return this._drawPendingPt(),this.addData(ct.Q,t,e,n,i),this._ctx&&this._ctx.quadraticCurveTo(t,e,n,i),this._xi=n,this._yi=i,this},r.prototype.arc=function(t,e,n,i,a,o){this._drawPendingPt(),Hi[0]=i,Hi[1]=a,ZS(Hi,o),i=Hi[0],a=Hi[1];var s=a-i;return this.addData(ct.A,t,e,n,n,i,s,0,o?0:1),this._ctx&&this._ctx.arc(t,e,n,i,a,o),this._xi=rn(a)*n+t,this._yi=nn(a)*n+e,this},r.prototype.arcTo=function(t,e,n,i,a){return this._drawPendingPt(),this._ctx&&this._ctx.arcTo(t,e,n,i,a),this},r.prototype.rect=function(t,e,n,i){return this._drawPendingPt(),this._ctx&&this._ctx.rect(t,e,n,i),this.addData(ct.R,t,e,n,i),this},r.prototype.closePath=function(){this._drawPendingPt(),this.addData(ct.Z);var t=this._ctx,e=this._x0,n=this._y0;return t&&t.closePath(),this._xi=e,this._yi=n,this},r.prototype.fill=function(t){t&&t.fill(),this.toStatic()},r.prototype.stroke=function(t){t&&t.stroke(),this.toStatic()},r.prototype.len=function(){return this._len},r.prototype.setData=function(t){if(this._saveData){var e=t.length;!(this.data&&this.data.length===e)&&Vl&&(this.data=new Float32Array(e));for(var n=0;n<e;n++)this.data[n]=t[n];this._len=e}},r.prototype.appendPath=function(t){if(this._saveData){t instanceof Array||(t=[t]);for(var e=t.length,n=0,i=this._len,a=0;a<e;a++)n+=t[a].len();var o=this.data;if(Vl&&(o instanceof Float32Array||!o)&&(this.data=new Float32Array(i+n),i>0&&o))for(var s=0;s<i;s++)this.data[s]=o[s];for(var a=0;a<e;a++)for(var l=t[a].data,s=0;s<l.length;s++)this.data[i++]=l[s];this._len=i}},r.prototype.addData=function(t,e,n,i,a,o,s,l,u){if(this._saveData){var f=this.data;this._len+arguments.length>f.length&&(this._expandData(),f=this.data);for(var h=0;h<arguments.length;h++)f[this._len++]=arguments[h]}},r.prototype._drawPendingPt=function(){this._pendingPtDist>0&&(this._ctx&&this._ctx.lineTo(this._pendingPtX,this._pendingPtY),this._pendingPtDist=0)},r.prototype._expandData=function(){if(!(this.data instanceof Array)){for(var t=[],e=0;e<this._len;e++)t[e]=this.data[e];this.data=t}},r.prototype.toStatic=function(){if(this._saveData){this._drawPendingPt();var t=this.data;t instanceof Array&&(t.length=this._len,Vl&&this._len>11&&(this.data=new Float32Array(t)))}},r.prototype.getBoundingRect=function(){Be[0]=Be[1]=Ne[0]=Ne[1]=Number.MAX_VALUE,pr[0]=pr[1]=Fe[0]=Fe[1]=-Number.MAX_VALUE;var t=this.data,e=0,n=0,i=0,a=0,o;for(o=0;o<this._len;){var s=t[o++],l=o===1;switch(l&&(e=t[o],n=t[o+1],i=e,a=n),s){case ct.M:e=i=t[o++],n=a=t[o++],Ne[0]=i,Ne[1]=a,Fe[0]=i,Fe[1]=a;break;case ct.L:ic(e,n,t[o],t[o+1],Ne,Fe),e=t[o++],n=t[o++];break;case ct.C:WS(e,n,t[o++],t[o++],t[o++],t[o++],t[o],t[o+1],Ne,Fe),e=t[o++],n=t[o++];break;case ct.Q:US(e,n,t[o++],t[o++],t[o],t[o+1],Ne,Fe),e=t[o++],n=t[o++];break;case ct.A:var u=t[o++],f=t[o++],h=t[o++],c=t[o++],v=t[o++],d=t[o++]+v;o+=1;var p=!t[o++];l&&(i=rn(v)*h+u,a=nn(v)*c+f),YS(u,f,h,c,v,d,p,Ne,Fe),e=rn(d)*h+u,n=nn(d)*c+f;break;case ct.R:i=e=t[o++],a=n=t[o++];var g=t[o++],m=t[o++];ic(i,a,i+g,a+m,Ne,Fe);break;case ct.Z:e=i,n=a;break}hi(Be,Be,Ne),vi(pr,pr,Fe)}return o===0&&(Be[0]=Be[1]=pr[0]=pr[1]=0),new it(Be[0],Be[1],pr[0]-Be[0],pr[1]-Be[1])},r.prototype._calculateLength=function(){var t=this.data,e=this._len,n=this._ux,i=this._uy,a=0,o=0,s=0,l=0;this._pathSegLen||(this._pathSegLen=[]);for(var u=this._pathSegLen,f=0,h=0,c=0;c<e;){var v=t[c++],d=c===1;d&&(a=t[c],o=t[c+1],s=a,l=o);var p=-1;switch(v){case ct.M:a=s=t[c++],o=l=t[c++];break;case ct.L:{var g=t[c++],m=t[c++],y=g-a,_=m-o;(Je(y)>n||Je(_)>i||c===e-1)&&(p=Math.sqrt(y*y+_*_),a=g,o=m);break}case ct.C:{var S=t[c++],w=t[c++],g=t[c++],m=t[c++],b=t[c++],T=t[c++];p=SS(a,o,S,w,g,m,b,T,10),a=b,o=T;break}case ct.Q:{var S=t[c++],w=t[c++],g=t[c++],m=t[c++];p=wS(a,o,S,w,g,m,10),a=g,o=m;break}case ct.A:var C=t[c++],x=t[c++],M=t[c++],A=t[c++],P=t[c++],L=t[c++],I=L+P;c+=1,d&&(s=rn(P)*M+C,l=nn(P)*A+x),p=Hl(M,A)*zl(Tr,Math.abs(L)),a=rn(I)*M+C,o=nn(I)*A+x;break;case ct.R:{s=a=t[c++],l=o=t[c++];var R=t[c++],E=t[c++];p=R*2+E*2;break}case ct.Z:{var y=s-a,_=l-o;p=Math.sqrt(y*y+_*_),a=s,o=l;break}}p>=0&&(u[h++]=p,f+=p)}return this._pathLen=f,f},r.prototype.rebuildPath=function(t,e){var n=this.data,i=this._ux,a=this._uy,o=this._len,s,l,u,f,h,c,v=e<1,d,p,g=0,m=0,y,_=0,S,w;if(!(v&&(this._pathSegLen||this._calculateLength(),d=this._pathSegLen,p=this._pathLen,y=e*p,!y)))t:for(var b=0;b<o;){var T=n[b++],C=b===1;switch(C&&(u=n[b],f=n[b+1],s=u,l=f),T!==ct.L&&_>0&&(t.lineTo(S,w),_=0),T){case ct.M:s=u=n[b++],l=f=n[b++],t.moveTo(u,f);break;case ct.L:{h=n[b++],c=n[b++];var x=Je(h-u),M=Je(c-f);if(x>i||M>a){if(v){var A=d[m++];if(g+A>y){var P=(y-g)/A;t.lineTo(u*(1-P)+h*P,f*(1-P)+c*P);break t}g+=A}t.lineTo(h,c),u=h,f=c,_=0}else{var L=x*x+M*M;L>_&&(S=h,w=c,_=L)}break}case ct.C:{var I=n[b++],R=n[b++],E=n[b++],V=n[b++],B=n[b++],k=n[b++];if(v){var A=d[m++];if(g+A>y){var P=(y-g)/A;Nr(u,I,E,B,P,tn),Nr(f,R,V,k,P,en),t.bezierCurveTo(tn[1],en[1],tn[2],en[2],tn[3],en[3]);break t}g+=A}t.bezierCurveTo(I,R,E,V,B,k),u=B,f=k;break}case ct.Q:{var I=n[b++],R=n[b++],E=n[b++],V=n[b++];if(v){var A=d[m++];if(g+A>y){var P=(y-g)/A;gs(u,I,E,P,tn),gs(f,R,V,P,en),t.quadraticCurveTo(tn[1],en[1],tn[2],en[2]);break t}g+=A}t.quadraticCurveTo(I,R,E,V),u=E,f=V;break}case ct.A:var G=n[b++],U=n[b++],Z=n[b++],j=n[b++],ot=n[b++],yt=n[b++],Ht=n[b++],de=!n[b++],pe=Z>j?Z:j,Vt=Je(Z-j)>.001,Dt=ot+yt,rt=!1;if(v){var A=d[m++];g+A>y&&(Dt=ot+yt*(y-g)/A,rt=!0),g+=A}if(Vt&&t.ellipse?t.ellipse(G,U,Z,j,Ht,ot,Dt,de):t.arc(G,U,pe,ot,Dt,de),rt)break t;C&&(s=rn(ot)*Z+G,l=nn(ot)*j+U),u=rn(Dt)*Z+G,f=nn(Dt)*j+U;break;case ct.R:s=u=n[b],l=f=n[b+1],h=n[b++],c=n[b++];var lt=n[b++],Yr=n[b++];if(v){var A=d[m++];if(g+A>y){var Zt=y-g;t.moveTo(h,c),t.lineTo(h+zl(Zt,lt),c),Zt-=lt,Zt>0&&t.lineTo(h+lt,c+zl(Zt,Yr)),Zt-=Yr,Zt>0&&t.lineTo(h+Hl(lt-Zt,0),c+Yr),Zt-=lt,Zt>0&&t.lineTo(h,c+Hl(Yr-Zt,0));break t}g+=A}t.rect(h,c,lt,Yr);break;case ct.Z:if(v){var A=d[m++];if(g+A>y){var P=(y-g)/A;t.lineTo(u*(1-P)+s*P,f*(1-P)+l*P);break t}g+=A}t.closePath(),u=s,f=l}}},r.prototype.clone=function(){var t=new r,e=this.data;return t.data=e.slice?e.slice():Array.prototype.slice.call(e),t._len=this._len,t},r.prototype.canSave=function(){return!!this._saveData},r.CMD=ct,r.initDefaultProps=(function(){var t=r.prototype;t._saveData=!0,t._ux=0,t._uy=0,t._pendingPtDist=0,t._version=0})(),r})();function Yn(r,t,e,n,i,a,o){if(i===0)return!1;var s=i,l=0,u=r;if(o>t+s&&o>n+s||o<t-s&&o<n-s||a>r+s&&a>e+s||a<r-s&&a<e-s)return!1;if(r!==e)l=(t-n)/(r-e),u=(r*n-e*t)/(r-e);else return Math.abs(a-r)<=s/2;var f=l*a-o+u,h=f*f/(l*l+1);return h<=s/2*s/2}function XS(r,t,e,n,i,a,o,s,l,u,f){if(l===0)return!1;var h=l;if(f>t+h&&f>n+h&&f>a+h&&f>s+h||f<t-h&&f<n-h&&f<a-h&&f<s-h||u>r+h&&u>e+h&&u>i+h&&u>o+h||u<r-h&&u<e-h&&u<i-h&&u<o-h)return!1;var c=pm(r,t,e,n,i,a,o,s,u,f,null);return c<=h/2}function $S(r,t,e,n,i,a,o,s,l){if(o===0)return!1;var u=o;if(l>t+u&&l>n+u&&l>a+u||l<t-u&&l<n-u&&l<a-u||s>r+u&&s>e+u&&s>i+u||s<r-u&&s<e-u&&s<i-u)return!1;var f=mm(r,t,e,n,i,a,s,l,null);return f<=u/2}var sc=Math.PI*2;function ar(r){return r%=sc,r<0&&(r+=sc),r}var Vi=Math.PI*2;function qS(r,t,e,n,i,a,o,s,l){if(o===0)return!1;var u=o;s-=r,l-=t;var f=Math.sqrt(s*s+l*l);if(f-u>e||f+u<e)return!1;if(Math.abs(n-i)%Vi<1e-4)return!0;if(a){var h=n;n=ar(i),i=ar(h)}else n=ar(n),i=ar(i);n>i&&(i+=Vi);var c=Math.atan2(l,s);return c<0&&(c+=Vi),c>=n&&c<=i||c+Vi>=n&&c+Vi<=i}function an(r,t,e,n,i,a){if(a>t&&a>n||a<t&&a<n||n===t)return 0;var o=(a-t)/(n-t),s=n<t?1:-1;(o===1||o===0)&&(s=n<t?.5:-.5);var l=o*(e-r)+r;return l===i?1/0:l>i?s:0}var gr=vr.CMD,on=Math.PI*2,KS=1e-4;function QS(r,t){return Math.abs(r-t)<KS}var $t=[-1,-1,-1],Se=[-1,-1];function jS(){var r=Se[0];Se[0]=Se[1],Se[1]=r}function JS(r,t,e,n,i,a,o,s,l,u){if(u>t&&u>n&&u>a&&u>s||u<t&&u<n&&u<a&&u<s)return 0;var f=ps(t,n,a,s,u,$t);if(f===0)return 0;for(var h=0,c=-1,v=void 0,d=void 0,p=0;p<f;p++){var g=$t[p],m=g===0||g===1?.5:1,y=Lt(r,e,i,o,g);y<l||(c<0&&(c=dm(t,n,a,s,Se),Se[1]<Se[0]&&c>1&&jS(),v=Lt(t,n,a,s,Se[0]),c>1&&(d=Lt(t,n,a,s,Se[1]))),c===2?g<Se[0]?h+=v<t?m:-m:g<Se[1]?h+=d<v?m:-m:h+=s<d?m:-m:g<Se[0]?h+=v<t?m:-m:h+=s<v?m:-m)}return h}function tb(r,t,e,n,i,a,o,s){if(s>t&&s>n&&s>a||s<t&&s<n&&s<a)return 0;var l=bS(t,n,a,s,$t);if(l===0)return 0;var u=gm(t,n,a);if(u>=0&&u<=1){for(var f=0,h=Ut(t,n,a,u),c=0;c<l;c++){var v=$t[c]===0||$t[c]===1?.5:1,d=Ut(r,e,i,$t[c]);d<o||($t[c]<u?f+=h<t?v:-v:f+=a<h?v:-v)}return f}else{var v=$t[0]===0||$t[0]===1?.5:1,d=Ut(r,e,i,$t[0]);return d<o?0:a<t?v:-v}}function eb(r,t,e,n,i,a,o,s){if(s-=t,s>e||s<-e)return 0;var l=Math.sqrt(e*e-s*s);$t[0]=-l,$t[1]=l;var u=Math.abs(n-i);if(u<1e-4)return 0;if(u>=on-1e-4){n=0,i=on;var f=a?1:-1;return o>=$t[0]+r&&o<=$t[1]+r?f:0}if(n>i){var h=n;n=i,i=h}n<0&&(n+=on,i+=on);for(var c=0,v=0;v<2;v++){var d=$t[v];if(d+r>o){var p=Math.atan2(s,d),f=a?1:-1;p<0&&(p=on+p),(p>=n&&p<=i||p+on>=n&&p+on<=i)&&(p>Math.PI/2&&p<Math.PI*1.5&&(f=-f),c+=f)}}return c}function Tm(r,t,e,n,i){for(var a=r.data,o=r.len(),s=0,l=0,u=0,f=0,h=0,c,v,d=0;d<o;){var p=a[d++],g=d===1;switch(p===gr.M&&d>1&&(e||(s+=an(l,u,f,h,n,i))),g&&(l=a[d],u=a[d+1],f=l,h=u),p){case gr.M:f=a[d++],h=a[d++],l=f,u=h;break;case gr.L:if(e){if(Yn(l,u,a[d],a[d+1],t,n,i))return!0}else s+=an(l,u,a[d],a[d+1],n,i)||0;l=a[d++],u=a[d++];break;case gr.C:if(e){if(XS(l,u,a[d++],a[d++],a[d++],a[d++],a[d],a[d+1],t,n,i))return!0}else s+=JS(l,u,a[d++],a[d++],a[d++],a[d++],a[d],a[d+1],n,i)||0;l=a[d++],u=a[d++];break;case gr.Q:if(e){if($S(l,u,a[d++],a[d++],a[d],a[d+1],t,n,i))return!0}else s+=tb(l,u,a[d++],a[d++],a[d],a[d+1],n,i)||0;l=a[d++],u=a[d++];break;case gr.A:var m=a[d++],y=a[d++],_=a[d++],S=a[d++],w=a[d++],b=a[d++];d+=1;var T=!!(1-a[d++]);c=Math.cos(w)*_+m,v=Math.sin(w)*S+y,g?(f=c,h=v):s+=an(l,u,c,v,n,i);var C=(n-m)*S/_+m;if(e){if(qS(m,y,S,w,w+b,T,t,C,i))return!0}else s+=eb(m,y,S,w,w+b,T,C,i);l=Math.cos(w+b)*_+m,u=Math.sin(w+b)*S+y;break;case gr.R:f=l=a[d++],h=u=a[d++];var x=a[d++],M=a[d++];if(c=f+x,v=h+M,e){if(Yn(f,h,c,h,t,n,i)||Yn(c,h,c,v,t,n,i)||Yn(c,v,f,v,t,n,i)||Yn(f,v,f,h,t,n,i))return!0}else s+=an(c,h,c,v,n,i),s+=an(f,v,f,h,n,i);break;case gr.Z:if(e){if(Yn(l,u,f,h,t,n,i))return!0}else s+=an(l,u,f,h,n,i);l=f,u=h;break}}return!e&&!QS(u,h)&&(s+=an(l,u,f,h,n,i)||0),s!==0}function rb(r,t,e){return Tm(r,0,!1,t,e)}function nb(r,t,e,n){return Tm(r,t,!0,e,n)}var Mm=at({fill:"#000",stroke:null,strokePercent:1,fillOpacity:1,strokeOpacity:1,lineDashOffset:0,lineWidth:1,lineCap:"butt",miterLimit:10,strokeNoScale:!1,strokeFirst:!1},Ln),ib={style:at({fill:!0,stroke:!0,strokePercent:!0,fillOpacity:!0,strokeOpacity:!0,lineDashOffset:!0,lineWidth:!0,miterLimit:!0},ol.style)},Wl=Ea.concat(["invisible","culling","z","z2","zlevel","parent"]),ht=(function(r){z(t,r);function t(e){return r.call(this,e)||this}return t.prototype.update=function(){var e=this;r.prototype.update.call(this);var n=this.style;if(n.decal){var i=this._decalEl=this._decalEl||new t;i.buildPath===t.prototype.buildPath&&(i.buildPath=function(l){e.buildPath(l,e.shape)}),i.silent=!0;var a=i.style;for(var o in n)a[o]!==n[o]&&(a[o]=n[o]);a.fill=n.fill?n.decal:null,a.decal=null,a.shadowColor=null,n.strokeFirst&&(a.stroke=null);for(var s=0;s<Wl.length;++s)i[Wl[s]]=this[Wl[s]];i.__dirty|=fe}else this._decalEl&&(this._decalEl=null)},t.prototype.getDecalElement=function(){return this._decalEl},t.prototype._init=function(e){var n=St(e);this.shape=this.getDefaultShape();var i=this.getDefaultStyle();i&&this.useStyle(i);for(var a=0;a<n.length;a++){var o=n[a],s=e[o];o==="style"?this.style?O(this.style,s):this.useStyle(s):o==="shape"?O(this.shape,s):r.prototype.attrKV.call(this,o,s)}this.style||this.useStyle({})},t.prototype.getDefaultStyle=function(){return null},t.prototype.getDefaultShape=function(){return{}},t.prototype.canBeInsideText=function(){return this.hasFill()},t.prototype.getInsideTextFill=function(){var e=this.style.fill;if(e!=="none"){if(W(e)){var n=ms(e,0);return n>.5?pf:n>.2?kS:gf}else if(e)return gf}return pf},t.prototype.getInsideTextStroke=function(e){var n=this.style.fill;if(W(n)){var i=this.__zr,a=!!(i&&i.isDarkMode()),o=ms(e,0)<df;if(a===o)return n}},t.prototype.buildPath=function(e,n,i){},t.prototype.pathUpdated=function(){this.__dirty&=~li},t.prototype.getUpdatedPathProxy=function(e){return!this.path&&this.createPathProxy(),this.path.beginPath(),this.buildPath(this.path,this.shape,e),this.path},t.prototype.createPathProxy=function(){this.path=new vr(!1)},t.prototype.hasStroke=function(){var e=this.style,n=e.stroke;return!(n==null||n==="none"||!(e.lineWidth>0))},t.prototype.hasFill=function(){var e=this.style,n=e.fill;return n!=null&&n!=="none"},t.prototype.getBoundingRect=function(){var e=this._rect,n=this.style,i=!e;if(i){var a=!1;this.path||(a=!0,this.createPathProxy());var o=this.path;(a||this.__dirty&li)&&(o.beginPath(),this.buildPath(o,this.shape,!1),this.pathUpdated()),e=o.getBoundingRect()}if(this._rect=e,this.hasStroke()&&this.path&&this.path.len()>0){var s=this._rectStroke||(this._rectStroke=e.clone());if(this.__dirty||i){s.copy(e);var l=n.strokeNoScale?this.getLineScale():1,u=n.lineWidth;if(!this.hasFill()){var f=this.strokeContainThreshold;u=Math.max(u,f??4)}l>1e-10&&(s.width+=u/l,s.height+=u/l,s.x-=u/l/2,s.y-=u/l/2)}return s}return e},t.prototype.contain=function(e,n){var i=this.transformCoordToLocal(e,n),a=this.getBoundingRect(),o=this.style;if(e=i[0],n=i[1],a.contain(e,n)){var s=this.path;if(this.hasStroke()){var l=o.lineWidth,u=o.strokeNoScale?this.getLineScale():1;if(u>1e-10&&(this.hasFill()||(l=Math.max(l,this.strokeContainThreshold)),nb(s,l/u,e,n)))return!0}if(this.hasFill())return rb(s,e,n)}return!1},t.prototype.dirtyShape=function(){this.__dirty|=li,this._rect&&(this._rect=null),this._decalEl&&this._decalEl.dirtyShape(),this.markRedraw()},t.prototype.dirty=function(){this.dirtyStyle(),this.dirtyShape()},t.prototype.animateShape=function(e){return this.animate("shape",e)},t.prototype.updateDuringAnimation=function(e){e==="style"?this.dirtyStyle():e==="shape"?this.dirtyShape():this.markRedraw()},t.prototype.attrKV=function(e,n){e==="shape"?this.setShape(n):r.prototype.attrKV.call(this,e,n)},t.prototype.setShape=function(e,n){var i=this.shape;return i||(i=this.shape={}),typeof e=="string"?i[e]=n:O(i,e),this.dirtyShape(),this},t.prototype.shapeChanged=function(){return!!(this.__dirty&li)},t.prototype.createStyle=function(e){return tl(Mm,e)},t.prototype._innerSaveToNormal=function(e){r.prototype._innerSaveToNormal.call(this,e);var n=this._normalState;e.shape&&!n.shape&&(n.shape=O({},this.shape))},t.prototype._applyStateObj=function(e,n,i,a,o,s){r.prototype._applyStateObj.call(this,e,n,i,a,o,s);var l=!(n&&a),u;if(n&&n.shape?o?a?u=n.shape:(u=O({},i.shape),O(u,n.shape)):(u=O({},a?this.shape:i.shape),O(u,n.shape)):l&&(u=i.shape),u)if(o){this.shape=O({},this.shape);for(var f={},h=St(u),c=0;c<h.length;c++){var v=h[c];typeof u[v]=="object"?this.shape[v]=u[v]:f[v]=u[v]}this._transitionState(e,{shape:f},s)}else this.shape=u,this.dirtyShape()},t.prototype._mergeStates=function(e){for(var n=r.prototype._mergeStates.call(this,e),i,a=0;a<e.length;a++){var o=e[a];o.shape&&(i=i||{},this._mergeStyle(i,o.shape))}return i&&(n.shape=i),n},t.prototype.getAnimationStyleProps=function(){return ib},t.prototype.isZeroArea=function(){return!1},t.extend=function(e){var n=(function(a){z(o,a);function o(s){var l=a.call(this,s)||this;return e.init&&e.init.call(l,s),l}return o.prototype.getDefaultStyle=function(){return st(e.style)},o.prototype.getDefaultShape=function(){return st(e.shape)},o})(t);for(var i in e)typeof e[i]=="function"&&(n.prototype[i]=e[i]);return n},t.initDefaultProps=(function(){var e=t.prototype;e.type="path",e.strokeContainThreshold=5,e.segmentIgnoreThreshold=0,e.subPixelOptimize=!1,e.autoBatch=!1,e.__dirty=fe|ha|li})(),t})(Bi),ab=at({strokeFirst:!0,font:Br,x:0,y:0,textAlign:"left",textBaseline:"top",miterLimit:2},Mm),_s=(function(r){z(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.hasStroke=function(){return hm(this.style)},t.prototype.hasFill=function(){var e=this.style,n=e.fill;return n!=null&&n!=="none"},t.prototype.createStyle=function(e){return tl(ab,e)},t.prototype.setBoundingRect=function(e){this._rect=e},t.prototype.getBoundingRect=function(){return this._rect||(this._rect=cS(this.style)),this._rect},t.initDefaultProps=(function(){var e=t.prototype;e.dirtyRectTolerance=10})(),t})(Bi);_s.prototype.type="tspan";var ob=at({x:0,y:0},Ln),sb={style:at({x:!0,y:!0,width:!0,height:!0,sx:!0,sy:!0,sWidth:!0,sHeight:!0},ol.style)};function lb(r){return!!(r&&typeof r!="string"&&r.width&&r.height)}var Wr=(function(r){z(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.createStyle=function(e){return tl(ob,e)},t.prototype._getSize=function(e){var n=this.style,i=n[e];if(i!=null)return i;var a=lb(n.image)?n.image:this.__image;if(!a)return 0;var o=e==="width"?"height":"width",s=n[o];return s==null?a[e]:a[e]/a[o]*s},t.prototype.getWidth=function(){return this._getSize("width")},t.prototype.getHeight=function(){return this._getSize("height")},t.prototype.getAnimationStyleProps=function(){return sb},t.prototype.getBoundingRect=function(){var e=this.style;return this._rect||(this._rect=new it(e.x||0,e.y||0,this.getWidth(),this.getHeight())),this._rect},t})(Bi);Wr.prototype.type="image";function ub(r,t){var e=t.x,n=t.y,i=t.width,a=t.height,o=t.r,s,l,u,f;i<0&&(e=e+i,i=-i),a<0&&(n=n+a,a=-a),typeof o=="number"?s=l=u=f=o:o instanceof Array?o.length===1?s=l=u=f=o[0]:o.length===2?(s=u=o[0],l=f=o[1]):o.length===3?(s=o[0],l=f=o[1],u=o[2]):(s=o[0],l=o[1],u=o[2],f=o[3]):s=l=u=f=0;var h;s+l>i&&(h=s+l,s*=i/h,l*=i/h),u+f>i&&(h=u+f,u*=i/h,f*=i/h),l+u>a&&(h=l+u,l*=a/h,u*=a/h),s+f>a&&(h=s+f,s*=a/h,f*=a/h),r.moveTo(e+s,n),r.lineTo(e+i-l,n),l!==0&&r.arc(e+i-l,n+l,l,-Math.PI/2,0),r.lineTo(e+i,n+a-u),u!==0&&r.arc(e+i-u,n+a-u,u,0,Math.PI/2),r.lineTo(e+f,n+a),f!==0&&r.arc(e+f,n+a-f,f,Math.PI/2,Math.PI),r.lineTo(e,n+s),s!==0&&r.arc(e+s,n+s,s,Math.PI,Math.PI*1.5)}var ci=Math.round;function Cm(r,t,e){if(t){var n=t.x1,i=t.x2,a=t.y1,o=t.y2;r.x1=n,r.x2=i,r.y1=a,r.y2=o;var s=e&&e.lineWidth;return s&&(ci(n*2)===ci(i*2)&&(r.x1=r.x2=xn(n,s,!0)),ci(a*2)===ci(o*2)&&(r.y1=r.y2=xn(a,s,!0))),r}}function Dm(r,t,e){if(t){var n=t.x,i=t.y,a=t.width,o=t.height;r.x=n,r.y=i,r.width=a,r.height=o;var s=e&&e.lineWidth;return s&&(r.x=xn(n,s,!0),r.y=xn(i,s,!0),r.width=Math.max(xn(n+a,s,!1)-r.x,a===0?0:1),r.height=Math.max(xn(i+o,s,!1)-r.y,o===0?0:1)),r}}function xn(r,t,e){if(!t)return r;var n=ci(r*2);return(n+ci(t))%2===0?n/2:(n+(e?1:-1))/2}var fb=(function(){function r(){this.x=0,this.y=0,this.width=0,this.height=0}return r})(),hb={},Tt=(function(r){z(t,r);function t(e){return r.call(this,e)||this}return t.prototype.getDefaultShape=function(){return new fb},t.prototype.buildPath=function(e,n){var i,a,o,s;if(this.subPixelOptimize){var l=Dm(hb,n,this.style);i=l.x,a=l.y,o=l.width,s=l.height,l.r=n.r,n=l}else i=n.x,a=n.y,o=n.width,s=n.height;n.r?ub(e,n):e.rect(i,a,o,s)},t.prototype.isZeroArea=function(){return!this.shape.width||!this.shape.height},t})(ht);Tt.prototype.type="rect";var lc={fill:"#000"},uc=2,ze={},vb={style:at({fill:!0,stroke:!0,fillOpacity:!0,strokeOpacity:!0,lineWidth:!0,fontSize:!0,lineHeight:!0,width:!0,height:!0,textShadowColor:!0,textShadowBlur:!0,textShadowOffsetX:!0,textShadowOffsetY:!0,backgroundColor:!0,padding:!0,borderColor:!0,borderWidth:!0,borderRadius:!0},ol.style)},oe=(function(r){z(t,r);function t(e){var n=r.call(this)||this;return n.type="text",n._children=[],n._defaultStyle=lc,n.attr(e),n}return t.prototype.childrenRef=function(){return this._children},t.prototype.update=function(){r.prototype.update.call(this),this.styleChanged()&&this._updateSubTexts();for(var e=0;e<this._children.length;e++){var n=this._children[e];n.zlevel=this.zlevel,n.z=this.z,n.z2=this.z2,n.culling=this.culling,n.cursor=this.cursor,n.invisible=this.invisible}},t.prototype.updateTransform=function(){var e=this.innerTransformable;e?(e.updateTransform(),e.transform&&(this.transform=e.transform)):r.prototype.updateTransform.call(this)},t.prototype.getLocalTransform=function(e){var n=this.innerTransformable;return n?n.getLocalTransform(e):r.prototype.getLocalTransform.call(this,e)},t.prototype.getComputedTransform=function(){return this.__hostTarget&&(this.__hostTarget.getComputedTransform(),this.__hostTarget.updateInnerText(!0)),r.prototype.getComputedTransform.call(this)},t.prototype._updateSubTexts=function(){this._childCursor=0,mb(this.style),this.style.rich?this._updateRichTexts():this._updatePlainTexts(),this._children.length=this._childCursor,this.styleUpdated()},t.prototype.addSelfToZr=function(e){r.prototype.addSelfToZr.call(this,e);for(var n=0;n<this._children.length;n++)this._children[n].__zr=e},t.prototype.removeSelfFromZr=function(e){r.prototype.removeSelfFromZr.call(this,e);for(var n=0;n<this._children.length;n++)this._children[n].__zr=null},t.prototype.getBoundingRect=function(){if(this.styleChanged()&&this._updateSubTexts(),!this._rect){for(var e=new it(0,0,0,0),n=this._children,i=[],a=null,o=0;o<n.length;o++){var s=n[o],l=s.getBoundingRect(),u=s.getLocalTransform(i);u?(e.copy(l),e.applyTransform(u),a=a||e.clone(),a.union(e)):(a=a||l.clone(),a.union(l))}this._rect=a||e}return this._rect},t.prototype.setDefaultTextStyle=function(e){this._defaultStyle=e||lc},t.prototype.setTextContent=function(e){},t.prototype._mergeStyle=function(e,n){if(!n)return e;var i=n.rich,a=e.rich||i&&{};return O(e,n),i&&a?(this._mergeRich(a,i),e.rich=a):a&&(e.rich=a),e},t.prototype._mergeRich=function(e,n){for(var i=St(n),a=0;a<i.length;a++){var o=i[a];e[o]=e[o]||{},O(e[o],n[o])}},t.prototype.getAnimationStyleProps=function(){return vb},t.prototype._getOrCreateChild=function(e){var n=this._children[this._childCursor];return(!n||!(n instanceof e))&&(n=new e),this._children[this._childCursor++]=n,n.__zr=this.__zr,n.parent=this,n},t.prototype._updatePlainTexts=function(){var e=this.style,n=e.font||Br,i=e.padding,a=this._defaultStyle,o=e.x||0,s=e.y||0,l=e.align||a.align||"left",u=e.verticalAlign||a.verticalAlign||"top";Vv(ze,a.overflowRect,o,s,l,u),o=ze.baseX,s=ze.baseY;var f=gc(e),h=oS(f,e,ze.outerWidth,ze.outerHeight),c=Ul(e),v=!!e.backgroundColor,d=h.outerHeight,p=h.outerWidth,g=h.lines,m=h.lineHeight;this.isTruncated=!!h.isTruncated;var y=o,_=Dn(s,h.contentHeight,u);if(c||i){var S=Mi(o,p,l),w=Dn(s,d,u);c&&this._renderBackground(e,e,S,w,p,d)}_+=m/2,i&&(y=pc(o,l,i),u==="top"?_+=i[0]:u==="bottom"&&(_-=i[2]));for(var b=0,T=!1,C=!1,x=dc("fill"in e?e.fill:(C=!0,a.fill)),M=cc("stroke"in e?e.stroke:!v&&(!a.autoStroke||C)?(b=uc,T=!0,a.stroke):null),A=e.textShadowBlur>0,P=0;P<g.length;P++){var L=this._getOrCreateChild(_s),I=L.createStyle();L.useStyle(I),I.text=g[P],I.x=y,I.y=_,I.textAlign=l,I.textBaseline="middle",I.opacity=e.opacity,I.strokeFirst=!0,A&&(I.shadowBlur=e.textShadowBlur||0,I.shadowColor=e.textShadowColor||"transparent",I.shadowOffsetX=e.textShadowOffsetX||0,I.shadowOffsetY=e.textShadowOffsetY||0),I.stroke=M,I.fill=x,M&&(I.lineWidth=e.lineWidth||b,I.lineDash=e.lineDash,I.lineDashOffset=e.lineDashOffset||0),I.font=n,hc(I,e),_+=m,L.setBoundingRect(rf(I,h.contentWidth,h.calculatedLineHeight,T?0:null))}},t.prototype._updateRichTexts=function(){var e=this.style,n=this._defaultStyle,i=e.align||n.align,a=e.verticalAlign||n.verticalAlign,o=e.x||0,s=e.y||0;Vv(ze,n.overflowRect,o,s,i,a),o=ze.baseX,s=ze.baseY;var l=gc(e),u=uS(l,e,ze.outerWidth,ze.outerHeight,i),f=u.width,h=u.outerWidth,c=u.outerHeight,v=e.padding;this.isTruncated=!!u.isTruncated;var d=Mi(o,h,i),p=Dn(s,c,a),g=d,m=p;v&&(g+=v[3],m+=v[0]);var y=g+f;Ul(e)&&this._renderBackground(e,e,d,p,h,c);for(var _=!!e.backgroundColor,S=0;S<u.lines.length;S++){for(var w=u.lines[S],b=w.tokens,T=b.length,C=w.lineHeight,x=w.width,M=0,A=g,P=y,L=T-1,I=void 0;M<T&&(I=b[M],!I.align||I.align==="left");)this._placeToken(I,e,C,m,A,"left",_),x-=I.width,A+=I.width,M++;for(;L>=0&&(I=b[L],I.align==="right");)this._placeToken(I,e,C,m,P,"right",_),x-=I.width,P-=I.width,L--;for(A+=(f-(A-g)-(y-P)-x)/2;M<=L;)I=b[M],this._placeToken(I,e,C,m,A+I.width/2,"center",_),A+=I.width,M++;m+=C}},t.prototype._placeToken=function(e,n,i,a,o,s,l){var u=n.rich[e.styleName]||{};u.text=e.text;var f=e.verticalAlign,h=a+i/2;f==="top"?h=a+e.height/2:f==="bottom"&&(h=a+i-e.height/2);var c=!e.isLineHolder&&Ul(u);c&&this._renderBackground(u,n,s==="right"?o-e.width:s==="center"?o-e.width/2:o,h-e.height/2,e.width,e.height);var v=!!u.backgroundColor,d=e.textPadding;d&&(o=pc(o,s,d),h-=e.height/2-d[0]-e.innerHeight/2);var p=this._getOrCreateChild(_s),g=p.createStyle();p.useStyle(g);var m=this._defaultStyle,y=!1,_=0,S=!1,w=dc("fill"in u?u.fill:"fill"in n?n.fill:(y=!0,m.fill)),b=cc("stroke"in u?u.stroke:"stroke"in n?n.stroke:!v&&!l&&(!m.autoStroke||y)?(_=uc,S=!0,m.stroke):null),T=u.textShadowBlur>0||n.textShadowBlur>0;g.text=e.text,g.x=o,g.y=h,T&&(g.shadowBlur=u.textShadowBlur||n.textShadowBlur||0,g.shadowColor=u.textShadowColor||n.textShadowColor||"transparent",g.shadowOffsetX=u.textShadowOffsetX||n.textShadowOffsetX||0,g.shadowOffsetY=u.textShadowOffsetY||n.textShadowOffsetY||0),g.textAlign=s,g.textBaseline="middle",g.font=e.font||Br,g.opacity=_i(u.opacity,n.opacity,1),hc(g,u),b&&(g.lineWidth=_i(u.lineWidth,n.lineWidth,_),g.lineDash=q(u.lineDash,n.lineDash),g.lineDashOffset=n.lineDashOffset||0,g.stroke=b),w&&(g.fill=w),p.setBoundingRect(rf(g,e.contentWidth,e.contentHeight,S?0:null))},t.prototype._renderBackground=function(e,n,i,a,o,s){var l=e.backgroundColor,u=e.borderWidth,f=e.borderColor,h=l&&l.image,c=l&&!h,v=e.borderRadius,d=this,p,g;if(c||e.lineHeight||u&&f){p=this._getOrCreateChild(Tt),p.useStyle(p.createStyle()),p.style.fill=null;var m=p.shape;m.x=i,m.y=a,m.width=o,m.height=s,m.r=v,p.dirtyShape()}if(c){var y=p.style;y.fill=l||null,y.fillOpacity=q(e.fillOpacity,1)}else if(h){g=this._getOrCreateChild(Wr),g.onload=function(){d.dirtyStyle()};var _=g.style;_.image=l.image,_.x=i,_.y=a,_.width=o,_.height=s}if(u&&f){var y=p.style;y.lineWidth=u,y.stroke=f,y.strokeOpacity=q(e.strokeOpacity,1),y.lineDash=e.borderDash,y.lineDashOffset=e.borderDashOffset||0,p.strokeContainThreshold=0,p.hasFill()&&p.hasStroke()&&(y.strokeFirst=!0,y.lineWidth*=2)}var S=(p||g).style;S.shadowBlur=e.shadowBlur||0,S.shadowColor=e.shadowColor||"transparent",S.shadowOffsetX=e.shadowOffsetX||0,S.shadowOffsetY=e.shadowOffsetY||0,S.opacity=_i(e.opacity,n.opacity,1)},t.makeFont=function(e){var n="";return gb(e)&&(n=[e.fontStyle,e.fontWeight,pb(e.fontSize),e.fontFamily||"sans-serif"].join(" ")),n&&We(n)||e.textFont||e.font},t})(Bi),cb={left:!0,right:1,center:1},db={top:1,bottom:1,middle:1},fc=["fontStyle","fontWeight","fontSize","fontFamily"];function pb(r){return typeof r=="string"&&(r.indexOf("px")!==-1||r.indexOf("rem")!==-1||r.indexOf("em")!==-1)?r:isNaN(+r)?mh+"px":r+"px"}function hc(r,t){for(var e=0;e<fc.length;e++){var n=fc[e],i=t[n];i!=null&&(r[n]=i)}}function gb(r){return r.fontSize!=null||r.fontFamily||r.fontWeight}function mb(r){return vc(r),D(r.rich,vc),r}function vc(r){if(r){r.font=oe.makeFont(r);var t=r.align;t==="middle"&&(t="center"),r.align=t==null||cb[t]?t:"left";var e=r.verticalAlign;e==="center"&&(e="middle"),r.verticalAlign=e==null||db[e]?e:"top";var n=r.padding;n&&(r.padding=wh(r.padding))}}function cc(r,t){return r==null||t<=0||r==="transparent"||r==="none"?null:r.image||r.colorStops?"#000":r}function dc(r){return r==null||r==="none"?null:r.image||r.colorStops?"#000":r}function pc(r,t,e){return t==="right"?r-e[1]:t==="center"?r+e[3]/2-e[1]/2:r+e[3]}function gc(r){var t=r.text;return t!=null&&(t+=""),t}function Ul(r){return!!(r.backgroundColor||r.lineHeight||r.borderWidth&&r.borderColor)}var mc=1e-4,Am=20;function yb(r){return r.replace(/^\s+|\s+$/g,"")}var ka=Math.min,he=Math.max,Ye=Math.abs;function Et(r,t,e,n){var i=t[0],a=t[1],o=e[0],s=e[1],l=a-i,u=s-o;if(l===0)return u===0?o:(o+s)/2;if(n)if(l>0){if(r<=i)return o;if(r>=a)return s}else{if(r>=i)return o;if(r<=a)return s}else{if(r===i)return o;if(r===a)return s}return(r-i)/l*u+o}var It=_b;function _b(r,t,e){switch(r){case"center":case"middle":r="50%";break;case"left":case"top":r="0%";break;case"right":case"bottom":r="100%";break}return _f(r,t,e)}function _f(r,t,e){return W(r)?yb(r).match(/%$/)?parseFloat(r)/100*t+(e||0):parseFloat(r):r==null?NaN:+r}function Nt(r,t,e){return t==null&&(t=10),t=Math.min(Math.max(0,t),Am),r=(+r).toFixed(t),e?r:+r}function va(r){return r.sort(function(t,e){return t-e}),r}function or(r){if(r=+r,isNaN(r))return 0;if(r>1e-14){for(var t=1,e=0;e<15;e++,t*=10)if(Math.round(r*t)/t===r)return e}return Sb(r)}function Sb(r){var t=r.toString().toLowerCase(),e=t.indexOf("e"),n=e>0?+t.slice(e+1):0,i=e>0?e:t.length,a=t.indexOf("."),o=a<0?0:i-1-a;return Math.max(0,o-n)}function Lm(r,t){var e=Math.log,n=Math.LN10,i=Math.floor(e(r[1]-r[0])/n),a=Math.round(e(Ye(t[1]-t[0]))/n),o=Math.min(Math.max(-i+a,0),20);return isFinite(o)?o:20}function bb(r,t){var e=Math.max(or(r),or(t)),n=r+t;return e>Am?n:Nt(n,e)}function Im(r){var t=Math.PI*2;return(r%t+t)%t}function Ss(r){return r>-mc&&r<mc}var wb=/^(?:(\d{4})(?:[-\/](\d{1,2})(?:[-\/](\d{1,2})(?:[T ](\d{1,2})(?::(\d{1,2})(?::(\d{1,2})(?:[.,](\d+))?)?)?(Z|[\+\-]\d\d:?\d\d)?)?)?)?)?$/;function Ni(r){if(r instanceof Date)return r;if(W(r)){var t=wb.exec(r);if(!t)return new Date(NaN);if(t[8]){var e=+t[4]||0;return t[8].toUpperCase()!=="Z"&&(e-=+t[8].slice(0,3)),new Date(Date.UTC(+t[1],+(t[2]||1)-1,+t[3]||1,e,+(t[5]||0),+t[6]||0,t[7]?+t[7].substring(0,3):0))}else return new Date(+t[1],+(t[2]||1)-1,+t[3]||1,+t[4]||0,+(t[5]||0),+t[6]||0,t[7]?+t[7].substring(0,3):0)}else if(r==null)return new Date(NaN);return new Date(Math.round(r))}function xb(r){return Math.pow(10,Ah(r))}function Ah(r){if(r===0)return 0;var t=Math.floor(Math.log(r)/Math.LN10);return r/Math.pow(10,t)>=10&&t++,t}function Pm(r,t){var e=Ah(r),n=Math.pow(10,e),i=r/n,a;return i<1.5?a=1:i<2.5?a=2:i<4?a=3:i<7?a=5:a=10,r=a*n,e>=-20?+r.toFixed(e<0?-e:0):r}function Fr(r){var t=parseFloat(r);return t==r&&(t!==0||!W(r)||r.indexOf("x")<=0)?t:NaN}function Tb(r){return!isNaN(Fr(r))}function Rm(){return Math.round(Math.random()*9)}function Em(r,t){return t===0?r:Em(t,r%t)}function yc(r,t){return r==null?t:t==null?r:r*t/Em(r,t)}var Mb="[ECharts] ",Cb=typeof console<"u"&&console.warn&&console.log;function Db(r,t,e){Cb&&console[r](Mb+t)}function km(r,t){Db("error",r)}function ut(r){throw new Error(r)}function _c(r,t,e){return(t-r)*e+r}var Om="series\0",Ab="\0_ec_\0";function Ct(r){return r instanceof Array?r:r==null?[]:[r]}function Sc(r,t,e){if(r){r[t]=r[t]||{},r.emphasis=r.emphasis||{},r.emphasis[t]=r.emphasis[t]||{};for(var n=0,i=e.length;n<i;n++){var a=e[n];!r.emphasis[t].hasOwnProperty(a)&&r[t].hasOwnProperty(a)&&(r.emphasis[t][a]=r[t][a])}}}var bc=["fontStyle","fontWeight","fontSize","fontFamily","rich","tag","color","textBorderColor","textBorderWidth","width","height","lineHeight","align","verticalAlign","baseline","shadowColor","shadowBlur","shadowOffsetX","shadowOffsetY","textShadowColor","textShadowBlur","textShadowOffsetX","textShadowOffsetY","backgroundColor","borderColor","borderWidth","borderRadius","padding"];function ja(r){return X(r)&&!H(r)&&!(r instanceof Date)?r.value:r}function Lb(r){return X(r)&&!(r instanceof Array)}function Ib(r,t,e){var n=e==="normalMerge",i=e==="replaceMerge",a=e==="replaceAll";r=r||[],t=(t||[]).slice();var o=K();D(t,function(l,u){if(!X(l)){t[u]=null;return}});var s=Pb(r,o,e);return(n||i)&&Rb(s,r,o,t),n&&Eb(s,t),n||i?kb(s,t,i):a&&Ob(s,t),Bb(s),s}function Pb(r,t,e){var n=[];if(e==="replaceAll")return n;for(var i=0;i<r.length;i++){var a=r[i];a&&a.id!=null&&t.set(a.id,i),n.push({existing:e==="replaceMerge"||Oa(a)?null:a,newOption:null,keyInfo:null,brandNew:null})}return n}function Rb(r,t,e,n){D(n,function(i,a){if(!(!i||i.id==null)){var o=wa(i.id),s=e.get(o);if(s!=null){var l=r[s];hr(!l.newOption,'Duplicated option on id "'+o+'".'),l.newOption=i,l.existing=t[s],n[a]=null}}})}function Eb(r,t){D(t,function(e,n){if(!(!e||e.name==null))for(var i=0;i<r.length;i++){var a=r[i].existing;if(!r[i].newOption&&a&&(a.id==null||e.id==null)&&!Oa(e)&&!Oa(a)&&Bm("name",a,e)){r[i].newOption=e,t[n]=null;return}}})}function kb(r,t,e){D(t,function(n){if(n){for(var i,a=0;(i=r[a])&&(i.newOption||Oa(i.existing)||i.existing&&n.id!=null&&!Bm("id",n,i.existing));)a++;i?(i.newOption=n,i.brandNew=e):r.push({newOption:n,brandNew:e,existing:null,keyInfo:null}),a++}})}function Ob(r,t){D(t,function(e){r.push({newOption:e,brandNew:!0,existing:null,keyInfo:null})})}function Bb(r){var t=K();D(r,function(e){var n=e.existing;n&&t.set(n.id,e)}),D(r,function(e){var n=e.newOption;hr(!n||n.id==null||!t.get(n.id)||t.get(n.id)===e,"id duplicates: "+(n&&n.id)),n&&n.id!=null&&t.set(n.id,e),!e.keyInfo&&(e.keyInfo={})}),D(r,function(e,n){var i=e.existing,a=e.newOption,o=e.keyInfo;if(X(a)){if(o.name=a.name!=null?wa(a.name):i?i.name:Om+n,i)o.id=wa(i.id);else if(a.id!=null)o.id=wa(a.id);else{var s=0;do o.id="\0"+o.name+"\0"+s++;while(t.get(o.id))}t.set(o.id,e)}})}function Bm(r,t,e){var n=$e(t[r],null),i=$e(e[r],null);return n!=null&&i!=null&&n===i}function wa(r){return $e(r,"")}function $e(r,t){return r==null?t:W(r)?r:mt(r)||Qu(r)?r+"":t}function Nm(r){var t=r.name;return!!(t&&t.indexOf(Om))}function Oa(r){return r&&r.id!=null&&wa(r.id).indexOf(Ab)===0}function Nb(r,t,e){D(r,function(n){var i=n.newOption;X(i)&&(n.keyInfo.mainType=t,n.keyInfo.subType=Fb(t,i,n.existing,e))})}function Fb(r,t,e,n){var i=t.type?t.type:e?e.subType:n.determineSubType(r,t);return i}function kn(r,t){if(t.dataIndexInside!=null)return t.dataIndexInside;if(t.dataIndex!=null)return H(t.dataIndex)?$(t.dataIndex,function(e){return r.indexOfRawIndex(e)}):r.indexOfRawIndex(t.dataIndex);if(t.name!=null)return H(t.name)?$(t.name,function(e){return r.indexOfName(e)}):r.indexOfName(t.name)}function gt(){var r="__ec_inner_"+zb++;return function(t){return t[r]||(t[r]={})}}var zb=Rm();function Yl(r,t,e){var n=Lh(t,e),i=n.mainTypeSpecified,a=n.queryOptionMap,o=n.others,s=o,l=e?e.defaultMainType:null;return!i&&l&&a.set(l,{}),a.each(function(u,f){var h=Ja(r,f,u,{useDefault:l===f,enableAll:e&&e.enableAll!=null?e.enableAll:!0,enableNone:e&&e.enableNone!=null?e.enableNone:!0});s[f+"Models"]=h.models,s[f+"Model"]=h.models[0]}),s}function Lh(r,t){var e;if(W(r)){var n={};n[r+"Index"]=0,e=n}else e=r;var i=K(),a={},o=!1;return D(e,function(s,l){if(l==="dataIndex"||l==="dataIndexInside"){a[l]=s;return}var u=l.match(/^(\w+)(Index|Id|Name)$/)||[],f=u[1],h=(u[2]||"").toLowerCase();if(!(!f||!h||t&&t.includeMainTypes&&ft(t.includeMainTypes,f)<0)){o=o||!!f;var c=i.get(f)||i.set(f,{});c[h]=s}}),{mainTypeSpecified:o,queryOptionMap:i,others:a}}var qt={useDefault:!0,enableAll:!1,enableNone:!1},Hb={useDefault:!1,enableAll:!0,enableNone:!0};function Ja(r,t,e,n){n=n||qt;var i=e.index,a=e.id,o=e.name,s={models:null,specified:i!=null||a!=null||o!=null};if(!s.specified){var l=void 0;return s.models=n.useDefault&&(l=r.getComponent(t))?[l]:[],s}if(i==="none"||i===!1){if(n.enableNone)return s.models=[],s;i=-1}return i==="all"&&(n.enableAll?i=a=o=null:i=-1),s.models=r.queryComponents({mainType:t,index:i,id:a,name:o}),s}function Fm(r,t,e){r.setAttribute?r.setAttribute(t,e):r[t]=e}function Vb(r,t){return r.getAttribute?r.getAttribute(t):r[t]}function Gb(r){return r==="auto"?nt.domSupported?"html":"richText":r||"html"}function zm(r,t,e,n,i){var a=t==null||t==="auto";if(n==null)return n;if(mt(n)){var o=_c(e||0,n,i);return Nt(o,a?Math.max(or(e||0),or(n)):t)}else{if(W(n))return i<1?e:n;for(var s=[],l=e,u=n,f=Math.max(l?l.length:0,u.length),h=0;h<f;++h){var c=r.getDimensionInfo(h);if(c&&c.type==="ordinal")s[h]=(i<1&&l?l:u)[h];else{var v=l&&l[h]?l[h]:0,d=u[h],o=_c(v,d,i);s[h]=Nt(o,a?Math.max(or(v),or(d)):t)}}return s}}var pt=gt(),Wb=function(r,t,e,n){if(n){var i=pt(n);i.dataIndex=e,i.dataType=t,i.seriesIndex=r,i.ssrType="chart",n.type==="group"&&n.traverse(function(a){var o=pt(a);o.seriesIndex=r,o.dataIndex=e,o.dataType=t,o.ssrType="chart"})}},wc=1,xc={},Hm=gt(),Ih=gt(),Ph=0,sl=1,ll=2,Te=["emphasis","blur","select"],bs=["normal","emphasis","blur","select"],Ub=10,Yb=9,In="highlight",jo="downplay",ws="select",Sf="unselect",xs="toggleSelect",Rh="selectchanged";function Zn(r){return r!=null&&r!=="none"}function ul(r,t,e){r.onHoverStateChange&&(r.hoverState||0)!==e&&r.onHoverStateChange(t),r.hoverState=e}function Vm(r){ul(r,"emphasis",ll)}function Gm(r){r.hoverState===ll&&ul(r,"normal",Ph)}function Eh(r){ul(r,"blur",sl)}function Wm(r){r.hoverState===sl&&ul(r,"normal",Ph)}function Zb(r){r.selected=!0}function Xb(r){r.selected=!1}function Tc(r,t,e){t(r,e)}function dr(r,t,e){Tc(r,t,e),r.isGroup&&r.traverse(function(n){Tc(n,t,e)})}function Mc(r,t){switch(t){case"emphasis":r.hoverState=ll;break;case"normal":r.hoverState=Ph;break;case"blur":r.hoverState=sl;break;case"select":r.selected=!0}}function $b(r,t,e,n){for(var i=r.style,a={},o=0;o<t.length;o++){var s=t[o],l=i[s];a[s]=l??(n&&n[s])}for(var o=0;o<r.animators.length;o++){var u=r.animators[o];u.__fromStateTransition&&u.__fromStateTransition.indexOf(e)<0&&u.targetName==="style"&&u.saveTo(a,t)}return a}function qb(r,t,e,n){var i=e&&ft(e,"select")>=0,a=!1;if(r instanceof ht){var o=Hm(r),s=i&&o.selectFill||o.normalFill,l=i&&o.selectStroke||o.normalStroke;if(Zn(s)||Zn(l)){n=n||{};var u=n.style||{};u.fill==="inherit"?(a=!0,n=O({},n),u=O({},u),u.fill=s):!Zn(u.fill)&&Zn(s)?(a=!0,n=O({},n),u=O({},u),u.fill=Jv(s)):!Zn(u.stroke)&&Zn(l)&&(a||(n=O({},n),u=O({},u)),u.stroke=Jv(l)),n.style=u}}if(n&&n.z2==null){a||(n=O({},n));var f=r.z2EmphasisLift;n.z2=r.z2+(f??Ub)}return n}function Kb(r,t,e){if(e&&e.z2==null){e=O({},e);var n=r.z2SelectLift;e.z2=r.z2+(n??Yb)}return e}function Qb(r,t,e){var n=ft(r.currentStates,t)>=0,i=r.style.opacity,a=n?null:$b(r,["opacity"],t,{opacity:1});e=e||{};var o=e.style||{};return o.opacity==null&&(e=O({},e),o=O({opacity:n?i:a.opacity*.1},o),e.style=o),e}function Zl(r,t){var e=this.states[r];if(this.style){if(r==="emphasis")return qb(this,r,t,e);if(r==="blur")return Qb(this,r,e);if(r==="select")return Kb(this,r,e)}return e}function jb(r){r.stateProxy=Zl;var t=r.getTextContent(),e=r.getTextGuideLine();t&&(t.stateProxy=Zl),e&&(e.stateProxy=Zl)}function Cc(r,t){!Xm(r,t)&&!r.__highByOuter&&dr(r,Vm)}function Dc(r,t){!Xm(r,t)&&!r.__highByOuter&&dr(r,Gm)}function Ts(r,t){r.__highByOuter|=1<<(t||0),dr(r,Vm)}function Ms(r,t){!(r.__highByOuter&=~(1<<(t||0)))&&dr(r,Gm)}function Jb(r){dr(r,Eh)}function Um(r){dr(r,Wm)}function Ym(r){dr(r,Zb)}function Zm(r){dr(r,Xb)}function Xm(r,t){return r.__highDownSilentOnTouch&&t.zrByTouch}function $m(r){var t=r.getModel(),e=[],n=[];t.eachComponent(function(i,a){var o=Ih(a),s=i==="series",l=s?r.getViewOfSeriesModel(a):r.getViewOfComponentModel(a);!s&&n.push(l),o.isBlured&&(l.group.traverse(function(u){Wm(u)}),s&&e.push(a)),o.isBlured=!1}),D(n,function(i){i&&i.toggleBlurSeries&&i.toggleBlurSeries(e,!1,t)})}function bf(r,t,e,n){var i=n.getModel();e=e||"coordinateSystem";function a(u,f){for(var h=0;h<f.length;h++){var c=u.getItemGraphicEl(f[h]);c&&Um(c)}}if(r!=null&&!(!t||t==="none")){var o=i.getSeriesByIndex(r),s=o.coordinateSystem;s&&s.master&&(s=s.master);var l=[];i.eachSeries(function(u){var f=o===u,h=u.coordinateSystem;h&&h.master&&(h=h.master);var c=h&&s?h===s:f;if(!(e==="series"&&!f||e==="coordinateSystem"&&!c||t==="series"&&f)){var v=n.getViewOfSeriesModel(u);if(v.group.traverse(function(g){g.__highByOuter&&f&&t==="self"||Eh(g)}),Qt(t))a(u.getData(),t);else if(X(t))for(var d=St(t),p=0;p<d.length;p++)a(u.getData(d[p]),t[d[p]]);l.push(u),Ih(u).isBlured=!0}}),i.eachComponent(function(u,f){if(u!=="series"){var h=n.getViewOfComponentModel(f);h&&h.toggleBlurSeries&&h.toggleBlurSeries(l,!0,i)}})}}function wf(r,t,e){if(!(r==null||t==null)){var n=e.getModel().getComponent(r,t);if(n){Ih(n).isBlured=!0;var i=e.getViewOfComponentModel(n);!i||!i.focusBlurEnabled||i.group.traverse(function(a){Eh(a)})}}}function tw(r,t,e){var n=r.seriesIndex,i=r.getData(t.dataType);if(i){var a=kn(i,t);a=(H(a)?a[0]:a)||0;var o=i.getItemGraphicEl(a);if(!o)for(var s=i.count(),l=0;!o&&l<s;)o=i.getItemGraphicEl(l++);if(o){var u=pt(o);bf(n,u.focus,u.blurScope,e)}else{var f=r.get(["emphasis","focus"]),h=r.get(["emphasis","blurScope"]);f!=null&&bf(n,f,h,e)}}}function kh(r,t,e,n){var i={focusSelf:!1,dispatchers:null};if(r==null||r==="series"||t==null||e==null)return i;var a=n.getModel().getComponent(r,t);if(!a)return i;var o=n.getViewOfComponentModel(a);if(!o||!o.findHighDownDispatchers)return i;for(var s=o.findHighDownDispatchers(e),l,u=0;u<s.length;u++)if(pt(s[u]).focus==="self"){l=!0;break}return{focusSelf:l,dispatchers:s}}function ew(r,t,e){var n=pt(r),i=kh(n.componentMainType,n.componentIndex,n.componentHighDownName,e),a=i.dispatchers,o=i.focusSelf;a?(o&&wf(n.componentMainType,n.componentIndex,e),D(a,function(s){return Cc(s,t)})):(bf(n.seriesIndex,n.focus,n.blurScope,e),n.focus==="self"&&wf(n.componentMainType,n.componentIndex,e),Cc(r,t))}function rw(r,t,e){$m(e);var n=pt(r),i=kh(n.componentMainType,n.componentIndex,n.componentHighDownName,e).dispatchers;i?D(i,function(a){return Dc(a,t)}):Dc(r,t)}function nw(r,t,e){if(Mf(t)){var n=t.dataType,i=r.getData(n),a=kn(i,t);H(a)||(a=[a]),r[t.type===xs?"toggleSelect":t.type===ws?"select":"unselect"](a,n)}}function Ac(r){var t=r.getAllData();D(t,function(e){var n=e.data,i=e.type;n.eachItemGraphicEl(function(a,o){r.isSelected(o,i)?Ym(a):Zm(a)})})}function iw(r){var t=[];return r.eachSeries(function(e){var n=e.getAllData();D(n,function(i){i.data;var a=i.type,o=e.getSelectedDataIndices();if(o.length>0){var s={dataIndex:o,seriesIndex:e.seriesIndex};a!=null&&(s.dataType=a),t.push(s)}})}),t}function qm(r,t,e){Km(r,!0),dr(r,jb),ow(r,t,e)}function aw(r){Km(r,!1)}function xf(r,t,e,n){n?aw(r):qm(r,t,e)}function ow(r,t,e){var n=pt(r);t!=null?(n.focus=t,n.blurScope=e):n.focus&&(n.focus=null)}var Lc=["emphasis","blur","select"],sw={itemStyle:"getItemStyle",lineStyle:"getLineStyle",areaStyle:"getAreaStyle"};function Ic(r,t,e,n){e=e||"itemStyle";for(var i=0;i<Lc.length;i++){var a=Lc[i],o=t.getModel([a,e]),s=r.ensureState(a);s.style=o[sw[e]]()}}function Km(r,t){var e=t===!1,n=r;r.highDownSilentOnTouch&&(n.__highDownSilentOnTouch=r.highDownSilentOnTouch),(!e||n.__highDownDispatcher)&&(n.__highByOuter=n.__highByOuter||0,n.__highDownDispatcher=!e)}function Tf(r){return!!(r&&r.__highDownDispatcher)}function lw(r){var t=xc[r];return t==null&&wc<=32&&(t=xc[r]=wc++),t}function Mf(r){var t=r.type;return t===ws||t===Sf||t===xs}function Pc(r){var t=r.type;return t===In||t===jo}function uw(r){var t=Hm(r);t.normalFill=r.style.fill,t.normalStroke=r.style.stroke;var e=r.states.select||{};t.selectFill=e.style&&e.style.fill||null,t.selectStroke=e.style&&e.style.stroke||null}var Xn=vr.CMD,fw=[[],[],[]],Rc=Math.sqrt,hw=Math.atan2;function Qm(r,t){if(t){var e=r.data,n=r.len(),i,a,o,s,l,u,f=Xn.M,h=Xn.C,c=Xn.L,v=Xn.R,d=Xn.A,p=Xn.Q;for(o=0,s=0;o<n;){switch(i=e[o++],s=o,a=0,i){case f:a=1;break;case c:a=1;break;case h:a=3;break;case p:a=2;break;case d:var g=t[4],m=t[5],y=Rc(t[0]*t[0]+t[1]*t[1]),_=Rc(t[2]*t[2]+t[3]*t[3]),S=hw(-t[1]/_,t[0]/y);e[o]*=y,e[o++]+=g,e[o]*=_,e[o++]+=m,e[o++]*=y,e[o++]*=_,e[o++]+=S,e[o++]+=S,o+=2,s=o;break;case v:u[0]=e[o++],u[1]=e[o++],xe(u,u,t),e[s++]=u[0],e[s++]=u[1],u[0]+=e[o++],u[1]+=e[o++],xe(u,u,t),e[s++]=u[0],e[s++]=u[1]}for(l=0;l<a;l++){var w=fw[l];w[0]=e[o++],w[1]=e[o++],xe(w,w,t),e[s++]=w[0],e[s++]=w[1]}}r.increaseVersion()}}var Xl=Math.sqrt,_o=Math.sin,So=Math.cos,Gi=Math.PI;function Ec(r){return Math.sqrt(r[0]*r[0]+r[1]*r[1])}function Cf(r,t){return(r[0]*t[0]+r[1]*t[1])/(Ec(r)*Ec(t))}function kc(r,t){return(r[0]*t[1]<r[1]*t[0]?-1:1)*Math.acos(Cf(r,t))}function Oc(r,t,e,n,i,a,o,s,l,u,f){var h=l*(Gi/180),c=So(h)*(r-e)/2+_o(h)*(t-n)/2,v=-1*_o(h)*(r-e)/2+So(h)*(t-n)/2,d=c*c/(o*o)+v*v/(s*s);d>1&&(o*=Xl(d),s*=Xl(d));var p=(i===a?-1:1)*Xl((o*o*(s*s)-o*o*(v*v)-s*s*(c*c))/(o*o*(v*v)+s*s*(c*c)))||0,g=p*o*v/s,m=p*-s*c/o,y=(r+e)/2+So(h)*g-_o(h)*m,_=(t+n)/2+_o(h)*g+So(h)*m,S=kc([1,0],[(c-g)/o,(v-m)/s]),w=[(c-g)/o,(v-m)/s],b=[(-1*c-g)/o,(-1*v-m)/s],T=kc(w,b);if(Cf(w,b)<=-1&&(T=Gi),Cf(w,b)>=1&&(T=0),T<0){var C=Math.round(T/Gi*1e6)/1e6;T=Gi*2+C%2*Gi}f.addData(u,y,_,o,s,S,T,h,a)}var vw=/([mlvhzcqtsa])([^mlvhzcqtsa]*)/ig,cw=/-?([0-9]*\.)?[0-9]+([eE]-?[0-9]+)?/g;function dw(r){var t=new vr;if(!r)return t;var e=0,n=0,i=e,a=n,o,s=vr.CMD,l=r.match(vw);if(!l)return t;for(var u=0;u<l.length;u++){for(var f=l[u],h=f.charAt(0),c=void 0,v=f.match(cw)||[],d=v.length,p=0;p<d;p++)v[p]=parseFloat(v[p]);for(var g=0;g<d;){var m=void 0,y=void 0,_=void 0,S=void 0,w=void 0,b=void 0,T=void 0,C=e,x=n,M=void 0,A=void 0;switch(h){case"l":e+=v[g++],n+=v[g++],c=s.L,t.addData(c,e,n);break;case"L":e=v[g++],n=v[g++],c=s.L,t.addData(c,e,n);break;case"m":e+=v[g++],n+=v[g++],c=s.M,t.addData(c,e,n),i=e,a=n,h="l";break;case"M":e=v[g++],n=v[g++],c=s.M,t.addData(c,e,n),i=e,a=n,h="L";break;case"h":e+=v[g++],c=s.L,t.addData(c,e,n);break;case"H":e=v[g++],c=s.L,t.addData(c,e,n);break;case"v":n+=v[g++],c=s.L,t.addData(c,e,n);break;case"V":n=v[g++],c=s.L,t.addData(c,e,n);break;case"C":c=s.C,t.addData(c,v[g++],v[g++],v[g++],v[g++],v[g++],v[g++]),e=v[g-2],n=v[g-1];break;case"c":c=s.C,t.addData(c,v[g++]+e,v[g++]+n,v[g++]+e,v[g++]+n,v[g++]+e,v[g++]+n),e+=v[g-2],n+=v[g-1];break;case"S":m=e,y=n,M=t.len(),A=t.data,o===s.C&&(m+=e-A[M-4],y+=n-A[M-3]),c=s.C,C=v[g++],x=v[g++],e=v[g++],n=v[g++],t.addData(c,m,y,C,x,e,n);break;case"s":m=e,y=n,M=t.len(),A=t.data,o===s.C&&(m+=e-A[M-4],y+=n-A[M-3]),c=s.C,C=e+v[g++],x=n+v[g++],e+=v[g++],n+=v[g++],t.addData(c,m,y,C,x,e,n);break;case"Q":C=v[g++],x=v[g++],e=v[g++],n=v[g++],c=s.Q,t.addData(c,C,x,e,n);break;case"q":C=v[g++]+e,x=v[g++]+n,e+=v[g++],n+=v[g++],c=s.Q,t.addData(c,C,x,e,n);break;case"T":m=e,y=n,M=t.len(),A=t.data,o===s.Q&&(m+=e-A[M-4],y+=n-A[M-3]),e=v[g++],n=v[g++],c=s.Q,t.addData(c,m,y,e,n);break;case"t":m=e,y=n,M=t.len(),A=t.data,o===s.Q&&(m+=e-A[M-4],y+=n-A[M-3]),e+=v[g++],n+=v[g++],c=s.Q,t.addData(c,m,y,e,n);break;case"A":_=v[g++],S=v[g++],w=v[g++],b=v[g++],T=v[g++],C=e,x=n,e=v[g++],n=v[g++],c=s.A,Oc(C,x,e,n,b,T,_,S,w,c,t);break;case"a":_=v[g++],S=v[g++],w=v[g++],b=v[g++],T=v[g++],C=e,x=n,e+=v[g++],n+=v[g++],c=s.A,Oc(C,x,e,n,b,T,_,S,w,c,t);break}}(h==="z"||h==="Z")&&(c=s.Z,t.addData(c),e=i,n=a),o=c}return t.toStatic(),t}var jm=(function(r){z(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.applyTransform=function(e){},t})(ht);function Jm(r){return r.setData!=null}function ty(r,t){var e=dw(r),n=O({},t);return n.buildPath=function(i){var a=Jm(i);if(a&&i.canSave()){i.appendPath(e);var o=i.getContext();o&&i.rebuildPath(o,1)}else{var o=a?i.getContext():i;o&&e.rebuildPath(o,1)}},n.applyTransform=function(i){Qm(e,i),this.dirtyShape()},n}function pw(r,t){return new jm(ty(r,t))}function gw(r,t){var e=ty(r,t),n=(function(i){z(a,i);function a(o){var s=i.call(this,o)||this;return s.applyTransform=e.applyTransform,s.buildPath=e.buildPath,s}return a})(jm);return n}function mw(r,t){for(var e=[],n=r.length,i=0;i<n;i++){var a=r[i];e.push(a.getUpdatedPathProxy(!0))}var o=new ht(t);return o.createPathProxy(),o.buildPath=function(s){if(Jm(s)){s.appendPath(e);var l=s.getContext();l&&s.rebuildPath(l,1)}},o}function Oh(r,t){t=t||{};var e=new ht;return r.shape&&e.setShape(r.shape),e.setStyle(r.style),t.bakeTransform?Qm(e.path,r.getComputedTransform()):t.toLocal?e.setLocalTransform(r.getComputedTransform()):e.copyTransform(r),e.buildPath=r.buildPath,e.applyTransform=e.applyTransform,e.z=r.z,e.z2=r.z2,e.zlevel=r.zlevel,e}var Ft=(function(r){z(t,r);function t(e){var n=r.call(this)||this;return n.isGroup=!0,n._children=[],n.attr(e),n}return t.prototype.childrenRef=function(){return this._children},t.prototype.children=function(){return this._children.slice()},t.prototype.childAt=function(e){return this._children[e]},t.prototype.childOfName=function(e){for(var n=this._children,i=0;i<n.length;i++)if(n[i].name===e)return n[i]},t.prototype.childCount=function(){return this._children.length},t.prototype.add=function(e){return e&&e!==this&&e.parent!==this&&(this._children.push(e),this._doAdd(e)),this},t.prototype.addBefore=function(e,n){if(e&&e!==this&&e.parent!==this&&n&&n.parent===this){var i=this._children,a=i.indexOf(n);a>=0&&(i.splice(a,0,e),this._doAdd(e))}return this},t.prototype.replace=function(e,n){var i=ft(this._children,e);return i>=0&&this.replaceAt(n,i),this},t.prototype.replaceAt=function(e,n){var i=this._children,a=i[n];if(e&&e!==this&&e.parent!==this&&e!==a){i[n]=e,a.parent=null;var o=this.__zr;o&&a.removeSelfFromZr(o),this._doAdd(e)}return this},t.prototype._doAdd=function(e){e.parent&&e.parent.remove(e),e.parent=this;var n=this.__zr;n&&n!==e.__zr&&e.addSelfToZr(n),n&&n.refresh()},t.prototype.remove=function(e){var n=this.__zr,i=this._children,a=ft(i,e);return a<0?this:(i.splice(a,1),e.parent=null,n&&e.removeSelfFromZr(n),n&&n.refresh(),this)},t.prototype.removeAll=function(){for(var e=this._children,n=this.__zr,i=0;i<e.length;i++){var a=e[i];n&&a.removeSelfFromZr(n),a.parent=null}return e.length=0,this},t.prototype.eachChild=function(e,n){for(var i=this._children,a=0;a<i.length;a++){var o=i[a];e.call(n,o,a)}return this},t.prototype.traverse=function(e,n){for(var i=0;i<this._children.length;i++){var a=this._children[i],o=e.call(n,a);a.isGroup&&!o&&a.traverse(e,n)}return this},t.prototype.addSelfToZr=function(e){r.prototype.addSelfToZr.call(this,e);for(var n=0;n<this._children.length;n++){var i=this._children[n];i.addSelfToZr(e)}},t.prototype.removeSelfFromZr=function(e){r.prototype.removeSelfFromZr.call(this,e);for(var n=0;n<this._children.length;n++){var i=this._children[n];i.removeSelfFromZr(e)}},t.prototype.getBoundingRect=function(e){for(var n=new it(0,0,0,0),i=e||this._children,a=[],o=null,s=0;s<i.length;s++){var l=i[s];if(!(l.ignore||l.invisible)){var u=l.getBoundingRect(),f=l.getLocalTransform(a);f?(it.applyTransform(n,u,f),o=o||n.clone(),o.union(n)):(o=o||u.clone(),o.union(u))}}return o||n},t})(al);Ft.prototype.type="group";var yw=(function(){function r(){this.cx=0,this.cy=0,this.r=0}return r})(),fl=(function(r){z(t,r);function t(e){return r.call(this,e)||this}return t.prototype.getDefaultShape=function(){return new yw},t.prototype.buildPath=function(e,n){e.moveTo(n.cx+n.r,n.cy),e.arc(n.cx,n.cy,n.r,0,Math.PI*2)},t})(ht);fl.prototype.type="circle";var _w=(function(){function r(){this.cx=0,this.cy=0,this.rx=0,this.ry=0}return r})(),Bh=(function(r){z(t,r);function t(e){return r.call(this,e)||this}return t.prototype.getDefaultShape=function(){return new _w},t.prototype.buildPath=function(e,n){var i=.5522848,a=n.cx,o=n.cy,s=n.rx,l=n.ry,u=s*i,f=l*i;e.moveTo(a-s,o),e.bezierCurveTo(a-s,o-f,a-u,o-l,a,o-l),e.bezierCurveTo(a+u,o-l,a+s,o-f,a+s,o),e.bezierCurveTo(a+s,o+f,a+u,o+l,a,o+l),e.bezierCurveTo(a-u,o+l,a-s,o+f,a-s,o),e.closePath()},t})(ht);Bh.prototype.type="ellipse";var ey=Math.PI,$l=ey*2,sn=Math.sin,$n=Math.cos,Sw=Math.acos,Gt=Math.atan2,Bc=Math.abs,xa=Math.sqrt,ca=Math.max,He=Math.min,Ae=1e-4;function bw(r,t,e,n,i,a,o,s){var l=e-r,u=n-t,f=o-i,h=s-a,c=h*l-f*u;if(!(c*c<Ae))return c=(f*(t-a)-h*(r-i))/c,[r+c*l,t+c*u]}function bo(r,t,e,n,i,a,o){var s=r-e,l=t-n,u=(o?a:-a)/xa(s*s+l*l),f=u*l,h=-u*s,c=r+f,v=t+h,d=e+f,p=n+h,g=(c+d)/2,m=(v+p)/2,y=d-c,_=p-v,S=y*y+_*_,w=i-a,b=c*p-d*v,T=(_<0?-1:1)*xa(ca(0,w*w*S-b*b)),C=(b*_-y*T)/S,x=(-b*y-_*T)/S,M=(b*_+y*T)/S,A=(-b*y+_*T)/S,P=C-g,L=x-m,I=M-g,R=A-m;return P*P+L*L>I*I+R*R&&(C=M,x=A),{cx:C,cy:x,x0:-f,y0:-h,x1:C*(i/w-1),y1:x*(i/w-1)}}function ww(r){var t;if(H(r)){var e=r.length;if(!e)return r;e===1?t=[r[0],r[0],0,0]:e===2?t=[r[0],r[0],r[1],r[1]]:e===3?t=r.concat(r[2]):t=r}else t=[r,r,r,r];return t}function xw(r,t){var e,n=ca(t.r,0),i=ca(t.r0||0,0),a=n>0,o=i>0;if(!(!a&&!o)){if(a||(n=i,i=0),i>n){var s=n;n=i,i=s}var l=t.startAngle,u=t.endAngle;if(!(isNaN(l)||isNaN(u))){var f=t.cx,h=t.cy,c=!!t.clockwise,v=Bc(u-l),d=v>$l&&v%$l;if(d>Ae&&(v=d),!(n>Ae))r.moveTo(f,h);else if(v>$l-Ae)r.moveTo(f+n*$n(l),h+n*sn(l)),r.arc(f,h,n,l,u,!c),i>Ae&&(r.moveTo(f+i*$n(u),h+i*sn(u)),r.arc(f,h,i,u,l,c));else{var p=void 0,g=void 0,m=void 0,y=void 0,_=void 0,S=void 0,w=void 0,b=void 0,T=void 0,C=void 0,x=void 0,M=void 0,A=void 0,P=void 0,L=void 0,I=void 0,R=n*$n(l),E=n*sn(l),V=i*$n(u),B=i*sn(u),k=v>Ae;if(k){var G=t.cornerRadius;G&&(e=ww(G),p=e[0],g=e[1],m=e[2],y=e[3]);var U=Bc(n-i)/2;if(_=He(U,m),S=He(U,y),w=He(U,p),b=He(U,g),x=T=ca(_,S),M=C=ca(w,b),(T>Ae||C>Ae)&&(A=n*$n(u),P=n*sn(u),L=i*$n(l),I=i*sn(l),v<ey)){var Z=bw(R,E,L,I,A,P,V,B);if(Z){var j=R-Z[0],ot=E-Z[1],yt=A-Z[0],Ht=P-Z[1],de=1/sn(Sw((j*yt+ot*Ht)/(xa(j*j+ot*ot)*xa(yt*yt+Ht*Ht)))/2),pe=xa(Z[0]*Z[0]+Z[1]*Z[1]);x=He(T,(n-pe)/(de+1)),M=He(C,(i-pe)/(de-1))}}}if(!k)r.moveTo(f+R,h+E);else if(x>Ae){var Vt=He(m,x),Dt=He(y,x),rt=bo(L,I,R,E,n,Vt,c),lt=bo(A,P,V,B,n,Dt,c);r.moveTo(f+rt.cx+rt.x0,h+rt.cy+rt.y0),x<T&&Vt===Dt?r.arc(f+rt.cx,h+rt.cy,x,Gt(rt.y0,rt.x0),Gt(lt.y0,lt.x0),!c):(Vt>0&&r.arc(f+rt.cx,h+rt.cy,Vt,Gt(rt.y0,rt.x0),Gt(rt.y1,rt.x1),!c),r.arc(f,h,n,Gt(rt.cy+rt.y1,rt.cx+rt.x1),Gt(lt.cy+lt.y1,lt.cx+lt.x1),!c),Dt>0&&r.arc(f+lt.cx,h+lt.cy,Dt,Gt(lt.y1,lt.x1),Gt(lt.y0,lt.x0),!c))}else r.moveTo(f+R,h+E),r.arc(f,h,n,l,u,!c);if(!(i>Ae)||!k)r.lineTo(f+V,h+B);else if(M>Ae){var Vt=He(p,M),Dt=He(g,M),rt=bo(V,B,A,P,i,-Dt,c),lt=bo(R,E,L,I,i,-Vt,c);r.lineTo(f+rt.cx+rt.x0,h+rt.cy+rt.y0),M<C&&Vt===Dt?r.arc(f+rt.cx,h+rt.cy,M,Gt(rt.y0,rt.x0),Gt(lt.y0,lt.x0),!c):(Dt>0&&r.arc(f+rt.cx,h+rt.cy,Dt,Gt(rt.y0,rt.x0),Gt(rt.y1,rt.x1),!c),r.arc(f,h,i,Gt(rt.cy+rt.y1,rt.cx+rt.x1),Gt(lt.cy+lt.y1,lt.cx+lt.x1),c),Vt>0&&r.arc(f+lt.cx,h+lt.cy,Vt,Gt(lt.y1,lt.x1),Gt(lt.y0,lt.x0),!c))}else r.lineTo(f+V,h+B),r.arc(f,h,i,u,l,c)}r.closePath()}}}var Tw=(function(){function r(){this.cx=0,this.cy=0,this.r0=0,this.r=0,this.startAngle=0,this.endAngle=Math.PI*2,this.clockwise=!0,this.cornerRadius=0}return r})(),Ci=(function(r){z(t,r);function t(e){return r.call(this,e)||this}return t.prototype.getDefaultShape=function(){return new Tw},t.prototype.buildPath=function(e,n){xw(e,n)},t.prototype.isZeroArea=function(){return this.shape.startAngle===this.shape.endAngle||this.shape.r===this.shape.r0},t})(ht);Ci.prototype.type="sector";var Mw=(function(){function r(){this.cx=0,this.cy=0,this.r=0,this.r0=0}return r})(),Nh=(function(r){z(t,r);function t(e){return r.call(this,e)||this}return t.prototype.getDefaultShape=function(){return new Mw},t.prototype.buildPath=function(e,n){var i=n.cx,a=n.cy,o=Math.PI*2;e.moveTo(i+n.r,a),e.arc(i,a,n.r,0,o,!1),e.moveTo(i+n.r0,a),e.arc(i,a,n.r0,0,o,!0)},t})(ht);Nh.prototype.type="ring";function Cw(r,t,e,n){var i=[],a=[],o=[],s=[],l,u,f,h;if(n){f=[1/0,1/0],h=[-1/0,-1/0];for(var c=0,v=r.length;c<v;c++)hi(f,f,r[c]),vi(h,h,r[c]);hi(f,f,n[0]),vi(h,h,n[1])}for(var c=0,v=r.length;c<v;c++){var d=r[c];if(e)l=r[c?c-1:v-1],u=r[(c+1)%v];else if(c===0||c===v-1){i.push(dS(r[c]));continue}else l=r[c-1],u=r[c+1];pS(a,u,l),Ml(a,a,t);var p=nf(d,l),g=nf(d,u),m=p+g;m!==0&&(p/=m,g/=m),Ml(o,a,-p),Ml(s,a,g);var y=Uv([],d,o),_=Uv([],d,s);n&&(vi(y,y,f),hi(y,y,h),vi(_,_,f),hi(_,_,h)),i.push(y),i.push(_)}return e&&i.push(i.shift()),i}function ry(r,t,e){var n=t.smooth,i=t.points;if(i&&i.length>=2){if(n){var a=Cw(i,n,e,t.smoothConstraint);r.moveTo(i[0][0],i[0][1]);for(var o=i.length,s=0;s<(e?o:o-1);s++){var l=a[s*2],u=a[s*2+1],f=i[(s+1)%o];r.bezierCurveTo(l[0],l[1],u[0],u[1],f[0],f[1])}}else{r.moveTo(i[0][0],i[0][1]);for(var s=1,h=i.length;s<h;s++)r.lineTo(i[s][0],i[s][1])}e&&r.closePath()}}var Dw=(function(){function r(){this.points=null,this.smooth=0,this.smoothConstraint=null}return r})(),to=(function(r){z(t,r);function t(e){return r.call(this,e)||this}return t.prototype.getDefaultShape=function(){return new Dw},t.prototype.buildPath=function(e,n){ry(e,n,!0)},t})(ht);to.prototype.type="polygon";var Aw=(function(){function r(){this.points=null,this.percent=1,this.smooth=0,this.smoothConstraint=null}return r})(),eo=(function(r){z(t,r);function t(e){return r.call(this,e)||this}return t.prototype.getDefaultStyle=function(){return{stroke:"#000",fill:null}},t.prototype.getDefaultShape=function(){return new Aw},t.prototype.buildPath=function(e,n){ry(e,n,!1)},t})(ht);eo.prototype.type="polyline";var Lw={},Iw=(function(){function r(){this.x1=0,this.y1=0,this.x2=0,this.y2=0,this.percent=1}return r})(),zr=(function(r){z(t,r);function t(e){return r.call(this,e)||this}return t.prototype.getDefaultStyle=function(){return{stroke:"#000",fill:null}},t.prototype.getDefaultShape=function(){return new Iw},t.prototype.buildPath=function(e,n){var i,a,o,s;if(this.subPixelOptimize){var l=Cm(Lw,n,this.style);i=l.x1,a=l.y1,o=l.x2,s=l.y2}else i=n.x1,a=n.y1,o=n.x2,s=n.y2;var u=n.percent;u!==0&&(e.moveTo(i,a),u<1&&(o=i*(1-u)+o*u,s=a*(1-u)+s*u),e.lineTo(o,s))},t.prototype.pointAt=function(e){var n=this.shape;return[n.x1*(1-e)+n.x2*e,n.y1*(1-e)+n.y2*e]},t})(ht);zr.prototype.type="line";var jt=[],Pw=(function(){function r(){this.x1=0,this.y1=0,this.x2=0,this.y2=0,this.cpx1=0,this.cpy1=0,this.percent=1}return r})();function Nc(r,t,e){var n=r.cpx2,i=r.cpy2;return n!=null||i!=null?[(e?$v:Lt)(r.x1,r.cpx1,r.cpx2,r.x2,t),(e?$v:Lt)(r.y1,r.cpy1,r.cpy2,r.y2,t)]:[(e?qv:Ut)(r.x1,r.cpx1,r.x2,t),(e?qv:Ut)(r.y1,r.cpy1,r.y2,t)]}var Fh=(function(r){z(t,r);function t(e){return r.call(this,e)||this}return t.prototype.getDefaultStyle=function(){return{stroke:"#000",fill:null}},t.prototype.getDefaultShape=function(){return new Pw},t.prototype.buildPath=function(e,n){var i=n.x1,a=n.y1,o=n.x2,s=n.y2,l=n.cpx1,u=n.cpy1,f=n.cpx2,h=n.cpy2,c=n.percent;c!==0&&(e.moveTo(i,a),f==null||h==null?(c<1&&(gs(i,l,o,c,jt),l=jt[1],o=jt[2],gs(a,u,s,c,jt),u=jt[1],s=jt[2]),e.quadraticCurveTo(l,u,o,s)):(c<1&&(Nr(i,l,f,o,c,jt),l=jt[1],f=jt[2],o=jt[3],Nr(a,u,h,s,c,jt),u=jt[1],h=jt[2],s=jt[3]),e.bezierCurveTo(l,u,f,h,o,s)))},t.prototype.pointAt=function(e){return Nc(this.shape,e,!1)},t.prototype.tangentAt=function(e){var n=Nc(this.shape,e,!0);return yS(n,n)},t})(ht);Fh.prototype.type="bezier-curve";var Rw=(function(){function r(){this.cx=0,this.cy=0,this.r=0,this.startAngle=0,this.endAngle=Math.PI*2,this.clockwise=!0}return r})(),hl=(function(r){z(t,r);function t(e){return r.call(this,e)||this}return t.prototype.getDefaultStyle=function(){return{stroke:"#000",fill:null}},t.prototype.getDefaultShape=function(){return new Rw},t.prototype.buildPath=function(e,n){var i=n.cx,a=n.cy,o=Math.max(n.r,0),s=n.startAngle,l=n.endAngle,u=n.clockwise,f=Math.cos(s),h=Math.sin(s);e.moveTo(f*o+i,h*o+a),e.arc(i,a,o,s,l,!u)},t})(ht);hl.prototype.type="arc";var Ew=(function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type="compound",e}return t.prototype._updatePathDirty=function(){for(var e=this.shape.paths,n=this.shapeChanged(),i=0;i<e.length;i++)n=n||e[i].shapeChanged();n&&this.dirtyShape()},t.prototype.beforeBrush=function(){this._updatePathDirty();for(var e=this.shape.paths||[],n=this.getGlobalScale(),i=0;i<e.length;i++)e[i].path||e[i].createPathProxy(),e[i].path.setScale(n[0],n[1],e[i].segmentIgnoreThreshold)},t.prototype.buildPath=function(e,n){for(var i=n.paths||[],a=0;a<i.length;a++)i[a].buildPath(e,i[a].shape,!0)},t.prototype.afterBrush=function(){for(var e=this.shape.paths||[],n=0;n<e.length;n++)e[n].pathUpdated()},t.prototype.getBoundingRect=function(){return this._updatePathDirty.call(this),ht.prototype.getBoundingRect.call(this)},t})(ht),ny=(function(){function r(t){this.colorStops=t||[]}return r.prototype.addColorStop=function(t,e){this.colorStops.push({offset:t,color:e})},r})(),iy=(function(r){z(t,r);function t(e,n,i,a,o,s){var l=r.call(this,o)||this;return l.x=e??0,l.y=n??0,l.x2=i??1,l.y2=a??0,l.type="linear",l.global=s||!1,l}return t})(ny),kw=(function(r){z(t,r);function t(e,n,i,a,o){var s=r.call(this,a)||this;return s.x=e??.5,s.y=n??.5,s.r=i??.5,s.type="radial",s.global=o||!1,s}return t})(ny),ql=Math.min,Ow=Math.max,wo=Math.abs,ln=[0,0],un=[0,0],Rt=im(),xo=Rt.minTv,To=Rt.maxTv,ay=(function(){function r(t,e){this._corners=[],this._axes=[],this._origin=[0,0];for(var n=0;n<4;n++)this._corners[n]=new tt;for(var n=0;n<2;n++)this._axes[n]=new tt;t&&this.fromBoundingRect(t,e)}return r.prototype.fromBoundingRect=function(t,e){var n=this._corners,i=this._axes,a=t.x,o=t.y,s=a+t.width,l=o+t.height;if(n[0].set(a,o),n[1].set(s,o),n[2].set(s,l),n[3].set(a,l),e)for(var u=0;u<4;u++)n[u].transform(e);tt.sub(i[0],n[1],n[0]),tt.sub(i[1],n[3],n[0]),i[0].normalize(),i[1].normalize();for(var u=0;u<2;u++)this._origin[u]=i[u].dot(n[0])},r.prototype.intersect=function(t,e,n){var i=!0,a=!e;return e&&tt.set(e,0,0),Rt.reset(n,!a),!this._intersectCheckOneSide(this,t,a,1)&&(i=!1,a)||!this._intersectCheckOneSide(t,this,a,-1)&&(i=!1,a)||!a&&!Rt.negativeSize&&tt.copy(e,i?Rt.useDir?Rt.dirMinTv:xo:To),i},r.prototype._intersectCheckOneSide=function(t,e,n,i){for(var a=!0,o=0;o<2;o++){var s=t._axes[o];if(t._getProjMinMaxOnAxis(o,t._corners,ln),t._getProjMinMaxOnAxis(o,e._corners,un),Rt.negativeSize||ln[1]<un[0]||ln[0]>un[1]){if(a=!1,Rt.negativeSize||n)return a;var l=wo(un[0]-ln[1]),u=wo(ln[0]-un[1]);ql(l,u)>To.len()&&(l<u?tt.scale(To,s,-l*i):tt.scale(To,s,u*i))}else if(!n){var l=wo(un[0]-ln[1]),u=wo(ln[0]-un[1]);(Rt.useDir||ql(l,u)<xo.len())&&((l<u||!Rt.bidirectional)&&(tt.scale(xo,s,l*i),Rt.useDir&&Rt.calcDirMTV()),(l>=u||!Rt.bidirectional)&&(tt.scale(xo,s,-u*i),Rt.useDir&&Rt.calcDirMTV()))}}return a},r.prototype._getProjMinMaxOnAxis=function(t,e,n){for(var i=this._axes[t],a=this._origin,o=e[0].dot(i)+a[t],s=o,l=o,u=1;u<e.length;u++){var f=e[u].dot(i)+a[t];s=ql(f,s),l=Ow(f,l)}n[0]=s+Rt.touchThreshold,n[1]=l-Rt.touchThreshold,Rt.negativeSize=n[1]<n[0]},r})(),Bw=[],Nw=(function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.notClear=!0,e.incremental=!0,e._displayables=[],e._temporaryDisplayables=[],e._cursor=0,e}return t.prototype.traverse=function(e,n){e.call(n,this)},t.prototype.useStyle=function(){this.style={}},t.prototype.getCursor=function(){return this._cursor},t.prototype.innerAfterBrush=function(){this._cursor=this._displayables.length},t.prototype.clearDisplaybles=function(){this._displayables=[],this._temporaryDisplayables=[],this._cursor=0,this.markRedraw(),this.notClear=!1},t.prototype.clearTemporalDisplayables=function(){this._temporaryDisplayables=[]},t.prototype.addDisplayable=function(e,n){n?this._temporaryDisplayables.push(e):this._displayables.push(e),this.markRedraw()},t.prototype.addDisplayables=function(e,n){n=n||!1;for(var i=0;i<e.length;i++)this.addDisplayable(e[i],n)},t.prototype.getDisplayables=function(){return this._displayables},t.prototype.getTemporalDisplayables=function(){return this._temporaryDisplayables},t.prototype.eachPendingDisplayable=function(e){for(var n=this._cursor;n<this._displayables.length;n++)e&&e(this._displayables[n]);for(var n=0;n<this._temporaryDisplayables.length;n++)e&&e(this._temporaryDisplayables[n])},t.prototype.update=function(){this.updateTransform();for(var e=this._cursor;e<this._displayables.length;e++){var n=this._displayables[e];n.parent=this,n.update(),n.parent=null}for(var e=0;e<this._temporaryDisplayables.length;e++){var n=this._temporaryDisplayables[e];n.parent=this,n.update(),n.parent=null}},t.prototype.getBoundingRect=function(){if(!this._rect){for(var e=new it(1/0,1/0,-1/0,-1/0),n=0;n<this._displayables.length;n++){var i=this._displayables[n],a=i.getBoundingRect().clone();i.needLocalTransform()&&a.applyTransform(i.getLocalTransform(Bw)),e.union(a)}this._rect=e}return this._rect},t.prototype.contain=function(e,n){var i=this.transformCoordToLocal(e,n),a=this.getBoundingRect();if(a.contain(i[0],i[1]))for(var o=0;o<this._displayables.length;o++){var s=this._displayables[o];if(s.contain(e,n))return!0}return!1},t})(Bi),oy=gt();function vl(r,t,e,n,i){var a;if(t&&t.ecModel){var o=t.ecModel.getUpdatePayload();a=o&&o.animation}var s=t&&t.isAnimationEnabled(),l=r==="update";if(s){var u=void 0,f=void 0,h=void 0;n?(u=q(n.duration,200),f=q(n.easing,"cubicOut"),h=0):(u=t.getShallow(l?"animationDurationUpdate":"animationDuration"),f=t.getShallow(l?"animationEasingUpdate":"animationEasing"),h=t.getShallow(l?"animationDelayUpdate":"animationDelay")),a&&(a.duration!=null&&(u=a.duration),a.easing!=null&&(f=a.easing),a.delay!=null&&(h=a.delay)),et(h)&&(h=h(e,i)),et(u)&&(u=u(e));var c={duration:u||0,delay:h,easing:f};return c}else return null}function zh(r,t,e,n,i,a,o){var s=!1,l;et(i)?(o=a,a=i,i=null):X(i)&&(a=i.cb,o=i.during,s=i.isFrom,l=i.removeOpt,i=i.dataIndex);var u=r==="leave";u||t.stopAnimation("leave");var f=vl(r,n,i,u?l||{}:null,n&&n.getAnimationDelayParams?n.getAnimationDelayParams(t,i):null);if(f&&f.duration>0){var h=f.duration,c=f.delay,v=f.easing,d={duration:h,delay:c||0,easing:v,done:a,force:!!a||!!o,setToFinal:!u,scope:r,during:o};s?t.animateFrom(e,d):t.animateTo(e,d)}else t.stopAnimation(),!s&&t.attr(e),o&&o(1),a&&a()}function Ke(r,t,e,n,i,a){zh("update",r,t,e,n,i,a)}function cr(r,t,e,n,i,a){zh("enter",r,t,e,n,i,a)}function wi(r){if(!r.__zr)return!0;for(var t=0;t<r.animators.length;t++){var e=r.animators[t];if(e.scope==="leave")return!0}return!1}function Cs(r,t,e,n,i,a){wi(r)||zh("leave",r,t,e,n,i,a)}function Fc(r,t,e,n){r.removeTextContent(),r.removeTextGuideLine(),Cs(r,{style:{opacity:0}},t,e,n)}function Fw(r,t,e){function n(){r.parent&&r.parent.remove(r)}r.isGroup?r.traverse(function(i){i.isGroup||Fc(i,t,e,n)}):Fc(r,t,e,n)}function zw(r){oy(r).oldStyle=r.style}function Hw(r){return oy(r).oldStyle}var Df={},Dr=["x","y"],Di=["width","height"];function Vw(r){return ht.extend(r)}var Gw=gw;function Ww(r,t){return Gw(r,t)}function Oe(r,t){Df[r]=t}function Uw(r){if(Df.hasOwnProperty(r))return Df[r]}function Hh(r,t,e,n){var i=pw(r,t);return e&&(n==="center"&&(e=ly(e,i.getBoundingRect())),uy(i,e)),i}function sy(r,t,e){var n=new Wr({style:{image:r,x:t.x,y:t.y,width:t.width,height:t.height},onload:function(i){if(e==="center"){var a={width:i.width,height:i.height};n.setStyle(ly(t,a))}}});return n}function ly(r,t){var e=t.width/t.height,n=r.height*e,i;n<=r.width?i=r.height:(n=r.width,i=n/e);var a=r.x+r.width/2,o=r.y+r.height/2;return{x:a-n/2,y:o-i/2,width:n,height:i}}var Yw=mw;function uy(r,t){if(r.applyTransform){var e=r.getBoundingRect(),n=e.calculateTransform(t);r.applyTransform(n)}}function Ba(r,t){return Cm(r,r,{lineWidth:t}),r}function Zw(r,t){return Dm(r,r,t),r}var Xw=xn;function fy(r,t){for(var e=Th([]);r&&r!==t;)_a(e,r.getLocalTransform(),e),r=r.parent;return e}function Na(r,t,e){return t&&!Qt(t)&&(t=Qa.getLocalTransform(t)),e&&(t=ki([],t)),xe([],r,t)}function hy(r,t,e){var n=t[4]===0||t[5]===0||t[0]===0?1:Ye(2*t[4]/t[0]),i=t[4]===0||t[5]===0||t[2]===0?1:Ye(2*t[4]/t[2]),a=[r==="left"?-n:r==="right"?n:0,r==="top"?-i:r==="bottom"?i:0];return a=Na(a,t,e),Ye(a[0])>Ye(a[1])?a[0]>0?"right":"left":a[1]>0?"bottom":"top"}function zc(r){return!r.isGroup}function $w(r){return r.shape!=null}function vy(r,t,e){if(!r||!t)return;function n(o){var s={};return o.traverse(function(l){zc(l)&&l.anid&&(s[l.anid]=l)}),s}function i(o){var s={x:o.x,y:o.y,rotation:o.rotation};return $w(o)&&(s.shape=st(o.shape)),s}var a=n(r);t.traverse(function(o){if(zc(o)&&o.anid){var s=a[o.anid];if(s){var l=i(o);o.attr(i(s)),Ke(o,l,e,pt(o).dataIndex)}}})}function qw(r,t){return $(r,function(e){var n=e[0];n=he(n,t.x),n=ka(n,t.x+t.width);var i=e[1];return i=he(i,t.y),i=ka(i,t.y+t.height),[n,i]})}function Kw(r,t){var e=he(r.x,t.x),n=ka(r.x+r.width,t.x+t.width),i=he(r.y,t.y),a=ka(r.y+r.height,t.y+t.height);if(n>=e&&a>=i)return{x:e,y:i,width:n-e,height:a-i}}function cy(r,t,e){var n=O({rectHover:!0},t),i=n.style={strokeNoScale:!0};if(e=e||{x:-1,y:-1,width:2,height:2},r)return r.indexOf("image://")===0?(i.image=r.slice(8),at(i,e),new Wr(n)):Hh(r.replace("path://",""),n,e,"center")}function Qw(r,t,e,n,i){for(var a=0,o=i[i.length-1];a<i.length;a++){var s=i[a];if(dy(r,t,e,n,s[0],s[1],o[0],o[1]))return!0;o=s}}function dy(r,t,e,n,i,a,o,s){var l=e-r,u=n-t,f=o-i,h=s-a,c=Kl(f,h,l,u);if(jw(c))return!1;var v=r-i,d=t-a,p=Kl(v,d,l,u)/c;if(p<0||p>1)return!1;var g=Kl(v,d,f,h)/c;return!(g<0||g>1)}function Kl(r,t,e,n){return r*n-e*t}function jw(r){return r<=1e-6&&r>=-1e-6}function Ds(r,t,e,n,i){return t==null||(mt(t)?_t[0]=_t[1]=_t[2]=_t[3]=t:(_t[0]=t[0],_t[1]=t[1],_t[2]=t[2],_t[3]=t[3]),n&&(_t[0]=he(0,_t[0]),_t[1]=he(0,_t[1]),_t[2]=he(0,_t[2]),_t[3]=he(0,_t[3])),e&&(_t[0]=-_t[0],_t[1]=-_t[1],_t[2]=-_t[2],_t[3]=-_t[3]),Hc(r,_t,"x","width",3,1,i&&i[0]||0),Hc(r,_t,"y","height",0,2,i&&i[1]||0)),r}var _t=[0,0,0,0];function Hc(r,t,e,n,i,a,o){var s=t[a]+t[i],l=r[n];r[n]+=s,o=he(0,ka(o,l)),r[n]<o?(r[n]=o,r[e]+=t[i]>=0?-t[i]:t[a]>=0?l+t[a]:Ye(s)>1e-8?(l-o)*t[i]/s:0):r[e]-=t[i]}function Vh(r){var t=r.itemTooltipOption,e=r.componentModel,n=r.itemName,i=W(t)?{formatter:t}:t,a=e.mainType,o=e.componentIndex,s={componentType:a,name:n,$vars:["name"]};s[a+"Index"]=o;var l=r.formatterParamsExtra;l&&D(St(l),function(f){ve(s,f)||(s[f]=l[f],s.$vars.push(f))});var u=pt(r.el);u.componentMainType=a,u.componentIndex=o,u.tooltipConfig={name:n,option:at({content:n,encodeHTMLContent:!0,formatterParams:s},i)}}function Af(r,t){var e;r.isGroup&&(e=t(r)),e||r.traverse(t)}function Gh(r,t){if(r)if(H(r))for(var e=0;e<r.length;e++)Af(r[e],t);else Af(r,t)}function Wh(r){return!r||Ye(r[1])<Mo&&Ye(r[2])<Mo||Ye(r[0])<Mo&&Ye(r[3])<Mo}var Mo=1e-5;function Fa(r,t){return r?it.copy(r,t):t.clone()}function Uh(r,t){return t?nm(r||lr(),t):void 0}function za(r){return{z:r.get("z")||0,zlevel:r.get("zlevel")||0}}function Jw(r){var t=-1/0,e=1/0;Af(r,function(a){n(a),n(a.getTextContent()),n(a.getTextGuideLine())});function n(a){if(!(!a||a.isGroup)){var o=a.currentStates;if(o.length)for(var s=0;s<o.length;s++)i(a.states[o[s]]);i(a)}}function i(a){if(a){var o=a.z2;o>t&&(t=o),o<e&&(e=o)}}return e>t&&(e=t=0),{min:e,max:t}}function py(r,t,e){gy(r,t,e,-1/0)}function gy(r,t,e,n){if(r.ignoreModelZ)return n;var i=r.getTextContent(),a=r.getTextGuideLine(),o=r.isGroup;if(o)for(var s=r.childrenRef(),l=0;l<s.length;l++)n=he(gy(s[l],t,e,n),n);else r.z=t,r.zlevel=e,n=he(r.z2||0,n);if(i&&(i.z=t,i.zlevel=e,isFinite(n)&&(i.z2=n+2)),a){var u=r.textGuideLineConfig;a.z=t,a.zlevel=e,isFinite(n)&&(a.z2=n+(u&&u.showAbove?1:-1))}return n}Oe("circle",fl);Oe("ellipse",Bh);Oe("sector",Ci);Oe("ring",Nh);Oe("polygon",to);Oe("polyline",eo);Oe("rect",Tt);Oe("line",zr);Oe("bezierCurve",Fh);Oe("arc",hl);const tx=Object.freeze(Object.defineProperty({__proto__:null,Arc:hl,BezierCurve:Fh,BoundingRect:it,Circle:fl,CompoundPath:Ew,Ellipse:Bh,Group:Ft,Image:Wr,IncrementalDisplayable:Nw,Line:zr,LinearGradient:iy,OrientedBoundingRect:ay,Path:ht,Point:tt,Polygon:to,Polyline:eo,RadialGradient:kw,Rect:Tt,Ring:Nh,Sector:Ci,Text:oe,WH:Di,XY:Dr,applyTransform:Na,calcZ2Range:Jw,clipPointsByRect:qw,clipRectByRect:Kw,createIcon:cy,ensureCopyRect:Fa,ensureCopyTransform:Uh,expandOrShrinkRect:Ds,extendPath:Ww,extendShape:Vw,getShapeClass:Uw,getTransform:fy,groupTransition:vy,initProps:cr,isBoundingRectAxisAligned:Wh,isElementRemoved:wi,lineLineIntersect:dy,linePolygonIntersect:Qw,makeImage:sy,makePath:Hh,mergePath:Yw,registerShape:Oe,removeElement:Cs,removeElementWithFadeOut:Fw,resizePath:uy,retrieveZInfo:za,setTooltipConfig:Vh,subPixelOptimize:Xw,subPixelOptimizeLine:Ba,subPixelOptimizeRect:Zw,transformDirection:hy,traverseElements:Gh,traverseUpdateZ:py,updateProps:Ke},Symbol.toStringTag,{value:"Module"}));var cl={};function my(r,t){for(var e=0;e<Te.length;e++){var n=Te[e],i=t[n],a=r.ensureState(n);a.style=a.style||{},a.style.text=i}var o=r.currentStates.slice();r.clearStates(!0),r.setStyle({text:t.normal}),r.useStates(o,!0)}function Lf(r,t,e){var n=r.labelFetcher,i=r.labelDataIndex,a=r.labelDimIndex,o=t.normal,s;n&&(s=n.getFormattedLabel(i,"normal",null,a,o&&o.get("formatter"),e!=null?{interpolatedValue:e}:null)),s==null&&(s=et(r.defaultText)?r.defaultText(i,r,e):r.defaultText);for(var l={normal:s},u=0;u<Te.length;u++){var f=Te[u],h=t[f];l[f]=q(n?n.getFormattedLabel(i,f,null,a,h&&h.get("formatter")):null,s)}return l}function yy(r,t,e,n){e=e||cl;for(var i=r instanceof oe,a=!1,o=0;o<bs.length;o++){var s=t[bs[o]];if(s&&s.getShallow("show")){a=!0;break}}var l=i?r:r.getTextContent();if(a){i||(l||(l=new oe,r.setTextContent(l)),r.stateProxy&&(l.stateProxy=r.stateProxy));var u=Lf(e,t),f=t.normal,h=!!f.getShallow("show"),c=Hr(f,n&&n.normal,e,!1,!i);c.text=u.normal,i||r.setTextConfig(Vc(f,e,!1));for(var o=0;o<Te.length;o++){var v=Te[o],s=t[v];if(s){var d=l.ensureState(v),p=!!q(s.getShallow("show"),h);if(p!==h&&(d.ignore=!p),d.style=Hr(s,n&&n[v],e,!0,!i),d.style.text=u[v],!i){var g=r.ensureState(v);g.textConfig=Vc(s,e,!0)}}}l.silent=!!f.getShallow("silent"),l.style.x!=null&&(c.x=l.style.x),l.style.y!=null&&(c.y=l.style.y),l.ignore=!h,l.useStyle(c),l.dirty(),e.enableTextSetter&&(dl(l).setLabelText=function(m){var y=Lf(e,t,m);my(l,y)})}else l&&(l.ignore=!0);r.dirty()}function Yh(r,t){t=t||"label";for(var e={normal:r.getModel(t)},n=0;n<Te.length;n++){var i=Te[n];e[i]=r.getModel([i,t])}return e}function Hr(r,t,e,n,i){var a={};return ex(a,r,e,n,i),t&&O(a,t),a}function Vc(r,t,e){t=t||{};var n={},i,a=r.getShallow("rotate"),o=q(r.getShallow("distance"),e?null:5),s=r.getShallow("offset");return i=r.getShallow("position")||(e?null:"inside"),i==="outside"&&(i=t.defaultOutsidePosition||"top"),i!=null&&(n.position=i),s!=null&&(n.offset=s),a!=null&&(a*=Math.PI/180,n.rotation=a),o!=null&&(n.distance=o),n.outsideFill=r.get("color")==="inherit"?t.inheritColor||null:"auto",t.autoOverflowArea!=null&&(n.autoOverflowArea=t.autoOverflowArea),t.layoutRect!=null&&(n.layoutRect=t.layoutRect),n}function ex(r,t,e,n,i){e=e||cl;var a=t.ecModel,o=a&&a.option.textStyle,s=rx(t),l;if(s){l={};var u="richInheritPlainLabel",f=q(t.get(u),a?a.get(u):void 0);for(var h in s)if(s.hasOwnProperty(h)){var c=t.getModel(["rich",h]);Yc(l[h]={},c,o,t,f,e,n,i,!1,!0)}}l&&(r.rich=l);var v=t.get("overflow");v&&(r.overflow=v);var d=t.get("lineOverflow");d&&(r.lineOverflow=d);var p=r,g=t.get("minMargin");if(g!=null)g=mt(g)?g/2:0,p.margin=[g,g,g,g],p.__marginType=di.minMargin;else{var m=t.get("textMargin");m!=null&&(p.margin=wh(m),p.__marginType=di.textMargin)}Yc(r,t,o,null,null,e,n,i,!0,!1)}function rx(r){for(var t;r&&r!==r.ecModel;){var e=(r.option||cl).rich;if(e){t=t||{};for(var n=St(e),i=0;i<n.length;i++){var a=n[i];t[a]=1}}r=r.parentModel}return t}var Gc=["fontStyle","fontWeight","fontSize","fontFamily","textShadowColor","textShadowBlur","textShadowOffsetX","textShadowOffsetY"],Wc=["align","lineHeight","width","height","tag","verticalAlign","ellipsis"],Uc=["padding","borderWidth","borderRadius","borderDashOffset","backgroundColor","borderColor","shadowColor","shadowBlur","shadowOffsetX","shadowOffsetY"];function Yc(r,t,e,n,i,a,o,s,l,u){e=!o&&e||cl;var f=a&&a.inheritColor,h=t.getShallow("color"),c=t.getShallow("textBorderColor"),v=q(t.getShallow("opacity"),e.opacity);(h==="inherit"||h==="auto")&&(f?h=f:h=null),(c==="inherit"||c==="auto")&&(f?c=f:c=null),s||(h=h||e.color,c=c||e.textBorderColor),h!=null&&(r.fill=h),c!=null&&(r.stroke=c);var d=q(t.getShallow("textBorderWidth"),e.textBorderWidth);d!=null&&(r.lineWidth=d);var p=q(t.getShallow("textBorderType"),e.textBorderType);p!=null&&(r.lineDash=p);var g=q(t.getShallow("textBorderDashOffset"),e.textBorderDashOffset);g!=null&&(r.lineDashOffset=g),!o&&v==null&&!u&&(v=a&&a.defaultOpacity),v!=null&&(r.opacity=v),!o&&!s&&r.fill==null&&a.inheritColor&&(r.fill=a.inheritColor);for(var m=0;m<Gc.length;m++){var y=Gc[m],_=i!==!1&&n?_i(t.getShallow(y),n.getShallow(y),e[y]):q(t.getShallow(y),e[y]);_!=null&&(r[y]=_)}for(var m=0;m<Wc.length;m++){var y=Wc[m],_=t.getShallow(y);_!=null&&(r[y]=_)}if(r.verticalAlign==null){var S=t.getShallow("baseline");S!=null&&(r.verticalAlign=S)}if(!l||!a.disableBox){for(var m=0;m<Uc.length;m++){var y=Uc[m],_=t.getShallow(y);_!=null&&(r[y]=_)}var w=t.getShallow("borderType");w!=null&&(r.borderDash=w),(r.backgroundColor==="auto"||r.backgroundColor==="inherit")&&f&&(r.backgroundColor=f),(r.borderColor==="auto"||r.borderColor==="inherit")&&f&&(r.borderColor=f)}}function nx(r,t){var e=t&&t.getModel("textStyle");return We([r.fontStyle||e&&e.getShallow("fontStyle")||"",r.fontWeight||e&&e.getShallow("fontWeight")||"",(r.fontSize||e&&e.getShallow("fontSize")||12)+"px",r.fontFamily||e&&e.getShallow("fontFamily")||"sans-serif"].join(" "))}var dl=gt();function ix(r,t,e,n,i){var a=dl(r);if(!a.valueAnimation||a.prevValue===a.value)return;var o=a.defaultInterpolatedText,s=q(a.interpolatedValue,a.prevValue),l=a.value;function u(f){var h=zm(e,a.precision,s,l,f);a.interpolatedValue=f===1?null:h;var c=Lf({labelDataIndex:t,labelFetcher:i,defaultText:o?o(h):h+""},a.statesModels,h);my(r,c)}r.percent=0,(a.prevValue==null?cr:Ke)(r,{percent:1},n,t,null,u)}var di={minMargin:1,textMargin:2},ax=["textStyle","color"],Ql=["fontStyle","fontWeight","fontSize","fontFamily","padding","lineHeight","rich","width","height","overflow"],jl=new oe,ox=(function(){function r(){}return r.prototype.getTextColor=function(t){var e=this.ecModel;return this.getShallow("color")||(!t&&e?e.get(ax):null)},r.prototype.getFont=function(){return nx({fontStyle:this.getShallow("fontStyle"),fontWeight:this.getShallow("fontWeight"),fontSize:this.getShallow("fontSize"),fontFamily:this.getShallow("fontFamily")},this.ecModel)},r.prototype.getTextRect=function(t){for(var e={text:t,verticalAlign:this.getShallow("verticalAlign")||this.getShallow("baseline")},n=0;n<Ql.length;n++)e[Ql[n]]=this.getShallow(Ql[n]);return jl.useStyle(e),jl.update(),jl.getBoundingRect()},r})(),_y=[["lineWidth","width"],["stroke","color"],["opacity"],["shadowBlur"],["shadowOffsetX"],["shadowOffsetY"],["shadowColor"],["lineDash","type"],["lineDashOffset","dashOffset"],["lineCap","cap"],["lineJoin","join"],["miterLimit"]],sx=Ra(_y),lx=(function(){function r(){}return r.prototype.getLineStyle=function(t){return sx(this,t)},r})(),Sy=[["fill","color"],["stroke","borderColor"],["lineWidth","borderWidth"],["opacity"],["shadowBlur"],["shadowOffsetX"],["shadowOffsetY"],["shadowColor"],["lineDash","borderType"],["lineDashOffset","borderDashOffset"],["lineCap","borderCap"],["lineJoin","borderJoin"],["miterLimit","borderMiterLimit"]],ux=Ra(Sy),fx=(function(){function r(){}return r.prototype.getItemStyle=function(t,e){return ux(this,t,e)},r})(),xt=(function(){function r(t,e,n){this.parentModel=e,this.ecModel=n,this.option=t}return r.prototype.init=function(t,e,n){},r.prototype.mergeOption=function(t,e){vt(this.option,t,!0)},r.prototype.get=function(t,e){return t==null?this.option:this._doGet(this.parsePath(t),!e&&this.parentModel)},r.prototype.getShallow=function(t,e){var n=this.option,i=n==null?n:n[t];if(i==null&&!e){var a=this.parentModel;a&&(i=a.getShallow(t))}return i},r.prototype.getModel=function(t,e){var n=t!=null,i=n?this.parsePath(t):null,a=n?this._doGet(i):this.option;return e=e||this.parentModel&&this.parentModel.getModel(this.resolveParentPath(i)),new r(a,e,this.ecModel)},r.prototype.isEmpty=function(){return this.option==null},r.prototype.restoreData=function(){},r.prototype.clone=function(){var t=this.constructor;return new t(st(this.option))},r.prototype.parsePath=function(t){return typeof t=="string"?t.split("."):t},r.prototype.resolveParentPath=function(t){return t},r.prototype.isAnimationEnabled=function(){if(!nt.node&&this.option){if(this.option.animation!=null)return!!this.option.animation;if(this.parentModel)return this.parentModel.isAnimationEnabled()}},r.prototype._doGet=function(t,e){var n=this.option;if(!t)return n;for(var i=0;i<t.length&&!(t[i]&&(n=n&&typeof n=="object"?n[t[i]]:null,n==null));i++);return n==null&&e&&(n=e._doGet(this.resolveParentPath(t),e.parentModel)),n},r})();xh(xt);Y1(xt);Qe(xt,lx);Qe(xt,fx);Qe(xt,K1);Qe(xt,ox);function Wi(r){return r==null?0:r.length||1}function Zc(r){return r}var If=(function(){function r(t,e,n,i,a,o){this._old=t,this._new=e,this._oldKeyGetter=n||Zc,this._newKeyGetter=i||Zc,this.context=a,this._diffModeMultiple=o==="multiple"}return r.prototype.add=function(t){return this._add=t,this},r.prototype.update=function(t){return this._update=t,this},r.prototype.updateManyToOne=function(t){return this._updateManyToOne=t,this},r.prototype.updateOneToMany=function(t){return this._updateOneToMany=t,this},r.prototype.updateManyToMany=function(t){return this._updateManyToMany=t,this},r.prototype.remove=function(t){return this._remove=t,this},r.prototype.execute=function(){this[this._diffModeMultiple?"_executeMultiple":"_executeOneToOne"]()},r.prototype._executeOneToOne=function(){var t=this._old,e=this._new,n={},i=new Array(t.length),a=new Array(e.length);this._initIndexMap(t,null,i,"_oldKeyGetter"),this._initIndexMap(e,n,a,"_newKeyGetter");for(var o=0;o<t.length;o++){var s=i[o],l=n[s],u=Wi(l);if(u>1){var f=l.shift();l.length===1&&(n[s]=l[0]),this._update&&this._update(f,o)}else u===1?(n[s]=null,this._update&&this._update(l,o)):this._remove&&this._remove(o)}this._performRestAdd(a,n)},r.prototype._executeMultiple=function(){var t=this._old,e=this._new,n={},i={},a=[],o=[];this._initIndexMap(t,n,a,"_oldKeyGetter"),this._initIndexMap(e,i,o,"_newKeyGetter");for(var s=0;s<a.length;s++){var l=a[s],u=n[l],f=i[l],h=Wi(u),c=Wi(f);if(h>1&&c===1)this._updateManyToOne&&this._updateManyToOne(f,u),i[l]=null;else if(h===1&&c>1)this._updateOneToMany&&this._updateOneToMany(f,u),i[l]=null;else if(h===1&&c===1)this._update&&this._update(f,u),i[l]=null;else if(h>1&&c>1)this._updateManyToMany&&this._updateManyToMany(f,u),i[l]=null;else if(h>1)for(var v=0;v<h;v++)this._remove&&this._remove(u[v]);else this._remove&&this._remove(u)}this._performRestAdd(o,i)},r.prototype._performRestAdd=function(t,e){for(var n=0;n<t.length;n++){var i=t[n],a=e[i],o=Wi(a);if(o>1)for(var s=0;s<o;s++)this._add&&this._add(a[s]);else o===1&&this._add&&this._add(a);e[i]=null}},r.prototype._initIndexMap=function(t,e,n,i){for(var a=this._diffModeMultiple,o=0;o<t.length;o++){var s="_ec_"+this[i](t[o],o);if(a||(n[o]=s),!!e){var l=e[s],u=Wi(l);u===0?(e[s]=o,a&&n.push(s)):u===1?e[s]=[l,o]:l.push(o)}}},r})(),by=K(["tooltip","label","itemName","itemId","itemGroupId","itemChildGroupId","seriesName"]),ce="original",zt="arrayRows",Ce="objectRows",je="keyedColumns",kr="typedArray",wy="unknown",Re="column",zn="row",se={Must:1,Might:2,Not:3},xy=gt();function hx(r){xy(r).datasetMap=K()}function vx(r,t,e){var n={},i=Ty(t);if(!i||!r)return n;var a=[],o=[],s=t.ecModel,l=xy(s).datasetMap,u=i.uid+"_"+e.seriesLayoutBy,f,h;r=r.slice(),D(r,function(p,g){var m=X(p)?p:r[g]={name:p};m.type==="ordinal"&&f==null&&(f=g,h=d(m)),n[m.name]=[]});var c=l.get(u)||l.set(u,{categoryWayDim:h,valueWayDim:0});D(r,function(p,g){var m=p.name,y=d(p);if(f==null){var _=c.valueWayDim;v(n[m],_,y),v(o,_,y),c.valueWayDim+=y}else if(f===g)v(n[m],0,y),v(a,0,y);else{var _=c.categoryWayDim;v(n[m],_,y),v(o,_,y),c.categoryWayDim+=y}});function v(p,g,m){for(var y=0;y<m;y++)p.push(g+y)}function d(p){var g=p.dimsDef;return g?g.length:1}return a.length&&(n.itemName=a),o.length&&(n.seriesName=o),n}function Ty(r){var t=r.get("data",!0);if(!t)return Ja(r.ecModel,"dataset",{index:r.get("datasetIndex",!0),id:r.get("datasetId",!0)},qt).models[0]}function cx(r){return!r.get("transform",!0)&&!r.get("fromTransformResult",!0)?[]:Ja(r.ecModel,"dataset",{index:r.get("fromDatasetIndex",!0),id:r.get("fromDatasetId",!0)},qt).models}function My(r,t){return dx(r.data,r.sourceFormat,r.seriesLayoutBy,r.dimensionsDefine,r.startIndex,t)}function dx(r,t,e,n,i,a){var o,s=5;if(ae(r))return se.Not;var l,u;if(n){var f=n[a];X(f)?(l=f.name,u=f.type):W(f)&&(l=f)}if(u!=null)return u==="ordinal"?se.Must:se.Not;if(t===zt){var h=r;if(e===zn){for(var c=h[a],v=0;v<(c||[]).length&&v<s;v++)if((o=S(c[i+v]))!=null)return o}else for(var v=0;v<h.length&&v<s;v++){var d=h[i+v];if(d&&(o=S(d[a]))!=null)return o}}else if(t===Ce){var p=r;if(!l)return se.Not;for(var v=0;v<p.length&&v<s;v++){var g=p[v];if(g&&(o=S(g[l]))!=null)return o}}else if(t===je){var m=r;if(!l)return se.Not;var c=m[l];if(!c||ae(c))return se.Not;for(var v=0;v<c.length&&v<s;v++)if((o=S(c[v]))!=null)return o}else if(t===ce)for(var y=r,v=0;v<y.length&&v<s;v++){var g=y[v],_=ja(g);if(!H(_))return se.Not;if((o=S(_[a]))!=null)return o}function S(w){var b=W(w);if(w!=null&&Number.isFinite(Number(w))&&w!=="")return b?se.Might:se.Not;if(b&&w!=="-")return se.Must}return se.Not}var pl=(function(){function r(t){this.data=t.data||(t.sourceFormat===je?{}:[]),this.sourceFormat=t.sourceFormat||wy,this.seriesLayoutBy=t.seriesLayoutBy||Re,this.startIndex=t.startIndex||0,this.dimensionsDetectedCount=t.dimensionsDetectedCount,this.metaRawOption=t.metaRawOption;var e=this.dimensionsDefine=t.dimensionsDefine;if(e)for(var n=0;n<e.length;n++){var i=e[n];i.type==null&&My(this,n)===se.Must&&(i.type="ordinal")}}return r})();function Zh(r){return r instanceof pl}function Pf(r,t,e){e=e||Dy(r);var n=t.seriesLayoutBy,i=gx(r,e,n,t.sourceHeader,t.dimensions),a=new pl({data:r,sourceFormat:e,seriesLayoutBy:n,dimensionsDefine:i.dimensionsDefine,startIndex:i.startIndex,dimensionsDetectedCount:i.dimensionsDetectedCount,metaRawOption:st(t)});return a}function Cy(r){return new pl({data:r,sourceFormat:ae(r)?kr:ce})}function px(r){return new pl({data:r.data,sourceFormat:r.sourceFormat,seriesLayoutBy:r.seriesLayoutBy,dimensionsDefine:st(r.dimensionsDefine),startIndex:r.startIndex,dimensionsDetectedCount:r.dimensionsDetectedCount})}function Dy(r){var t=wy;if(ae(r))t=kr;else if(H(r)){r.length===0&&(t=zt);for(var e=0,n=r.length;e<n;e++){var i=r[e];if(i!=null){if(H(i)||ae(i)){t=zt;break}else if(X(i)){t=Ce;break}}}}else if(X(r)){for(var a in r)if(ve(r,a)&&Qt(r[a])){t=je;break}}return t}function gx(r,t,e,n,i){var a,o;if(!r)return{dimensionsDefine:Xc(i),startIndex:o,dimensionsDetectedCount:a};if(t===zt){var s=r;n==="auto"||n==null?$c(function(u){u!=null&&u!=="-"&&(W(u)?o==null&&(o=1):o=0)},e,s,10):o=mt(n)?n:n?1:0,!i&&o===1&&(i=[],$c(function(u,f){i[f]=u!=null?u+"":""},e,s,1/0)),a=i?i.length:e===zn?s.length:s[0]?s[0].length:null}else if(t===Ce)i||(i=mx(r));else if(t===je)i||(i=[],D(r,function(u,f){i.push(f)}));else if(t===ce){var l=ja(r[0]);a=H(l)&&l.length||1}return{startIndex:o,dimensionsDefine:Xc(i),dimensionsDetectedCount:a}}function mx(r){for(var t=0,e;t<r.length&&!(e=r[t++]););if(e)return St(e)}function Xc(r){if(r){var t=K();return $(r,function(e,n){e=X(e)?e:{name:e};var i={name:e.name,displayName:e.displayName,type:e.type};if(i.name==null)return i;i.name+="",i.displayName==null&&(i.displayName=i.name);var a=t.get(i.name);return a?i.name+="-"+a.count++:t.set(i.name,{count:1}),i})}}function $c(r,t,e,n){if(t===zn)for(var i=0;i<e.length&&i<n;i++)r(e[i]?e[i][0]:null,i);else for(var a=e[0]||[],i=0;i<a.length&&i<n;i++)r(a[i],i)}function Ay(r){var t=r.sourceFormat;return t===Ce||t===je}var fn,hn,vn,cn,qc,Kc,Ly=(function(){function r(t,e){var n=Zh(t)?t:Cy(t);this._source=n;var i=this._data=n.data,a=n.sourceFormat;n.seriesLayoutBy,a===kr&&(this._offset=0,this._dimSize=e,this._data=i),Kc(this,i,n)}return r.prototype.getSource=function(){return this._source},r.prototype.count=function(){return 0},r.prototype.getItem=function(t,e){},r.prototype.appendData=function(t){},r.prototype.clean=function(){},r.protoInitialize=(function(){var t=r.prototype;t.pure=!1,t.persistent=!0})(),r.internalField=(function(){var t;Kc=function(o,s,l){var u=l.sourceFormat,f=l.seriesLayoutBy,h=l.startIndex,c=l.dimensionsDefine,v=qc[Xh(u,f)];if(O(o,v),u===kr)o.getItem=e,o.count=i,o.fillStorage=n;else{var d=Iy(u,f);o.getItem=Q(d,null,s,h,c);var p=Py(u,f);o.count=Q(p,null,s,h,c)}};var e=function(o,s){o=o-this._offset,s=s||[];for(var l=this._data,u=this._dimSize,f=u*o,h=0;h<u;h++)s[h]=l[f+h];return s},n=function(o,s,l,u){for(var f=this._data,h=this._dimSize,c=0;c<h;c++){for(var v=u[c],d=v[0]==null?1/0:v[0],p=v[1]==null?-1/0:v[1],g=s-o,m=l[c],y=0;y<g;y++){var _=f[y*h+c];m[o+y]=_,_<d&&(d=_),_>p&&(p=_)}v[0]=d,v[1]=p}},i=function(){return this._data?this._data.length/this._dimSize:0};qc=(t={},t[zt+"_"+Re]={pure:!0,appendData:a},t[zt+"_"+zn]={pure:!0,appendData:function(){throw new Error('Do not support appendData when set seriesLayoutBy: "row".')}},t[Ce]={pure:!0,appendData:a},t[je]={pure:!0,appendData:function(o){var s=this._data;D(o,function(l,u){for(var f=s[u]||(s[u]=[]),h=0;h<(l||[]).length;h++)f.push(l[h])})}},t[ce]={appendData:a},t[kr]={persistent:!1,pure:!0,appendData:function(o){this._data=o},clean:function(){this._offset+=this.count(),this._data=null}},t);function a(o){for(var s=0;s<o.length;s++)this._data.push(o[s])}})(),r})(),Co=function(r){H(r)||km("series.data or dataset.source must be an array.")};fn={},fn[zt+"_"+Re]=Co,fn[zt+"_"+zn]=Co,fn[Ce]=Co,fn[je]=function(r,t){for(var e=0;e<t.length;e++){var n=t[e].name;n==null&&km("dimension name must not be null/undefined.")}},fn[ce]=Co;var Qc=function(r,t,e,n){return r[n]},yx=(hn={},hn[zt+"_"+Re]=function(r,t,e,n){return r[n+t]},hn[zt+"_"+zn]=function(r,t,e,n,i){n+=t;for(var a=i||[],o=r,s=0;s<o.length;s++){var l=o[s];a[s]=l?l[n]:null}return a},hn[Ce]=Qc,hn[je]=function(r,t,e,n,i){for(var a=i||[],o=0;o<e.length;o++){var s=e[o].name,l=s!=null?r[s]:null;a[o]=l?l[n]:null}return a},hn[ce]=Qc,hn);function Iy(r,t){var e=yx[Xh(r,t)];return e}var jc=function(r,t,e){return r.length},_x=(vn={},vn[zt+"_"+Re]=function(r,t,e){return Math.max(0,r.length-t)},vn[zt+"_"+zn]=function(r,t,e){var n=r[0];return n?Math.max(0,n.length-t):0},vn[Ce]=jc,vn[je]=function(r,t,e){var n=e[0].name,i=n!=null?r[n]:null;return i?i.length:0},vn[ce]=jc,vn);function Py(r,t){var e=_x[Xh(r,t)];return e}var Jl=function(r,t,e){return r[t]},Sx=(cn={},cn[zt]=Jl,cn[Ce]=function(r,t,e){return r[e]},cn[je]=Jl,cn[ce]=function(r,t,e){var n=ja(r);return n instanceof Array?n[t]:n},cn[kr]=Jl,cn);function Ry(r){var t=Sx[r];return t}function Xh(r,t){return r===zt?r+"_"+t:r}function Ai(r,t,e){if(r){var n=r.getRawDataItem(t);if(n!=null){var i=r.getStore(),a=i.getSource().sourceFormat;if(e!=null){var o=r.getDimensionIndex(e),s=i.getDimensionProperty(o);return Ry(a)(n,o,s)}else{var l=n;return a===ce&&(l=ja(n)),l}}}}var bx=(function(){function r(t,e){this._encode=t,this._schema=e}return r.prototype.get=function(){return{fullDimensions:this._getFullDimensionNames(),encode:this._encode}},r.prototype._getFullDimensionNames=function(){return this._cachedDimNames||(this._cachedDimNames=this._schema?this._schema.makeOutputDimensionNames():[]),this._cachedDimNames},r})();function xx(r,t){var e={},n=e.encode={},i=K(),a=[],o=[],s={};D(r.dimensions,function(c){var v=r.getDimensionInfo(c),d=v.coordDim;if(d){var p=v.coordDimIndex;tu(n,d)[p]=c,v.isExtraCoord||(i.set(d,1),Mx(v.type)&&(a[0]=c),tu(s,d)[p]=r.getDimensionIndex(v.name)),v.defaultTooltip&&o.push(c)}by.each(function(g,m){var y=tu(n,m),_=v.otherDims[m];_!=null&&_!==!1&&(y[_]=v.name)})});var l=[],u={};i.each(function(c,v){var d=n[v];u[v]=d[0],l=l.concat(d)}),e.dataDimsOnCoord=l,e.dataDimIndicesOnCoord=$(l,function(c){return r.getDimensionInfo(c).storeDimIndex}),e.encodeFirstDimNotExtra=u;var f=n.label;f&&f.length&&(a=f.slice());var h=n.tooltip;return h&&h.length?o=h.slice():o.length||(o=a.slice()),n.defaultedLabel=a,n.defaultedTooltip=o,e.userOutput=new bx(s,t),e}function tu(r,t){return r.hasOwnProperty(t)||(r[t]=[]),r[t]}function Tx(r){return r==="category"?"ordinal":r==="time"?"time":"float"}function Mx(r){return!(r==="ordinal"||r==="time")}var Jo=(function(){function r(t){this.otherDims={},t!=null&&O(this,t)}return r})();function ts(r,t){var e=t&&t.type;return e==="ordinal"?r:(e==="time"&&!mt(r)&&r!=null&&r!=="-"&&(r=+Ni(r)),r==null||r===""?NaN:Number(r))}var Cx=K({number:function(r){return parseFloat(r)},time:function(r){return+Ni(r)},trim:function(r){return W(r)?We(r):r}});function Ey(r){return Cx.get(r)}var ky={lt:function(r,t){return r<t},lte:function(r,t){return r<=t},gt:function(r,t){return r>t},gte:function(r,t){return r>=t}},Dx=(function(){function r(t,e){if(!mt(e)){var n="";ut(n)}this._opFn=ky[t],this._rvalFloat=Fr(e)}return r.prototype.evaluate=function(t){return mt(t)?this._opFn(t,this._rvalFloat):this._opFn(Fr(t),this._rvalFloat)},r})(),Oy=(function(){function r(t,e){var n=t==="desc";this._resultLT=n?1:-1,e==null&&(e=n?"min":"max"),this._incomparable=e==="min"?-1/0:1/0}return r.prototype.evaluate=function(t,e){var n=mt(t)?t:Fr(t),i=mt(e)?e:Fr(e),a=isNaN(n),o=isNaN(i);if(a&&(n=this._incomparable),o&&(i=this._incomparable),a&&o){var s=W(t),l=W(e);s&&(n=l?t:0),l&&(i=s?e:0)}return n<i?this._resultLT:n>i?-this._resultLT:0},r})(),Ax=(function(){function r(t,e){this._rval=e,this._isEQ=t,this._rvalTypeof=typeof e,this._rvalFloat=Fr(e)}return r.prototype.evaluate=function(t){var e=t===this._rval;if(!e){var n=typeof t;n!==this._rvalTypeof&&(n==="number"||this._rvalTypeof==="number")&&(e=Fr(t)===this._rvalFloat)}return this._isEQ?e:!e},r})();function Lx(r,t){return r==="eq"||r==="ne"?new Ax(r==="eq",t):ve(ky,r)?new Dx(r,t):null}var gl="undefined",Ix=typeof Uint32Array===gl?Array:Uint32Array,Px=typeof Uint16Array===gl?Array:Uint16Array,By=typeof Int32Array===gl?Array:Int32Array,Jc=typeof Float64Array===gl?Array:Float64Array,Ny={float:Jc,int:By,ordinal:Array,number:Array,time:Jc},eu;function qn(r){return r>65535?Ix:Px}function Kn(){return[1/0,-1/0]}function Rx(r){var t=r.constructor;return t===Array?r.slice():new t(r)}function td(r,t,e,n,i){var a=Ny[e||"float"];if(i){var o=r[t],s=o&&o.length;if(s!==n){for(var l=new a(n),u=0;u<s;u++)l[u]=o[u];r[t]=l}}else r[t]=new a(n)}var Rf=(function(){function r(){this._chunks=[],this._rawExtent=[],this._extent=[],this._count=0,this._rawCount=0,this._calcDimNameToIdx=K()}return r.prototype.initData=function(t,e,n){this._provider=t,this._chunks=[],this._indices=null,this.getRawIndex=this._getRawIdxIdentity;var i=t.getSource(),a=this.defaultDimValueGetter=eu[i.sourceFormat];this._dimValueGetter=n||a,this._rawExtent=[],Ay(i),this._dimensions=$(e,function(o){return{type:o.type,property:o.property}}),this._initDataFromProvider(0,t.count())},r.prototype.getProvider=function(){return this._provider},r.prototype.getSource=function(){return this._provider.getSource()},r.prototype.ensureCalculationDimension=function(t,e){var n=this._calcDimNameToIdx,i=this._dimensions,a=n.get(t);if(a!=null){if(i[a].type===e)return a}else a=i.length;return i[a]={type:e},n.set(t,a),this._chunks[a]=new Ny[e||"float"](this._rawCount),this._rawExtent[a]=Kn(),a},r.prototype.collectOrdinalMeta=function(t,e){var n=this._chunks[t],i=this._dimensions[t],a=this._rawExtent,o=i.ordinalOffset||0,s=n.length;o===0&&(a[t]=Kn());for(var l=a[t],u=o;u<s;u++){var f=n[u]=e.parseAndCollect(n[u]);isNaN(f)||(l[0]=Math.min(f,l[0]),l[1]=Math.max(f,l[1]))}i.ordinalMeta=e,i.ordinalOffset=s,i.type="ordinal"},r.prototype.getOrdinalMeta=function(t){var e=this._dimensions[t],n=e.ordinalMeta;return n},r.prototype.getDimensionProperty=function(t){var e=this._dimensions[t];return e&&e.property},r.prototype.appendData=function(t){var e=this._provider,n=this.count();e.appendData(t);var i=e.count();return e.persistent||(i+=n),n<i&&this._initDataFromProvider(n,i,!0),[n,i]},r.prototype.appendValues=function(t,e){for(var n=this._chunks,i=this._dimensions,a=i.length,o=this._rawExtent,s=this.count(),l=s+Math.max(t.length,e||0),u=0;u<a;u++){var f=i[u];td(n,u,f.type,l,!0)}for(var h=[],c=s;c<l;c++)for(var v=c-s,d=0;d<a;d++){var f=i[d],p=eu.arrayRows.call(this,t[v]||h,f.property,v,d);n[d][c]=p;var g=o[d];p<g[0]&&(g[0]=p),p>g[1]&&(g[1]=p)}return this._rawCount=this._count=l,{start:s,end:l}},r.prototype._initDataFromProvider=function(t,e,n){for(var i=this._provider,a=this._chunks,o=this._dimensions,s=o.length,l=this._rawExtent,u=$(o,function(y){return y.property}),f=0;f<s;f++){var h=o[f];l[f]||(l[f]=Kn()),td(a,f,h.type,e,n)}if(i.fillStorage)i.fillStorage(t,e,a,l);else for(var c=[],v=t;v<e;v++){c=i.getItem(v,c);for(var d=0;d<s;d++){var p=a[d],g=this._dimValueGetter(c,u[d],v,d);p[v]=g;var m=l[d];g<m[0]&&(m[0]=g),g>m[1]&&(m[1]=g)}}!i.persistent&&i.clean&&i.clean(),this._rawCount=this._count=e,this._extent=[]},r.prototype.count=function(){return this._count},r.prototype.get=function(t,e){if(!(e>=0&&e<this._count))return NaN;var n=this._chunks[t];return n?n[this.getRawIndex(e)]:NaN},r.prototype.getValues=function(t,e){var n=[],i=[];if(e==null){e=t,t=[];for(var a=0;a<this._dimensions.length;a++)i.push(a)}else i=t;for(var a=0,o=i.length;a<o;a++)n.push(this.get(i[a],e));return n},r.prototype.getByRawIndex=function(t,e){if(!(e>=0&&e<this._rawCount))return NaN;var n=this._chunks[t];return n?n[e]:NaN},r.prototype.getSum=function(t){var e=this._chunks[t],n=0;if(e)for(var i=0,a=this.count();i<a;i++){var o=this.get(t,i);isNaN(o)||(n+=o)}return n},r.prototype.getMedian=function(t){var e=[];this.each([t],function(a){isNaN(a)||e.push(a)});var n=e.sort(function(a,o){return a-o}),i=this.count();return i===0?0:i%2===1?n[(i-1)/2]:(n[i/2]+n[i/2-1])/2},r.prototype.indexOfRawIndex=function(t){if(t>=this._rawCount||t<0)return-1;if(!this._indices)return t;var e=this._indices,n=e[t];if(n!=null&&n<this._count&&n===t)return t;for(var i=0,a=this._count-1;i<=a;){var o=(i+a)/2|0;if(e[o]<t)i=o+1;else if(e[o]>t)a=o-1;else return o}return-1},r.prototype.getIndices=function(){var t,e=this._indices;if(e){var n=e.constructor,i=this._count;if(n===Array){t=new n(i);for(var a=0;a<i;a++)t[a]=e[a]}else t=new n(e.buffer,0,i)}else{var n=qn(this._rawCount);t=new n(this.count());for(var a=0;a<t.length;a++)t[a]=a}return t},r.prototype.filter=function(t,e){if(!this._count)return this;for(var n=this.clone(),i=n.count(),a=qn(n._rawCount),o=new a(i),s=[],l=t.length,u=0,f=t[0],h=n._chunks,c=0;c<i;c++){var v=void 0,d=n.getRawIndex(c);if(l===0)v=e(c);else if(l===1){var p=h[f][d];v=e(p,c)}else{for(var g=0;g<l;g++)s[g]=h[t[g]][d];s[g]=c,v=e.apply(null,s)}v&&(o[u++]=d)}return u<i&&(n._indices=o),n._count=u,n._extent=[],n._updateGetRawIdx(),n},r.prototype.selectRange=function(t){var e=this.clone(),n=e._count;if(!n)return this;var i=St(t),a=i.length;if(!a)return this;var o=e.count(),s=qn(e._rawCount),l=new s(o),u=0,f=i[0],h=t[f][0],c=t[f][1],v=e._chunks,d=!1;if(!e._indices){var p=0;if(a===1){for(var g=v[i[0]],m=0;m<n;m++){var y=g[m];(y>=h&&y<=c||isNaN(y))&&(l[u++]=p),p++}d=!0}else if(a===2){for(var g=v[i[0]],_=v[i[1]],S=t[i[1]][0],w=t[i[1]][1],m=0;m<n;m++){var y=g[m],b=_[m];(y>=h&&y<=c||isNaN(y))&&(b>=S&&b<=w||isNaN(b))&&(l[u++]=p),p++}d=!0}}if(!d)if(a===1)for(var m=0;m<o;m++){var T=e.getRawIndex(m),y=v[i[0]][T];(y>=h&&y<=c||isNaN(y))&&(l[u++]=T)}else for(var m=0;m<o;m++){for(var C=!0,T=e.getRawIndex(m),x=0;x<a;x++){var M=i[x],y=v[M][T];(y<t[M][0]||y>t[M][1])&&(C=!1)}C&&(l[u++]=e.getRawIndex(m))}return u<o&&(e._indices=l),e._count=u,e._extent=[],e._updateGetRawIdx(),e},r.prototype.map=function(t,e){var n=this.clone(t);return this._updateDims(n,t,e),n},r.prototype.modify=function(t,e){this._updateDims(this,t,e)},r.prototype._updateDims=function(t,e,n){for(var i=t._chunks,a=[],o=e.length,s=t.count(),l=[],u=t._rawExtent,f=0;f<e.length;f++)u[e[f]]=Kn();for(var h=0;h<s;h++){for(var c=t.getRawIndex(h),v=0;v<o;v++)l[v]=i[e[v]][c];l[o]=h;var d=n&&n.apply(null,l);if(d!=null){typeof d!="object"&&(a[0]=d,d=a);for(var f=0;f<d.length;f++){var p=e[f],g=d[f],m=u[p],y=i[p];y&&(y[c]=g),g<m[0]&&(m[0]=g),g>m[1]&&(m[1]=g)}}}},r.prototype.lttbDownSample=function(t,e){var n=this.clone([t],!0),i=n._chunks,a=i[t],o=this.count(),s=0,l=Math.floor(1/e),u=this.getRawIndex(0),f,h,c,v=new(qn(this._rawCount))(Math.min((Math.ceil(o/l)+2)*2,o));v[s++]=u;for(var d=1;d<o-1;d+=l){for(var p=Math.min(d+l,o-1),g=Math.min(d+l*2,o),m=(g+p)/2,y=0,_=p;_<g;_++){var S=this.getRawIndex(_),w=a[S];isNaN(w)||(y+=w)}y/=g-p;var b=d,T=Math.min(d+l,o),C=d-1,x=a[u];f=-1,c=b;for(var M=-1,A=0,_=b;_<T;_++){var S=this.getRawIndex(_),w=a[S];if(isNaN(w)){A++,M<0&&(M=S);continue}h=Math.abs((C-m)*(w-x)-(C-_)*(y-x)),h>f&&(f=h,c=S)}A>0&&A<T-b&&(v[s++]=Math.min(M,c),c=Math.max(M,c)),v[s++]=c,u=c}return v[s++]=this.getRawIndex(o-1),n._count=s,n._indices=v,n.getRawIndex=this._getRawIdx,n},r.prototype.minmaxDownSample=function(t,e){for(var n=this.clone([t],!0),i=n._chunks,a=Math.floor(1/e),o=i[t],s=this.count(),l=new(qn(this._rawCount))(Math.ceil(s/a)*2),u=0,f=0;f<s;f+=a){var h=f,c=o[this.getRawIndex(h)],v=f,d=o[this.getRawIndex(v)],p=a;f+a>s&&(p=s-f);for(var g=0;g<p;g++){var m=this.getRawIndex(f+g),y=o[m];y<c&&(c=y,h=f+g),y>d&&(d=y,v=f+g)}var _=this.getRawIndex(h),S=this.getRawIndex(v);h<v?(l[u++]=_,l[u++]=S):(l[u++]=S,l[u++]=_)}return n._count=u,n._indices=l,n._updateGetRawIdx(),n},r.prototype.downSample=function(t,e,n,i){for(var a=this.clone([t],!0),o=a._chunks,s=[],l=Math.floor(1/e),u=o[t],f=this.count(),h=a._rawExtent[t]=Kn(),c=new(qn(this._rawCount))(Math.ceil(f/l)),v=0,d=0;d<f;d+=l){l>f-d&&(l=f-d,s.length=l);for(var p=0;p<l;p++){var g=this.getRawIndex(d+p);s[p]=u[g]}var m=n(s),y=this.getRawIndex(Math.min(d+i(s,m)||0,f-1));u[y]=m,m<h[0]&&(h[0]=m),m>h[1]&&(h[1]=m),c[v++]=y}return a._count=v,a._indices=c,a._updateGetRawIdx(),a},r.prototype.each=function(t,e){if(this._count)for(var n=t.length,i=this._chunks,a=0,o=this.count();a<o;a++){var s=this.getRawIndex(a);switch(n){case 0:e(a);break;case 1:e(i[t[0]][s],a);break;case 2:e(i[t[0]][s],i[t[1]][s],a);break;default:for(var l=0,u=[];l<n;l++)u[l]=i[t[l]][s];u[l]=a,e.apply(null,u)}}},r.prototype.getDataExtent=function(t){var e=this._chunks[t],n=Kn();if(!e)return n;var i=this.count(),a=!this._indices,o;if(a)return this._rawExtent[t].slice();if(o=this._extent[t],o)return o.slice();o=n;for(var s=o[0],l=o[1],u=0;u<i;u++){var f=this.getRawIndex(u),h=e[f];h<s&&(s=h),h>l&&(l=h)}return o=[s,l],this._extent[t]=o,o},r.prototype.getRawDataItem=function(t){var e=this.getRawIndex(t);if(this._provider.persistent)return this._provider.getItem(e);for(var n=[],i=this._chunks,a=0;a<i.length;a++)n.push(i[a][e]);return n},r.prototype.clone=function(t,e){var n=new r,i=this._chunks,a=t&&Ei(t,function(s,l){return s[l]=!0,s},{});if(a)for(var o=0;o<i.length;o++)n._chunks[o]=a[o]?Rx(i[o]):i[o];else n._chunks=i;return this._copyCommonProps(n),e||(n._indices=this._cloneIndices()),n._updateGetRawIdx(),n},r.prototype._copyCommonProps=function(t){t._count=this._count,t._rawCount=this._rawCount,t._provider=this._provider,t._dimensions=this._dimensions,t._extent=st(this._extent),t._rawExtent=st(this._rawExtent)},r.prototype._cloneIndices=function(){if(this._indices){var t=this._indices.constructor,e=void 0;if(t===Array){var n=this._indices.length;e=new t(n);for(var i=0;i<n;i++)e[i]=this._indices[i]}else e=new t(this._indices);return e}return null},r.prototype._getRawIdxIdentity=function(t){return t},r.prototype._getRawIdx=function(t){return t<this._count&&t>=0?this._indices[t]:-1},r.prototype._updateGetRawIdx=function(){this.getRawIndex=this._indices?this._getRawIdx:this._getRawIdxIdentity},r.internalField=(function(){function t(e,n,i,a){return ts(e[a],this._dimensions[a])}eu={arrayRows:t,objectRows:function(e,n,i,a){return ts(e[n],this._dimensions[a])},keyedColumns:t,original:function(e,n,i,a){var o=e&&(e.value==null?e:e.value);return ts(o instanceof Array?o[a]:o,this._dimensions[a])},typedArray:function(e,n,i,a){return e[a]}}})(),r})(),Ex=gt(),kx={float:"f",int:"i",ordinal:"o",number:"n",time:"t"},Fy=(function(){function r(t){this.dimensions=t.dimensions,this._dimOmitted=t.dimensionOmitted,this.source=t.source,this._fullDimCount=t.fullDimensionCount,this._updateDimOmitted(t.dimensionOmitted)}return r.prototype.isDimensionOmitted=function(){return this._dimOmitted},r.prototype._updateDimOmitted=function(t){this._dimOmitted=t,t&&(this._dimNameMap||(this._dimNameMap=Vy(this.source)))},r.prototype.getSourceDimensionIndex=function(t){return q(this._dimNameMap.get(t),-1)},r.prototype.getSourceDimension=function(t){var e=this.source.dimensionsDefine;if(e)return e[t]},r.prototype.makeStoreSchema=function(){for(var t=this._fullDimCount,e=Ay(this.source),n=!Gy(t),i="",a=[],o=0,s=0;o<t;o++){var l=void 0,u=void 0,f=void 0,h=this.dimensions[s];if(h&&h.storeDimIndex===o)l=e?h.name:null,u=h.type,f=h.ordinalMeta,s++;else{var c=this.getSourceDimension(o);c&&(l=e?c.name:null,u=c.type)}a.push({property:l,type:u,ordinalMeta:f}),e&&l!=null&&(!h||!h.isCalculationCoord)&&(i+=n?l.replace(/\`/g,"`1").replace(/\$/g,"`2"):l),i+="$",i+=kx[u]||"f",f&&(i+=f.uid),i+="$"}var v=this.source,d=[v.seriesLayoutBy,v.startIndex,i].join("$$");return{dimensions:a,hash:d}},r.prototype.makeOutputDimensionNames=function(){for(var t=[],e=0,n=0;e<this._fullDimCount;e++){var i=void 0,a=this.dimensions[n];if(a&&a.storeDimIndex===e)a.isCalculationCoord||(i=a.name),n++;else{var o=this.getSourceDimension(e);o&&(i=o.name)}t.push(i)}return t},r.prototype.appendCalculationDimension=function(t){this.dimensions.push(t),t.isCalculationCoord=!0,this._fullDimCount++,this._updateDimOmitted(!0)},r})();function zy(r){return r instanceof Fy}function Hy(r){for(var t=K(),e=0;e<(r||[]).length;e++){var n=r[e],i=X(n)?n.name:n;i!=null&&t.get(i)==null&&t.set(i,e)}return t}function Vy(r){var t=Ex(r);return t.dimNameMap||(t.dimNameMap=Hy(r.dimensionsDefine))}function Gy(r){return r>30}var Ui=X,mr=$,Ox=typeof Int32Array>"u"?Array:Int32Array,Bx="e\0\0",ed=-1,Nx=["hasItemOption","_nameList","_idList","_invertedIndicesMap","_dimSummary","userOutput","_rawData","_dimValueGetter","_nameDimIdx","_idDimIdx","_nameRepeatCount"],Fx=["_approximateExtent"],rd,Do,Yi,Zi,ru,Xi,nu,zx=(function(){function r(t,e){this.type="list",this._dimOmitted=!1,this._nameList=[],this._idList=[],this._visual={},this._layout={},this._itemVisuals=[],this._itemLayouts=[],this._graphicEls=[],this._approximateExtent={},this._calculationInfo={},this.hasItemOption=!1,this.TRANSFERABLE_METHODS=["cloneShallow","downSample","minmaxDownSample","lttbDownSample","map"],this.CHANGABLE_METHODS=["filterSelf","selectRange"],this.DOWNSAMPLE_METHODS=["downSample","minmaxDownSample","lttbDownSample"];var n,i=!1;zy(t)?(n=t.dimensions,this._dimOmitted=t.isDimensionOmitted(),this._schema=t):(i=!0,n=t),n=n||["x","y"];for(var a={},o=[],s={},l=!1,u={},f=0;f<n.length;f++){var h=n[f],c=W(h)?new Jo({name:h}):h instanceof Jo?h:new Jo(h),v=c.name;c.type=c.type||"float",c.coordDim||(c.coordDim=v,c.coordDimIndex=0);var d=c.otherDims=c.otherDims||{};o.push(v),a[v]=c,u[v]!=null&&(l=!0),c.createInvertedIndices&&(s[v]=[]);var p=f;mt(c.storeDimIndex)&&(p=c.storeDimIndex),d.itemName===0&&(this._nameDimIdx=p),d.itemId===0&&(this._idDimIdx=p),i&&(c.storeDimIndex=f)}if(this.dimensions=o,this._dimInfos=a,this._initGetDimensionInfo(l),this.hostModel=e,this._invertedIndicesMap=s,this._dimOmitted){var g=this._dimIdxToName=K();D(o,function(m){g.set(a[m].storeDimIndex,m)})}}return r.prototype.getDimension=function(t){var e=this._recognizeDimIndex(t);if(e==null)return t;if(e=t,!this._dimOmitted)return this.dimensions[e];var n=this._dimIdxToName.get(e);if(n!=null)return n;var i=this._schema.getSourceDimension(e);if(i)return i.name},r.prototype.getDimensionIndex=function(t){var e=this._recognizeDimIndex(t);if(e!=null)return e;if(t==null)return-1;var n=this._getDimInfo(t);return n?n.storeDimIndex:this._dimOmitted?this._schema.getSourceDimensionIndex(t):-1},r.prototype._recognizeDimIndex=function(t){if(mt(t)||t!=null&&!isNaN(t)&&!this._getDimInfo(t)&&(!this._dimOmitted||this._schema.getSourceDimensionIndex(t)<0))return+t},r.prototype._getStoreDimIndex=function(t){var e=this.getDimensionIndex(t);return e},r.prototype.getDimensionInfo=function(t){return this._getDimInfo(this.getDimension(t))},r.prototype._initGetDimensionInfo=function(t){var e=this._dimInfos;this._getDimInfo=t?function(n){return e.hasOwnProperty(n)?e[n]:void 0}:function(n){return e[n]}},r.prototype.getDimensionsOnCoord=function(){return this._dimSummary.dataDimsOnCoord.slice()},r.prototype.mapDimension=function(t,e){var n=this._dimSummary;if(e==null)return n.encodeFirstDimNotExtra[t];var i=n.encode[t];return i?i[e]:null},r.prototype.mapDimensionsAll=function(t){var e=this._dimSummary,n=e.encode[t];return(n||[]).slice()},r.prototype.getStore=function(){return this._store},r.prototype.initData=function(t,e,n){var i=this,a;if(t instanceof Rf&&(a=t),!a){var o=this.dimensions,s=Zh(t)||Qt(t)?new Ly(t,o.length):t;a=new Rf;var l=mr(o,function(u){return{type:i._dimInfos[u].type,property:u}});a.initData(s,l,n)}this._store=a,this._nameList=(e||[]).slice(),this._idList=[],this._nameRepeatCount={},this._doInit(0,a.count()),this._dimSummary=xx(this,this._schema),this.userOutput=this._dimSummary.userOutput},r.prototype.appendData=function(t){var e=this._store.appendData(t);this._doInit(e[0],e[1])},r.prototype.appendValues=function(t,e){var n=this._store.appendValues(t,e&&e.length),i=n.start,a=n.end,o=this._shouldMakeIdFromName();if(this._updateOrdinalMeta(),e)for(var s=i;s<a;s++){var l=s-i;this._nameList[s]=e[l],o&&nu(this,s)}},r.prototype._updateOrdinalMeta=function(){for(var t=this._store,e=this.dimensions,n=0;n<e.length;n++){var i=this._dimInfos[e[n]];i.ordinalMeta&&t.collectOrdinalMeta(i.storeDimIndex,i.ordinalMeta)}},r.prototype._shouldMakeIdFromName=function(){var t=this._store.getProvider();return this._idDimIdx==null&&t.getSource().sourceFormat!==kr&&!t.fillStorage},r.prototype._doInit=function(t,e){if(!(t>=e)){var n=this._store,i=n.getProvider();this._updateOrdinalMeta();var a=this._nameList,o=this._idList,s=i.getSource().sourceFormat,l=s===ce;if(l&&!i.pure)for(var u=[],f=t;f<e;f++){var h=i.getItem(f,u);if(!this.hasItemOption&&Lb(h)&&(this.hasItemOption=!0),h){var c=h.name;a[f]==null&&c!=null&&(a[f]=$e(c,null));var v=h.id;o[f]==null&&v!=null&&(o[f]=$e(v,null))}}if(this._shouldMakeIdFromName())for(var f=t;f<e;f++)nu(this,f);rd(this)}},r.prototype.getApproximateExtent=function(t){return this._approximateExtent[t]||this._store.getDataExtent(this._getStoreDimIndex(t))},r.prototype.setApproximateExtent=function(t,e){e=this.getDimension(e),this._approximateExtent[e]=t.slice()},r.prototype.getCalculationInfo=function(t){return this._calculationInfo[t]},r.prototype.setCalculationInfo=function(t,e){Ui(t)?O(this._calculationInfo,t):this._calculationInfo[t]=e},r.prototype.getName=function(t){var e=this.getRawIndex(t),n=this._nameList[e];return n==null&&this._nameDimIdx!=null&&(n=Yi(this,this._nameDimIdx,e)),n==null&&(n=""),n},r.prototype._getCategory=function(t,e){var n=this._store.get(t,e),i=this._store.getOrdinalMeta(t);return i?i.categories[n]:n},r.prototype.getId=function(t){return Do(this,this.getRawIndex(t))},r.prototype.count=function(){return this._store.count()},r.prototype.get=function(t,e){var n=this._store,i=this._dimInfos[t];if(i)return n.get(i.storeDimIndex,e)},r.prototype.getByRawIndex=function(t,e){var n=this._store,i=this._dimInfos[t];if(i)return n.getByRawIndex(i.storeDimIndex,e)},r.prototype.getIndices=function(){return this._store.getIndices()},r.prototype.getDataExtent=function(t){return this._store.getDataExtent(this._getStoreDimIndex(t))},r.prototype.getSum=function(t){return this._store.getSum(this._getStoreDimIndex(t))},r.prototype.getMedian=function(t){return this._store.getMedian(this._getStoreDimIndex(t))},r.prototype.getValues=function(t,e){var n=this,i=this._store;return H(t)?i.getValues(mr(t,function(a){return n._getStoreDimIndex(a)}),e):i.getValues(t)},r.prototype.hasValue=function(t){for(var e=this._dimSummary.dataDimIndicesOnCoord,n=0,i=e.length;n<i;n++)if(isNaN(this._store.get(e[n],t)))return!1;return!0},r.prototype.indexOfName=function(t){for(var e=0,n=this._store.count();e<n;e++)if(this.getName(e)===t)return e;return-1},r.prototype.getRawIndex=function(t){return this._store.getRawIndex(t)},r.prototype.indexOfRawIndex=function(t){return this._store.indexOfRawIndex(t)},r.prototype.rawIndexOf=function(t,e){var n=t&&this._invertedIndicesMap[t],i=n&&n[e];return i==null||isNaN(i)?ed:i},r.prototype.each=function(t,e,n){et(t)&&(n=e,e=t,t=[]);var i=n||this,a=mr(Zi(t),this._getStoreDimIndex,this);this._store.each(a,i?Q(e,i):e)},r.prototype.filterSelf=function(t,e,n){et(t)&&(n=e,e=t,t=[]);var i=n||this,a=mr(Zi(t),this._getStoreDimIndex,this);return this._store=this._store.filter(a,i?Q(e,i):e),this},r.prototype.selectRange=function(t){var e=this,n={},i=St(t);return D(i,function(a){var o=e._getStoreDimIndex(a);n[o]=t[a]}),this._store=this._store.selectRange(n),this},r.prototype.mapArray=function(t,e,n){et(t)&&(n=e,e=t,t=[]),n=n||this;var i=[];return this.each(t,function(){i.push(e&&e.apply(this,arguments))},n),i},r.prototype.map=function(t,e,n,i){var a=n||i||this,o=mr(Zi(t),this._getStoreDimIndex,this),s=Xi(this);return s._store=this._store.map(o,a?Q(e,a):e),s},r.prototype.modify=function(t,e,n,i){var a=n||i||this,o=mr(Zi(t),this._getStoreDimIndex,this);this._store.modify(o,a?Q(e,a):e)},r.prototype.downSample=function(t,e,n,i){var a=Xi(this);return a._store=this._store.downSample(this._getStoreDimIndex(t),e,n,i),a},r.prototype.minmaxDownSample=function(t,e){var n=Xi(this);return n._store=this._store.minmaxDownSample(this._getStoreDimIndex(t),e),n},r.prototype.lttbDownSample=function(t,e){var n=Xi(this);return n._store=this._store.lttbDownSample(this._getStoreDimIndex(t),e),n},r.prototype.getRawDataItem=function(t){return this._store.getRawDataItem(t)},r.prototype.getItemModel=function(t){var e=this.hostModel,n=this.getRawDataItem(t);return new xt(n,e,e&&e.ecModel)},r.prototype.diff=function(t){var e=this;return new If(t?t.getStore().getIndices():[],this.getStore().getIndices(),function(n){return Do(t,n)},function(n){return Do(e,n)})},r.prototype.getVisual=function(t){var e=this._visual;return e&&e[t]},r.prototype.setVisual=function(t,e){this._visual=this._visual||{},Ui(t)?O(this._visual,t):this._visual[t]=e},r.prototype.getItemVisual=function(t,e){var n=this._itemVisuals[t],i=n&&n[e];return i??this.getVisual(e)},r.prototype.hasItemVisual=function(){return this._itemVisuals.length>0},r.prototype.ensureUniqueItemVisual=function(t,e){var n=this._itemVisuals,i=n[t];i||(i=n[t]={});var a=i[e];return a==null&&(a=this.getVisual(e),H(a)?a=a.slice():Ui(a)&&(a=O({},a)),i[e]=a),a},r.prototype.setItemVisual=function(t,e,n){var i=this._itemVisuals[t]||{};this._itemVisuals[t]=i,Ui(e)?O(i,e):i[e]=n},r.prototype.clearAllVisual=function(){this._visual={},this._itemVisuals=[]},r.prototype.setLayout=function(t,e){Ui(t)?O(this._layout,t):this._layout[t]=e},r.prototype.getLayout=function(t){return this._layout[t]},r.prototype.getItemLayout=function(t){return this._itemLayouts[t]},r.prototype.setItemLayout=function(t,e,n){this._itemLayouts[t]=n?O(this._itemLayouts[t]||{},e):e},r.prototype.clearItemLayouts=function(){this._itemLayouts.length=0},r.prototype.setItemGraphicEl=function(t,e){var n=this.hostModel&&this.hostModel.seriesIndex;Wb(n,this.dataType,t,e),this._graphicEls[t]=e},r.prototype.getItemGraphicEl=function(t){return this._graphicEls[t]},r.prototype.eachItemGraphicEl=function(t,e){D(this._graphicEls,function(n,i){n&&t&&t.call(e,n,i)})},r.prototype.cloneShallow=function(t){return t||(t=new r(this._schema?this._schema:mr(this.dimensions,this._getDimInfo,this),this.hostModel)),ru(t,this),t._store=this._store,t},r.prototype.wrapMethod=function(t,e){var n=this[t];et(n)&&(this.__wrappedMethods=this.__wrappedMethods||[],this.__wrappedMethods.push(t),this[t]=function(){var i=n.apply(this,arguments);return e.apply(this,[i].concat(bh(arguments)))})},r.internalField=(function(){rd=function(t){var e=t._invertedIndicesMap;D(e,function(n,i){var a=t._dimInfos[i],o=a.ordinalMeta,s=t._store;if(o){n=e[i]=new Ox(o.categories.length);for(var l=0;l<n.length;l++)n[l]=ed;for(var l=0;l<s.count();l++)n[s.get(a.storeDimIndex,l)]=l}})},Yi=function(t,e,n){return $e(t._getCategory(e,n),null)},Do=function(t,e){var n=t._idList[e];return n==null&&t._idDimIdx!=null&&(n=Yi(t,t._idDimIdx,e)),n==null&&(n=Bx+e),n},Zi=function(t){return H(t)||(t=t!=null?[t]:[]),t},Xi=function(t){var e=new r(t._schema?t._schema:mr(t.dimensions,t._getDimInfo,t),t.hostModel);return ru(e,t),e},ru=function(t,e){D(Nx.concat(e.__wrappedMethods||[]),function(n){e.hasOwnProperty(n)&&(t[n]=e[n])}),t.__wrappedMethods=e.__wrappedMethods,D(Fx,function(n){t[n]=st(e[n])}),t._calculationInfo=O({},e._calculationInfo)},nu=function(t,e){var n=t._nameList,i=t._idList,a=t._nameDimIdx,o=t._idDimIdx,s=n[e],l=i[e];if(s==null&&a!=null&&(n[e]=s=Yi(t,a,e)),l==null&&o!=null&&(i[e]=l=Yi(t,o,e)),l==null&&s!=null){var u=t._nameRepeatCount,f=u[s]=(u[s]||0)+1;l=s,f>1&&(l+="__ec__"+f),i[e]=l}}})(),r})();function Hx(r,t){Zh(r)||(r=Cy(r)),t=t||{};var e=t.coordDimensions||[],n=t.dimensionsDefine||r.dimensionsDefine||[],i=K(),a=[],o=Gx(r,e,n,t.dimensionsCount),s=t.canOmitUnusedDimensions&&Gy(o),l=n===r.dimensionsDefine,u=l?Vy(r):Hy(n),f=t.encodeDefine;!f&&t.encodeDefaulter&&(f=t.encodeDefaulter(r,o));for(var h=K(f),c=new By(o),v=0;v<c.length;v++)c[v]=-1;function d(x){var M=c[x];if(M<0){var A=n[x],P=X(A)?A:{name:A},L=new Jo,I=P.name;I!=null&&u.get(I)!=null&&(L.name=L.displayName=I),P.type!=null&&(L.type=P.type),P.displayName!=null&&(L.displayName=P.displayName);var R=a.length;return c[x]=R,L.storeDimIndex=x,a.push(L),L}return a[M]}if(!s)for(var v=0;v<o;v++)d(v);h.each(function(x,M){var A=Ct(x).slice();if(A.length===1&&!W(A[0])&&A[0]<0){h.set(M,!1);return}var P=h.set(M,[]);D(A,function(L,I){var R=W(L)?u.get(L):L;R!=null&&R<o&&(P[I]=R,g(d(R),M,I))})});var p=0;D(e,function(x){var M,A,P,L;if(W(x))M=x,L={};else{L=x,M=L.name;var I=L.ordinalMeta;L.ordinalMeta=null,L=O({},L),L.ordinalMeta=I,A=L.dimsDef,P=L.otherDims,L.name=L.coordDim=L.coordDimIndex=L.dimsDef=L.otherDims=null}var R=h.get(M);if(R!==!1){if(R=Ct(R),!R.length)for(var E=0;E<(A&&A.length||1);E++){for(;p<o&&d(p).coordDim!=null;)p++;p<o&&R.push(p++)}D(R,function(V,B){var k=d(V);if(l&&L.type!=null&&(k.type=L.type),g(at(k,L),M,B),k.name==null&&A){var G=A[B];!X(G)&&(G={name:G}),k.name=k.displayName=G.name,k.defaultTooltip=G.defaultTooltip}P&&at(k.otherDims,P)})}});function g(x,M,A){by.get(M)!=null?x.otherDims[M]=A:(x.coordDim=M,x.coordDimIndex=A,i.set(M,!0))}var m=t.generateCoord,y=t.generateCoordCount,_=y!=null;y=m?y||1:0;var S=m||"value";function w(x){x.name==null&&(x.name=x.coordDim)}if(s)D(a,function(x){w(x)}),a.sort(function(x,M){return x.storeDimIndex-M.storeDimIndex});else for(var b=0;b<o;b++){var T=d(b),C=T.coordDim;C==null&&(T.coordDim=Wx(S,i,_),T.coordDimIndex=0,(!m||y<=0)&&(T.isExtraCoord=!0),y--),w(T),T.type==null&&(My(r,b)===se.Must||T.isExtraCoord&&(T.otherDims.itemName!=null||T.otherDims.seriesName!=null))&&(T.type="ordinal")}return Vx(a),new Fy({source:r,dimensions:a,fullDimensionCount:o,dimensionOmitted:s})}function Vx(r){for(var t=K(),e=0;e<r.length;e++){var n=r[e],i=n.name,a=t.get(i)||0;a>0&&(n.name=i+(a-1)),a++,t.set(i,a)}}function Gx(r,t,e,n){var i=Math.max(r.dimensionsDetectedCount||1,t.length,e.length,n||0);return D(t,function(a){var o;X(a)&&(o=a.dimsDef)&&(i=Math.max(i,o.length))}),i}function Wx(r,t,e){if(e||t.hasKey(r)){for(var n=0;t.hasKey(r+n);)n++;r+=n}return t.set(r,!0),r}var es={},iu={},$h=(function(){function r(){this._normalMasterList=[],this._nonSeriesBoxMasterList=[]}return r.prototype.create=function(t,e){this._nonSeriesBoxMasterList=n(es),this._normalMasterList=n(iu);function n(i,a){var o=[];return D(i,function(s,l){var u=s.create(t,e);o=o.concat(u||[])}),o}},r.prototype.update=function(t,e){D(this._normalMasterList,function(n){n.update&&n.update(t,e)})},r.prototype.getCoordinateSystems=function(){return this._normalMasterList.concat(this._nonSeriesBoxMasterList)},r.register=function(t,e){if(t==="matrix"||t==="calendar"){es[t]=e;return}iu[t]=e},r.get=function(t){return iu[t]||es[t]},r})();function Ux(r){return!!es[r]}var nd={coord:1,coord2:2},Yx=K();function Zx(r){var t=r.getShallow("coord",!0),e=nd.coord;if(t==null){var n=Yx.get(r.type);n&&n.getCoord2&&(e=nd.coord2,t=n.getCoord2(r))}return{coord:t,from:e}}var ir={none:0,dataCoordSys:1,boxCoordSys:2};function Xx(r,t){var e=r.getShallow("coordinateSystem"),n=r.getShallow("coordinateSystemUsage",!0),i=ir.none;if(e){var a=r.mainType==="series";n==null&&(n=a?"data":"box"),n==="data"?(i=ir.dataCoordSys,a||(i=ir.none)):n==="box"&&(i=ir.boxCoordSys,!a&&!Ux(e)&&(i=ir.none))}return{coordSysType:e,kind:i}}function $x(r){var t=r.targetModel,e=r.coordSysType,n=r.coordSysProvider,i=r.isDefaultDataCoordSys,a=Xx(t),o=a.kind,s=a.coordSysType;if(i&&o!==ir.dataCoordSys&&(o=ir.dataCoordSys,s=e),o===ir.none||s!==e)return!1;var l=n(e,t);return l?(o===ir.dataCoordSys?t.coordinateSystem=l:t.boxCoordinateSystem=l,!0):!1}var qx=(function(){function r(t){this.coordSysDims=[],this.axisMap=K(),this.categoryAxisMap=K(),this.coordSysName=t}return r})();function Kx(r){var t=r.get("coordinateSystem"),e=new qx(t),n=Qx[t];if(n)return n(r,e,e.axisMap,e.categoryAxisMap),e}var Qx={cartesian2d:function(r,t,e,n){var i=r.getReferringComponents("xAxis",qt).models[0],a=r.getReferringComponents("yAxis",qt).models[0];t.coordSysDims=["x","y"],e.set("x",i),e.set("y",a),Qn(i)&&(n.set("x",i),t.firstCategoryDimIndex=0),Qn(a)&&(n.set("y",a),t.firstCategoryDimIndex==null&&(t.firstCategoryDimIndex=1))},singleAxis:function(r,t,e,n){var i=r.getReferringComponents("singleAxis",qt).models[0];t.coordSysDims=["single"],e.set("single",i),Qn(i)&&(n.set("single",i),t.firstCategoryDimIndex=0)},polar:function(r,t,e,n){var i=r.getReferringComponents("polar",qt).models[0],a=i.findAxisModel("radiusAxis"),o=i.findAxisModel("angleAxis");t.coordSysDims=["radius","angle"],e.set("radius",a),e.set("angle",o),Qn(a)&&(n.set("radius",a),t.firstCategoryDimIndex=0),Qn(o)&&(n.set("angle",o),t.firstCategoryDimIndex==null&&(t.firstCategoryDimIndex=1))},geo:function(r,t,e,n){t.coordSysDims=["lng","lat"]},parallel:function(r,t,e,n){var i=r.ecModel,a=i.getComponent("parallel",r.get("parallelIndex")),o=t.coordSysDims=a.dimensions.slice();D(a.parallelAxisIndex,function(s,l){var u=i.getComponent("parallelAxis",s),f=o[l];e.set(f,u),Qn(u)&&(n.set(f,u),t.firstCategoryDimIndex==null&&(t.firstCategoryDimIndex=l))})},matrix:function(r,t,e,n){var i=r.getReferringComponents("matrix",qt).models[0];t.coordSysDims=["x","y"];var a=i.getDimensionModel("x"),o=i.getDimensionModel("y");e.set("x",a),e.set("y",o),n.set("x",a),n.set("y",o)}};function Qn(r){return r.get("type")==="category"}function jx(r,t,e){e=e||{};var n=e.byIndex,i=e.stackedCoordDimension,a,o,s;Jx(t)?a=t:(o=t.schema,a=o.dimensions,s=t.store);var l=!!(r&&r.get("stack")),u,f,h,c;if(D(a,function(y,_){W(y)&&(a[_]=y={name:y}),l&&!y.isExtraCoord&&(!n&&!u&&y.ordinalMeta&&(u=y),!f&&y.type!=="ordinal"&&y.type!=="time"&&(!i||i===y.coordDim)&&(f=y))}),f&&!n&&!u&&(n=!0),f){h="__\0ecstackresult_"+r.id,c="__\0ecstackedover_"+r.id,u&&(u.createInvertedIndices=!0);var v=f.coordDim,d=f.type,p=0;D(a,function(y){y.coordDim===v&&p++});var g={name:h,coordDim:v,coordDimIndex:p,type:d,isExtraCoord:!0,isCalculationCoord:!0,storeDimIndex:a.length},m={name:c,coordDim:c,coordDimIndex:p+1,type:d,isExtraCoord:!0,isCalculationCoord:!0,storeDimIndex:a.length+1};o?(s&&(g.storeDimIndex=s.ensureCalculationDimension(c,d),m.storeDimIndex=s.ensureCalculationDimension(h,d)),o.appendCalculationDimension(g),o.appendCalculationDimension(m)):(a.push(g),a.push(m))}return{stackedDimension:f&&f.name,stackedByDimension:u&&u.name,isStackedByIndex:n,stackedOverDimension:c,stackResultDimension:h}}function Jx(r){return!zy(r.schema)}function Ha(r,t){return!!t&&t===r.getCalculationInfo("stackedDimension")}function tT(r,t){return Ha(r,t)?r.getCalculationInfo("stackResultDimension"):t}function eT(r,t){var e=r.get("coordinateSystem"),n=$h.get(e),i;return t&&t.coordSysDims&&(i=$(t.coordSysDims,function(a){var o={name:a},s=t.axisMap.get(a);if(s){var l=s.get("type");o.type=Tx(l)}return o})),i||(i=n&&(n.getDimensionsInfo?n.getDimensionsInfo():n.dimensions.slice())||["x","y"]),i}function rT(r,t,e){var n,i;return e&&D(r,function(a,o){var s=a.coordDim,l=e.categoryAxisMap.get(s);l&&(n==null&&(n=o),a.ordinalMeta=l.getOrdinalMeta(),t&&(a.createInvertedIndices=!0)),a.otherDims.itemName!=null&&(i=!0)}),!i&&n!=null&&(r[n].otherDims.itemName=0),n}function nT(r,t,e){e=e||{};var n=t.getSourceManager(),i,a=!1;i=n.getSource(),a=i.sourceFormat===ce;var o=Kx(t),s=eT(t,o),l=e.useEncodeDefaulter,u=et(l)?l:l?ie(vx,s,t):null,f={coordDimensions:s,generateCoord:e.generateCoord,encodeDefine:t.getEncode(),encodeDefaulter:u,canOmitUnusedDimensions:!a},h=Hx(i,f),c=rT(h.dimensions,e.createInvertedIndices,o),v=a?null:n.getSharedDataStore(h),d=jx(t,{schema:h,store:v}),p=new zx(h,t);p.setCalculationInfo(d);var g=c!=null&&iT(i)?function(m,y,_,S){return S===c?_:this.defaultDimValueGetter(m,y,_,S)}:null;return p.hasItemOption=!1,p.initData(a?i:v,null,g),p}function iT(r){if(r.sourceFormat===ce){var t=aT(r.data||[]);return!H(ja(t))}}function aT(r){for(var t=0;t<r.length&&r[t]==null;)t++;return r[t]}var oT=Math.round(Math.random()*10);function ml(r){return[r||"",oT++].join("_")}function sT(r){var t={};r.registerSubTypeDefaulter=function(e,n){var i=Ue(e);t[i.main]=n},r.determineSubType=function(e,n){var i=n.type;if(!i){var a=Ue(e).main;r.hasSubTypes(e)&&t[a]&&(i=t[a](n))}return i}}function lT(r,t){r.topologicalTravel=function(a,o,s,l){if(!a.length)return;var u=e(o),f=u.graph,h=u.noEntryList,c={};for(D(a,function(y){c[y]=!0});h.length;){var v=h.pop(),d=f[v],p=!!c[v];p&&(s.call(l,v,d.originalDeps.slice()),delete c[v]),D(d.successor,p?m:g)}D(c,function(){var y="";throw new Error(y)});function g(y){f[y].entryCount--,f[y].entryCount===0&&h.push(y)}function m(y){c[y]=!0,g(y)}};function e(a){var o={},s=[];return D(a,function(l){var u=n(o,l),f=u.originalDeps=t(l),h=i(f,a);u.entryCount=h.length,u.entryCount===0&&s.push(l),D(h,function(c){ft(u.predecessor,c)<0&&u.predecessor.push(c);var v=n(o,c);ft(v.successor,c)<0&&v.successor.push(l)})}),{graph:o,noEntryList:s}}function n(a,o){return a[o]||(a[o]={predecessor:[],successor:[]}),a[o]}function i(a,o){var s=[];return D(a,function(l){ft(o,l)>=0&&s.push(l)}),s}}function Wy(r,t){return vt(vt({},r,!0),t,!0)}var uT=Math.log(2);function Ef(r,t,e,n,i,a){var o=n+"-"+i,s=r.length;if(a.hasOwnProperty(o))return a[o];if(t===1){var l=Math.round(Math.log((1<<s)-1&~i)/uT);return r[e][l]}for(var u=n|1<<e,f=e+1;n&1<<f;)f++;for(var h=0,c=0,v=0;c<s;c++){var d=1<<c;d&i||(h+=(v%2?-1:1)*r[e][c]*Ef(r,t-1,f,u,i|d,a),v++)}return a[o]=h,h}function id(r,t){var e=[[r[0],r[1],1,0,0,0,-t[0]*r[0],-t[0]*r[1]],[0,0,0,r[0],r[1],1,-t[1]*r[0],-t[1]*r[1]],[r[2],r[3],1,0,0,0,-t[2]*r[2],-t[2]*r[3]],[0,0,0,r[2],r[3],1,-t[3]*r[2],-t[3]*r[3]],[r[4],r[5],1,0,0,0,-t[4]*r[4],-t[4]*r[5]],[0,0,0,r[4],r[5],1,-t[5]*r[4],-t[5]*r[5]],[r[6],r[7],1,0,0,0,-t[6]*r[6],-t[6]*r[7]],[0,0,0,r[6],r[7],1,-t[7]*r[6],-t[7]*r[7]]],n={},i=Ef(e,8,0,0,0,n);if(i!==0){for(var a=[],o=0;o<8;o++)for(var s=0;s<8;s++)a[s]==null&&(a[s]=0),a[s]+=((o+s)%2?-1:1)*Ef(e,7,o===0?1:0,1<<o,1<<s,n)/i*t[o];return function(l,u,f){var h=u*a[6]+f*a[7]+1;l[0]=(u*a[0]+f*a[1]+a[2])/h,l[1]=(u*a[3]+f*a[4]+a[5])/h}}}var As="___zrEVENTSAVED",au=[];function fT(r,t,e,n,i){return kf(au,t,n,i,!0)&&kf(r,e,au[0],au[1])}function hT(r,t){r&&e(r),t&&e(t);function e(n){var i=n[As];i&&(i.clearMarkers&&i.clearMarkers(),delete n[As])}}function kf(r,t,e,n,i){if(t.getBoundingClientRect&&nt.domSupported&&!Uy(t)){var a=t[As]||(t[As]={}),o=vT(t,a),s=cT(o,a,i);if(s)return s(r,e,n),!0}return!1}function vT(r,t){var e=t.markers;if(e)return e;e=t.markers=[];for(var n=["left","right"],i=["top","bottom"],a=0;a<4;a++){var o=document.createElement("div"),s=o.style,l=a%2,u=(a>>1)%2;s.cssText=["position: absolute","visibility: hidden","padding: 0","margin: 0","border-width: 0","user-select: none","width:0","height:0",n[l]+":0",i[u]+":0",n[1-l]+":auto",i[1-u]+":auto",""].join("!important;"),r.appendChild(o),e.push(o)}return t.clearMarkers=function(){D(e,function(f){f.parentNode&&f.parentNode.removeChild(f)})},e}function cT(r,t,e){for(var n=e?"invTrans":"trans",i=t[n],a=t.srcCoords,o=[],s=[],l=!0,u=0;u<4;u++){var f=r[u].getBoundingClientRect(),h=2*u,c=f.left,v=f.top;o.push(c,v),l=l&&a&&c===a[h]&&v===a[h+1],s.push(r[u].offsetLeft,r[u].offsetTop)}return l&&i?i:(t.srcCoords=o,t[n]=e?id(s,o):id(o,s))}function Uy(r){return r.nodeName.toUpperCase()==="CANVAS"}var dT=/([&<>"'])/g,pT={"&":"&amp;","<":"&lt;",">":"&gt;",'"':"&quot;","'":"&#39;"};function re(r){return r==null?"":(r+"").replace(dT,function(t,e){return pT[e]})}const gT={time:{month:["January","February","March","April","May","June","July","August","September","October","November","December"],monthAbbr:["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"],dayOfWeek:["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"],dayOfWeekAbbr:["Sun","Mon","Tue","Wed","Thu","Fri","Sat"]},legend:{selector:{all:"All",inverse:"Inv"}},toolbox:{brush:{title:{rect:"Box Select",polygon:"Lasso Select",lineX:"Horizontally Select",lineY:"Vertically Select",keep:"Keep Selections",clear:"Clear Selections"}},dataView:{title:"Data View",lang:["Data View","Close","Refresh"]},dataZoom:{title:{zoom:"Zoom",back:"Zoom Reset"}},magicType:{title:{line:"Switch to Line Chart",bar:"Switch to Bar Chart",stack:"Stack",tiled:"Tile"}},restore:{title:"Restore"},saveAsImage:{title:"Save as Image",lang:["Right Click to Save Image"]}},series:{typeNames:{pie:"Pie chart",bar:"Bar chart",line:"Line chart",scatter:"Scatter plot",effectScatter:"Ripple scatter plot",radar:"Radar chart",tree:"Tree",treemap:"Treemap",boxplot:"Boxplot",candlestick:"Candlestick",k:"K line chart",heatmap:"Heat map",map:"Map",parallel:"Parallel coordinate map",lines:"Line graph",graph:"Relationship graph",sankey:"Sankey diagram",funnel:"Funnel chart",gauge:"Gauge",pictorialBar:"Pictorial bar",themeRiver:"Theme River Map",sunburst:"Sunburst",custom:"Custom chart",chart:"Chart"}},aria:{general:{withTitle:'This is a chart about "{title}"',withoutTitle:"This is a chart"},series:{single:{prefix:"",withName:" with type {seriesType} named {seriesName}.",withoutName:" with type {seriesType}."},multiple:{prefix:". It consists of {seriesCount} series count.",withName:" The {seriesId} series is a {seriesType} representing {seriesName}.",withoutName:" The {seriesId} series is a {seriesType}.",separator:{middle:"",end:""}}},data:{allData:"The data is as follows: ",partialData:"The first {displayCnt} items are: ",withName:"the data for {name} is {value}",withoutName:"{value}",separator:{middle:", ",end:". "}}}},mT={time:{month:["一月","二月","三月","四月","五月","六月","七月","八月","九月","十月","十一月","十二月"],monthAbbr:["1月","2月","3月","4月","5月","6月","7月","8月","9月","10月","11月","12月"],dayOfWeek:["星期日","星期一","星期二","星期三","星期四","星期五","星期六"],dayOfWeekAbbr:["日","一","二","三","四","五","六"]},legend:{selector:{all:"全选",inverse:"反选"}},toolbox:{brush:{title:{rect:"矩形选择",polygon:"圈选",lineX:"横向选择",lineY:"纵向选择",keep:"保持选择",clear:"清除选择"}},dataView:{title:"数据视图",lang:["数据视图","关闭","刷新"]},dataZoom:{title:{zoom:"区域缩放",back:"区域缩放还原"}},magicType:{title:{line:"切换为折线图",bar:"切换为柱状图",stack:"切换为堆叠",tiled:"切换为平铺"}},restore:{title:"还原"},saveAsImage:{title:"保存为图片",lang:["右键另存为图片"]}},series:{typeNames:{pie:"饼图",bar:"柱状图",line:"折线图",scatter:"散点图",effectScatter:"涟漪散点图",radar:"雷达图",tree:"树图",treemap:"矩形树图",boxplot:"箱型图",candlestick:"K线图",k:"K线图",heatmap:"热力图",map:"地图",parallel:"平行坐标图",lines:"线图",graph:"关系图",sankey:"桑基图",funnel:"漏斗图",gauge:"仪表盘图",pictorialBar:"象形柱图",themeRiver:"主题河流图",sunburst:"旭日图",custom:"自定义图表",chart:"图表"}},aria:{general:{withTitle:"这是一个关于“{title}”的图表。",withoutTitle:"这是一个图表，"},series:{single:{prefix:"",withName:"图表类型是{seriesType}，表示{seriesName}。",withoutName:"图表类型是{seriesType}。"},multiple:{prefix:"它由{seriesCount}个图表系列组成。",withName:"第{seriesId}个系列是一个表示{seriesName}的{seriesType}，",withoutName:"第{seriesId}个系列是一个{seriesType}，",separator:{middle:"；",end:"。"}}},data:{allData:"其数据是——",partialData:"其中，前{displayCnt}项是——",withName:"{name}的数据是{value}",withoutName:"{value}",separator:{middle:"，",end:""}}}};var Ls="ZH",qh="EN",xi=qh,rs={},Kh={},Yy=nt.domSupported?(function(){var r=(document.documentElement.lang||navigator.language||navigator.browserLanguage||xi).toUpperCase();return r.indexOf(Ls)>-1?Ls:xi})():xi;function Zy(r,t){r=r.toUpperCase(),Kh[r]=new xt(t),rs[r]=t}function yT(r){if(W(r)){var t=rs[r.toUpperCase()]||{};return r===Ls||r===qh?st(t):vt(st(t),st(rs[xi]),!1)}else return vt(st(r),st(rs[xi]),!1)}function _T(r){return Kh[r]}function ST(){return Kh[xi]}Zy(qh,gT);Zy(Ls,mT);var bT=null;function Is(){return bT}var Qh=1e3,jh=Qh*60,Ta=jh*60,we=Ta*24,ad=we*365,wT={year:/({yyyy}|{yy})/,month:/({MMMM}|{MMM}|{MM}|{M})/,day:/({dd}|{d})/,hour:/({HH}|{H}|{hh}|{h})/,minute:/({mm}|{m})/,second:/({ss}|{s})/,millisecond:/({SSS}|{S})/},ns={year:"{yyyy}",month:"{MMM}",day:"{d}",hour:"{HH}:{mm}",minute:"{HH}:{mm}",second:"{HH}:{mm}:{ss}",millisecond:"{HH}:{mm}:{ss} {SSS}"},xT="{yyyy}-{MM}-{dd} {HH}:{mm}:{ss} {SSS}",Ao="{yyyy}-{MM}-{dd}",od={year:"{yyyy}",month:"{yyyy}-{MM}",day:Ao,hour:Ao+" "+ns.hour,minute:Ao+" "+ns.minute,second:Ao+" "+ns.second,millisecond:xT},Pn=["year","month","day","hour","minute","second","millisecond"],TT=["year","half-year","quarter","month","week","half-week","day","half-day","quarter-day","hour","minute","second","millisecond"];function MT(r){return!W(r)&&!et(r)?CT(r):r}function CT(r){r=r||{};var t={},e=!0;return D(Pn,function(n){e&&(e=r[n]==null)}),D(Pn,function(n,i){var a=r[n];t[n]={};for(var o=null,s=i;s>=0;s--){var l=Pn[s],u=X(a)&&!H(a)?a[l]:a,f=void 0;H(u)?(f=u.slice(),o=f[0]||""):W(u)?(o=u,f=[o]):(o==null?o=ns[n]:wT[l].test(o)||(o=t[l][l][0]+" "+o),f=[o],e&&(f[1]="{primary|"+o+"}")),t[n][l]=f}}),t}function yr(r,t){return r+="","0000".substr(0,t-r.length)+r}function Ma(r){switch(r){case"half-year":case"quarter":return"month";case"week":case"half-week":return"day";case"half-day":case"quarter-day":return"hour";default:return r}}function DT(r){return r===Ma(r)}function AT(r){switch(r){case"year":case"month":return"day";case"millisecond":return"millisecond";default:return"second"}}function yl(r,t,e,n){var i=Ni(r),a=i[Xy(e)](),o=i[Jh(e)]()+1,s=Math.floor((o-1)/3)+1,l=i[tv(e)](),u=i["get"+(e?"UTC":"")+"Day"](),f=i[ev(e)](),h=(f-1)%12+1,c=i[rv(e)](),v=i[nv(e)](),d=i[iv(e)](),p=f>=12?"pm":"am",g=p.toUpperCase(),m=n instanceof xt?n:_T(n||Yy)||ST(),y=m.getModel("time"),_=y.get("month"),S=y.get("monthAbbr"),w=y.get("dayOfWeek"),b=y.get("dayOfWeekAbbr");return(t||"").replace(/{a}/g,p+"").replace(/{A}/g,g+"").replace(/{yyyy}/g,a+"").replace(/{yy}/g,yr(a%100+"",2)).replace(/{Q}/g,s+"").replace(/{MMMM}/g,_[o-1]).replace(/{MMM}/g,S[o-1]).replace(/{MM}/g,yr(o,2)).replace(/{M}/g,o+"").replace(/{dd}/g,yr(l,2)).replace(/{d}/g,l+"").replace(/{eeee}/g,w[u]).replace(/{ee}/g,b[u]).replace(/{e}/g,u+"").replace(/{HH}/g,yr(f,2)).replace(/{H}/g,f+"").replace(/{hh}/g,yr(h+"",2)).replace(/{h}/g,h+"").replace(/{mm}/g,yr(c,2)).replace(/{m}/g,c+"").replace(/{ss}/g,yr(v,2)).replace(/{s}/g,v+"").replace(/{SSS}/g,yr(d,3)).replace(/{S}/g,d+"")}function LT(r,t,e,n,i){var a=null;if(W(e))a=e;else if(et(e)){var o={time:r.time,level:r.time.level},s=Is();s&&s.makeAxisLabelFormatterParamBreak(o,r.break),a=e(r.value,t,o)}else{var l=r.time;if(l){var u=e[l.lowerTimeUnit][l.upperTimeUnit];a=u[Math.min(l.level,u.length-1)]||""}else{var f=Ps(r.value,i);a=e[f][f][0]}}return yl(new Date(r.value),a,i,n)}function Ps(r,t){var e=Ni(r),n=e[Jh(t)]()+1,i=e[tv(t)](),a=e[ev(t)](),o=e[rv(t)](),s=e[nv(t)](),l=e[iv(t)](),u=l===0,f=u&&s===0,h=f&&o===0,c=h&&a===0,v=c&&i===1,d=v&&n===1;return d?"year":v?"month":c?"day":h?"hour":f?"minute":u?"second":"millisecond"}function Of(r,t,e){switch(t){case"year":r[$y(e)](0);case"month":r[qy(e)](1);case"day":r[Ky(e)](0);case"hour":r[Qy(e)](0);case"minute":r[jy(e)](0);case"second":r[Jy(e)](0)}return r}function Xy(r){return r?"getUTCFullYear":"getFullYear"}function Jh(r){return r?"getUTCMonth":"getMonth"}function tv(r){return r?"getUTCDate":"getDate"}function ev(r){return r?"getUTCHours":"getHours"}function rv(r){return r?"getUTCMinutes":"getMinutes"}function nv(r){return r?"getUTCSeconds":"getSeconds"}function iv(r){return r?"getUTCMilliseconds":"getMilliseconds"}function IT(r){return r?"setUTCFullYear":"setFullYear"}function $y(r){return r?"setUTCMonth":"setMonth"}function qy(r){return r?"setUTCDate":"setDate"}function Ky(r){return r?"setUTCHours":"setHours"}function Qy(r){return r?"setUTCMinutes":"setMinutes"}function jy(r){return r?"setUTCSeconds":"setSeconds"}function Jy(r){return r?"setUTCMilliseconds":"setMilliseconds"}function t0(r){if(!Tb(r))return W(r)?r:"-";var t=(r+"").split(".");return t[0].replace(/(\d{1,3})(?=(?:\d{3})+(?!\d))/g,"$1,")+(t.length>1?"."+t[1]:"")}function e0(r,t){return r=(r||"").toLowerCase().replace(/-(.)/g,function(e,n){return n.toUpperCase()}),t&&r&&(r=r.charAt(0).toUpperCase()+r.slice(1)),r}var av=wh;function Bf(r,t,e){var n="{yyyy}-{MM}-{dd} {HH}:{mm}:{ss}";function i(f){return f&&We(f)?f:"-"}function a(f){return!!(f!=null&&!isNaN(f)&&isFinite(f))}var o=t==="time",s=r instanceof Date;if(o||s){var l=o?Ni(r):r;if(isNaN(+l)){if(s)return"-"}else return yl(l,n,e)}if(t==="ordinal")return Qu(r)?i(r):mt(r)&&a(r)?r+"":"-";var u=Fr(r);return a(u)?t0(u):Qu(r)?i(r):typeof r=="boolean"?r+"":"-"}var sd=["a","b","c","d","e","f","g"],ou=function(r,t){return"{"+r+(t??"")+"}"};function r0(r,t,e){H(t)||(t=[t]);var n=t.length;if(!n)return"";for(var i=t[0].$vars||[],a=0;a<i.length;a++){var o=sd[a];r=r.replace(ou(o),ou(o,0))}for(var s=0;s<n;s++)for(var l=0;l<i.length;l++){var u=t[s][i[l]];r=r.replace(ou(sd[l],s),e?re(u):u)}return r}function PT(r,t){var e=W(r)?{color:r,extraCssText:t}:r||{},n=e.color,i=e.type;t=e.extraCssText;var a=e.renderMode||"html";if(!n)return"";if(a==="html")return i==="subItem"?'<span style="display:inline-block;vertical-align:middle;margin-right:8px;margin-left:3px;border-radius:4px;width:4px;height:4px;background-color:'+re(n)+";"+(t||"")+'"></span>':'<span style="display:inline-block;margin-right:4px;border-radius:10px;width:10px;height:10px;background-color:'+re(n)+";"+(t||"")+'"></span>';var o=e.markerId||"markerX";return{renderMode:a,content:"{"+o+"|}  ",style:i==="subItem"?{width:4,height:4,borderRadius:2,backgroundColor:n}:{width:10,height:10,borderRadius:5,backgroundColor:n}}}function On(r,t){return t=t||"transparent",W(r)?r:X(r)&&r.colorStops&&(r.colorStops[0]||{}).color||t}function ld(r,t){if(t==="_blank"||t==="blank"){var e=window.open();e.opener=null,e.location.href=r}else window.open(r,t)}var is=D,RT=["left","right","top","bottom","width","height"],Lo=[["width","left","right"],["height","top","bottom"]];function n0(r,t,e,n,i){var a=0,o=0;n==null&&(n=1/0),i==null&&(i=1/0);var s=0;t.eachChild(function(l,u){var f=l.getBoundingRect(),h=t.childAt(u+1),c=h&&h.getBoundingRect(),v,d;if(r==="horizontal"){var p=f.width+(c?-c.x+f.x:0);v=a+p,v>n||l.newline?(a=0,v=p,o+=s+e,s=f.height):s=Math.max(s,f.height)}else{var g=f.height+(c?-c.y+f.y:0);d=o+g,d>i||l.newline?(a+=s+e,o=0,d=g,s=f.width):s=Math.max(s,f.width)}l.newline||(l.x=a,l.y=o,l.markRedraw(),r==="horizontal"?a=v+e:o=d+e)})}ie(n0,"vertical");ie(n0,"horizontal");function ET(r,t){return{left:r.getShallow("left",t),top:r.getShallow("top",t),right:r.getShallow("right",t),bottom:r.getShallow("bottom",t),width:r.getShallow("width",t),height:r.getShallow("height",t)}}function ro(r,t,e){e=av(e||0);var n=t.width,i=t.height,a=It(r.left,n),o=It(r.top,i),s=It(r.right,n),l=It(r.bottom,i),u=It(r.width,n),f=It(r.height,i),h=e[2]+e[0],c=e[1]+e[3],v=r.aspect;switch(isNaN(u)&&(u=n-s-c-a),isNaN(f)&&(f=i-l-h-o),v!=null&&(isNaN(u)&&isNaN(f)&&(v>n/i?u=n*.8:f=i*.8),isNaN(u)&&(u=v*f),isNaN(f)&&(f=u/v)),isNaN(a)&&(a=n-s-u-c),isNaN(o)&&(o=i-l-f-h),r.left||r.right){case"center":a=n/2-u/2-e[3];break;case"right":a=n-u-c;break}switch(r.top||r.bottom){case"middle":case"center":o=i/2-f/2-e[0];break;case"bottom":o=i-f-h;break}a=a||0,o=o||0,isNaN(u)&&(u=n-c-a-(s||0)),isNaN(f)&&(f=i-h-o-(l||0));var d=new it((t.x||0)+a+e[3],(t.y||0)+o+e[0],u,f);return d.margin=e,d}var su={rect:1};function ov(r,t,e){var n,i,a,o=r.boxCoordinateSystem,s;if(o){var l=Zx(r),u=l.coord,f=l.from;if(o.dataToLayout){a=su.rect,s=f;var h=o.dataToLayout(u);n=h.contentRect||h.rect}}return a==null&&(a=su.rect),a===su.rect&&(n||(n={x:0,y:0,width:t.getWidth(),height:t.getHeight()}),i=[n.x+n.width/2,n.y+n.height/2]),{type:a,refContainer:n,refPoint:i,boxCoordFrom:s}}function Va(r){var t=r.layoutMode||r.constructor.layoutMode;return X(t)?t:t?{type:t}:null}function Bn(r,t,e){var n=e&&e.ignoreSize;!H(n)&&(n=[n,n]);var i=o(Lo[0],0),a=o(Lo[1],1);l(Lo[0],r,i),l(Lo[1],r,a);function o(u,f){var h={},c=0,v={},d=0,p=2;if(is(u,function(y){v[y]=r[y]}),is(u,function(y){ve(t,y)&&(h[y]=v[y]=t[y]),s(h,y)&&c++,s(v,y)&&d++}),n[f])return s(t,u[1])?v[u[2]]=null:s(t,u[2])&&(v[u[1]]=null),v;if(d===p||!c)return v;if(c>=p)return h;for(var g=0;g<u.length;g++){var m=u[g];if(!ve(h,m)&&ve(r,m)){h[m]=r[m];break}}return h}function s(u,f){return u[f]!=null&&u[f]!=="auto"}function l(u,f,h){is(u,function(c){f[c]=h[c]})}}function no(r){return kT({},r)}function kT(r,t){return t&&r&&is(RT,function(e){ve(t,e)&&(r[e]=t[e])}),r}var OT=gt(),dt=(function(r){z(t,r);function t(e,n,i){var a=r.call(this,e,n,i)||this;return a.uid=ml("ec_cpt_model"),a}return t.prototype.init=function(e,n,i){this.mergeDefaultAndTheme(e,i)},t.prototype.mergeDefaultAndTheme=function(e,n){var i=Va(this),a=i?no(e):{},o=n.getTheme();vt(e,o.get(this.mainType)),vt(e,this.getDefaultOption()),i&&Bn(e,a,i)},t.prototype.mergeOption=function(e,n){vt(this.option,e,!0);var i=Va(this);i&&Bn(this.option,e,i)},t.prototype.optionUpdated=function(e,n){},t.prototype.getDefaultOption=function(){var e=this.constructor;if(!G1(e))return e.defaultOption;var n=OT(this);if(!n.defaultOption){for(var i=[],a=e;a;){var o=a.prototype.defaultOption;o&&i.push(o),a=a.superClass}for(var s={},l=i.length-1;l>=0;l--)s=vt(s,i[l],!0);n.defaultOption=s}return n.defaultOption},t.prototype.getReferringComponents=function(e,n){var i=e+"Index",a=e+"Id";return Ja(this.ecModel,e,{index:this.get(i,!0),id:this.get(a,!0)},n)},t.prototype.getBoxLayoutParams=function(){return ET(this,!1)},t.prototype.getZLevelKey=function(){return""},t.prototype.setZLevel=function(e){this.option.zlevel=e},t.protoInitialize=(function(){var e=t.prototype;e.type="component",e.id="",e.name="",e.mainType="",e.subType="",e.componentIndex=0})(),t})(xt);tm(dt,xt);el(dt);sT(dt);lT(dt,BT);function BT(r){var t=[];return D(dt.getClassesByMainType(r),function(e){t=t.concat(e.dependencies||e.prototype.dependencies||[])}),t=$(t,function(e){return Ue(e).main}),r!=="dataset"&&ft(t,"dataset")<=0&&t.unshift("dataset"),t}var ud=gt();gt();var sv=(function(){function r(){}return r.prototype.getColorFromPalette=function(t,e,n){var i=Ct(this.get("color",!0)),a=this.get("colorLayer",!0);return FT(this,ud,i,a,t,e,n)},r.prototype.clearColorPalette=function(){zT(this,ud)},r})();function NT(r,t){for(var e=r.length,n=0;n<e;n++)if(r[n].length>t)return r[n];return r[e-1]}function FT(r,t,e,n,i,a,o){a=a||r;var s=t(a),l=s.paletteIdx||0,u=s.paletteNameMap=s.paletteNameMap||{};if(u.hasOwnProperty(i))return u[i];var f=o==null||!n?e:NT(n,o);if(f=f||e,!(!f||!f.length)){var h=f[l];return i&&(u[i]=h),s.paletteIdx=(l+1)%f.length,h}}function zT(r,t){t(r).paletteIdx=0,t(r).paletteNameMap={}}var HT=/\{@(.+?)\}/g,VT=(function(){function r(){}return r.prototype.getDataParams=function(t,e){var n=this.getData(e),i=this.getRawValue(t,e),a=n.getRawIndex(t),o=n.getName(t),s=n.getRawDataItem(t),l=n.getItemVisual(t,"style"),u=l&&l[n.getItemVisual(t,"drawType")||"fill"],f=l&&l.stroke,h=this.mainType,c=h==="series",v=n.userOutput&&n.userOutput.get();return{componentType:h,componentSubType:this.subType,componentIndex:this.componentIndex,seriesType:c?this.subType:null,seriesIndex:this.seriesIndex,seriesId:c?this.id:null,seriesName:c?this.name:null,name:o,dataIndex:a,data:s,dataType:e,value:i,color:u,borderColor:f,dimensionNames:v?v.fullDimensions:null,encode:v?v.encode:null,$vars:["seriesName","name","value"]}},r.prototype.getFormattedLabel=function(t,e,n,i,a,o){e=e||"normal";var s=this.getData(n),l=this.getDataParams(t,n);if(o&&(l.value=o.interpolatedValue),i!=null&&H(l.value)&&(l.value=l.value[i]),!a){var u=s.getItemModel(t);a=u.get(e==="normal"?["label","formatter"]:[e,"label","formatter"])}if(et(a))return l.status=e,l.dimensionIndex=i,a(l);if(W(a)){var f=r0(a,l);return f.replace(HT,function(h,c){var v=c.length,d=c;d.charAt(0)==="["&&d.charAt(v-1)==="]"&&(d=+d.slice(1,v-1));var p=Ai(s,t,d);if(o&&H(o.interpolatedValue)){var g=s.getDimensionIndex(d);g>=0&&(p=o.interpolatedValue[g])}return p!=null?p+"":""})}},r.prototype.getRawValue=function(t,e){return Ai(this.getData(e),t)},r.prototype.formatTooltip=function(t,e,n){},r})();function fd(r){var t,e;return X(r)?r.type&&(e=r):t=r,{text:t,frag:e}}function Ca(r){return new GT(r)}var GT=(function(){function r(t){t=t||{},this._reset=t.reset,this._plan=t.plan,this._count=t.count,this._onDirty=t.onDirty,this._dirty=!0}return r.prototype.perform=function(t){var e=this._upstream,n=t&&t.skip;if(this._dirty&&e){var i=this.context;i.data=i.outputData=e.context.outputData}this.__pipeline&&(this.__pipeline.currentTask=this);var a;this._plan&&!n&&(a=this._plan(this.context));var o=f(this._modBy),s=this._modDataCount||0,l=f(t&&t.modBy),u=t&&t.modDataCount||0;(o!==l||s!==u)&&(a="reset");function f(y){return!(y>=1)&&(y=1),y}var h;(this._dirty||a==="reset")&&(this._dirty=!1,h=this._doReset(n)),this._modBy=l,this._modDataCount=u;var c=t&&t.step;if(e?this._dueEnd=e._outputDueEnd:this._dueEnd=this._count?this._count(this.context):1/0,this._progress){var v=this._dueIndex,d=Math.min(c!=null?this._dueIndex+c:1/0,this._dueEnd);if(!n&&(h||v<d)){var p=this._progress;if(H(p))for(var g=0;g<p.length;g++)this._doProgress(p[g],v,d,l,u);else this._doProgress(p,v,d,l,u)}this._dueIndex=d;var m=this._settedOutputEnd!=null?this._settedOutputEnd:d;this._outputDueEnd=m}else this._dueIndex=this._outputDueEnd=this._settedOutputEnd!=null?this._settedOutputEnd:this._dueEnd;return this.unfinished()},r.prototype.dirty=function(){this._dirty=!0,this._onDirty&&this._onDirty(this.context)},r.prototype._doProgress=function(t,e,n,i,a){hd.reset(e,n,i,a),this._callingProgress=t,this._callingProgress({start:e,end:n,count:n-e,next:hd.next},this.context)},r.prototype._doReset=function(t){this._dueIndex=this._outputDueEnd=this._dueEnd=0,this._settedOutputEnd=null;var e,n;!t&&this._reset&&(e=this._reset(this.context),e&&e.progress&&(n=e.forceFirstProgress,e=e.progress),H(e)&&!e.length&&(e=null)),this._progress=e,this._modBy=this._modDataCount=null;var i=this._downstream;return i&&i.dirty(),n},r.prototype.unfinished=function(){return this._progress&&this._dueIndex<this._dueEnd},r.prototype.pipe=function(t){(this._downstream!==t||this._dirty)&&(this._downstream=t,t._upstream=this,t.dirty())},r.prototype.dispose=function(){this._disposed||(this._upstream&&(this._upstream._downstream=null),this._downstream&&(this._downstream._upstream=null),this._dirty=!1,this._disposed=!0)},r.prototype.getUpstream=function(){return this._upstream},r.prototype.getDownstream=function(){return this._downstream},r.prototype.setOutputEnd=function(t){this._outputDueEnd=this._settedOutputEnd=t},r})(),hd=(function(){var r,t,e,n,i,a={reset:function(l,u,f,h){t=l,r=u,e=f,n=h,i=Math.ceil(n/e),a.next=e>1&&n>0?s:o}};return a;function o(){return t<r?t++:null}function s(){var l=t%i*e+Math.ceil(t/i),u=t>=r?null:l<n?l:t;return t++,u}})(),WT=(function(){function r(){}return r.prototype.getRawData=function(){throw new Error("not supported")},r.prototype.getRawDataItem=function(t){throw new Error("not supported")},r.prototype.cloneRawData=function(){},r.prototype.getDimensionInfo=function(t){},r.prototype.cloneAllDimensionInfo=function(){},r.prototype.count=function(){},r.prototype.retrieveValue=function(t,e){},r.prototype.retrieveValueFromItem=function(t,e){},r.prototype.convertValue=function(t,e){return ts(t,e)},r})();function UT(r,t){var e=new WT,n=r.data,i=e.sourceFormat=r.sourceFormat,a=r.startIndex,o="";r.seriesLayoutBy!==Re&&ut(o);var s=[],l={},u=r.dimensionsDefine;if(u)D(u,function(p,g){var m=p.name,y={index:g,name:m,displayName:p.displayName};if(s.push(y),m!=null){var _="";ve(l,m)&&ut(_),l[m]=y}});else for(var f=0;f<r.dimensionsDetectedCount;f++)s.push({index:f});var h=Iy(i,Re);t.__isBuiltIn&&(e.getRawDataItem=function(p){return h(n,a,s,p)},e.getRawData=Q(YT,null,r)),e.cloneRawData=Q(ZT,null,r);var c=Py(i,Re);e.count=Q(c,null,n,a,s);var v=Ry(i);e.retrieveValue=function(p,g){var m=h(n,a,s,p);return d(m,g)};var d=e.retrieveValueFromItem=function(p,g){if(p!=null){var m=s[g];if(m)return v(p,g,m.name)}};return e.getDimensionInfo=Q(XT,null,s,l),e.cloneAllDimensionInfo=Q($T,null,s),e}function YT(r){var t=r.sourceFormat;if(!lv(t)){var e="";ut(e)}return r.data}function ZT(r){var t=r.sourceFormat,e=r.data;if(!lv(t)){var n="";ut(n)}if(t===zt){for(var i=[],a=0,o=e.length;a<o;a++)i.push(e[a].slice());return i}else if(t===Ce){for(var i=[],a=0,o=e.length;a<o;a++)i.push(O({},e[a]));return i}}function XT(r,t,e){if(e!=null){if(mt(e)||!isNaN(e)&&!ve(t,e))return r[e];if(ve(t,e))return t[e]}}function $T(r){return st(r)}var i0=K();function qT(r){r=st(r);var t=r.type,e="";t||ut(e);var n=t.split(":");n.length!==2&&ut(e);var i=!1;n[0]==="echarts"&&(t=n[1],i=!0),r.__isBuiltIn=i,i0.set(t,r)}function KT(r,t,e){var n=Ct(r),i=n.length,a="";i||ut(a);for(var o=0,s=i;o<s;o++){var l=n[o];t=QT(l,t),o!==s-1&&(t.length=Math.max(t.length,1))}return t}function QT(r,t,e,n){var i="";t.length||ut(i),X(r)||ut(i);var a=r.type,o=i0.get(a);o||ut(i);var s=$(t,function(u){return UT(u,o)}),l=Ct(o.transform({upstream:s[0],upstreamList:s,config:st(r.config)}));return $(l,function(u,f){var h="";X(u)||ut(h),u.data||ut(h);var c=Dy(u.data);lv(c)||ut(h);var v,d=t[0];if(d&&f===0&&!u.dimensions){var p=d.startIndex;p&&(u.data=d.data.slice(0,p).concat(u.data)),v={seriesLayoutBy:Re,sourceHeader:p,dimensions:d.metaRawOption.dimensions}}else v={seriesLayoutBy:Re,sourceHeader:0,dimensions:u.dimensions};return Pf(u.data,v,null)})}function lv(r){return r===zt||r===Ce}var a0=(function(){function r(t){this._sourceList=[],this._storeList=[],this._upstreamSignList=[],this._versionSignBase=0,this._dirty=!0,this._sourceHost=t}return r.prototype.dirty=function(){this._setLocalSource([],[]),this._storeList=[],this._dirty=!0},r.prototype._setLocalSource=function(t,e){this._sourceList=t,this._upstreamSignList=e,this._versionSignBase++,this._versionSignBase>9e10&&(this._versionSignBase=0)},r.prototype._getVersionSign=function(){return this._sourceHost.uid+"_"+this._versionSignBase},r.prototype.prepareSource=function(){this._isDirty()&&(this._createSource(),this._dirty=!1)},r.prototype._createSource=function(){this._setLocalSource([],[]);var t=this._sourceHost,e=this._getUpstreamSourceManagers(),n=!!e.length,i,a;if(Io(t)){var o=t,s=void 0,l=void 0,u=void 0;if(n){var f=e[0];f.prepareSource(),u=f.getSource(),s=u.data,l=u.sourceFormat,a=[f._getVersionSign()]}else s=o.get("data",!0),l=ae(s)?kr:ce,a=[];var h=this._getSourceMetaRawOption()||{},c=u&&u.metaRawOption||{},v=q(h.seriesLayoutBy,c.seriesLayoutBy)||null,d=q(h.sourceHeader,c.sourceHeader),p=q(h.dimensions,c.dimensions),g=v!==c.seriesLayoutBy||!!d!=!!c.sourceHeader||p;i=g?[Pf(s,{seriesLayoutBy:v,sourceHeader:d,dimensions:p},l)]:[]}else{var m=t;if(n){var y=this._applyTransform(e);i=y.sourceList,a=y.upstreamSignList}else{var _=m.get("source",!0);i=[Pf(_,this._getSourceMetaRawOption(),null)],a=[]}}this._setLocalSource(i,a)},r.prototype._applyTransform=function(t){var e=this._sourceHost,n=e.get("transform",!0),i=e.get("fromTransformResult",!0);if(i!=null){var a="";t.length!==1&&cd(a)}var o,s=[],l=[];return D(t,function(u){u.prepareSource();var f=u.getSource(i||0),h="";i!=null&&!f&&cd(h),s.push(f),l.push(u._getVersionSign())}),n?o=KT(n,s,{datasetIndex:e.componentIndex}):i!=null&&(o=[px(s[0])]),{sourceList:o,upstreamSignList:l}},r.prototype._isDirty=function(){if(this._dirty)return!0;for(var t=this._getUpstreamSourceManagers(),e=0;e<t.length;e++){var n=t[e];if(n._isDirty()||this._upstreamSignList[e]!==n._getVersionSign())return!0}},r.prototype.getSource=function(t){t=t||0;var e=this._sourceList[t];if(!e){var n=this._getUpstreamSourceManagers();return n[0]&&n[0].getSource(t)}return e},r.prototype.getSharedDataStore=function(t){var e=t.makeStoreSchema();return this._innerGetDataStore(e.dimensions,t.source,e.hash)},r.prototype._innerGetDataStore=function(t,e,n){var i=0,a=this._storeList,o=a[i];o||(o=a[i]={});var s=o[n];if(!s){var l=this._getUpstreamSourceManagers()[0];Io(this._sourceHost)&&l?s=l._innerGetDataStore(t,e,n):(s=new Rf,s.initData(new Ly(e,t.length),t)),o[n]=s}return s},r.prototype._getUpstreamSourceManagers=function(){var t=this._sourceHost;if(Io(t)){var e=Ty(t);return e?[e.getSourceManager()]:[]}else return $(cx(t),function(n){return n.getSourceManager()})},r.prototype._getSourceMetaRawOption=function(){var t=this._sourceHost,e,n,i;if(Io(t))e=t.get("seriesLayoutBy",!0),n=t.get("sourceHeader",!0),i=t.get("dimensions",!0);else if(!this._getUpstreamSourceManagers().length){var a=t;e=a.get("seriesLayoutBy",!0),n=a.get("sourceHeader",!0),i=a.get("dimensions",!0)}return{seriesLayoutBy:e,sourceHeader:n,dimensions:i}},r})();function vd(r){var t=r.option.transform;t&&cs(r.option.transform)}function Io(r){return r.mainType==="series"}function cd(r){throw new Error(r)}var Y={color:{},darkColor:{},size:{}},bt=Y.color={theme:["#5070dd","#b6d634","#505372","#ff994d","#0ca8df","#ffd10a","#fb628b","#785db0","#3fbe95"],neutral00:"#fff",neutral05:"#f4f7fd",neutral10:"#e8ebf0",neutral15:"#dbdee4",neutral20:"#cfd2d7",neutral25:"#c3c5cb",neutral30:"#b7b9be",neutral35:"#aaacb2",neutral40:"#9ea0a5",neutral45:"#929399",neutral50:"#86878c",neutral55:"#797b7f",neutral60:"#6d6e73",neutral65:"#616266",neutral70:"#54555a",neutral75:"#48494d",neutral80:"#3c3c41",neutral85:"#303034",neutral90:"#232328",neutral95:"#17171b",neutral99:"#000",accent05:"#eff1f9",accent10:"#e0e4f2",accent15:"#d0d6ec",accent20:"#c0c9e6",accent25:"#b1bbdf",accent30:"#a1aed9",accent35:"#91a0d3",accent40:"#8292cc",accent45:"#7285c6",accent50:"#6578ba",accent55:"#5c6da9",accent60:"#536298",accent65:"#4a5787",accent70:"#404c76",accent75:"#374165",accent80:"#2e3654",accent85:"#252b43",accent90:"#1b2032",accent95:"#121521",transparent:"rgba(0,0,0,0)",highlight:"rgba(255,231,130,0.8)"};O(bt,{primary:bt.neutral80,secondary:bt.neutral70,tertiary:bt.neutral60,quaternary:bt.neutral50,disabled:bt.neutral20,border:bt.neutral30,borderTint:bt.neutral20,borderShade:bt.neutral40,background:bt.neutral05,backgroundTint:"rgba(234,237,245,0.5)",backgroundTransparent:"rgba(255,255,255,0)",backgroundShade:bt.neutral10,shadow:"rgba(0,0,0,0.2)",shadowTint:"rgba(129,130,136,0.2)",axisLine:bt.neutral70,axisLineTint:bt.neutral40,axisTick:bt.neutral70,axisTickMinor:bt.neutral60,axisLabel:bt.neutral70,axisSplitLine:bt.neutral15,axisMinorSplitLine:bt.neutral05});for(var dn in bt)if(bt.hasOwnProperty(dn)){var dd=bt[dn];dn==="theme"?Y.darkColor.theme=bt.theme.slice():dn==="highlight"?Y.darkColor.highlight="rgba(255,231,130,0.4)":dn.indexOf("accent")===0?Y.darkColor[dn]=ff(dd,null,function(r){return r*.5},function(r){return Math.min(1,1.3-r)}):Y.darkColor[dn]=ff(dd,null,function(r){return r*.9},function(r){return 1-Math.pow(r,1.5)})}Y.size={xxs:2,xs:5,s:10,m:15,l:20,xl:30,xxl:40,xxxl:50};var jT="line-height:1";function o0(r){var t=r.lineHeight;return t==null?jT:"line-height:"+re(t+"")+"px"}function s0(r,t){var e=r.color||Y.color.tertiary,n=r.fontSize||12,i=r.fontWeight||"400",a=r.color||Y.color.secondary,o=r.fontSize||14,s=r.fontWeight||"900";return t==="html"?{nameStyle:"font-size:"+re(n+"")+"px;color:"+re(e)+";font-weight:"+re(i+""),valueStyle:"font-size:"+re(o+"")+"px;color:"+re(a)+";font-weight:"+re(s+"")}:{nameStyle:{fontSize:n,fill:e,fontWeight:i},valueStyle:{fontSize:o,fill:a,fontWeight:s}}}var JT=[0,10,20,30],tM=["",`
`,`

`,`


`];function Ga(r,t){return t.type=r,t}function Nf(r){return r.type==="section"}function l0(r){return Nf(r)?eM:rM}function u0(r){if(Nf(r)){var t=0,e=r.blocks.length,n=e>1||e>0&&!r.noHeader;return D(r.blocks,function(i){var a=u0(i);a>=t&&(t=a+ +(n&&(!a||Nf(i)&&!i.noHeader)))}),t}return 0}function eM(r,t,e,n){var i=t.noHeader,a=nM(u0(t)),o=[],s=t.blocks||[];hr(!s||H(s)),s=s||[];var l=r.orderMode;if(t.sortBlocks&&l){s=s.slice();var u={valueAsc:"asc",valueDesc:"desc"};if(ve(u,l)){var f=new Oy(u[l],null);s.sort(function(p,g){return f.evaluate(p.sortParam,g.sortParam)})}else l==="seriesDesc"&&s.reverse()}D(s,function(p,g){var m=t.valueFormatter,y=l0(p)(m?O(O({},r),{valueFormatter:m}):r,p,g>0?a.html:0,n);y!=null&&o.push(y)});var h=r.renderMode==="richText"?o.join(a.richText):Ff(n,o.join(""),i?e:a.html);if(i)return h;var c=Bf(t.header,"ordinal",r.useUTC),v=s0(n,r.renderMode).nameStyle,d=o0(n);return r.renderMode==="richText"?f0(r,c,v)+a.richText+h:Ff(n,'<div style="'+v+";"+d+';">'+re(c)+"</div>"+h,e)}function rM(r,t,e,n){var i=r.renderMode,a=t.noName,o=t.noValue,s=!t.markerType,l=t.name,u=r.useUTC,f=t.valueFormatter||r.valueFormatter||function(S){return S=H(S)?S:[S],$(S,function(w,b){return Bf(w,H(v)?v[b]:v,u)})};if(!(a&&o)){var h=s?"":r.markupStyleCreator.makeTooltipMarker(t.markerType,t.markerColor||Y.color.secondary,i),c=a?"":Bf(l,"ordinal",u),v=t.valueType,d=o?[]:f(t.value,t.dataIndex),p=!s||!a,g=!s&&a,m=s0(n,i),y=m.nameStyle,_=m.valueStyle;return i==="richText"?(s?"":h)+(a?"":f0(r,c,y))+(o?"":oM(r,d,p,g,_)):Ff(n,(s?"":h)+(a?"":iM(c,!s,y))+(o?"":aM(d,p,g,_)),e)}}function pd(r,t,e,n,i,a){if(r){var o=l0(r),s={useUTC:i,renderMode:e,orderMode:n,markupStyleCreator:t,valueFormatter:r.valueFormatter};return o(s,r,0,a)}}function nM(r){return{html:JT[r],richText:tM[r]}}function Ff(r,t,e){var n='<div style="clear:both"></div>',i="margin: "+e+"px 0 0",a=o0(r);return'<div style="'+i+";"+a+';">'+t+n+"</div>"}function iM(r,t,e){var n=t?"margin-left:2px":"";return'<span style="'+e+";"+n+'">'+re(r)+"</span>"}function aM(r,t,e,n){var i=e?"10px":"20px",a=t?"float:right;margin-left:"+i:"";return r=H(r)?r:[r],'<span style="'+a+";"+n+'">'+$(r,function(o){return re(o)}).join("&nbsp;&nbsp;")+"</span>"}function f0(r,t,e){return r.markupStyleCreator.wrapRichTextStyle(t,e)}function oM(r,t,e,n,i){var a=[i],o=n?10:20;return e&&a.push({padding:[0,0,0,o],align:"right"}),r.markupStyleCreator.wrapRichTextStyle(H(t)?t.join("  "):t,a)}function sM(r,t){var e=r.getData().getItemVisual(t,"style"),n=e[r.visualDrawType];return On(n)}function h0(r,t){var e=r.get("padding");return e??(t==="richText"?[8,10]:10)}var lu=(function(){function r(){this.richTextStyles={},this._nextStyleNameId=Rm()}return r.prototype._generateStyleName=function(){return"__EC_aUTo_"+this._nextStyleNameId++},r.prototype.makeTooltipMarker=function(t,e,n){var i=n==="richText"?this._generateStyleName():null,a=PT({color:e,type:t,renderMode:n,markerId:i});return W(a)?a:(this.richTextStyles[i]=a.style,a.content)},r.prototype.wrapRichTextStyle=function(t,e){var n={};H(e)?D(e,function(a){return O(n,a)}):O(n,e);var i=this._generateStyleName();return this.richTextStyles[i]=n,"{"+i+"|"+t+"}"},r})();function lM(r){var t=r.series,e=r.dataIndex,n=r.multipleSeries,i=t.getData(),a=i.mapDimensionsAll("defaultedTooltip"),o=a.length,s=t.getRawValue(e),l=H(s),u=sM(t,e),f,h,c,v;if(o>1||l&&!o){var d=uM(s,t,e,a,u);f=d.inlineValues,h=d.inlineValueTypes,c=d.blocks,v=d.inlineValues[0]}else if(o){var p=i.getDimensionInfo(a[0]);v=f=Ai(i,e,a[0]),h=p.type}else v=f=l?s[0]:s;var g=Nm(t),m=g&&t.name||"",y=i.getName(e),_=n?m:y;return Ga("section",{header:m,noHeader:n||!g,sortParam:v,blocks:[Ga("nameValue",{markerType:"item",markerColor:u,name:_,noName:!We(_),value:f,valueType:h,dataIndex:e})].concat(c||[])})}function uM(r,t,e,n,i){var a=t.getData(),o=Ei(r,function(h,c,v){var d=a.getDimensionInfo(v);return h=h||d&&d.tooltip!==!1&&d.displayName!=null},!1),s=[],l=[],u=[];n.length?D(n,function(h){f(Ai(a,e,h),h)}):D(r,f);function f(h,c){var v=a.getDimensionInfo(c);!v||v.otherDims.tooltip===!1||(o?u.push(Ga("nameValue",{markerType:"subItem",markerColor:i,name:v.displayName,value:h,valueType:v.type})):(s.push(h),l.push(v.type)))}return{inlineValues:s,inlineValueTypes:l,blocks:u}}var _r=gt();function Po(r,t){return r.getName(t)||r.getId(t)}var as="__universalTransitionEnabled",Vr=(function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e._selectedDataIndicesMap={},e}return t.prototype.init=function(e,n,i){this.seriesIndex=this.componentIndex,this.dataTask=Ca({count:hM,reset:vM}),this.dataTask.context={model:this},this.mergeDefaultAndTheme(e,i);var a=_r(this).sourceManager=new a0(this);a.prepareSource();var o=this.getInitialData(e,i);md(o,this),this.dataTask.context.data=o,_r(this).dataBeforeProcessed=o,gd(this),this._initSelectedMapFromData(o)},t.prototype.mergeDefaultAndTheme=function(e,n){var i=Va(this),a=i?no(e):{},o=this.subType;dt.hasClass(o)&&(o+="Series"),vt(e,n.getTheme().get(this.subType)),vt(e,this.getDefaultOption()),Sc(e,"label",["show"]),this.fillDataTextStyle(e.data),i&&Bn(e,a,i)},t.prototype.mergeOption=function(e,n){e=vt(this.option,e,!0),this.fillDataTextStyle(e.data);var i=Va(this);i&&Bn(this.option,e,i);var a=_r(this).sourceManager;a.dirty(),a.prepareSource();var o=this.getInitialData(e,n);md(o,this),this.dataTask.dirty(),this.dataTask.context.data=o,_r(this).dataBeforeProcessed=o,gd(this),this._initSelectedMapFromData(o)},t.prototype.fillDataTextStyle=function(e){if(e&&!ae(e))for(var n=["show"],i=0;i<e.length;i++)e[i]&&e[i].label&&Sc(e[i],"label",n)},t.prototype.getInitialData=function(e,n){},t.prototype.appendData=function(e){var n=this.getRawData();n.appendData(e.data)},t.prototype.getData=function(e){var n=zf(this);if(n){var i=n.context.data;return e==null||!i.getLinkedData?i:i.getLinkedData(e)}else return _r(this).data},t.prototype.getAllData=function(){var e=this.getData();return e&&e.getLinkedDataAll?e.getLinkedDataAll():[{data:e}]},t.prototype.setData=function(e){var n=zf(this);if(n){var i=n.context;i.outputData=e,n!==this.dataTask&&(i.data=e)}_r(this).data=e},t.prototype.getEncode=function(){var e=this.get("encode",!0);if(e)return K(e)},t.prototype.getSourceManager=function(){return _r(this).sourceManager},t.prototype.getSource=function(){return this.getSourceManager().getSource()},t.prototype.getRawData=function(){return _r(this).dataBeforeProcessed},t.prototype.getColorBy=function(){var e=this.get("colorBy");return e||"series"},t.prototype.isColorBySeries=function(){return this.getColorBy()==="series"},t.prototype.getBaseAxis=function(){var e=this.coordinateSystem;return e&&e.getBaseAxis&&e.getBaseAxis()},t.prototype.indicesOfNearest=function(e,n,i,a){var o=this.getData(),s=this.coordinateSystem,l=s&&s.getAxis(e);if(!s||!l)return[];var u=l.dataToCoord(i);a==null&&(a=1/0);var f=[],h=1/0,c=-1,v=0;return o.each(n,function(d,p){var g=l.dataToCoord(d),m=u-g,y=Math.abs(m);y<=a&&((y<h||y===h&&m>=0&&c<0)&&(h=y,c=m,v=0),m===c&&(f[v++]=p))}),f.length=v,f},t.prototype.formatTooltip=function(e,n,i){return lM({series:this,dataIndex:e,multipleSeries:n})},t.prototype.isAnimationEnabled=function(){var e=this.ecModel;if(nt.node&&!(e&&e.ssr))return!1;var n=this.getShallow("animation");return n&&this.getData().count()>this.getShallow("animationThreshold")&&(n=!1),!!n},t.prototype.restoreData=function(){this.dataTask.dirty()},t.prototype.getColorFromPalette=function(e,n,i){var a=this.ecModel,o=sv.prototype.getColorFromPalette.call(this,e,n,i);return o||(o=a.getColorFromPalette(e,n,i)),o},t.prototype.coordDimToDataDim=function(e){return this.getRawData().mapDimensionsAll(e)},t.prototype.getProgressive=function(){return this.get("progressive")},t.prototype.getProgressiveThreshold=function(){return this.get("progressiveThreshold")},t.prototype.select=function(e,n){this._innerSelect(this.getData(n),e)},t.prototype.unselect=function(e,n){var i=this.option.selectedMap;if(i){var a=this.option.selectedMode,o=this.getData(n);if(a==="series"||i==="all"){this.option.selectedMap={},this._selectedDataIndicesMap={};return}for(var s=0;s<e.length;s++){var l=e[s],u=Po(o,l);i[u]=!1,this._selectedDataIndicesMap[u]=-1}}},t.prototype.toggleSelect=function(e,n){for(var i=[],a=0;a<e.length;a++)i[0]=e[a],this.isSelected(e[a],n)?this.unselect(i,n):this.select(i,n)},t.prototype.getSelectedDataIndices=function(){if(this.option.selectedMap==="all")return[].slice.call(this.getData().getIndices());for(var e=this._selectedDataIndicesMap,n=St(e),i=[],a=0;a<n.length;a++){var o=e[n[a]];o>=0&&i.push(o)}return i},t.prototype.isSelected=function(e,n){var i=this.option.selectedMap;if(!i)return!1;var a=this.getData(n);return(i==="all"||i[Po(a,e)])&&!a.getItemModel(e).get(["select","disabled"])},t.prototype.isUniversalTransitionEnabled=function(){if(this[as])return!0;var e=this.option.universalTransition;return e?e===!0?!0:e&&e.enabled:!1},t.prototype._innerSelect=function(e,n){var i,a,o=this.option,s=o.selectedMode,l=n.length;if(!(!s||!l)){if(s==="series")o.selectedMap="all";else if(s==="multiple"){X(o.selectedMap)||(o.selectedMap={});for(var u=o.selectedMap,f=0;f<l;f++){var h=n[f],c=Po(e,h);u[c]=!0,this._selectedDataIndicesMap[c]=e.getRawIndex(h)}}else if(s==="single"||s===!0){var v=n[l-1],c=Po(e,v);o.selectedMap=(i={},i[c]=!0,i),this._selectedDataIndicesMap=(a={},a[c]=e.getRawIndex(v),a)}}},t.prototype._initSelectedMapFromData=function(e){if(!this.option.selectedMap){var n=[];e.hasItemOption&&e.each(function(i){var a=e.getRawDataItem(i);a&&a.selected&&n.push(i)}),n.length>0&&this._innerSelect(e,n)}},t.registerClass=function(e){return dt.registerClass(e)},t.protoInitialize=(function(){var e=t.prototype;e.type="series.__base__",e.seriesIndex=0,e.ignoreStyleOnData=!1,e.hasSymbolVisual=!1,e.defaultSymbol="circle",e.visualStyleAccessPath="itemStyle",e.visualDrawType="fill"})(),t})(dt);Qe(Vr,VT);Qe(Vr,sv);tm(Vr,dt);function gd(r){var t=r.name;Nm(r)||(r.name=fM(r)||t)}function fM(r){var t=r.getRawData(),e=t.mapDimensionsAll("seriesName"),n=[];return D(e,function(i){var a=t.getDimensionInfo(i);a.displayName&&n.push(a.displayName)}),n.join(" ")}function hM(r){return r.model.getRawData().count()}function vM(r){var t=r.model;return t.setData(t.getRawData().cloneShallow()),cM}function cM(r,t){t.outputData&&r.end>t.outputData.count()&&t.model.getRawData().cloneShallow(t.outputData)}function md(r,t){D(O1(r.CHANGABLE_METHODS,r.DOWNSAMPLE_METHODS),function(e){r.wrapMethod(e,ie(dM,t))})}function dM(r,t){var e=zf(r);return e&&e.setOutputEnd((t||this).count()),t}function zf(r){var t=(r.ecModel||{}).scheduler,e=t&&t.getPipeline(r.uid);if(e){var n=e.currentTask;if(n){var i=n.agentStubMap;i&&(n=i.get(r.uid))}return n}}var pM=ht.extend({type:"triangle",shape:{cx:0,cy:0,width:0,height:0},buildPath:function(r,t){var e=t.cx,n=t.cy,i=t.width/2,a=t.height/2;r.moveTo(e,n-a),r.lineTo(e+i,n+a),r.lineTo(e-i,n+a),r.closePath()}}),gM=ht.extend({type:"diamond",shape:{cx:0,cy:0,width:0,height:0},buildPath:function(r,t){var e=t.cx,n=t.cy,i=t.width/2,a=t.height/2;r.moveTo(e,n-a),r.lineTo(e+i,n),r.lineTo(e,n+a),r.lineTo(e-i,n),r.closePath()}}),mM=ht.extend({type:"pin",shape:{x:0,y:0,width:0,height:0},buildPath:function(r,t){var e=t.x,n=t.y,i=t.width/5*3,a=Math.max(i,t.height),o=i/2,s=o*o/(a-o),l=n-a+o+s,u=Math.asin(s/o),f=Math.cos(u)*o,h=Math.sin(u),c=Math.cos(u),v=o*.6,d=o*.7;r.moveTo(e-f,l+s),r.arc(e,l,o,Math.PI-u,Math.PI*2+u),r.bezierCurveTo(e+f-h*v,l+s+c*v,e,n-d,e,n),r.bezierCurveTo(e,n-d,e-f+h*v,l+s+c*v,e-f,l+s),r.closePath()}}),yM=ht.extend({type:"arrow",shape:{x:0,y:0,width:0,height:0},buildPath:function(r,t){var e=t.height,n=t.width,i=t.x,a=t.y,o=n/3*2;r.moveTo(i,a),r.lineTo(i+o,a+e),r.lineTo(i,a+e/4*3),r.lineTo(i-o,a+e),r.lineTo(i,a),r.closePath()}}),_M={line:zr,rect:Tt,roundRect:Tt,square:Tt,circle:fl,diamond:gM,pin:mM,arrow:yM,triangle:pM},SM={line:function(r,t,e,n,i){i.x1=r,i.y1=t+n/2,i.x2=r+e,i.y2=t+n/2},rect:function(r,t,e,n,i){i.x=r,i.y=t,i.width=e,i.height=n},roundRect:function(r,t,e,n,i){i.x=r,i.y=t,i.width=e,i.height=n,i.r=Math.min(e,n)/4},square:function(r,t,e,n,i){var a=Math.min(e,n);i.x=r,i.y=t,i.width=a,i.height=a},circle:function(r,t,e,n,i){i.cx=r+e/2,i.cy=t+n/2,i.r=Math.min(e,n)/2},diamond:function(r,t,e,n,i){i.cx=r+e/2,i.cy=t+n/2,i.width=e,i.height=n},pin:function(r,t,e,n,i){i.x=r+e/2,i.y=t+n/2,i.width=e,i.height=n},arrow:function(r,t,e,n,i){i.x=r+e/2,i.y=t+n/2,i.width=e,i.height=n},triangle:function(r,t,e,n,i){i.cx=r+e/2,i.cy=t+n/2,i.width=e,i.height=n}},Rs={};D(_M,function(r,t){Rs[t]=new r});var bM=ht.extend({type:"symbol",shape:{symbolType:"",x:0,y:0,width:0,height:0},calculateTextPosition:function(r,t,e){var n=sm(r,t,e),i=this.shape;return i&&i.symbolType==="pin"&&t.position==="inside"&&(n.y=e.y+e.height*.4),n},buildPath:function(r,t,e){var n=t.symbolType;if(n!=="none"){var i=Rs[n];i||(n="rect",i=Rs[n]),SM[n](t.x,t.y,t.width,t.height,i.shape),i.buildPath(r,i.shape,e)}}});function wM(r,t){if(this.type!=="image"){var e=this.style;this.__isEmptyBrush?(e.stroke=r,e.fill=t||Y.color.neutral00,e.lineWidth=2):this.shape.symbolType==="line"?e.stroke=r:e.fill=r,this.markRedraw()}}function Nn(r,t,e,n,i,a,o){var s=r.indexOf("empty")===0;s&&(r=r.substr(5,1).toLowerCase()+r.substr(6));var l;return r.indexOf("image://")===0?l=sy(r.slice(8),new it(t,e,n,i),o?"center":"cover"):r.indexOf("path://")===0?l=Hh(r.slice(7),{},new it(t,e,n,i),o?"center":"cover"):l=new bM({shape:{symbolType:r,x:t,y:e,width:n,height:i}}),l.__isEmptyBrush=s,l.setColor=wM,a&&l.setColor(a),l}function xM(r){return H(r)||(r=[+r,+r]),[r[0]||0,r[1]||0]}function v0(r,t){if(r!=null)return H(r)||(r=[r,r]),[It(r[0],t[0])||0,It(q(r[1],r[0]),t[1])||0]}var TM=(function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.hasSymbolVisual=!0,e}return t.prototype.getInitialData=function(e){return nT(null,this,{useEncodeDefaulter:!0})},t.prototype.getLegendIcon=function(e){var n=new Ft,i=Nn("line",0,e.itemHeight/2,e.itemWidth,0,e.lineStyle.stroke,!1);n.add(i),i.setStyle(e.lineStyle);var a=this.getData().getVisual("symbol"),o=this.getData().getVisual("symbolRotate"),s=a==="none"?"circle":a,l=e.itemHeight*.8,u=Nn(s,(e.itemWidth-l)/2,(e.itemHeight-l)/2,l,l,e.itemStyle.fill);n.add(u),u.setStyle(e.itemStyle);var f=e.iconRotate==="inherit"?o:e.iconRotate||0;return u.rotation=f*Math.PI/180,u.setOrigin([e.itemWidth/2,e.itemHeight/2]),s.indexOf("empty")>-1&&(u.style.stroke=u.style.fill,u.style.fill=Y.color.neutral00,u.style.lineWidth=2),n},t.type="series.line",t.dependencies=["grid","polar"],t.defaultOption={z:3,coordinateSystem:"cartesian2d",legendHoverLink:!0,clip:!0,label:{position:"top"},endLabel:{show:!1,valueAnimation:!0,distance:8},lineStyle:{width:2,type:"solid"},emphasis:{scale:!0},step:!1,smooth:!1,smoothMonotone:null,symbol:"emptyCircle",symbolSize:6,symbolRotate:null,showSymbol:!0,showAllSymbol:"auto",connectNulls:!1,sampling:"none",animationEasing:"linear",progressive:0,hoverLayerThreshold:1/0,universalTransition:{divideShape:"clone"},triggerLineEvent:!1},t})(Vr);function c0(r,t){var e=r.mapDimensionsAll("defaultedLabel"),n=e.length;if(n===1){var i=Ai(r,t,e[0]);return i!=null?i+"":null}else if(n){for(var a=[],o=0;o<e.length;o++)a.push(Ai(r,t,e[o]));return a.join(" ")}}function MM(r,t){var e=r.mapDimensionsAll("defaultedLabel");if(!H(t))return t+"";for(var n=[],i=0;i<e.length;i++){var a=r.getDimensionIndex(e[i]);a>=0&&n.push(t[a])}return n.join(" ")}var uv=(function(r){z(t,r);function t(e,n,i,a){var o=r.call(this)||this;return o.updateData(e,n,i,a),o}return t.prototype._createSymbol=function(e,n,i,a,o,s){this.removeAll();var l=Nn(e,-1,-1,2,2,null,s);l.attr({z2:q(o,100),culling:!0,scaleX:a[0]/2,scaleY:a[1]/2}),l.drift=CM,this._symbolType=e,this.add(l)},t.prototype.stopSymbolAnimation=function(e){this.childAt(0).stopAnimation(null,e)},t.prototype.getSymbolType=function(){return this._symbolType},t.prototype.getSymbolPath=function(){return this.childAt(0)},t.prototype.highlight=function(){Ts(this.childAt(0))},t.prototype.downplay=function(){Ms(this.childAt(0))},t.prototype.setZ=function(e,n){var i=this.childAt(0);i.zlevel=e,i.z=n},t.prototype.setDraggable=function(e,n){var i=this.childAt(0);i.draggable=e,i.cursor=!n&&e?"move":i.cursor},t.prototype.updateData=function(e,n,i,a){this.silent=!1;var o=e.getItemVisual(n,"symbol")||"circle",s=e.hostModel,l=t.getSymbolSize(e,n),u=t.getSymbolZ2(e,n),f=o!==this._symbolType,h=a&&a.disableAnimation;if(f){var c=e.getItemVisual(n,"symbolKeepAspect");this._createSymbol(o,e,n,l,u,c)}else{var v=this.childAt(0);v.silent=!1;var d={scaleX:l[0]/2,scaleY:l[1]/2};h?v.attr(d):Ke(v,d,s,n),zw(v)}if(this._updateCommon(e,n,l,i,a),f){var v=this.childAt(0);if(!h){var d={scaleX:this._sizeX,scaleY:this._sizeY,style:{opacity:v.style.opacity}};v.scaleX=v.scaleY=0,v.style.opacity=0,cr(v,d,s,n)}}h&&this.childAt(0).stopAnimation("leave")},t.prototype._updateCommon=function(e,n,i,a,o){var s=this.childAt(0),l=e.hostModel,u,f,h,c,v,d,p,g,m;if(a&&(u=a.emphasisItemStyle,f=a.blurItemStyle,h=a.selectItemStyle,c=a.focus,v=a.blurScope,p=a.labelStatesModels,g=a.hoverScale,m=a.cursorStyle,d=a.emphasisDisabled),!a||e.hasItemOption){var y=a&&a.itemModel?a.itemModel:e.getItemModel(n),_=y.getModel("emphasis");u=_.getModel("itemStyle").getItemStyle(),h=y.getModel(["select","itemStyle"]).getItemStyle(),f=y.getModel(["blur","itemStyle"]).getItemStyle(),c=_.get("focus"),v=_.get("blurScope"),d=_.get("disabled"),p=Yh(y),g=_.getShallow("scale"),m=y.getShallow("cursor")}var S=e.getItemVisual(n,"symbolRotate");s.attr("rotation",(S||0)*Math.PI/180||0);var w=v0(e.getItemVisual(n,"symbolOffset"),i);w&&(s.x=w[0],s.y=w[1]),m&&s.attr("cursor",m);var b=e.getItemVisual(n,"style"),T=b.fill;if(s instanceof Wr){var C=s.style;s.useStyle(O({image:C.image,x:C.x,y:C.y,width:C.width,height:C.height},b))}else s.__isEmptyBrush?s.useStyle(O({},b)):s.useStyle(b),s.style.decal=null,s.setColor(T,o&&o.symbolInnerColor),s.style.strokeNoScale=!0;var x=e.getItemVisual(n,"liftZ"),M=this._z2;x!=null?M==null&&(this._z2=s.z2,s.z2+=x):M!=null&&(s.z2=M,this._z2=null);var A=o&&o.useNameLabel;yy(s,p,{labelFetcher:l,labelDataIndex:n,defaultText:P,inheritColor:T,defaultOpacity:b.opacity});function P(R){return A?e.getName(R):c0(e,R)}this._sizeX=i[0]/2,this._sizeY=i[1]/2;var L=s.ensureState("emphasis");L.style=u,s.ensureState("select").style=h,s.ensureState("blur").style=f;var I=g==null||g===!0?Math.max(1.1,3/this._sizeY):isFinite(g)&&g>0?+g:1;L.scaleX=this._sizeX*I,L.scaleY=this._sizeY*I,this.setSymbolScale(1),xf(this,c,v,d)},t.prototype.setSymbolScale=function(e){this.scaleX=this.scaleY=e},t.prototype.fadeOut=function(e,n,i){var a=this.childAt(0),o=pt(this).dataIndex,s=i&&i.animation;if(this.silent=a.silent=!0,i&&i.fadeLabel){var l=a.getTextContent();l&&Cs(l,{style:{opacity:0}},n,{dataIndex:o,removeOpt:s,cb:function(){a.removeTextContent()}})}else a.removeTextContent();Cs(a,{style:{opacity:0},scaleX:0,scaleY:0},n,{dataIndex:o,cb:e,removeOpt:s})},t.getSymbolSize=function(e,n){return xM(e.getItemVisual(n,"symbolSize"))},t.getSymbolZ2=function(e,n){return e.getItemVisual(n,"z2")},t})(Ft);function CM(r,t){this.parent.drift(r,t)}function uu(r,t,e,n){return t&&!isNaN(t[0])&&!isNaN(t[1])&&!(n.isIgnore&&n.isIgnore(e))&&!(n.clipShape&&!n.clipShape.contain(t[0],t[1]))&&r.getItemVisual(e,"symbol")!=="none"}function yd(r){return r!=null&&!X(r)&&(r={isIgnore:r}),r||{}}function _d(r){var t=r.hostModel,e=t.getModel("emphasis");return{emphasisItemStyle:e.getModel("itemStyle").getItemStyle(),blurItemStyle:t.getModel(["blur","itemStyle"]).getItemStyle(),selectItemStyle:t.getModel(["select","itemStyle"]).getItemStyle(),focus:e.get("focus"),blurScope:e.get("blurScope"),emphasisDisabled:e.get("disabled"),hoverScale:e.get("scale"),labelStatesModels:Yh(t),cursorStyle:t.get("cursor")}}var DM=(function(){function r(t){this.group=new Ft,this._SymbolCtor=t||uv}return r.prototype.updateData=function(t,e){this._progressiveEls=null,e=yd(e);var n=this.group,i=t.hostModel,a=this._data,o=this._SymbolCtor,s=e.disableAnimation,l=_d(t),u={disableAnimation:s},f=e.getSymbolPoint||function(h){return t.getItemLayout(h)};a||n.removeAll(),t.diff(a).add(function(h){var c=f(h);if(uu(t,c,h,e)){var v=new o(t,h,l,u);v.setPosition(c),t.setItemGraphicEl(h,v),n.add(v)}}).update(function(h,c){var v=a.getItemGraphicEl(c),d=f(h);if(!uu(t,d,h,e)){n.remove(v);return}var p=t.getItemVisual(h,"symbol")||"circle",g=v&&v.getSymbolType&&v.getSymbolType();if(!v||g&&g!==p)n.remove(v),v=new o(t,h,l,u),v.setPosition(d);else{v.updateData(t,h,l,u);var m={x:d[0],y:d[1]};s?v.attr(m):Ke(v,m,i)}n.add(v),t.setItemGraphicEl(h,v)}).remove(function(h){var c=a.getItemGraphicEl(h);c&&c.fadeOut(function(){n.remove(c)},i)}).execute(),this._getSymbolPoint=f,this._data=t},r.prototype.updateLayout=function(){var t=this,e=this._data;e&&e.eachItemGraphicEl(function(n,i){var a=t._getSymbolPoint(i);n.setPosition(a),n.markRedraw()})},r.prototype.incrementalPrepareUpdate=function(t){this._seriesScope=_d(t),this._data=null,this.group.removeAll()},r.prototype.incrementalUpdate=function(t,e,n){this._progressiveEls=[],n=yd(n);function i(l){l.isGroup||(l.incremental=!0,l.ensureState("emphasis").hoverLayer=!0)}for(var a=t.start;a<t.end;a++){var o=e.getItemLayout(a);if(uu(e,o,a,n)){var s=new this._SymbolCtor(e,a,this._seriesScope);s.traverse(i),s.setPosition(o),this.group.add(s),e.setItemGraphicEl(a,s),this._progressiveEls.push(s)}}},r.prototype.eachRendered=function(t){Gh(this._progressiveEls||this.group,t)},r.prototype.remove=function(t){var e=this.group,n=this._data;n&&t?n.eachItemGraphicEl(function(i){i.fadeOut(function(){e.remove(i)},n.hostModel)}):e.removeAll()},r})();function d0(r,t,e){var n=r.getBaseAxis(),i=r.getOtherAxis(n),a=AM(i,e),o=n.dim,s=i.dim,l=t.mapDimension(s),u=t.mapDimension(o),f=s==="x"||s==="radius"?1:0,h=$(r.dimensions,function(d){return t.mapDimension(d)}),c=!1,v=t.getCalculationInfo("stackResultDimension");return Ha(t,h[0])&&(c=!0,h[0]=v),Ha(t,h[1])&&(c=!0,h[1]=v),{dataDimsForPoint:h,valueStart:a,valueAxisDim:s,baseAxisDim:o,stacked:!!c,valueDim:l,baseDim:u,baseDataOffset:f,stackedOverDimension:t.getCalculationInfo("stackedOverDimension")}}function AM(r,t){var e=0,n=r.scale.getExtent();return t==="start"?e=n[0]:t==="end"?e=n[1]:mt(t)&&!isNaN(t)?e=t:n[0]>0?e=n[0]:n[1]<0&&(e=n[1]),e}function p0(r,t,e,n){var i=NaN;r.stacked&&(i=e.get(e.getCalculationInfo("stackedOverDimension"),n)),isNaN(i)&&(i=r.valueStart);var a=r.baseDataOffset,o=[];return o[a]=e.get(r.baseDim,n),o[1-a]=i,t.dataToPoint(o)}var g0=typeof Float32Array<"u",LM=g0?Float32Array:Array;function pi(r){return H(r)?g0?new Float32Array(r):r:new LM(r)}function IM(r,t){var e=[];return t.diff(r).add(function(n){e.push({cmd:"+",idx:n})}).update(function(n,i){e.push({cmd:"=",idx:i,idx1:n})}).remove(function(n){e.push({cmd:"-",idx:n})}).execute(),e}function PM(r,t,e,n,i,a,o,s){for(var l=IM(r,t),u=[],f=[],h=[],c=[],v=[],d=[],p=[],g=d0(i,t,o),m=r.getLayout("points")||[],y=t.getLayout("points")||[],_=0;_<l.length;_++){var S=l[_],w=!0,b=void 0,T=void 0;switch(S.cmd){case"=":b=S.idx*2,T=S.idx1*2;var C=m[b],x=m[b+1],M=y[T],A=y[T+1];(isNaN(C)||isNaN(x))&&(C=M,x=A),u.push(C,x),f.push(M,A),h.push(e[b],e[b+1]),c.push(n[T],n[T+1]),p.push(t.getRawIndex(S.idx1));break;case"+":var P=S.idx,L=g.dataDimsForPoint,I=i.dataToPoint([t.get(L[0],P),t.get(L[1],P)]);T=P*2,u.push(I[0],I[1]),f.push(y[T],y[T+1]);var R=p0(g,i,t,P);h.push(R[0],R[1]),c.push(n[T],n[T+1]),p.push(t.getRawIndex(P));break;case"-":w=!1}w&&(v.push(S),d.push(d.length))}d.sort(function(yt,Ht){return p[yt]-p[Ht]});for(var E=u.length,V=pi(E),B=pi(E),k=pi(E),G=pi(E),U=[],_=0;_<d.length;_++){var Z=d[_],j=_*2,ot=Z*2;V[j]=u[ot],V[j+1]=u[ot+1],B[j]=f[ot],B[j+1]=f[ot+1],k[j]=h[ot],k[j+1]=h[ot+1],G[j]=c[ot],G[j+1]=c[ot+1],U[_]=v[Z]}return{current:V,next:B,stackedOnCurrent:k,stackedOnNext:G,status:U}}var Sr=Math.min,br=Math.max;function Rn(r,t){return isNaN(r)||isNaN(t)}function Hf(r,t,e,n,i,a,o,s,l){for(var u,f,h,c,v,d,p=e,g=0;g<n;g++){var m=t[p*2],y=t[p*2+1];if(p>=i||p<0)break;if(Rn(m,y)){if(l){p+=a;continue}break}if(p===e)r[a>0?"moveTo":"lineTo"](m,y),h=m,c=y;else{var _=m-u,S=y-f;if(_*_+S*S<.5){p+=a;continue}if(o>0){for(var w=p+a,b=t[w*2],T=t[w*2+1];b===m&&T===y&&g<n;)g++,w+=a,p+=a,b=t[w*2],T=t[w*2+1],m=t[p*2],y=t[p*2+1],_=m-u,S=y-f;var C=g+1;if(l)for(;Rn(b,T)&&C<n;)C++,w+=a,b=t[w*2],T=t[w*2+1];var x=.5,M=0,A=0,P=void 0,L=void 0;if(C>=n||Rn(b,T))v=m,d=y;else{M=b-u,A=T-f;var I=m-u,R=b-m,E=y-f,V=T-y,B=void 0,k=void 0;if(s==="x"){B=Math.abs(I),k=Math.abs(R);var G=M>0?1:-1;v=m-G*B*o,d=y,P=m+G*k*o,L=y}else if(s==="y"){B=Math.abs(E),k=Math.abs(V);var U=A>0?1:-1;v=m,d=y-U*B*o,P=m,L=y+U*k*o}else B=Math.sqrt(I*I+E*E),k=Math.sqrt(R*R+V*V),x=k/(k+B),v=m-M*o*(1-x),d=y-A*o*(1-x),P=m+M*o*x,L=y+A*o*x,P=Sr(P,br(b,m)),L=Sr(L,br(T,y)),P=br(P,Sr(b,m)),L=br(L,Sr(T,y)),M=P-m,A=L-y,v=m-M*B/k,d=y-A*B/k,v=Sr(v,br(u,m)),d=Sr(d,br(f,y)),v=br(v,Sr(u,m)),d=br(d,Sr(f,y)),M=m-v,A=y-d,P=m+M*k/B,L=y+A*k/B}r.bezierCurveTo(h,c,v,d,m,y),h=P,c=L}else r.lineTo(m,y)}u=m,f=y,p+=a}return g}var m0=(function(){function r(){this.smooth=0,this.smoothConstraint=!0}return r})(),RM=(function(r){z(t,r);function t(e){var n=r.call(this,e)||this;return n.type="ec-polyline",n}return t.prototype.getDefaultStyle=function(){return{stroke:Y.color.neutral99,fill:null}},t.prototype.getDefaultShape=function(){return new m0},t.prototype.buildPath=function(e,n){var i=n.points,a=0,o=i.length/2;if(n.connectNulls){for(;o>0&&Rn(i[o*2-2],i[o*2-1]);o--);for(;a<o&&Rn(i[a*2],i[a*2+1]);a++);}for(;a<o;)a+=Hf(e,i,a,o,o,1,n.smooth,n.smoothMonotone,n.connectNulls)+1},t.prototype.getPointOn=function(e,n){this.path||(this.createPathProxy(),this.buildPath(this.path,this.shape));for(var i=this.path,a=i.data,o=vr.CMD,s,l,u=n==="x",f=[],h=0;h<a.length;){var c=a[h++],v=void 0,d=void 0,p=void 0,g=void 0,m=void 0,y=void 0,_=void 0;switch(c){case o.M:s=a[h++],l=a[h++];break;case o.L:if(v=a[h++],d=a[h++],_=u?(e-s)/(v-s):(e-l)/(d-l),_<=1&&_>=0){var S=u?(d-l)*_+l:(v-s)*_+s;return u?[e,S]:[S,e]}s=v,l=d;break;case o.C:v=a[h++],d=a[h++],p=a[h++],g=a[h++],m=a[h++],y=a[h++];var w=u?ps(s,v,p,m,e,f):ps(l,d,g,y,e,f);if(w>0)for(var b=0;b<w;b++){var T=f[b];if(T<=1&&T>=0){var S=u?Lt(l,d,g,y,T):Lt(s,v,p,m,T);return u?[e,S]:[S,e]}}s=m,l=y;break}}},t})(ht),EM=(function(r){z(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t})(m0),kM=(function(r){z(t,r);function t(e){var n=r.call(this,e)||this;return n.type="ec-polygon",n}return t.prototype.getDefaultShape=function(){return new EM},t.prototype.buildPath=function(e,n){var i=n.points,a=n.stackedOnPoints,o=0,s=i.length/2,l=n.smoothMonotone;if(n.connectNulls){for(;s>0&&Rn(i[s*2-2],i[s*2-1]);s--);for(;o<s&&Rn(i[o*2],i[o*2+1]);o++);}for(;o<s;){var u=Hf(e,i,o,s,s,1,n.smooth,l,n.connectNulls);Hf(e,a,o+u-1,u,s,-1,n.stackedOnSmooth,l,n.connectNulls),o+=u+1,e.closePath()}},t})(ht);function y0(){var r=gt();return function(t){var e=r(t),n=t.pipelineContext,i=!!e.large,a=!!e.progressiveRender,o=e.large=!!(n&&n.large),s=e.progressiveRender=!!(n&&n.progressiveRender);return(i!==o||a!==s)&&"reset"}}var _0=gt(),OM=y0(),qe=(function(){function r(){this.group=new Ft,this.uid=ml("viewChart"),this.renderTask=Ca({plan:BM,reset:NM}),this.renderTask.context={view:this}}return r.prototype.init=function(t,e){},r.prototype.render=function(t,e,n,i){},r.prototype.highlight=function(t,e,n,i){var a=t.getData(i&&i.dataType);a&&bd(a,i,"emphasis")},r.prototype.downplay=function(t,e,n,i){var a=t.getData(i&&i.dataType);a&&bd(a,i,"normal")},r.prototype.remove=function(t,e){this.group.removeAll()},r.prototype.dispose=function(t,e){},r.prototype.updateView=function(t,e,n,i){this.render(t,e,n,i)},r.prototype.updateLayout=function(t,e,n,i){this.render(t,e,n,i)},r.prototype.updateVisual=function(t,e,n,i){this.render(t,e,n,i)},r.prototype.eachRendered=function(t){Gh(this.group,t)},r.markUpdateMethod=function(t,e){_0(t).updateMethod=e},r.protoInitialize=(function(){var t=r.prototype;t.type="chart"})(),r})();function Sd(r,t,e){r&&Tf(r)&&(t==="emphasis"?Ts:Ms)(r,e)}function bd(r,t,e){var n=kn(r,t),i=t&&t.highlightKey!=null?lw(t.highlightKey):null;n!=null?D(Ct(n),function(a){Sd(r.getItemGraphicEl(a),e,i)}):r.eachItemGraphicEl(function(a){Sd(a,e,i)})}xh(qe);el(qe);function BM(r){return OM(r.model)}function NM(r){var t=r.model,e=r.ecModel,n=r.api,i=r.payload,a=t.pipelineContext.progressiveRender,o=r.view,s=i&&_0(i).updateMethod,l=a?"incrementalPrepareRender":s&&o[s]?s:"render";return l!=="render"&&o[l](t,e,n,i),FM[l]}var FM={incrementalPrepareRender:{progress:function(r,t){t.view.incrementalRender(r,t.model,t.ecModel,t.api,t.payload)}},render:{forceFirstProgress:!0,progress:function(r,t){t.view.render(t.model,t.ecModel,t.api,t.payload)}}};function zM(r,t,e,n,i){var a=r.getArea(),o=a.x,s=a.y,l=a.width,u=a.height,f=e.get(["lineStyle","width"])||0;o-=f/2,s-=f/2,l+=f,u+=f,l=Math.ceil(l),o!==Math.floor(o)&&(o=Math.floor(o),l++);var h=new Tt({shape:{x:o,y:s,width:l,height:u}});if(t){var c=r.getBaseAxis(),v=c.isHorizontal(),d=c.inverse;v?(d&&(h.shape.x+=l),h.shape.width=0):(d||(h.shape.y+=u),h.shape.height=0);var p=et(i)?function(g){i(g,h)}:null;cr(h,{shape:{width:l,height:u,x:o,y:s}},e,null,n,p)}return h}function HM(r,t,e){var n=r.getArea(),i=Nt(n.r0,1),a=Nt(n.r,1),o=new Ci({shape:{cx:Nt(r.cx,1),cy:Nt(r.cy,1),r0:i,r:a,startAngle:n.startAngle,endAngle:n.endAngle,clockwise:n.clockwise}});if(t){var s=r.getBaseAxis().dim==="angle";s?o.shape.endAngle=n.startAngle:o.shape.r=i,cr(o,{shape:{endAngle:n.endAngle,r:a}},e)}return o}function VM(r,t){return r.type===t}function wd(r,t){if(r.length===t.length){for(var e=0;e<r.length;e++)if(r[e]!==t[e])return;return!0}}function xd(r){for(var t=1/0,e=1/0,n=-1/0,i=-1/0,a=0;a<r.length;){var o=r[a++],s=r[a++];isNaN(o)||(t=Math.min(o,t),n=Math.max(o,n)),isNaN(s)||(e=Math.min(s,e),i=Math.max(s,i))}return[[t,e],[n,i]]}function Td(r,t){var e=xd(r),n=e[0],i=e[1],a=xd(t),o=a[0],s=a[1];return Math.max(Math.abs(n[0]-o[0]),Math.abs(n[1]-o[1]),Math.abs(i[0]-s[0]),Math.abs(i[1]-s[1]))}function Md(r){return mt(r)?r:r?.5:0}function GM(r,t,e){if(!e.valueDim)return[];for(var n=t.count(),i=pi(n*2),a=0;a<n;a++){var o=p0(e,r,t,a);i[a*2]=o[0],i[a*2+1]=o[1]}return i}function wr(r,t,e,n,i){var a=e.getBaseAxis(),o=a.dim==="x"||a.dim==="radius"?0:1,s=[],l=0,u=[],f=[],h=[],c=[];if(i){for(l=0;l<r.length;l+=2){var v=t||r;!isNaN(v[l])&&!isNaN(v[l+1])&&c.push(r[l],r[l+1])}r=c}for(l=0;l<r.length-2;l+=2)switch(h[0]=r[l+2],h[1]=r[l+3],f[0]=r[l],f[1]=r[l+1],s.push(f[0],f[1]),n){case"end":u[o]=h[o],u[1-o]=f[1-o],s.push(u[0],u[1]);break;case"middle":var d=(f[o]+h[o])/2,p=[];u[o]=p[o]=d,u[1-o]=f[1-o],p[1-o]=h[1-o],s.push(u[0],u[1]),s.push(p[0],p[1]);break;default:u[o]=f[o],u[1-o]=h[1-o],s.push(u[0],u[1])}return s.push(r[l++],r[l++]),s}function WM(r,t){var e=[],n=r.length,i,a;function o(f,h,c){var v=f.coord,d=(c-v)/(h.coord-v),p=CS(d,[f.color,h.color]);return{coord:c,color:p}}for(var s=0;s<n;s++){var l=r[s],u=l.coord;if(u<0)i=l;else if(u>t){a?e.push(o(a,l,t)):i&&e.push(o(i,l,0),o(i,l,t));break}else i&&(e.push(o(i,l,0)),i=null),e.push(l),a=l}return e}function UM(r,t,e){var n=r.getVisual("visualMeta");if(!(!n||!n.length||!r.count())&&t.type==="cartesian2d"){for(var i,a,o=n.length-1;o>=0;o--){var s=r.getDimensionInfo(n[o].dimension);if(i=s&&s.coordDim,i==="x"||i==="y"){a=n[o];break}}if(a){var l=t.getAxis(i),u=$(a.stops,function(_){return{coord:l.toGlobalCoord(l.dataToCoord(_.value)),color:_.color}}),f=u.length,h=a.outerColors.slice();f&&u[0].coord>u[f-1].coord&&(u.reverse(),h.reverse());var c=WM(u,i==="x"?e.getWidth():e.getHeight()),v=c.length;if(!v&&f)return u[0].coord<0?h[1]?h[1]:u[f-1].color:h[0]?h[0]:u[0].color;var d=10,p=c[0].coord-d,g=c[v-1].coord+d,m=g-p;if(m<.001)return"transparent";D(c,function(_){_.offset=(_.coord-p)/m}),c.push({offset:v?c[v-1].offset:.5,color:h[1]||"transparent"}),c.unshift({offset:v?c[0].offset:.5,color:h[0]||"transparent"});var y=new iy(0,0,0,0,c,!0);return y[i]=p,y[i+"2"]=g,y}}}function YM(r,t,e){var n=r.get("showAllSymbol"),i=n==="auto";if(!(n&&!i)){var a=e.getAxesByScale("ordinal")[0];if(a&&!(i&&ZM(a,t))){var o=t.mapDimension(a.dim),s={};return D(a.getViewLabels(),function(l){var u=a.scale.getRawOrdinalNumber(l.tickValue);s[u]=1}),function(l){return!s.hasOwnProperty(t.get(o,l))}}}}function ZM(r,t){var e=r.getExtent(),n=Math.abs(e[1]-e[0])/r.scale.count();isNaN(n)&&(n=0);for(var i=t.count(),a=Math.max(1,Math.round(i/5)),o=0;o<i;o+=a)if(uv.getSymbolSize(t,o)[r.isHorizontal()?1:0]*1.5>n)return!1;return!0}function XM(r,t){return isNaN(r)||isNaN(t)}function $M(r){for(var t=r.length/2;t>0&&XM(r[t*2-2],r[t*2-1]);t--);return t-1}function Cd(r,t){return[r[t*2],r[t*2+1]]}function qM(r,t,e){for(var n=r.length/2,i=e==="x"?0:1,a,o,s=0,l=-1,u=0;u<n;u++)if(o=r[u*2+i],!(isNaN(o)||isNaN(r[u*2+1-i]))){if(u===0){a=o;continue}if(a<=t&&o>=t||a>=t&&o<=t){l=u;break}s=u,a=o}return{range:[s,l],t:(t-a)/(o-a)}}function S0(r){if(r.get(["endLabel","show"]))return!0;for(var t=0;t<Te.length;t++)if(r.get([Te[t],"endLabel","show"]))return!0;return!1}function fu(r,t,e,n){if(VM(t,"cartesian2d")){var i=n.getModel("endLabel"),a=i.get("valueAnimation"),o=n.getData(),s={lastFrameIndex:0},l=S0(n)?function(v,d){r._endLabelOnDuring(v,d,o,s,a,i,t)}:null,u=t.getBaseAxis().isHorizontal(),f=zM(t,e,n,function(){var v=r._endLabel;v&&e&&s.originalX!=null&&v.attr({x:s.originalX,y:s.originalY})},l);if(!n.get("clip",!0)){var h=f.shape,c=Math.max(h.width,h.height);u?(h.y-=c,h.height+=c*2):(h.x-=c,h.width+=c*2)}return l&&l(1,f),f}else return HM(t,e,n)}function KM(r,t){var e=t.getBaseAxis(),n=e.isHorizontal(),i=e.inverse,a=n?i?"right":"left":"center",o=n?"middle":i?"top":"bottom";return{normal:{align:r.get("align")||a,verticalAlign:r.get("verticalAlign")||o}}}var QM=(function(r){z(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.init=function(){var e=new Ft,n=new DM;this.group.add(n.group),this._symbolDraw=n,this._lineGroup=e,this._changePolyState=Q(this._changePolyState,this)},t.prototype.render=function(e,n,i){var a=e.coordinateSystem,o=this.group,s=e.getData(),l=e.getModel("lineStyle"),u=e.getModel("areaStyle"),f=s.getLayout("points")||[],h=a.type==="polar",c=this._coordSys,v=this._symbolDraw,d=this._polyline,p=this._polygon,g=this._lineGroup,m=!n.ssr&&e.get("animation"),y=!u.isEmpty(),_=u.get("origin"),S=d0(a,s,_),w=y&&GM(a,s,S),b=e.get("showSymbol"),T=e.get("connectNulls"),C=b&&!h&&YM(e,s,a),x=this._data;x&&x.eachItemGraphicEl(function(yt,Ht){yt.__temp&&(o.remove(yt),x.setItemGraphicEl(Ht,null))}),b||v.remove(),o.add(g);var M=h?!1:e.get("step"),A;a&&a.getArea&&e.get("clip",!0)&&(A=a.getArea(),A.width!=null?(A.x-=.1,A.y-=.1,A.width+=.2,A.height+=.2):A.r0&&(A.r0-=.5,A.r+=.5)),this._clipShapeForSymbol=A;var P=UM(s,a,i)||s.getVisual("style")[s.getVisual("drawType")];if(!(d&&c.type===a.type&&M===this._step))b&&v.updateData(s,{isIgnore:C,clipShape:A,disableAnimation:!0,getSymbolPoint:function(yt){return[f[yt*2],f[yt*2+1]]}}),m&&this._initSymbolLabelAnimation(s,a,A),M&&(w&&(w=wr(w,f,a,M,T)),f=wr(f,null,a,M,T)),d=this._newPolyline(f),y?p=this._newPolygon(f,w):p&&(g.remove(p),p=this._polygon=null),h||this._initOrUpdateEndLabel(e,a,On(P)),g.setClipPath(fu(this,a,!0,e));else{y&&!p?p=this._newPolygon(f,w):p&&!y&&(g.remove(p),p=this._polygon=null),h||this._initOrUpdateEndLabel(e,a,On(P));var L=g.getClipPath();if(L){var I=fu(this,a,!1,e);cr(L,{shape:I.shape},e)}else g.setClipPath(fu(this,a,!0,e));b&&v.updateData(s,{isIgnore:C,clipShape:A,disableAnimation:!0,getSymbolPoint:function(yt){return[f[yt*2],f[yt*2+1]]}}),(!wd(this._stackedOnPoints,w)||!wd(this._points,f))&&(m?this._doUpdateAnimation(s,w,a,i,M,_,T):(M&&(w&&(w=wr(w,f,a,M,T)),f=wr(f,null,a,M,T)),d.setShape({points:f}),p&&p.setShape({points:f,stackedOnPoints:w})))}var R=e.getModel("emphasis"),E=R.get("focus"),V=R.get("blurScope"),B=R.get("disabled");if(d.useStyle(at(l.getLineStyle(),{fill:"none",stroke:P,lineJoin:"bevel"})),Ic(d,e,"lineStyle"),d.style.lineWidth>0&&e.get(["emphasis","lineStyle","width"])==="bolder"){var k=d.getState("emphasis").style;k.lineWidth=+d.style.lineWidth+1}pt(d).seriesIndex=e.seriesIndex,xf(d,E,V,B);var G=Md(e.get("smooth")),U=e.get("smoothMonotone");if(d.setShape({smooth:G,smoothMonotone:U,connectNulls:T}),p){var Z=s.getCalculationInfo("stackedOnSeries"),j=0;p.useStyle(at(u.getAreaStyle(),{fill:P,opacity:.7,lineJoin:"bevel",decal:s.getVisual("style").decal})),Z&&(j=Md(Z.get("smooth"))),p.setShape({smooth:G,stackedOnSmooth:j,smoothMonotone:U,connectNulls:T}),Ic(p,e,"areaStyle"),pt(p).seriesIndex=e.seriesIndex,xf(p,E,V,B)}var ot=this._changePolyState;s.eachItemGraphicEl(function(yt){yt&&(yt.onHoverStateChange=ot)}),this._polyline.onHoverStateChange=ot,this._data=s,this._coordSys=a,this._stackedOnPoints=w,this._points=f,this._step=M,this._valueOrigin=_,e.get("triggerLineEvent")&&(this.packEventData(e,d),p&&this.packEventData(e,p))},t.prototype.packEventData=function(e,n){pt(n).eventData={componentType:"series",componentSubType:"line",componentIndex:e.componentIndex,seriesIndex:e.seriesIndex,seriesName:e.name,seriesType:"line"}},t.prototype.highlight=function(e,n,i,a){var o=e.getData(),s=kn(o,a);if(this._changePolyState("emphasis"),!(s instanceof Array)&&s!=null&&s>=0){var l=o.getLayout("points"),u=o.getItemGraphicEl(s);if(!u){var f=l[s*2],h=l[s*2+1];if(isNaN(f)||isNaN(h)||this._clipShapeForSymbol&&!this._clipShapeForSymbol.contain(f,h))return;var c=e.get("zlevel")||0,v=e.get("z")||0;u=new uv(o,s),u.x=f,u.y=h,u.setZ(c,v);var d=u.getSymbolPath().getTextContent();d&&(d.zlevel=c,d.z=v,d.z2=this._polyline.z2+1),u.__temp=!0,o.setItemGraphicEl(s,u),u.stopSymbolAnimation(!0),this.group.add(u)}u.highlight()}else qe.prototype.highlight.call(this,e,n,i,a)},t.prototype.downplay=function(e,n,i,a){var o=e.getData(),s=kn(o,a);if(this._changePolyState("normal"),s!=null&&s>=0){var l=o.getItemGraphicEl(s);l&&(l.__temp?(o.setItemGraphicEl(s,null),this.group.remove(l)):l.downplay())}else qe.prototype.downplay.call(this,e,n,i,a)},t.prototype._changePolyState=function(e){var n=this._polygon;Mc(this._polyline,e),n&&Mc(n,e)},t.prototype._newPolyline=function(e){var n=this._polyline;return n&&this._lineGroup.remove(n),n=new RM({shape:{points:e},segmentIgnoreThreshold:2,z2:10}),this._lineGroup.add(n),this._polyline=n,n},t.prototype._newPolygon=function(e,n){var i=this._polygon;return i&&this._lineGroup.remove(i),i=new kM({shape:{points:e,stackedOnPoints:n},segmentIgnoreThreshold:2}),this._lineGroup.add(i),this._polygon=i,i},t.prototype._initSymbolLabelAnimation=function(e,n,i){var a,o,s=n.getBaseAxis(),l=s.inverse;n.type==="cartesian2d"?(a=s.isHorizontal(),o=!1):n.type==="polar"&&(a=s.dim==="angle",o=!0);var u=e.hostModel,f=u.get("animationDuration");et(f)&&(f=f(null));var h=u.get("animationDelay")||0,c=et(h)?h(null):h;e.eachItemGraphicEl(function(v,d){var p=v;if(p){var g=[v.x,v.y],m=void 0,y=void 0,_=void 0;if(i)if(o){var S=i,w=n.pointToCoord(g);a?(m=S.startAngle,y=S.endAngle,_=-w[1]/180*Math.PI):(m=S.r0,y=S.r,_=w[0])}else{var b=i;a?(m=b.x,y=b.x+b.width,_=v.x):(m=b.y+b.height,y=b.y,_=v.y)}var T=y===m?0:(_-m)/(y-m);l&&(T=1-T);var C=et(h)?h(d):f*T+c,x=p.getSymbolPath(),M=x.getTextContent();p.attr({scaleX:0,scaleY:0}),p.animateTo({scaleX:1,scaleY:1},{duration:200,setToFinal:!0,delay:C}),M&&M.animateFrom({style:{opacity:0}},{duration:300,delay:C}),x.disableLabelAnimation=!0}})},t.prototype._initOrUpdateEndLabel=function(e,n,i){var a=e.getModel("endLabel");if(S0(e)){var o=e.getData(),s=this._polyline,l=o.getLayout("points");if(!l){s.removeTextContent(),this._endLabel=null;return}var u=this._endLabel;u||(u=this._endLabel=new oe({z2:200}),u.ignoreClip=!0,s.setTextContent(this._endLabel),s.disableLabelAnimation=!0);var f=$M(l);f>=0&&(yy(s,Yh(e,"endLabel"),{inheritColor:i,labelFetcher:e,labelDataIndex:f,defaultText:function(h,c,v){return v!=null?MM(o,v):c0(o,h)},enableTextSetter:!0},KM(a,n)),s.textConfig.position=null)}else this._endLabel&&(this._polyline.removeTextContent(),this._endLabel=null)},t.prototype._endLabelOnDuring=function(e,n,i,a,o,s,l){var u=this._endLabel,f=this._polyline;if(u){e<1&&a.originalX==null&&(a.originalX=u.x,a.originalY=u.y);var h=i.getLayout("points"),c=i.hostModel,v=c.get("connectNulls"),d=s.get("precision"),p=s.get("distance")||0,g=l.getBaseAxis(),m=g.isHorizontal(),y=g.inverse,_=n.shape,S=y?m?_.x:_.y+_.height:m?_.x+_.width:_.y,w=(m?p:0)*(y?-1:1),b=(m?0:-p)*(y?-1:1),T=m?"x":"y",C=qM(h,S,T),x=C.range,M=x[1]-x[0],A=void 0;if(M>=1){if(M>1&&!v){var P=Cd(h,x[0]);u.attr({x:P[0]+w,y:P[1]+b}),o&&(A=c.getRawValue(x[0]))}else{var P=f.getPointOn(S,T);P&&u.attr({x:P[0]+w,y:P[1]+b});var L=c.getRawValue(x[0]),I=c.getRawValue(x[1]);o&&(A=zm(i,d,L,I,C.t))}a.lastFrameIndex=x[0]}else{var R=e===1||a.lastFrameIndex>0?x[0]:0,P=Cd(h,R);o&&(A=c.getRawValue(R)),u.attr({x:P[0]+w,y:P[1]+b})}if(o){var E=dl(u);typeof E.setLabelText=="function"&&E.setLabelText(A)}}},t.prototype._doUpdateAnimation=function(e,n,i,a,o,s,l){var u=this._polyline,f=this._polygon,h=e.hostModel,c=PM(this._data,e,this._stackedOnPoints,n,this._coordSys,i,this._valueOrigin),v=c.current,d=c.stackedOnCurrent,p=c.next,g=c.stackedOnNext;if(o&&(d=wr(c.stackedOnCurrent,c.current,i,o,l),v=wr(c.current,null,i,o,l),g=wr(c.stackedOnNext,c.next,i,o,l),p=wr(c.next,null,i,o,l)),Td(v,p)>3e3||f&&Td(d,g)>3e3){u.stopAnimation(),u.setShape({points:p}),f&&(f.stopAnimation(),f.setShape({points:p,stackedOnPoints:g}));return}u.shape.__points=c.current,u.shape.points=v;var m={shape:{points:p}};c.current!==v&&(m.shape.__points=c.next),u.stopAnimation(),Ke(u,m,h),f&&(f.setShape({points:v,stackedOnPoints:d}),f.stopAnimation(),Ke(f,{shape:{stackedOnPoints:g}},h),u.shape.points!==f.shape.points&&(f.shape.points=u.shape.points));for(var y=[],_=c.status,S=0;S<_.length;S++){var w=_[S].cmd;if(w==="="){var b=e.getItemGraphicEl(_[S].idx1);b&&y.push({el:b,ptIdx:S})}}u.animators&&u.animators.length&&u.animators[0].during(function(){f&&f.dirtyShape();for(var T=u.shape.__points,C=0;C<y.length;C++){var x=y[C].el,M=y[C].ptIdx*2;x.x=T[M],x.y=T[M+1],x.markRedraw()}})},t.prototype.remove=function(e){var n=this.group,i=this._data;this._lineGroup.removeAll(),this._symbolDraw.remove(!0),i&&i.eachItemGraphicEl(function(a,o){a.__temp&&(n.remove(a),i.setItemGraphicEl(o,null))}),this._polyline=this._polygon=this._coordSys=this._points=this._stackedOnPoints=this._endLabel=this._data=null},t.type="line",t})(qe);function jM(r,t){return{seriesType:r,plan:y0(),reset:function(e){var n=e.getData(),i=e.coordinateSystem;if(e.pipelineContext,!!i){var a=$(i.dimensions,function(h){return n.mapDimension(h)}).slice(0,2),o=a.length,s=n.getCalculationInfo("stackResultDimension");Ha(n,a[0])&&(a[0]=s),Ha(n,a[1])&&(a[1]=s);var l=n.getStore(),u=n.getDimensionIndex(a[0]),f=n.getDimensionIndex(a[1]);return o&&{progress:function(h,c){for(var v=h.end-h.start,d=pi(v*o),p=[],g=[],m=h.start,y=0;m<h.end;m++){var _=void 0;if(o===1){var S=l.get(u,m);_=i.dataToPoint(S,null,g)}else p[0]=l.get(u,m),p[1]=l.get(f,m),_=i.dataToPoint(p,null,g);d[y++]=_[0],d[y++]=_[1]}c.setLayout("points",d)}}}}}}var JM={average:function(r){for(var t=0,e=0,n=0;n<r.length;n++)isNaN(r[n])||(t+=r[n],e++);return e===0?NaN:t/e},sum:function(r){for(var t=0,e=0;e<r.length;e++)t+=r[e]||0;return t},max:function(r){for(var t=-1/0,e=0;e<r.length;e++)r[e]>t&&(t=r[e]);return isFinite(t)?t:NaN},min:function(r){for(var t=1/0,e=0;e<r.length;e++)r[e]<t&&(t=r[e]);return isFinite(t)?t:NaN},nearest:function(r){return r[0]}},tC=function(r){return Math.round(r.length/2)};function eC(r){return{seriesType:r,reset:function(t,e,n){var i=t.getData(),a=t.get("sampling"),o=t.coordinateSystem,s=i.count();if(s>10&&o.type==="cartesian2d"&&a){var l=o.getBaseAxis(),u=o.getOtherAxis(l),f=l.getExtent(),h=n.getDevicePixelRatio(),c=Math.abs(f[1]-f[0])*(h||1),v=Math.round(s/c);if(isFinite(v)&&v>1){a==="lttb"?t.setData(i.lttbDownSample(i.mapDimension(u.dim),1/v)):a==="minmax"&&t.setData(i.minmaxDownSample(i.mapDimension(u.dim),1/v));var d=void 0;W(a)?d=JM[a]:et(a)&&(d=a),d&&t.setData(i.downSample(i.mapDimension(u.dim),1/v,d,tC))}}}}}function rC(r){r.registerChartView(QM),r.registerSeriesModel(TM),r.registerLayout(jM("line")),r.registerVisual({seriesType:"line",reset:function(t){var e=t.getData(),n=t.getModel("lineStyle").getLineStyle();n&&!n.stroke&&(n.stroke=e.getVisual("style").fill),e.setVisual("legendLineStyle",n)}}),r.registerProcessor(r.PRIORITY.PROCESSOR.STATISTIC,eC("line"))}var nC="__ec_stack_";function iC(r){return r.get("stack")||nC+r.seriesIndex}function b0(r){return r.dim+r.index}function aC(r,t){var e=[];return t.eachSeriesByType(r,function(n){fC(n)&&e.push(n)}),e}function oC(r){var t={};D(r,function(l){var u=l.coordinateSystem,f=u.getBaseAxis();if(!(f.type!=="time"&&f.type!=="value"))for(var h=l.getData(),c=f.dim+"_"+f.index,v=h.getDimensionIndex(h.mapDimension(f.dim)),d=h.getStore(),p=0,g=d.count();p<g;++p){var m=d.get(v,p);t[c]?t[c].push(m):t[c]=[m]}});var e={};for(var n in t)if(t.hasOwnProperty(n)){var i=t[n];if(i){i.sort(function(l,u){return l-u});for(var a=null,o=1;o<i.length;++o){var s=i[o]-i[o-1];s>0&&(a=a===null?s:Math.min(a,s))}e[n]=a}}return e}function sC(r){var t=oC(r),e=[];return D(r,function(n){var i=n.coordinateSystem,a=i.getBaseAxis(),o=a.getExtent(),s;if(a.type==="category")s=a.getBandWidth();else if(a.type==="value"||a.type==="time"){var l=a.dim+"_"+a.index,u=t[l],f=Math.abs(o[1]-o[0]),h=a.scale.getExtent(),c=Math.abs(h[1]-h[0]);s=u?f/c*u:f}else{var v=n.getData();s=Math.abs(o[1]-o[0])/v.count()}var d=It(n.get("barWidth"),s),p=It(n.get("barMaxWidth"),s),g=It(n.get("barMinWidth")||(hC(n)?.5:1),s),m=n.get("barGap"),y=n.get("barCategoryGap"),_=n.get("defaultBarGap");e.push({bandWidth:s,barWidth:d,barMaxWidth:p,barMinWidth:g,barGap:m,barCategoryGap:y,defaultBarGap:_,axisKey:b0(a),stackId:iC(n)})}),lC(e)}function lC(r){var t={};D(r,function(n,i){var a=n.axisKey,o=n.bandWidth,s=t[a]||{bandWidth:o,remainedWidth:o,autoWidthCount:0,categoryGap:null,gap:n.defaultBarGap||0,stacks:{}},l=s.stacks;t[a]=s;var u=n.stackId;l[u]||s.autoWidthCount++,l[u]=l[u]||{width:0,maxWidth:0};var f=n.barWidth;f&&!l[u].width&&(l[u].width=f,f=Math.min(s.remainedWidth,f),s.remainedWidth-=f);var h=n.barMaxWidth;h&&(l[u].maxWidth=h);var c=n.barMinWidth;c&&(l[u].minWidth=c);var v=n.barGap;v!=null&&(s.gap=v);var d=n.barCategoryGap;d!=null&&(s.categoryGap=d)});var e={};return D(t,function(n,i){e[i]={};var a=n.stacks,o=n.bandWidth,s=n.categoryGap;if(s==null){var l=St(a).length;s=Math.max(35-l*4,15)+"%"}var u=It(s,o),f=It(n.gap,1),h=n.remainedWidth,c=n.autoWidthCount,v=(h-u)/(c+(c-1)*f);v=Math.max(v,0),D(a,function(m){var y=m.maxWidth,_=m.minWidth;if(m.width){var S=m.width;y&&(S=Math.min(S,y)),_&&(S=Math.max(S,_)),m.width=S,h-=S+f*S,c--}else{var S=v;y&&y<S&&(S=Math.min(y,h)),_&&_>S&&(S=_),S!==v&&(m.width=S,h-=S+f*S,c--)}}),v=(h-u)/(c+(c-1)*f),v=Math.max(v,0);var d=0,p;D(a,function(m,y){m.width||(m.width=v),p=m,d+=m.width*(1+f)}),p&&(d-=p.width*f);var g=-d/2;D(a,function(m,y){e[i][y]=e[i][y]||{bandWidth:o,offset:g,width:m.width},g+=m.width*(1+f)})}),e}function uC(r,t,e){if(r&&t){var n=r[b0(t)];return n}}function fC(r){return r.coordinateSystem&&r.coordinateSystem.type==="cartesian2d"}function hC(r){return r.pipelineContext&&r.pipelineContext.large}var Es="\0__throttleOriginMethod",Dd="\0__throttleRate",Ad="\0__throttleType";function w0(r,t,e){var n,i=0,a=0,o=null,s,l,u,f;t=t||0;function h(){a=new Date().getTime(),o=null,r.apply(l,u||[])}var c=function(){for(var v=[],d=0;d<arguments.length;d++)v[d]=arguments[d];n=new Date().getTime(),l=this,u=v;var p=f||t,g=f||e;f=null,s=n-(g?i:a)-p,clearTimeout(o),g?o=setTimeout(h,p):s>=0?h():o=setTimeout(h,-s),i=n};return c.clear=function(){o&&(clearTimeout(o),o=null)},c.debounceNextCall=function(v){f=v},c}function _l(r,t,e,n){var i=r[t];if(i){var a=i[Es]||i,o=i[Ad],s=i[Dd];if(s!==e||o!==n){if(e==null||!n)return r[t]=a;i=r[t]=w0(a,e,n==="debounce"),i[Es]=a,i[Ad]=n,i[Dd]=e}return i}}function ks(r,t){var e=r[t];e&&e[Es]&&(e.clear&&e.clear(),r[t]=e[Es])}function jn(r,t,e,n,i){var a=r+t;e.isSilent(a)||n.eachComponent({mainType:"series",subType:"pie"},function(o){for(var s=o.seriesIndex,l=o.option.selectedMap,u=i.selected,f=0;f<u.length;f++)if(u[f].seriesIndex===s){var h=o.getData(),c=kn(h,i.fromActionPayload);e.trigger(a,{type:a,seriesId:o.id,name:H(c)?h.getName(c[0]):h.getName(c),selected:W(l)?l:O({},l)})}})}function vC(r,t,e){r.on("selectchanged",function(n){var i=e.getModel();n.isFromClick?(jn("map","selectchanged",t,i,n),jn("pie","selectchanged",t,i,n)):n.fromAction==="select"?(jn("map","selected",t,i,n),jn("pie","selected",t,i,n)):n.fromAction==="unselect"&&(jn("map","unselected",t,i,n),jn("pie","unselected",t,i,n))})}var $i=Math.PI*2,pn=vr.CMD,cC=["top","right","bottom","left"];function dC(r,t,e,n,i){var a=e.width,o=e.height;switch(r){case"top":n.set(e.x+a/2,e.y-t),i.set(0,-1);break;case"bottom":n.set(e.x+a/2,e.y+o+t),i.set(0,1);break;case"left":n.set(e.x-t,e.y+o/2),i.set(-1,0);break;case"right":n.set(e.x+a+t,e.y+o/2),i.set(1,0);break}}function pC(r,t,e,n,i,a,o,s,l){o-=r,s-=t;var u=Math.sqrt(o*o+s*s);o/=u,s/=u;var f=o*e+r,h=s*e+t;if(Math.abs(n-i)%$i<1e-4)return l[0]=f,l[1]=h,u-e;if(a){var c=n;n=ar(i),i=ar(c)}else n=ar(n),i=ar(i);n>i&&(i+=$i);var v=Math.atan2(s,o);if(v<0&&(v+=$i),v>=n&&v<=i||v+$i>=n&&v+$i<=i)return l[0]=f,l[1]=h,u-e;var d=e*Math.cos(n)+r,p=e*Math.sin(n)+t,g=e*Math.cos(i)+r,m=e*Math.sin(i)+t,y=(d-o)*(d-o)+(p-s)*(p-s),_=(g-o)*(g-o)+(m-s)*(m-s);return y<_?(l[0]=d,l[1]=p,Math.sqrt(y)):(l[0]=g,l[1]=m,Math.sqrt(_))}function Vf(r,t,e,n,i,a,o,s){var l=i-r,u=a-t,f=e-r,h=n-t,c=Math.sqrt(f*f+h*h);f/=c,h/=c;var v=l*f+u*h,d=v/c;s&&(d=Math.min(Math.max(d,0),1)),d*=c;var p=o[0]=r+d*f,g=o[1]=t+d*h;return Math.sqrt((p-i)*(p-i)+(g-a)*(g-a))}function x0(r,t,e,n,i,a,o){e<0&&(r=r+e,e=-e),n<0&&(t=t+n,n=-n);var s=r+e,l=t+n,u=o[0]=Math.min(Math.max(i,r),s),f=o[1]=Math.min(Math.max(a,t),l);return Math.sqrt((u-i)*(u-i)+(f-a)*(f-a))}var Pe=[];function gC(r,t,e){var n=x0(t.x,t.y,t.width,t.height,r.x,r.y,Pe);return e.set(Pe[0],Pe[1]),n}function mC(r,t,e){for(var n=0,i=0,a=0,o=0,s,l,u=1/0,f=t.data,h=r.x,c=r.y,v=0;v<f.length;){var d=f[v++];v===1&&(n=f[v],i=f[v+1],a=n,o=i);var p=u;switch(d){case pn.M:a=f[v++],o=f[v++],n=a,i=o;break;case pn.L:p=Vf(n,i,f[v],f[v+1],h,c,Pe,!0),n=f[v++],i=f[v++];break;case pn.C:p=pm(n,i,f[v++],f[v++],f[v++],f[v++],f[v],f[v+1],h,c,Pe),n=f[v++],i=f[v++];break;case pn.Q:p=mm(n,i,f[v++],f[v++],f[v],f[v+1],h,c,Pe),n=f[v++],i=f[v++];break;case pn.A:var g=f[v++],m=f[v++],y=f[v++],_=f[v++],S=f[v++],w=f[v++];v+=1;var b=!!(1-f[v++]);s=Math.cos(S)*y+g,l=Math.sin(S)*_+m,v<=1&&(a=s,o=l);var T=(h-g)*_/y+g;p=pC(g,m,_,S,S+w,b,T,c,Pe),n=Math.cos(S+w)*y+g,i=Math.sin(S+w)*_+m;break;case pn.R:a=n=f[v++],o=i=f[v++];var C=f[v++],x=f[v++];p=x0(a,o,C,x,h,c,Pe);break;case pn.Z:p=Vf(n,i,a,o,h,c,Pe,!0),n=a,i=o;break}p<u&&(u=p,e.set(Pe[0],Pe[1]))}return u}var Tn=new tt,kt=new tt,le=new tt,gi=new tt,qi=new tt;function Ld(r,t){if(r){var e=r.getTextGuideLine(),n=r.getTextContent();if(n&&e){var i=r.textGuideLineConfig||{},a=[[0,0],[0,0],[0,0]],o=i.candidates||cC,s=n.getBoundingRect().clone();s.applyTransform(n.getComputedTransform());var l=1/0,u=i.anchor,f=r.getComputedTransform(),h=f&&ki([],f),c=t.get("length2")||0;u&&le.copy(u);for(var v=0;v<o.length;v++){var d=o[v];dC(d,0,s,Tn,gi),tt.scaleAndAdd(kt,Tn,gi,c),kt.transform(h);var p=r.getBoundingRect(),g=u?u.distance(kt):r instanceof ht?mC(kt,r.path,le):gC(kt,p,le);g<l&&(l=g,kt.transform(f),le.transform(f),le.toArray(a[0]),kt.toArray(a[1]),Tn.toArray(a[2]))}yC(a,t.get("minTurnAngle")),e.setShape({points:a})}}}var Id=[],gn=new tt;function yC(r,t){if(t<=180&&t>0){t=t/180*Math.PI,Tn.fromArray(r[0]),kt.fromArray(r[1]),le.fromArray(r[2]),tt.sub(gi,Tn,kt),tt.sub(qi,le,kt);var e=gi.len(),n=qi.len();if(!(e<.001||n<.001)){gi.scale(1/e),qi.scale(1/n);var i=gi.dot(qi),a=Math.cos(t);if(a<i){var o=Vf(kt.x,kt.y,le.x,le.y,Tn.x,Tn.y,Id,!1);gn.fromArray(Id),gn.scaleAndAdd(qi,o/Math.tan(Math.PI-t));var s=le.x!==kt.x?(gn.x-kt.x)/(le.x-kt.x):(gn.y-kt.y)/(le.y-kt.y);if(isNaN(s))return;s<0?tt.copy(gn,kt):s>1&&tt.copy(gn,le),gn.toArray(r[1])}}}}function hu(r,t,e,n){var i=e==="normal",a=i?r:r.ensureState(e);a.ignore=t;var o=n.get("smooth");o&&o===!0&&(o=.3),a.shape=a.shape||{},o>0&&(a.shape.smooth=o);var s=n.getModel("lineStyle").getLineStyle();i?r.useStyle(s):a.style=s}function _C(r,t){var e=t.smooth,n=t.points;if(n)if(r.moveTo(n[0][0],n[0][1]),e>0&&n.length>=3){var i=af(n[0],n[1]),a=af(n[1],n[2]);if(!i||!a){r.lineTo(n[1][0],n[1][1]),r.lineTo(n[2][0],n[2][1]);return}var o=Math.min(i,a)*e,s=$o([],n[1],n[0],o/i),l=$o([],n[1],n[2],o/a),u=$o([],s,l,.5);r.bezierCurveTo(s[0],s[1],s[0],s[1],u[0],u[1]),r.bezierCurveTo(l[0],l[1],l[0],l[1],n[2][0],n[2][1])}else for(var f=1;f<n.length;f++)r.lineTo(n[f][0],n[f][1])}function SC(r,t,e){var n=r.getTextGuideLine(),i=r.getTextContent();if(!i){n&&r.removeTextGuideLine();return}for(var a=t.normal,o=a.get("show"),s=i.ignore,l=0;l<bs.length;l++){var u=bs[l],f=t[u],h=u==="normal";if(f){var c=f.get("show"),v=h?s:q(i.states[u]&&i.states[u].ignore,s);if(v||!q(c,o)){var d=h?n:n&&n.states[u];d&&(d.ignore=!0),n&&hu(n,!0,u,f);continue}n||(n=new eo,r.setTextGuideLine(n),!h&&(s||!o)&&hu(n,!0,"normal",t.normal),r.stateProxy&&(n.stateProxy=r.stateProxy)),hu(n,!1,u,f)}}if(n){at(n.style,e),n.style.fill=null;var p=a.get("showAbove"),g=r.textGuideLineConfig=r.textGuideLineConfig||{};g.showAbove=p||!1,n.buildPath=_C}}function bC(r,t){t=t||"labelLine";for(var e={normal:r.getModel(t)},n=0;n<Te.length;n++){var i=Te[n];e[i]=r.getModel([i,t])}return e}var Pd=["label","labelLine","layoutOption","priority","defaultAttr","marginForce","minMarginForce","marginDefault","suggestIgnore"],wC=1,Os=2,T0=wC|Os;function Bs(r,t,e){e=e||T0,t?r.dirty|=e:r.dirty&=~e}function M0(r,t){return t=t||T0,r.dirty==null||!!(r.dirty&t)}function Gr(r){if(r)return M0(r)&&xC(r,r.label,r),r}function xC(r,t,e){var n=t.getComputedTransform();r.transform=Uh(r.transform,n);var i=r.localRect=Fa(r.localRect,t.getBoundingRect()),a=t.style,o=a.margin,s=e&&e.marginForce,l=e&&e.minMarginForce,u=e&&e.marginDefault,f=a.__marginType;f==null&&u&&(o=u,f=di.textMargin);for(var h=0;h<4;h++)vu[h]=f===di.minMargin&&l&&l[h]!=null?l[h]:s&&s[h]!=null?s[h]:o?o[h]:0;f===di.textMargin&&Ds(i,vu,!1,!1);var c=r.rect=Fa(r.rect,i);return n&&c.applyTransform(n),f===di.minMargin&&Ds(c,vu,!1,!1),r.axisAligned=Wh(n),(r.label=r.label||{}).ignore=t.ignore,Bs(r,!1),Bs(r,!0,Os),r}var vu=[0,0,0,0];function TC(r,t,e){return r.transform=Uh(r.transform,e),r.localRect=Fa(r.localRect,t),r.rect=Fa(r.rect,t),e&&r.rect.applyTransform(e),r.axisAligned=Wh(e),r.obb=void 0,(r.label=r.label||{}).ignore=!1,r}function MC(r,t){if(r){r.label.x+=t.x,r.label.y+=t.y,r.label.markRedraw();var e=r.transform;e&&(e[4]+=t.x,e[5]+=t.y);var n=r.rect;n&&(n.x+=t.x,n.y+=t.y);var i=r.obb;i&&i.fromBoundingRect(r.localRect,e)}}function Gf(r,t){for(var e=0;e<Pd.length;e++){var n=Pd[e];r[n]==null&&(r[n]=t[n])}return Gr(r)}function Rd(r){var t=r.obb;return(!t||M0(r,Os))&&(r.obb=t=t||new ay,t.fromBoundingRect(r.localRect,r.transform),Bs(r,!1,Os)),t}function Ed(r,t,e,n,i){var a=r.length,o=Dr[t],s=Di[t];if(a<2)return!1;r.sort(function(T,C){return T.rect[o]-C.rect[o]});for(var l=0,u,f=!1,h=0;h<a;h++){var c=r[h],v=c.rect;u=v[o]-l,u<0&&(v[o]-=u,c.label[o]-=u,f=!0),l=v[o]+v[s]}var d=r[0],p=r[a-1],g,m;y(),g<0&&w(-g,.8),m<0&&w(m,.8),y(),_(g,m,1),_(m,g,-1),y(),g<0&&b(-g),m<0&&b(m);function y(){g=d.rect[o]-e,m=n-p.rect[o]-p.rect[s]}function _(T,C,x){if(T<0){var M=Math.min(C,-T);if(M>0){S(M*x,0,a);var A=M+T;A<0&&w(-A*x,1)}else w(-T*x,1)}}function S(T,C,x){T!==0&&(f=!0);for(var M=C;M<x;M++){var A=r[M],P=A.rect;P[o]+=T,A.label[o]+=T}}function w(T,C){for(var x=[],M=0,A=1;A<a;A++){var P=r[A-1].rect,L=Math.max(r[A].rect[o]-P[o]-P[s],0);x.push(L),M+=L}if(M){var I=Math.min(Math.abs(T)/M,C);if(T>0)for(var A=0;A<a-1;A++){var R=x[A]*I;S(R,0,A+1)}else for(var A=a-1;A>0;A--){var R=x[A-1]*I;S(-R,A,a)}}}function b(T){var C=T<0?-1:1;T=Math.abs(T);for(var x=Math.ceil(T/(a-1)),M=0;M<a-1;M++)if(C>0?S(x,0,M+1):S(-x,a-M-1,a),T-=x,T<=0)return}return f}function CC(r){for(var t=0;t<r.length;t++){var e=r[t],n=e.defaultAttr,i=e.labelLine;e.label.attr("ignore",n.ignore),i&&i.attr("ignore",n.labelGuideIgnore)}}function C0(r){var t=[];r.sort(function(u,f){return(f.suggestIgnore?1:0)-(u.suggestIgnore?1:0)||f.priority-u.priority});function e(u){if(!u.ignore){var f=u.ensureState("emphasis");f.ignore==null&&(f.ignore=!1)}u.ignore=!0}for(var n=0;n<r.length;n++){var i=Gr(r[n]);if(!i.label.ignore){for(var a=i.label,o=i.labelLine,s=!1,l=0;l<t.length;l++)if(fv(i,t[l],null,{touchThreshold:.05})){s=!0;break}s?(e(a),o&&e(o)):t.push(i)}}}function fv(r,t,e,n){return!r||!t||r.label&&r.label.ignore||t.label&&t.label.ignore||!r.rect.intersect(t.rect,e,n)?!1:r.axisAligned&&t.axisAligned?!0:Rd(r).intersect(Rd(t),e,n)}var Jn=(function(){function r(t,e){this.target=t,this.topTarget=e&&e.topTarget}return r})(),DC=(function(){function r(t){this.handler=t,t.on("mousedown",this._dragStart,this),t.on("mousemove",this._drag,this),t.on("mouseup",this._dragEnd,this)}return r.prototype._dragStart=function(t){for(var e=t.target;e&&!e.draggable;)e=e.parent||e.__hostTarget;e&&(this._draggingTarget=e,e.dragging=!0,this._x=t.offsetX,this._y=t.offsetY,this.handler.dispatchToElement(new Jn(e,t),"dragstart",t.event))},r.prototype._drag=function(t){var e=this._draggingTarget;if(e){var n=t.offsetX,i=t.offsetY,a=n-this._x,o=i-this._y;this._x=n,this._y=i,e.drift(a,o,t),this.handler.dispatchToElement(new Jn(e,t),"drag",t.event);var s=this.handler.findHover(n,i,e).target,l=this._dropTarget;this._dropTarget=s,e!==s&&(l&&s!==l&&this.handler.dispatchToElement(new Jn(l,t),"dragleave",t.event),s&&s!==l&&this.handler.dispatchToElement(new Jn(s,t),"dragenter",t.event))}},r.prototype._dragEnd=function(t){var e=this._draggingTarget;e&&(e.dragging=!1),this.handler.dispatchToElement(new Jn(e,t),"dragend",t.event),this._dropTarget&&this.handler.dispatchToElement(new Jn(this._dropTarget,t),"drop",t.event),this._draggingTarget=null,this._dropTarget=null},r})(),AC=/^(?:mouse|pointer|contextmenu|drag|drop)|click/,cu=[],LC=nt.browser.firefox&&+nt.browser.version.split(".")[0]<39;function Wf(r,t,e,n){return e=e||{},n?kd(r,t,e):LC&&t.layerX!=null&&t.layerX!==t.offsetX?(e.zrX=t.layerX,e.zrY=t.layerY):t.offsetX!=null?(e.zrX=t.offsetX,e.zrY=t.offsetY):kd(r,t,e),e}function kd(r,t,e){if(nt.domSupported&&r.getBoundingClientRect){var n=t.clientX,i=t.clientY;if(Uy(r)){var a=r.getBoundingClientRect();e.zrX=n-a.left,e.zrY=i-a.top;return}else if(kf(cu,r,n,i)){e.zrX=cu[0],e.zrY=cu[1];return}}e.zrX=e.zrY=0}function hv(r){return r||window.event}function ye(r,t,e){if(t=hv(t),t.zrX!=null)return t;var n=t.type,i=n&&n.indexOf("touch")>=0;if(i){var o=n!=="touchend"?t.targetTouches[0]:t.changedTouches[0];o&&Wf(r,o,t,e)}else{Wf(r,t,t,e);var a=IC(t);t.zrDelta=a?a/120:-(t.detail||0)/3}var s=t.button;return t.which==null&&s!==void 0&&AC.test(t.type)&&(t.which=s&1?1:s&2?3:s&4?2:0),t}function IC(r){var t=r.wheelDelta;if(t)return t;var e=r.deltaX,n=r.deltaY;if(e==null||n==null)return t;var i=Math.abs(n!==0?n:e),a=n>0?-1:n<0?1:e>0?-1:1;return 3*i*a}function PC(r,t,e,n){r.addEventListener(t,e,n)}function RC(r,t,e,n){r.removeEventListener(t,e,n)}var Li=function(r){r.preventDefault(),r.stopPropagation(),r.cancelBubble=!0};function Od(r){return r.which===2||r.which===3}var EC=(function(){function r(){this._track=[]}return r.prototype.recognize=function(t,e,n){return this._doTrack(t,e,n),this._recognize(t)},r.prototype.clear=function(){return this._track.length=0,this},r.prototype._doTrack=function(t,e,n){var i=t.touches;if(i){for(var a={points:[],touches:[],target:e,event:t},o=0,s=i.length;o<s;o++){var l=i[o],u=Wf(n,l,{});a.points.push([u.zrX,u.zrY]),a.touches.push(l)}this._track.push(a)}},r.prototype._recognize=function(t){for(var e in du)if(du.hasOwnProperty(e)){var n=du[e](this._track,t);if(n)return n}},r})();function Bd(r){var t=r[1][0]-r[0][0],e=r[1][1]-r[0][1];return Math.sqrt(t*t+e*e)}function kC(r){return[(r[0][0]+r[1][0])/2,(r[0][1]+r[1][1])/2]}var du={pinch:function(r,t){var e=r.length;if(e){var n=(r[e-1]||{}).points,i=(r[e-2]||{}).points||n;if(i&&i.length>1&&n&&n.length>1){var a=Bd(n)/Bd(i);!isFinite(a)&&(a=1),t.pinchScale=a;var o=kC(n);return t.pinchX=o[0],t.pinchY=o[1],{type:"pinch",target:r[0].target,event:t}}}}},D0="silent";function OC(r,t,e){return{type:r,event:e,target:t.target,topTarget:t.topTarget,cancelBubble:!1,offsetX:e.zrX,offsetY:e.zrY,gestureEvent:e.gestureEvent,pinchX:e.pinchX,pinchY:e.pinchY,pinchScale:e.pinchScale,wheelDelta:e.zrDelta,zrByTouch:e.zrByTouch,which:e.which,stop:BC}}function BC(){Li(this.event)}var NC=(function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.handler=null,e}return t.prototype.dispose=function(){},t.prototype.setCursor=function(){},t})(ke),Ki=(function(){function r(t,e){this.x=t,this.y=e}return r})(),FC=["click","dblclick","mousewheel","mouseout","mouseup","mousedown","mousemove","contextmenu"],pu=new it(0,0,0,0),A0=(function(r){z(t,r);function t(e,n,i,a,o){var s=r.call(this)||this;return s._hovered=new Ki(0,0),s.storage=e,s.painter=n,s.painterRoot=a,s._pointerSize=o,i=i||new NC,s.proxy=null,s.setHandlerProxy(i),s._draggingMgr=new DC(s),s}return t.prototype.setHandlerProxy=function(e){this.proxy&&this.proxy.dispose(),e&&(D(FC,function(n){e.on&&e.on(n,this[n],this)},this),e.handler=this),this.proxy=e},t.prototype.mousemove=function(e){var n=e.zrX,i=e.zrY,a=L0(this,n,i),o=this._hovered,s=o.target;s&&!s.__zr&&(o=this.findHover(o.x,o.y),s=o.target);var l=this._hovered=a?new Ki(n,i):this.findHover(n,i),u=l.target,f=this.proxy;f.setCursor&&f.setCursor(u?u.cursor:"default"),s&&u!==s&&this.dispatchToElement(o,"mouseout",e),this.dispatchToElement(l,"mousemove",e),u&&u!==s&&this.dispatchToElement(l,"mouseover",e)},t.prototype.mouseout=function(e){var n=e.zrEventControl;n!=="only_globalout"&&this.dispatchToElement(this._hovered,"mouseout",e),n!=="no_globalout"&&this.trigger("globalout",{type:"globalout",event:e})},t.prototype.resize=function(){this._hovered=new Ki(0,0)},t.prototype.dispatch=function(e,n){var i=this[e];i&&i.call(this,n)},t.prototype.dispose=function(){this.proxy.dispose(),this.storage=null,this.proxy=null,this.painter=null},t.prototype.setCursorStyle=function(e){var n=this.proxy;n.setCursor&&n.setCursor(e)},t.prototype.dispatchToElement=function(e,n,i){e=e||{};var a=e.target;if(!(a&&a.silent)){for(var o="on"+n,s=OC(n,e,i);a&&(a[o]&&(s.cancelBubble=!!a[o].call(a,s)),a.trigger(n,s),a=a.__hostTarget?a.__hostTarget:a.parent,!s.cancelBubble););s.cancelBubble||(this.trigger(n,s),this.painter&&this.painter.eachOtherLayer&&this.painter.eachOtherLayer(function(l){typeof l[o]=="function"&&l[o].call(l,s),l.trigger&&l.trigger(n,s)}))}},t.prototype.findHover=function(e,n,i){var a=this.storage.getDisplayList(),o=new Ki(e,n);if(Nd(a,o,e,n,i),this._pointerSize&&!o.target){for(var s=[],l=this._pointerSize,u=l/2,f=new it(e-u,n-u,l,l),h=a.length-1;h>=0;h--){var c=a[h];c!==i&&!c.ignore&&!c.ignoreCoarsePointer&&(!c.parent||!c.parent.ignoreCoarsePointer)&&(pu.copy(c.getBoundingRect()),c.transform&&pu.applyTransform(c.transform),pu.intersect(f)&&s.push(c))}if(s.length)for(var v=4,d=Math.PI/12,p=Math.PI*2,g=0;g<u;g+=v)for(var m=0;m<p;m+=d){var y=e+g*Math.cos(m),_=n+g*Math.sin(m);if(Nd(s,o,y,_,i),o.target)return o}}return o},t.prototype.processGesture=function(e,n){this._gestureMgr||(this._gestureMgr=new EC);var i=this._gestureMgr;n==="start"&&i.clear();var a=i.recognize(e,this.findHover(e.zrX,e.zrY,null).target,this.proxy.dom);if(n==="end"&&i.clear(),a){var o=a.type;e.gestureEvent=o;var s=new Ki;s.target=a.target,this.dispatchToElement(s,o,a.event)}},t})(ke);D(["click","mousedown","mouseup","mousewheel","dblclick","contextmenu"],function(r){A0.prototype[r]=function(t){var e=t.zrX,n=t.zrY,i=L0(this,e,n),a,o;if((r!=="mouseup"||!i)&&(a=this.findHover(e,n),o=a.target),r==="mousedown")this._downEl=o,this._downPoint=[t.zrX,t.zrY],this._upEl=o;else if(r==="mouseup")this._upEl=o;else if(r==="click"){if(this._downEl!==this._upEl||!this._downPoint||af(this._downPoint,[t.zrX,t.zrY])>4)return;this._downPoint=null}this.dispatchToElement(a,r,t)}});function zC(r,t,e){if(r[r.rectHover?"rectContain":"contain"](t,e)){for(var n=r,i=void 0,a=!1;n;){if(n.ignoreClip&&(a=!0),!a){var o=n.getClipPath();if(o&&!o.contain(t,e))return!1}n.silent&&(i=!0);var s=n.__hostTarget;n=s?n.ignoreHostSilent?null:s:n.parent}return i?D0:!0}return!1}function Nd(r,t,e,n,i){for(var a=r.length-1;a>=0;a--){var o=r[a],s=void 0;if(o!==i&&!o.ignore&&(s=zC(o,e,n))&&(!t.topTarget&&(t.topTarget=o),s!==D0)){t.target=o;break}}}function L0(r,t,e){var n=r.painter;return t<0||t>n.getWidth()||e<0||e>n.getHeight()}var I0=32,Qi=7;function HC(r){for(var t=0;r>=I0;)t|=r&1,r>>=1;return r+t}function Fd(r,t,e,n){var i=t+1;if(i===e)return 1;if(n(r[i++],r[t])<0){for(;i<e&&n(r[i],r[i-1])<0;)i++;VC(r,t,i)}else for(;i<e&&n(r[i],r[i-1])>=0;)i++;return i-t}function VC(r,t,e){for(e--;t<e;){var n=r[t];r[t++]=r[e],r[e--]=n}}function zd(r,t,e,n,i){for(n===t&&n++;n<e;n++){for(var a=r[n],o=t,s=n,l;o<s;)l=o+s>>>1,i(a,r[l])<0?s=l:o=l+1;var u=n-o;switch(u){case 3:r[o+3]=r[o+2];case 2:r[o+2]=r[o+1];case 1:r[o+1]=r[o];break;default:for(;u>0;)r[o+u]=r[o+u-1],u--}r[o]=a}}function gu(r,t,e,n,i,a){var o=0,s=0,l=1;if(a(r,t[e+i])>0){for(s=n-i;l<s&&a(r,t[e+i+l])>0;)o=l,l=(l<<1)+1,l<=0&&(l=s);l>s&&(l=s),o+=i,l+=i}else{for(s=i+1;l<s&&a(r,t[e+i-l])<=0;)o=l,l=(l<<1)+1,l<=0&&(l=s);l>s&&(l=s);var u=o;o=i-l,l=i-u}for(o++;o<l;){var f=o+(l-o>>>1);a(r,t[e+f])>0?o=f+1:l=f}return l}function mu(r,t,e,n,i,a){var o=0,s=0,l=1;if(a(r,t[e+i])<0){for(s=i+1;l<s&&a(r,t[e+i-l])<0;)o=l,l=(l<<1)+1,l<=0&&(l=s);l>s&&(l=s);var u=o;o=i-l,l=i-u}else{for(s=n-i;l<s&&a(r,t[e+i+l])>=0;)o=l,l=(l<<1)+1,l<=0&&(l=s);l>s&&(l=s),o+=i,l+=i}for(o++;o<l;){var f=o+(l-o>>>1);a(r,t[e+f])<0?l=f:o=f+1}return l}function GC(r,t){var e=Qi,n,i,a=0,o=[];n=[],i=[];function s(v,d){n[a]=v,i[a]=d,a+=1}function l(){for(;a>1;){var v=a-2;if(v>=1&&i[v-1]<=i[v]+i[v+1]||v>=2&&i[v-2]<=i[v]+i[v-1])i[v-1]<i[v+1]&&v--;else if(i[v]>i[v+1])break;f(v)}}function u(){for(;a>1;){var v=a-2;v>0&&i[v-1]<i[v+1]&&v--,f(v)}}function f(v){var d=n[v],p=i[v],g=n[v+1],m=i[v+1];i[v]=p+m,v===a-3&&(n[v+1]=n[v+2],i[v+1]=i[v+2]),a--;var y=mu(r[g],r,d,p,0,t);d+=y,p-=y,p!==0&&(m=gu(r[d+p-1],r,g,m,m-1,t),m!==0&&(p<=m?h(d,p,g,m):c(d,p,g,m)))}function h(v,d,p,g){var m=0;for(m=0;m<d;m++)o[m]=r[v+m];var y=0,_=p,S=v;if(r[S++]=r[_++],--g===0){for(m=0;m<d;m++)r[S+m]=o[y+m];return}if(d===1){for(m=0;m<g;m++)r[S+m]=r[_+m];r[S+g]=o[y];return}for(var w=e,b,T,C;;){b=0,T=0,C=!1;do if(t(r[_],o[y])<0){if(r[S++]=r[_++],T++,b=0,--g===0){C=!0;break}}else if(r[S++]=o[y++],b++,T=0,--d===1){C=!0;break}while((b|T)<w);if(C)break;do{if(b=mu(r[_],o,y,d,0,t),b!==0){for(m=0;m<b;m++)r[S+m]=o[y+m];if(S+=b,y+=b,d-=b,d<=1){C=!0;break}}if(r[S++]=r[_++],--g===0){C=!0;break}if(T=gu(o[y],r,_,g,0,t),T!==0){for(m=0;m<T;m++)r[S+m]=r[_+m];if(S+=T,_+=T,g-=T,g===0){C=!0;break}}if(r[S++]=o[y++],--d===1){C=!0;break}w--}while(b>=Qi||T>=Qi);if(C)break;w<0&&(w=0),w+=2}if(e=w,e<1&&(e=1),d===1){for(m=0;m<g;m++)r[S+m]=r[_+m];r[S+g]=o[y]}else{if(d===0)throw new Error;for(m=0;m<d;m++)r[S+m]=o[y+m]}}function c(v,d,p,g){var m=0;for(m=0;m<g;m++)o[m]=r[p+m];var y=v+d-1,_=g-1,S=p+g-1,w=0,b=0;if(r[S--]=r[y--],--d===0){for(w=S-(g-1),m=0;m<g;m++)r[w+m]=o[m];return}if(g===1){for(S-=d,y-=d,b=S+1,w=y+1,m=d-1;m>=0;m--)r[b+m]=r[w+m];r[S]=o[_];return}for(var T=e;;){var C=0,x=0,M=!1;do if(t(o[_],r[y])<0){if(r[S--]=r[y--],C++,x=0,--d===0){M=!0;break}}else if(r[S--]=o[_--],x++,C=0,--g===1){M=!0;break}while((C|x)<T);if(M)break;do{if(C=d-mu(o[_],r,v,d,d-1,t),C!==0){for(S-=C,y-=C,d-=C,b=S+1,w=y+1,m=C-1;m>=0;m--)r[b+m]=r[w+m];if(d===0){M=!0;break}}if(r[S--]=o[_--],--g===1){M=!0;break}if(x=g-gu(r[y],o,0,g,g-1,t),x!==0){for(S-=x,_-=x,g-=x,b=S+1,w=_+1,m=0;m<x;m++)r[b+m]=o[w+m];if(g<=1){M=!0;break}}if(r[S--]=r[y--],--d===0){M=!0;break}T--}while(C>=Qi||x>=Qi);if(M)break;T<0&&(T=0),T+=2}if(e=T,e<1&&(e=1),g===1){for(S-=d,y-=d,b=S+1,w=y+1,m=d-1;m>=0;m--)r[b+m]=r[w+m];r[S]=o[_]}else{if(g===0)throw new Error;for(w=S-(g-1),m=0;m<g;m++)r[w+m]=o[m]}}return{mergeRuns:l,forceMergeRuns:u,pushRun:s}}function os(r,t,e,n){e||(e=0),n||(n=r.length);var i=n-e;if(!(i<2)){var a=0;if(i<I0){a=Fd(r,e,n,t),zd(r,e,n,e+a,t);return}var o=GC(r,t),s=HC(i);do{if(a=Fd(r,e,n,t),a<s){var l=i;l>s&&(l=s),zd(r,e,e+l,e+a,t),a=l}o.pushRun(e,a),o.mergeRuns(),i-=a,e+=a}while(i!==0);o.forceMergeRuns()}}var Hd=!1;function yu(){Hd||(Hd=!0,console.warn("z / z2 / zlevel of displayable is invalid, which may cause unexpected errors"))}function Vd(r,t){return r.zlevel===t.zlevel?r.z===t.z?r.z2-t.z2:r.z-t.z:r.zlevel-t.zlevel}var WC=(function(){function r(){this._roots=[],this._displayList=[],this._displayListLen=0,this.displayableSortFunc=Vd}return r.prototype.traverse=function(t,e){for(var n=0;n<this._roots.length;n++)this._roots[n].traverse(t,e)},r.prototype.getDisplayList=function(t,e){e=e||!1;var n=this._displayList;return(t||!n.length)&&this.updateDisplayList(e),n},r.prototype.updateDisplayList=function(t){this._displayListLen=0;for(var e=this._roots,n=this._displayList,i=0,a=e.length;i<a;i++)this._updateAndAddDisplayable(e[i],null,t);n.length=this._displayListLen,os(n,Vd)},r.prototype._updateAndAddDisplayable=function(t,e,n){if(!(t.ignore&&!n)){t.beforeUpdate(),t.update(),t.afterUpdate();var i=t.getClipPath(),a=e&&e.length,o=0,s=t.__clipPaths;if(!t.ignoreClip&&(a||i)){if(s||(s=t.__clipPaths=[]),a)for(var l=0;l<e.length;l++)s[o++]=e[l];for(var u=i,f=t;u;)u.parent=f,u.updateTransform(),s[o++]=u,f=u,u=u.getClipPath()}if(s&&(s.length=o),t.childrenRef){for(var h=t.childrenRef(),c=0;c<h.length;c++){var v=h[c];t.__dirty&&(v.__dirty|=fe),this._updateAndAddDisplayable(v,s,n)}t.__dirty=0}else{var d=t;isNaN(d.z)&&(yu(),d.z=0),isNaN(d.z2)&&(yu(),d.z2=0),isNaN(d.zlevel)&&(yu(),d.zlevel=0),this._displayList[this._displayListLen++]=d}var p=t.getDecalElement&&t.getDecalElement();p&&this._updateAndAddDisplayable(p,s,n);var g=t.getTextGuideLine();g&&this._updateAndAddDisplayable(g,s,n);var m=t.getTextContent();m&&this._updateAndAddDisplayable(m,s,n)}},r.prototype.addRoot=function(t){t.__zr&&t.__zr.storage===this||this._roots.push(t)},r.prototype.delRoot=function(t){if(t instanceof Array){for(var e=0,n=t.length;e<n;e++)this.delRoot(t[e]);return}var i=ft(this._roots,t);i>=0&&this._roots.splice(i,1)},r.prototype.delAllRoots=function(){this._roots=[],this._displayList=[],this._displayListLen=0},r.prototype.getRoots=function(){return this._roots},r.prototype.dispose=function(){this._displayList=null,this._roots=null},r})(),Ns;Ns=nt.hasGlobalWindow&&(window.requestAnimationFrame&&window.requestAnimationFrame.bind(window)||window.msRequestAnimationFrame&&window.msRequestAnimationFrame.bind(window)||window.mozRequestAnimationFrame||window.webkitRequestAnimationFrame)||function(r){return setTimeout(r,16)};function mi(){return new Date().getTime()}var UC=(function(r){z(t,r);function t(e){var n=r.call(this)||this;return n._running=!1,n._time=0,n._pausedTime=0,n._pauseStart=0,n._paused=!1,e=e||{},n.stage=e.stage||{},n}return t.prototype.addClip=function(e){e.animation&&this.removeClip(e),this._head?(this._tail.next=e,e.prev=this._tail,e.next=null,this._tail=e):this._head=this._tail=e,e.animation=this},t.prototype.addAnimator=function(e){e.animation=this;var n=e.getClip();n&&this.addClip(n)},t.prototype.removeClip=function(e){if(e.animation){var n=e.prev,i=e.next;n?n.next=i:this._head=i,i?i.prev=n:this._tail=n,e.next=e.prev=e.animation=null}},t.prototype.removeAnimator=function(e){var n=e.getClip();n&&this.removeClip(n),e.animation=null},t.prototype.update=function(e){for(var n=mi()-this._pausedTime,i=n-this._time,a=this._head;a;){var o=a.next,s=a.step(n,i);s&&(a.ondestroy(),this.removeClip(a)),a=o}this._time=n,e||(this.trigger("frame",i),this.stage.update&&this.stage.update())},t.prototype._startLoop=function(){var e=this;this._running=!0;function n(){e._running&&(Ns(n),!e._paused&&e.update())}Ns(n)},t.prototype.start=function(){this._running||(this._time=mi(),this._pausedTime=0,this._startLoop())},t.prototype.stop=function(){this._running=!1},t.prototype.pause=function(){this._paused||(this._pauseStart=mi(),this._paused=!0)},t.prototype.resume=function(){this._paused&&(this._pausedTime+=mi()-this._pauseStart,this._paused=!1)},t.prototype.clear=function(){for(var e=this._head;e;){var n=e.next;e.prev=e.next=e.animation=null,e=n}this._head=this._tail=null},t.prototype.isFinished=function(){return this._head==null},t.prototype.animate=function(e,n){n=n||{},this.start();var i=new Dh(e,n.loop);return this.addAnimator(i),i},t})(ke),YC=300,_u=nt.domSupported,Su=(function(){var r=["click","dblclick","mousewheel","wheel","mouseout","mouseup","mousedown","mousemove","contextmenu"],t=["touchstart","touchend","touchmove"],e={pointerdown:1,pointerup:1,pointermove:1,pointerout:1},n=$(r,function(i){var a=i.replace("mouse","pointer");return e.hasOwnProperty(a)?a:i});return{mouse:r,touch:t,pointer:n}})(),Gd={mouse:["mousemove","mouseup"],pointer:["pointermove","pointerup"]},Wd=!1;function Uf(r){var t=r.pointerType;return t==="pen"||t==="touch"}function ZC(r){r.touching=!0,r.touchTimer!=null&&(clearTimeout(r.touchTimer),r.touchTimer=null),r.touchTimer=setTimeout(function(){r.touching=!1,r.touchTimer=null},700)}function bu(r){r&&(r.zrByTouch=!0)}function XC(r,t){return ye(r.dom,new $C(r,t),!0)}function P0(r,t){for(var e=t,n=!1;e&&e.nodeType!==9&&!(n=e.domBelongToZr||e!==t&&e===r.painterRoot);)e=e.parentNode;return n}var $C=(function(){function r(t,e){this.stopPropagation=Kt,this.stopImmediatePropagation=Kt,this.preventDefault=Kt,this.type=e.type,this.target=this.currentTarget=t.dom,this.pointerType=e.pointerType,this.clientX=e.clientX,this.clientY=e.clientY}return r})(),Le={mousedown:function(r){r=ye(this.dom,r),this.__mayPointerCapture=[r.zrX,r.zrY],this.trigger("mousedown",r)},mousemove:function(r){r=ye(this.dom,r);var t=this.__mayPointerCapture;t&&(r.zrX!==t[0]||r.zrY!==t[1])&&this.__togglePointerCapture(!0),this.trigger("mousemove",r)},mouseup:function(r){r=ye(this.dom,r),this.__togglePointerCapture(!1),this.trigger("mouseup",r)},mouseout:function(r){r=ye(this.dom,r);var t=r.toElement||r.relatedTarget;P0(this,t)||(this.__pointerCapturing&&(r.zrEventControl="no_globalout"),this.trigger("mouseout",r))},wheel:function(r){Wd=!0,r=ye(this.dom,r),this.trigger("mousewheel",r)},mousewheel:function(r){Wd||(r=ye(this.dom,r),this.trigger("mousewheel",r))},touchstart:function(r){r=ye(this.dom,r),bu(r),this.__lastTouchMoment=new Date,this.handler.processGesture(r,"start"),Le.mousemove.call(this,r),Le.mousedown.call(this,r)},touchmove:function(r){r=ye(this.dom,r),bu(r),this.handler.processGesture(r,"change"),Le.mousemove.call(this,r)},touchend:function(r){r=ye(this.dom,r),bu(r),this.handler.processGesture(r,"end"),Le.mouseup.call(this,r),+new Date-+this.__lastTouchMoment<YC&&Le.click.call(this,r)},pointerdown:function(r){Le.mousedown.call(this,r)},pointermove:function(r){Uf(r)||Le.mousemove.call(this,r)},pointerup:function(r){Le.mouseup.call(this,r)},pointerout:function(r){Uf(r)||Le.mouseout.call(this,r)}};D(["click","dblclick","contextmenu"],function(r){Le[r]=function(t){t=ye(this.dom,t),this.trigger(r,t)}});var Yf={pointermove:function(r){Uf(r)||Yf.mousemove.call(this,r)},pointerup:function(r){Yf.mouseup.call(this,r)},mousemove:function(r){this.trigger("mousemove",r)},mouseup:function(r){var t=this.__pointerCapturing;this.__togglePointerCapture(!1),this.trigger("mouseup",r),t&&(r.zrEventControl="only_globalout",this.trigger("mouseout",r))}};function qC(r,t){var e=t.domHandlers;nt.pointerEventsSupported?D(Su.pointer,function(n){ss(t,n,function(i){e[n].call(r,i)})}):(nt.touchEventsSupported&&D(Su.touch,function(n){ss(t,n,function(i){e[n].call(r,i),ZC(t)})}),D(Su.mouse,function(n){ss(t,n,function(i){i=hv(i),t.touching||e[n].call(r,i)})}))}function KC(r,t){nt.pointerEventsSupported?D(Gd.pointer,e):nt.touchEventsSupported||D(Gd.mouse,e);function e(n){function i(a){a=hv(a),P0(r,a.target)||(a=XC(r,a),t.domHandlers[n].call(r,a))}ss(t,n,i,{capture:!0})}}function ss(r,t,e,n){r.mounted[t]=e,r.listenerOpts[t]=n,PC(r.domTarget,t,e,n)}function wu(r){var t=r.mounted;for(var e in t)t.hasOwnProperty(e)&&RC(r.domTarget,e,t[e],r.listenerOpts[e]);r.mounted={}}var Ud=(function(){function r(t,e){this.mounted={},this.listenerOpts={},this.touching=!1,this.domTarget=t,this.domHandlers=e}return r})(),QC=(function(r){z(t,r);function t(e,n){var i=r.call(this)||this;return i.__pointerCapturing=!1,i.dom=e,i.painterRoot=n,i._localHandlerScope=new Ud(e,Le),_u&&(i._globalHandlerScope=new Ud(document,Yf)),qC(i,i._localHandlerScope),i}return t.prototype.dispose=function(){wu(this._localHandlerScope),_u&&wu(this._globalHandlerScope)},t.prototype.setCursor=function(e){this.dom.style&&(this.dom.style.cursor=e||"default")},t.prototype.__togglePointerCapture=function(e){if(this.__mayPointerCapture=null,_u&&+this.__pointerCapturing^+e){this.__pointerCapturing=e;var n=this._globalHandlerScope;e?KC(this,n):wu(n)}},t})(ke);/*!
* ZRender, a high performance 2d drawing library.
*
* Copyright (c) 2013, Baidu Inc.
* All rights reserved.
*
* LICENSE
* https://github.com/ecomfe/zrender/blob/master/LICENSE.txt
*/var ls={},R0={};function jC(r){delete R0[r]}function JC(r){if(!r)return!1;if(typeof r=="string")return ms(r,1)<df;if(r.colorStops){for(var t=r.colorStops,e=0,n=t.length,i=0;i<n;i++)e+=ms(t[i].color,1);return e/=n,e<df}return!1}var tD=(function(){function r(t,e,n){var i=this;this._sleepAfterStill=10,this._stillFrameAccum=0,this._needsRefresh=!0,this._needsRefreshHover=!0,this._darkMode=!1,n=n||{},this.dom=e,this.id=t;var a=new WC,o=n.renderer||"canvas";ls[o]||(o=St(ls)[0]),n.useDirtyRect=n.useDirtyRect==null?!1:n.useDirtyRect;var s=new ls[o](e,a,n,t),l=n.ssr||s.ssrOnly;this.storage=a,this.painter=s;var u=!nt.node&&!nt.worker&&!l?new QC(s.getViewportRoot(),s.root):null,f=n.useCoarsePointer,h=f==null||f==="auto"?nt.touchEventsSupported:!!f,c=44,v;h&&(v=q(n.pointerSize,c)),this.handler=new A0(a,s,u,s.root,v),this.animation=new UC({stage:{update:l?null:function(){return i._flush(!0)}}}),l||this.animation.start()}return r.prototype.add=function(t){this._disposed||!t||(this.storage.addRoot(t),t.addSelfToZr(this),this.refresh())},r.prototype.remove=function(t){this._disposed||!t||(this.storage.delRoot(t),t.removeSelfFromZr(this),this.refresh())},r.prototype.configLayer=function(t,e){this._disposed||(this.painter.configLayer&&this.painter.configLayer(t,e),this.refresh())},r.prototype.setBackgroundColor=function(t){this._disposed||(this.painter.setBackgroundColor&&this.painter.setBackgroundColor(t),this.refresh(),this._backgroundColor=t,this._darkMode=JC(t))},r.prototype.getBackgroundColor=function(){return this._backgroundColor},r.prototype.setDarkMode=function(t){this._darkMode=t},r.prototype.isDarkMode=function(){return this._darkMode},r.prototype.refreshImmediately=function(t){this._disposed||(t||this.animation.update(!0),this._needsRefresh=!1,this.painter.refresh(),this._needsRefresh=!1)},r.prototype.refresh=function(){this._disposed||(this._needsRefresh=!0,this.animation.start())},r.prototype.flush=function(){this._disposed||this._flush(!1)},r.prototype._flush=function(t){var e,n=mi();this._needsRefresh&&(e=!0,this.refreshImmediately(t)),this._needsRefreshHover&&(e=!0,this.refreshHoverImmediately());var i=mi();e?(this._stillFrameAccum=0,this.trigger("rendered",{elapsedTime:i-n})):this._sleepAfterStill>0&&(this._stillFrameAccum++,this._stillFrameAccum>this._sleepAfterStill&&this.animation.stop())},r.prototype.setSleepAfterStill=function(t){this._sleepAfterStill=t},r.prototype.wakeUp=function(){this._disposed||(this.animation.start(),this._stillFrameAccum=0)},r.prototype.refreshHover=function(){this._needsRefreshHover=!0},r.prototype.refreshHoverImmediately=function(){this._disposed||(this._needsRefreshHover=!1,this.painter.refreshHover&&this.painter.getType()==="canvas"&&this.painter.refreshHover())},r.prototype.resize=function(t){this._disposed||(t=t||{},this.painter.resize(t.width,t.height),this.handler.resize())},r.prototype.clearAnimation=function(){this._disposed||this.animation.clear()},r.prototype.getWidth=function(){if(!this._disposed)return this.painter.getWidth()},r.prototype.getHeight=function(){if(!this._disposed)return this.painter.getHeight()},r.prototype.setCursorStyle=function(t){this._disposed||this.handler.setCursorStyle(t)},r.prototype.findHover=function(t,e){if(!this._disposed)return this.handler.findHover(t,e)},r.prototype.on=function(t,e,n){return this._disposed||this.handler.on(t,e,n),this},r.prototype.off=function(t,e){this._disposed||this.handler.off(t,e)},r.prototype.trigger=function(t,e){this._disposed||this.handler.trigger(t,e)},r.prototype.clear=function(){if(!this._disposed){for(var t=this.storage.getRoots(),e=0;e<t.length;e++)t[e]instanceof Ft&&t[e].removeSelfFromZr(this);this.storage.delAllRoots(),this.painter.clear()}},r.prototype.dispose=function(){this._disposed||(this.animation.stop(),this.clear(),this.storage.dispose(),this.painter.dispose(),this.handler.dispose(),this.animation=this.storage=this.painter=this.handler=null,this._disposed=!0,jC(this.id))},r})();function Yd(r,t){var e=new tD(qg(),r,t);return R0[e.id]=e,e}function eD(r,t){ls[r]=t}var E0="";typeof navigator<"u"&&(E0=navigator.platform||"");var ti="rgba(0, 0, 0, 0.2)",k0=Y.color.theme[0],rD=ff(k0,null,null,.9);const nD={darkMode:"auto",colorBy:"series",color:Y.color.theme,gradientColor:[rD,k0],aria:{decal:{decals:[{color:ti,dashArrayX:[1,0],dashArrayY:[2,5],symbolSize:1,rotation:Math.PI/6},{color:ti,symbol:"circle",dashArrayX:[[8,8],[0,8,8,0]],dashArrayY:[6,0],symbolSize:.8},{color:ti,dashArrayX:[1,0],dashArrayY:[4,3],rotation:-Math.PI/4},{color:ti,dashArrayX:[[6,6],[0,6,6,0]],dashArrayY:[6,0]},{color:ti,dashArrayX:[[1,0],[1,6]],dashArrayY:[1,0,6,0],rotation:Math.PI/4},{color:ti,symbol:"triangle",dashArrayX:[[9,9],[0,9,9,0]],dashArrayY:[7,2],symbolSize:.75}]}},textStyle:{fontFamily:E0.match(/^Win/)?"Microsoft YaHei":"sans-serif",fontSize:12,fontStyle:"normal",fontWeight:"normal"},blendMode:null,stateAnimation:{duration:300,easing:"cubicOut"},animation:"auto",animationDuration:1e3,animationDurationUpdate:500,animationEasing:"cubicInOut",animationEasingUpdate:"cubicInOut",animationThreshold:2e3,progressiveThreshold:3e3,progressive:400,hoverLayerThreshold:3e3,useUTC:!1};var iD=K();function aD(r,t,e){var n=iD.get(t);if(!n)return e;var i=n(r);return i?e.concat(i):e}var Ro,ji,Zd,Xd="\0_ec_inner",oD=1,vv=(function(r){z(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.init=function(e,n,i,a,o,s){a=a||{},this.option=null,this._theme=new xt(a),this._locale=new xt(o),this._optionManager=s},t.prototype.setOption=function(e,n,i){var a=Kd(n);this._optionManager.setOption(e,i,a),this._resetOption(null,a)},t.prototype.resetOption=function(e,n){return this._resetOption(e,Kd(n))},t.prototype._resetOption=function(e,n){var i=!1,a=this._optionManager;if(!e||e==="recreate"){var o=a.mountOption(e==="recreate");!this.option||e==="recreate"?Zd(this,o):(this.restoreData(),this._mergeOption(o,n)),i=!0}if((e==="timeline"||e==="media")&&this.restoreData(),!e||e==="recreate"||e==="timeline"){var s=a.getTimelineOption(this);s&&(i=!0,this._mergeOption(s,n))}if(!e||e==="recreate"||e==="media"){var l=a.getMediaOption(this);l.length&&D(l,function(u){i=!0,this._mergeOption(u,n)},this)}return i},t.prototype.mergeOption=function(e){this._mergeOption(e,null)},t.prototype._mergeOption=function(e,n){var i=this.option,a=this._componentsMap,o=this._componentsCount,s=[],l=K(),u=n&&n.replaceMergeMainTypeMap;hx(this),D(e,function(h,c){h!=null&&(dt.hasClass(c)?c&&(s.push(c),l.set(c,!0)):i[c]=i[c]==null?st(h):vt(i[c],h,!0))}),u&&u.each(function(h,c){dt.hasClass(c)&&!l.get(c)&&(s.push(c),l.set(c,!0))}),dt.topologicalTravel(s,dt.getAllClassMainTypes(),f,this);function f(h){var c=aD(this,h,Ct(e[h])),v=a.get(h),d=v?u&&u.get(h)?"replaceMerge":"normalMerge":"replaceAll",p=Ib(v,c,d);Nb(p,h,dt),i[h]=null,a.set(h,null),o.set(h,0);var g=[],m=[],y=0,_;D(p,function(S,w){var b=S.existing,T=S.newOption;if(!T)b&&(b.mergeOption({},this),b.optionUpdated({},!1));else{var C=h==="series",x=dt.getClass(h,S.keyInfo.subType,!C);if(!x)return;if(h==="tooltip"){if(_)return;_=!0}if(b&&b.constructor===x)b.name=S.keyInfo.name,b.mergeOption(T,this),b.optionUpdated(T,!1);else{var M=O({componentIndex:w},S.keyInfo);b=new x(T,this,this,M),O(b,M),S.brandNew&&(b.__requireNewView=!0),b.init(T,this,this),b.optionUpdated(null,!0)}}b?(g.push(b.option),m.push(b),y++):(g.push(void 0),m.push(void 0))},this),i[h]=g,a.set(h,m),o.set(h,y),h==="series"&&Ro(this)}this._seriesIndices||Ro(this)},t.prototype.getOption=function(){var e=st(this.option);return D(e,function(n,i){if(dt.hasClass(i)){for(var a=Ct(n),o=a.length,s=!1,l=o-1;l>=0;l--)a[l]&&!Oa(a[l])?s=!0:(a[l]=null,!s&&o--);a.length=o,e[i]=a}}),delete e[Xd],e},t.prototype.setTheme=function(e){this._theme=new xt(e),this._resetOption("recreate",null)},t.prototype.getTheme=function(){return this._theme},t.prototype.getLocaleModel=function(){return this._locale},t.prototype.setUpdatePayload=function(e){this._payload=e},t.prototype.getUpdatePayload=function(){return this._payload},t.prototype.getComponent=function(e,n){var i=this._componentsMap.get(e);if(i){var a=i[n||0];if(a)return a;if(n==null){for(var o=0;o<i.length;o++)if(i[o])return i[o]}}},t.prototype.queryComponents=function(e){var n=e.mainType;if(!n)return[];var i=e.index,a=e.id,o=e.name,s=this._componentsMap.get(n);if(!s||!s.length)return[];var l;return i!=null?(l=[],D(Ct(i),function(u){s[u]&&l.push(s[u])})):a!=null?l=$d("id",a,s):o!=null?l=$d("name",o,s):l=wt(s,function(u){return!!u}),qd(l,e)},t.prototype.findComponents=function(e){var n=e.query,i=e.mainType,a=s(n),o=a?this.queryComponents(a):wt(this._componentsMap.get(i),function(u){return!!u});return l(qd(o,e));function s(u){var f=i+"Index",h=i+"Id",c=i+"Name";return u&&(u[f]!=null||u[h]!=null||u[c]!=null)?{mainType:i,index:u[f],id:u[h],name:u[c]}:null}function l(u){return e.filter?wt(u,e.filter):u}},t.prototype.eachComponent=function(e,n,i){var a=this._componentsMap;if(et(e)){var o=n,s=e;a.each(function(h,c){for(var v=0;h&&v<h.length;v++){var d=h[v];d&&s.call(o,c,d,d.componentIndex)}})}else for(var l=W(e)?a.get(e):X(e)?this.findComponents(e):null,u=0;l&&u<l.length;u++){var f=l[u];f&&n.call(i,f,f.componentIndex)}},t.prototype.getSeriesByName=function(e){var n=$e(e,null);return wt(this._componentsMap.get("series"),function(i){return!!i&&n!=null&&i.name===n})},t.prototype.getSeriesByIndex=function(e){return this._componentsMap.get("series")[e]},t.prototype.getSeriesByType=function(e){return wt(this._componentsMap.get("series"),function(n){return!!n&&n.subType===e})},t.prototype.getSeries=function(){return wt(this._componentsMap.get("series"),function(e){return!!e})},t.prototype.getSeriesCount=function(){return this._componentsCount.get("series")},t.prototype.eachSeries=function(e,n){ji(this),D(this._seriesIndices,function(i){var a=this._componentsMap.get("series")[i];e.call(n,a,i)},this)},t.prototype.eachRawSeries=function(e,n){D(this._componentsMap.get("series"),function(i){i&&e.call(n,i,i.componentIndex)})},t.prototype.eachSeriesByType=function(e,n,i){ji(this),D(this._seriesIndices,function(a){var o=this._componentsMap.get("series")[a];o.subType===e&&n.call(i,o,a)},this)},t.prototype.eachRawSeriesByType=function(e,n,i){return D(this.getSeriesByType(e),n,i)},t.prototype.isSeriesFiltered=function(e){return ji(this),this._seriesIndicesMap.get(e.componentIndex)==null},t.prototype.getCurrentSeriesIndices=function(){return(this._seriesIndices||[]).slice()},t.prototype.filterSeries=function(e,n){ji(this);var i=[];D(this._seriesIndices,function(a){var o=this._componentsMap.get("series")[a];e.call(n,o,a)&&i.push(a)},this),this._seriesIndices=i,this._seriesIndicesMap=K(i)},t.prototype.restoreData=function(e){Ro(this);var n=this._componentsMap,i=[];n.each(function(a,o){dt.hasClass(o)&&i.push(o)}),dt.topologicalTravel(i,dt.getAllClassMainTypes(),function(a){D(n.get(a),function(o){o&&(a!=="series"||!sD(o,e))&&o.restoreData()})})},t.internalField=(function(){Ro=function(e){var n=e._seriesIndices=[];D(e._componentsMap.get("series"),function(i){i&&n.push(i.componentIndex)}),e._seriesIndicesMap=K(n)},ji=function(e){},Zd=function(e,n){e.option={},e.option[Xd]=oD,e._componentsMap=K({series:[]}),e._componentsCount=K();var i=n.aria;X(i)&&i.enabled==null&&(i.enabled=!0),lD(n,e._theme.option),vt(n,nD,!1),e._mergeOption(n,null)}})(),t})(xt);function sD(r,t){if(t){var e=t.seriesIndex,n=t.seriesId,i=t.seriesName;return e!=null&&r.componentIndex!==e||n!=null&&r.id!==n||i!=null&&r.name!==i}}function lD(r,t){var e=r.color&&!r.colorLayer;D(t,function(n,i){i==="colorLayer"&&e||i==="color"&&r.color||dt.hasClass(i)||(typeof n=="object"?r[i]=r[i]?vt(r[i],n,!1):st(n):r[i]==null&&(r[i]=n))})}function $d(r,t,e){if(H(t)){var n=K();return D(t,function(a){if(a!=null){var o=$e(a,null);o!=null&&n.set(a,!0)}}),wt(e,function(a){return a&&n.get(a[r])})}else{var i=$e(t,null);return wt(e,function(a){return a&&i!=null&&a[r]===i})}}function qd(r,t){return t.hasOwnProperty("subType")?wt(r,function(e){return e&&e.subType===t.subType}):r}function Kd(r){var t=K();return r&&D(Ct(r.replaceMerge),function(e){t.set(e,!0)}),{replaceMergeMainTypeMap:t}}Qe(vv,sv);var uD=["getDom","getZr","getWidth","getHeight","getDevicePixelRatio","dispatchAction","isSSR","isDisposed","on","off","getDataURL","getConnectedDataURL","getOption","getId","updateLabelLayout"],O0=(function(){function r(t){D(uD,function(e){this[e]=Q(t[e],t)},this)}return r})(),fD=/^(min|max)?(.+)$/,hD=(function(){function r(t){this._timelineOptions=[],this._mediaList=[],this._currentMediaIndices=[],this._api=t}return r.prototype.setOption=function(t,e,n){t&&(D(Ct(t.series),function(o){o&&o.data&&ae(o.data)&&cs(o.data)}),D(Ct(t.dataset),function(o){o&&o.source&&ae(o.source)&&cs(o.source)})),t=st(t);var i=this._optionBackup,a=vD(t,e,!i);this._newBaseOption=a.baseOption,i?(a.timelineOptions.length&&(i.timelineOptions=a.timelineOptions),a.mediaList.length&&(i.mediaList=a.mediaList),a.mediaDefault&&(i.mediaDefault=a.mediaDefault)):this._optionBackup=a},r.prototype.mountOption=function(t){var e=this._optionBackup;return this._timelineOptions=e.timelineOptions,this._mediaList=e.mediaList,this._mediaDefault=e.mediaDefault,this._currentMediaIndices=[],st(t?e.baseOption:this._newBaseOption)},r.prototype.getTimelineOption=function(t){var e,n=this._timelineOptions;if(n.length){var i=t.getComponent("timeline");i&&(e=st(n[i.getCurrentIndex()]))}return e},r.prototype.getMediaOption=function(t){var e=this._api.getWidth(),n=this._api.getHeight(),i=this._mediaList,a=this._mediaDefault,o=[],s=[];if(!i.length&&!a)return s;for(var l=0,u=i.length;l<u;l++)cD(i[l].query,e,n)&&o.push(l);return!o.length&&a&&(o=[-1]),o.length&&!pD(o,this._currentMediaIndices)&&(s=$(o,function(f){return st(f===-1?a.option:i[f].option)})),this._currentMediaIndices=o,s},r})();function vD(r,t,e){var n=[],i,a,o=r.baseOption,s=r.timeline,l=r.options,u=r.media,f=!!r.media,h=!!(l||s||o&&o.timeline);o?(a=o,a.timeline||(a.timeline=s)):((h||f)&&(r.options=r.media=null),a=r),f&&H(u)&&D(u,function(v){v&&v.option&&(v.query?n.push(v):i||(i=v))}),c(a),D(l,function(v){return c(v)}),D(n,function(v){return c(v.option)});function c(v){D(t,function(d){d(v,e)})}return{baseOption:a,timelineOptions:l||[],mediaDefault:i,mediaList:n}}function cD(r,t,e){var n={width:t,height:e,aspectratio:t/e},i=!0;return D(r,function(a,o){var s=o.match(fD);if(!(!s||!s[1]||!s[2])){var l=s[1],u=s[2].toLowerCase();dD(n[u],a,l)||(i=!1)}}),i}function dD(r,t,e){return e==="min"?r>=t:e==="max"?r<=t:r===t}function pD(r,t){return r.join(",")===t.join(",")}var De=D,Wa=X,Qd=["areaStyle","lineStyle","nodeStyle","linkStyle","chordStyle","label","labelLine"];function xu(r){var t=r&&r.itemStyle;if(t)for(var e=0,n=Qd.length;e<n;e++){var i=Qd[e],a=t.normal,o=t.emphasis;a&&a[i]&&(r[i]=r[i]||{},r[i].normal?vt(r[i].normal,a[i]):r[i].normal=a[i],a[i]=null),o&&o[i]&&(r[i]=r[i]||{},r[i].emphasis?vt(r[i].emphasis,o[i]):r[i].emphasis=o[i],o[i]=null)}}function Yt(r,t,e){if(r&&r[t]&&(r[t].normal||r[t].emphasis)){var n=r[t].normal,i=r[t].emphasis;n&&(e?(r[t].normal=r[t].emphasis=null,at(r[t],n)):r[t]=n),i&&(r.emphasis=r.emphasis||{},r.emphasis[t]=i,i.focus&&(r.emphasis.focus=i.focus),i.blurScope&&(r.emphasis.blurScope=i.blurScope))}}function da(r){Yt(r,"itemStyle"),Yt(r,"lineStyle"),Yt(r,"areaStyle"),Yt(r,"label"),Yt(r,"labelLine"),Yt(r,"upperLabel"),Yt(r,"edgeLabel")}function Mt(r,t){var e=Wa(r)&&r[t],n=Wa(e)&&e.textStyle;if(n)for(var i=0,a=bc.length;i<a;i++){var o=bc[i];n.hasOwnProperty(o)&&(e[o]=n[o])}}function _e(r){r&&(da(r),Mt(r,"label"),r.emphasis&&Mt(r.emphasis,"label"))}function gD(r){if(Wa(r)){xu(r),da(r),Mt(r,"label"),Mt(r,"upperLabel"),Mt(r,"edgeLabel"),r.emphasis&&(Mt(r.emphasis,"label"),Mt(r.emphasis,"upperLabel"),Mt(r.emphasis,"edgeLabel"));var t=r.markPoint;t&&(xu(t),_e(t));var e=r.markLine;e&&(xu(e),_e(e));var n=r.markArea;n&&_e(n);var i=r.data;if(r.type==="graph"){i=i||r.nodes;var a=r.links||r.edges;if(a&&!ae(a))for(var o=0;o<a.length;o++)_e(a[o]);D(r.categories,function(u){da(u)})}if(i&&!ae(i))for(var o=0;o<i.length;o++)_e(i[o]);if(t=r.markPoint,t&&t.data)for(var s=t.data,o=0;o<s.length;o++)_e(s[o]);if(e=r.markLine,e&&e.data)for(var l=e.data,o=0;o<l.length;o++)H(l[o])?(_e(l[o][0]),_e(l[o][1])):_e(l[o]);r.type==="gauge"?(Mt(r,"axisLabel"),Mt(r,"title"),Mt(r,"detail")):r.type==="treemap"?(Yt(r.breadcrumb,"itemStyle"),D(r.levels,function(u){da(u)})):r.type==="tree"&&da(r.leaves)}}function tr(r){return H(r)?r:r?[r]:[]}function jd(r){return(H(r)?r[0]:r)||{}}function mD(r,t){De(tr(r.series),function(n){Wa(n)&&gD(n)});var e=["xAxis","yAxis","radiusAxis","angleAxis","singleAxis","parallelAxis","radar"];t&&e.push("valueAxis","categoryAxis","logAxis","timeAxis"),De(e,function(n){De(tr(r[n]),function(i){i&&(Mt(i,"axisLabel"),Mt(i.axisPointer,"label"))})}),De(tr(r.parallel),function(n){var i=n&&n.parallelAxisDefault;Mt(i,"axisLabel"),Mt(i&&i.axisPointer,"label")}),De(tr(r.calendar),function(n){Yt(n,"itemStyle"),Mt(n,"dayLabel"),Mt(n,"monthLabel"),Mt(n,"yearLabel")}),De(tr(r.radar),function(n){Mt(n,"name"),n.name&&n.axisName==null&&(n.axisName=n.name,delete n.name),n.nameGap!=null&&n.axisNameGap==null&&(n.axisNameGap=n.nameGap,delete n.nameGap)}),De(tr(r.geo),function(n){Wa(n)&&(_e(n),De(tr(n.regions),function(i){_e(i)}))}),De(tr(r.timeline),function(n){_e(n),Yt(n,"label"),Yt(n,"itemStyle"),Yt(n,"controlStyle",!0);var i=n.data;H(i)&&D(i,function(a){X(a)&&(Yt(a,"label"),Yt(a,"itemStyle"))})}),De(tr(r.toolbox),function(n){Yt(n,"iconStyle"),De(n.feature,function(i){Yt(i,"iconStyle")})}),Mt(jd(r.axisPointer),"label"),Mt(jd(r.tooltip).axisPointer,"label")}function yD(r,t){for(var e=t.split(","),n=r,i=0;i<e.length&&(n=n&&n[e[i]],n!=null);i++);return n}function _D(r,t,e,n){for(var i=t.split(","),a=r,o,s=0;s<i.length-1;s++)o=i[s],a[o]==null&&(a[o]={}),a=a[o];a[i[s]]==null&&(a[i[s]]=e)}function Jd(r){r&&D(SD,function(t){t[0]in r&&!(t[1]in r)&&(r[t[1]]=r[t[0]])})}var SD=[["x","left"],["y","top"],["x2","right"],["y2","bottom"]],bD=["grid","geo","parallel","legend","toolbox","title","visualMap","dataZoom","timeline"],Tu=[["borderRadius","barBorderRadius"],["borderColor","barBorderColor"],["borderWidth","barBorderWidth"]];function Ji(r){var t=r&&r.itemStyle;if(t)for(var e=0;e<Tu.length;e++){var n=Tu[e][1],i=Tu[e][0];t[n]!=null&&(t[i]=t[n])}}function tp(r){r&&r.alignTo==="edge"&&r.margin!=null&&r.edgeDistance==null&&(r.edgeDistance=r.margin)}function ep(r){r&&r.downplay&&!r.blur&&(r.blur=r.downplay)}function wD(r){r&&r.focusNodeAdjacency!=null&&(r.emphasis=r.emphasis||{},r.emphasis.focus==null&&(r.emphasis.focus="adjacency"))}function B0(r,t){if(r)for(var e=0;e<r.length;e++)t(r[e]),r[e]&&B0(r[e].children,t)}function N0(r,t){mD(r,t),r.series=Ct(r.series),D(r.series,function(e){if(X(e)){var n=e.type;if(n==="line")e.clipOverflow!=null&&(e.clip=e.clipOverflow);else if(n==="pie"||n==="gauge"){e.clockWise!=null&&(e.clockwise=e.clockWise),tp(e.label);var i=e.data;if(i&&!ae(i))for(var a=0;a<i.length;a++)tp(i[a]);e.hoverOffset!=null&&(e.emphasis=e.emphasis||{},(e.emphasis.scaleSize=null)&&(e.emphasis.scaleSize=e.hoverOffset))}else if(n==="gauge"){var o=yD(e,"pointer.color");o!=null&&_D(e,"itemStyle.color",o)}else if(n==="bar"){Ji(e),Ji(e.backgroundStyle),Ji(e.emphasis);var i=e.data;if(i&&!ae(i))for(var a=0;a<i.length;a++)typeof i[a]=="object"&&(Ji(i[a]),Ji(i[a]&&i[a].emphasis))}else if(n==="sunburst"){var s=e.highlightPolicy;s&&(e.emphasis=e.emphasis||{},e.emphasis.focus||(e.emphasis.focus=s)),ep(e),B0(e.data,ep)}else n==="graph"||n==="sankey"?wD(e):n==="map"&&(e.mapType&&!e.map&&(e.map=e.mapType),e.mapLocation&&at(e,e.mapLocation));e.hoverAnimation!=null&&(e.emphasis=e.emphasis||{},e.emphasis&&e.emphasis.scale==null&&(e.emphasis.scale=e.hoverAnimation)),Jd(e)}}),r.dataRange&&(r.visualMap=r.dataRange),D(bD,function(e){var n=r[e];n&&(H(n)||(n=[n]),D(n,function(i){Jd(i)}))})}function xD(r){var t=K();r.eachSeries(function(e){var n=e.get("stack");if(n){var i=t.get(n)||t.set(n,[]),a=e.getData(),o={stackResultDimension:a.getCalculationInfo("stackResultDimension"),stackedOverDimension:a.getCalculationInfo("stackedOverDimension"),stackedDimension:a.getCalculationInfo("stackedDimension"),stackedByDimension:a.getCalculationInfo("stackedByDimension"),isStackedByIndex:a.getCalculationInfo("isStackedByIndex"),data:a,seriesModel:e};if(!o.stackedDimension||!(o.isStackedByIndex||o.stackedByDimension))return;i.push(o)}}),t.each(function(e){if(e.length!==0){var n=e[0].seriesModel,i=n.get("stackOrder")||"seriesAsc";i==="seriesDesc"&&e.reverse(),D(e,function(a,o){a.data.setCalculationInfo("stackedOnSeries",o>0?e[o-1].seriesModel:null)}),TD(e)}})}function TD(r){D(r,function(t,e){var n=[],i=[NaN,NaN],a=[t.stackResultDimension,t.stackedOverDimension],o=t.data,s=t.isStackedByIndex,l=t.seriesModel.get("stackStrategy")||"samesign";o.modify(a,function(u,f,h){var c=o.get(t.stackedDimension,h);if(isNaN(c))return i;var v,d;s?d=o.getRawIndex(h):v=o.get(t.stackedByDimension,h);for(var p=NaN,g=e-1;g>=0;g--){var m=r[g];if(s||(d=m.data.rawIndexOf(m.stackedByDimension,v)),d>=0){var y=m.data.getByRawIndex(m.stackResultDimension,d);if(l==="all"||l==="positive"&&y>0||l==="negative"&&y<0||l==="samesign"&&c>=0&&y>0||l==="samesign"&&c<=0&&y<0){c=bb(c,y),p=y;break}}}return n[0]=c,n[1]=p,n})})}var Me=(function(){function r(){this.group=new Ft,this.uid=ml("viewComponent")}return r.prototype.init=function(t,e){},r.prototype.render=function(t,e,n,i){},r.prototype.dispose=function(t,e){},r.prototype.updateView=function(t,e,n,i){},r.prototype.updateLayout=function(t,e,n,i){},r.prototype.updateVisual=function(t,e,n,i){},r.prototype.toggleBlurSeries=function(t,e,n){},r.prototype.eachRendered=function(t){var e=this.group;e&&e.traverse(t)},r})();xh(Me);el(Me);var rp=gt(),np={itemStyle:Ra(Sy,!0),lineStyle:Ra(_y,!0)},MD={lineStyle:"stroke",itemStyle:"fill"};function F0(r,t){var e=r.visualStyleMapper||np[t];return e||(console.warn("Unknown style type '"+t+"'."),np.itemStyle)}function z0(r,t){var e=r.visualDrawType||MD[t];return e||(console.warn("Unknown style type '"+t+"'."),"fill")}var CD={createOnAllSeries:!0,performRawSeries:!0,reset:function(r,t){var e=r.getData(),n=r.visualStyleAccessPath||"itemStyle",i=r.getModel(n),a=F0(r,n),o=a(i),s=i.getShallow("decal");s&&(e.setVisual("decal",s),s.dirty=!0);var l=z0(r,n),u=o[l],f=et(u)?u:null,h=o.fill==="auto"||o.stroke==="auto";if(!o[l]||f||h){var c=r.getColorFromPalette(r.name,null,t.getSeriesCount());o[l]||(o[l]=c,e.setVisual("colorFromPalette",!0)),o.fill=o.fill==="auto"||et(o.fill)?c:o.fill,o.stroke=o.stroke==="auto"||et(o.stroke)?c:o.stroke}if(e.setVisual("style",o),e.setVisual("drawType",l),!t.isSeriesFiltered(r)&&f)return e.setVisual("colorFromPalette",!1),{dataEach:function(v,d){var p=r.getDataParams(d),g=O({},o);g[l]=f(p),v.setItemVisual(d,"style",g)}}}},ta=new xt,DD={createOnAllSeries:!0,performRawSeries:!0,reset:function(r,t){if(!(r.ignoreStyleOnData||t.isSeriesFiltered(r))){var e=r.getData(),n=r.visualStyleAccessPath||"itemStyle",i=F0(r,n),a=e.getVisual("drawType");return{dataEach:e.hasItemOption?function(o,s){var l=o.getRawDataItem(s);if(l&&l[n]){ta.option=l[n];var u=i(ta),f=o.ensureUniqueItemVisual(s,"style");O(f,u),ta.option.decal&&(o.setItemVisual(s,"decal",ta.option.decal),ta.option.decal.dirty=!0),a in u&&o.setItemVisual(s,"colorFromPalette",!1)}}:null}}}},AD={performRawSeries:!0,overallReset:function(r){var t=K();r.eachSeries(function(e){var n=e.getColorBy();if(!e.isColorBySeries()){var i=e.type+"-"+n,a=t.get(i);a||(a={},t.set(i,a)),rp(e).scope=a}}),r.eachSeries(function(e){if(!(e.isColorBySeries()||r.isSeriesFiltered(e))){var n=e.getRawData(),i={},a=e.getData(),o=rp(e).scope,s=e.visualStyleAccessPath||"itemStyle",l=z0(e,s);a.each(function(u){var f=a.getRawIndex(u);i[f]=u}),n.each(function(u){var f=i[u],h=a.getItemVisual(f,"colorFromPalette");if(h){var c=a.ensureUniqueItemVisual(f,"style"),v=n.getName(u)||u+"",d=n.count();c[l]=e.getColorFromPalette(v,o,d)}})}})}},Eo=Math.PI;function LD(r,t){t=t||{},at(t,{text:"loading",textColor:Y.color.primary,fontSize:12,fontWeight:"normal",fontStyle:"normal",fontFamily:"sans-serif",maskColor:"rgba(255,255,255,0.8)",showSpinner:!0,color:Y.color.theme[0],spinnerRadius:10,lineWidth:5,zlevel:0});var e=new Ft,n=new Tt({style:{fill:t.maskColor},zlevel:t.zlevel,z:1e4});e.add(n);var i=new oe({style:{text:t.text,fill:t.textColor,fontSize:t.fontSize,fontWeight:t.fontWeight,fontStyle:t.fontStyle,fontFamily:t.fontFamily},zlevel:t.zlevel,z:10001}),a=new Tt({style:{fill:"none"},textContent:i,textConfig:{position:"right",distance:10},zlevel:t.zlevel,z:10001});e.add(a);var o;return t.showSpinner&&(o=new hl({shape:{startAngle:-Eo/2,endAngle:-Eo/2+.1,r:t.spinnerRadius},style:{stroke:t.color,lineCap:"round",lineWidth:t.lineWidth},zlevel:t.zlevel,z:10001}),o.animateShape(!0).when(1e3,{endAngle:Eo*3/2}).start("circularInOut"),o.animateShape(!0).when(1e3,{startAngle:Eo*3/2}).delay(300).start("circularInOut"),e.add(o)),e.resize=function(){var s=i.getBoundingRect().width,l=t.showSpinner?t.spinnerRadius:0,u=(r.getWidth()-l*2-(t.showSpinner&&s?10:0)-s)/2-(t.showSpinner&&s?0:5+s/2)+(t.showSpinner?0:s/2)+(s?0:l),f=r.getHeight()/2;t.showSpinner&&o.setShape({cx:u,cy:f}),a.setShape({x:u-l,y:f-l,width:l*2,height:l*2}),n.setShape({x:0,y:0,width:r.getWidth(),height:r.getHeight()})},e.resize(),e}var H0=(function(){function r(t,e,n,i){this._stageTaskMap=K(),this.ecInstance=t,this.api=e,n=this._dataProcessorHandlers=n.slice(),i=this._visualHandlers=i.slice(),this._allHandlers=n.concat(i)}return r.prototype.restoreData=function(t,e){t.restoreData(e),this._stageTaskMap.each(function(n){var i=n.overallTask;i&&i.dirty()})},r.prototype.getPerformArgs=function(t,e){if(t.__pipeline){var n=this._pipelineMap.get(t.__pipeline.id),i=n.context,a=!e&&n.progressiveEnabled&&(!i||i.progressiveRender)&&t.__idxInPipeline>n.blockIndex,o=a?n.step:null,s=i&&i.modDataCount,l=s!=null?Math.ceil(s/o):null;return{step:o,modBy:l,modDataCount:s}}},r.prototype.getPipeline=function(t){return this._pipelineMap.get(t)},r.prototype.updateStreamModes=function(t,e){var n=this._pipelineMap.get(t.uid),i=t.getData(),a=i.count(),o=n.progressiveEnabled&&e.incrementalPrepareRender&&a>=n.threshold,s=t.get("large")&&a>=t.get("largeThreshold"),l=t.get("progressiveChunkMode")==="mod"?a:null;t.pipelineContext=n.context={progressiveRender:o,modDataCount:l,large:s}},r.prototype.restorePipelines=function(t){var e=this,n=e._pipelineMap=K();t.eachSeries(function(i){var a=i.getProgressive(),o=i.uid;n.set(o,{id:o,head:null,tail:null,threshold:i.getProgressiveThreshold(),progressiveEnabled:a&&!(i.preventIncremental&&i.preventIncremental()),blockIndex:-1,step:Math.round(a||700),count:0}),e._pipe(i,i.dataTask)})},r.prototype.prepareStageTasks=function(){var t=this._stageTaskMap,e=this.api.getModel(),n=this.api;D(this._allHandlers,function(i){var a=t.get(i.uid)||t.set(i.uid,{}),o="";hr(!(i.reset&&i.overallReset),o),i.reset&&this._createSeriesStageTask(i,a,e,n),i.overallReset&&this._createOverallStageTask(i,a,e,n)},this)},r.prototype.prepareView=function(t,e,n,i){var a=t.renderTask,o=a.context;o.model=e,o.ecModel=n,o.api=i,a.__block=!t.incrementalPrepareRender,this._pipe(e,a)},r.prototype.performDataProcessorTasks=function(t,e){this._performStageTasks(this._dataProcessorHandlers,t,e,{block:!0})},r.prototype.performVisualTasks=function(t,e,n){this._performStageTasks(this._visualHandlers,t,e,n)},r.prototype._performStageTasks=function(t,e,n,i){i=i||{};var a=!1,o=this;D(t,function(l,u){if(!(i.visualType&&i.visualType!==l.visualType)){var f=o._stageTaskMap.get(l.uid),h=f.seriesTaskMap,c=f.overallTask;if(c){var v,d=c.agentStubMap;d.each(function(g){s(i,g)&&(g.dirty(),v=!0)}),v&&c.dirty(),o.updatePayload(c,n);var p=o.getPerformArgs(c,i.block);d.each(function(g){g.perform(p)}),c.perform(p)&&(a=!0)}else h&&h.each(function(g,m){s(i,g)&&g.dirty();var y=o.getPerformArgs(g,i.block);y.skip=!l.performRawSeries&&e.isSeriesFiltered(g.context.model),o.updatePayload(g,n),g.perform(y)&&(a=!0)})}});function s(l,u){return l.setDirty&&(!l.dirtyMap||l.dirtyMap.get(u.__pipeline.id))}this.unfinished=a||this.unfinished},r.prototype.performSeriesTasks=function(t){var e;t.eachSeries(function(n){e=n.dataTask.perform()||e}),this.unfinished=e||this.unfinished},r.prototype.plan=function(){this._pipelineMap.each(function(t){var e=t.tail;do{if(e.__block){t.blockIndex=e.__idxInPipeline;break}e=e.getUpstream()}while(e)})},r.prototype.updatePayload=function(t,e){e!=="remain"&&(t.context.payload=e)},r.prototype._createSeriesStageTask=function(t,e,n,i){var a=this,o=e.seriesTaskMap,s=e.seriesTaskMap=K(),l=t.seriesType,u=t.getTargetSeries;t.createOnAllSeries?n.eachRawSeries(f):l?n.eachRawSeriesByType(l,f):u&&u(n,i).each(f);function f(h){var c=h.uid,v=s.set(c,o&&o.get(c)||Ca({plan:kD,reset:OD,count:ND}));v.context={model:h,ecModel:n,api:i,useClearVisual:t.isVisual&&!t.isLayout,plan:t.plan,reset:t.reset,scheduler:a},a._pipe(h,v)}},r.prototype._createOverallStageTask=function(t,e,n,i){var a=this,o=e.overallTask=e.overallTask||Ca({reset:ID});o.context={ecModel:n,api:i,overallReset:t.overallReset,scheduler:a};var s=o.agentStubMap,l=o.agentStubMap=K(),u=t.seriesType,f=t.getTargetSeries,h=!0,c=!1,v="";hr(!t.createOnAllSeries,v),u?n.eachRawSeriesByType(u,d):f?f(n,i).each(d):(h=!1,D(n.getSeries(),d));function d(p){var g=p.uid,m=l.set(g,s&&s.get(g)||(c=!0,Ca({reset:PD,onDirty:ED})));m.context={model:p,overallProgress:h},m.agent=o,m.__block=h,a._pipe(p,m)}c&&o.dirty()},r.prototype._pipe=function(t,e){var n=t.uid,i=this._pipelineMap.get(n);!i.head&&(i.head=e),i.tail&&i.tail.pipe(e),i.tail=e,e.__idxInPipeline=i.count++,e.__pipeline=i},r.wrapStageHandler=function(t,e){return et(t)&&(t={overallReset:t,seriesType:FD(t)}),t.uid=ml("stageHandler"),e&&(t.visualType=e),t},r})();function ID(r){r.overallReset(r.ecModel,r.api,r.payload)}function PD(r){return r.overallProgress&&RD}function RD(){this.agent.dirty(),this.getDownstream().dirty()}function ED(){this.agent&&this.agent.dirty()}function kD(r){return r.plan?r.plan(r.model,r.ecModel,r.api,r.payload):null}function OD(r){r.useClearVisual&&r.data.clearAllVisual();var t=r.resetDefines=Ct(r.reset(r.model,r.ecModel,r.api,r.payload));return t.length>1?$(t,function(e,n){return V0(n)}):BD}var BD=V0(0);function V0(r){return function(t,e){var n=e.data,i=e.resetDefines[r];if(i&&i.dataEach)for(var a=t.start;a<t.end;a++)i.dataEach(n,a);else i&&i.progress&&i.progress(t,n)}}function ND(r){return r.data.count()}function FD(r){Fs=null;try{r(Ua,G0)}catch{}return Fs}var Ua={},G0={},Fs;W0(Ua,vv);W0(G0,O0);Ua.eachSeriesByType=Ua.eachRawSeriesByType=function(r){Fs=r};Ua.eachComponent=function(r){r.mainType==="series"&&r.subType&&(Fs=r.subType)};function W0(r,t){for(var e in t.prototype)r[e]=Kt}var F=Y.darkColor,zD=F.background,ea=function(){return{axisLine:{lineStyle:{color:F.axisLine}},splitLine:{lineStyle:{color:F.axisSplitLine}},splitArea:{areaStyle:{color:[F.backgroundTint,F.backgroundTransparent]}},minorSplitLine:{lineStyle:{color:F.axisMinorSplitLine}},axisLabel:{color:F.axisLabel},axisName:{}}},ip={label:{color:F.secondary},itemStyle:{borderColor:F.borderTint},dividerLineStyle:{color:F.border}},U0={darkMode:!0,color:F.theme,backgroundColor:zD,axisPointer:{lineStyle:{color:F.border},crossStyle:{color:F.borderShade},label:{color:F.tertiary}},legend:{textStyle:{color:F.secondary},pageTextStyle:{color:F.tertiary}},textStyle:{color:F.secondary},title:{textStyle:{color:F.primary},subtextStyle:{color:F.quaternary}},toolbox:{iconStyle:{borderColor:F.accent50}},tooltip:{backgroundColor:F.neutral20,defaultBorderColor:F.border,textStyle:{color:F.tertiary}},dataZoom:{borderColor:F.accent10,textStyle:{color:F.tertiary},brushStyle:{color:F.backgroundTint},handleStyle:{color:F.neutral00,borderColor:F.accent20},moveHandleStyle:{color:F.accent40},emphasis:{handleStyle:{borderColor:F.accent50}},dataBackground:{lineStyle:{color:F.accent30},areaStyle:{color:F.accent20}},selectedDataBackground:{lineStyle:{color:F.accent50},areaStyle:{color:F.accent30}}},visualMap:{textStyle:{color:F.secondary},handleStyle:{borderColor:F.neutral30}},timeline:{lineStyle:{color:F.accent10},label:{color:F.tertiary},controlStyle:{color:F.accent30,borderColor:F.accent30}},calendar:{itemStyle:{color:F.neutral00,borderColor:F.neutral20},dayLabel:{color:F.tertiary},monthLabel:{color:F.secondary},yearLabel:{color:F.secondary}},matrix:{x:ip,y:ip,backgroundColor:{borderColor:F.axisLine},body:{itemStyle:{borderColor:F.borderTint}}},timeAxis:ea(),logAxis:ea(),valueAxis:ea(),categoryAxis:ea(),line:{symbol:"circle"},graph:{color:F.theme},gauge:{title:{color:F.secondary},axisLine:{lineStyle:{color:[[1,F.neutral05]]}},axisLabel:{color:F.axisLabel},detail:{color:F.primary}},candlestick:{itemStyle:{color:"#f64e56",color0:"#54ea92",borderColor:"#f64e56",borderColor0:"#54ea92"}},funnel:{itemStyle:{borderColor:F.background}},radar:(function(){var r=ea();return r.axisName={color:F.axisLabel},r.axisLine.lineStyle.color=F.neutral20,r})(),treemap:{breadcrumb:{itemStyle:{color:F.neutral20,textStyle:{color:F.secondary}},emphasis:{itemStyle:{color:F.neutral30}}}},sunburst:{itemStyle:{borderColor:F.background}},map:{itemStyle:{borderColor:F.border,areaColor:F.neutral10},label:{color:F.tertiary},emphasis:{label:{color:F.primary},itemStyle:{areaColor:F.highlight}},select:{label:{color:F.primary},itemStyle:{areaColor:F.highlight}}},geo:{itemStyle:{borderColor:F.border,areaColor:F.neutral10},emphasis:{label:{color:F.primary},itemStyle:{areaColor:F.highlight}},select:{label:{color:F.primary},itemStyle:{color:F.highlight}}}};U0.categoryAxis.splitLine.show=!1;var HD=(function(){function r(){}return r.prototype.normalizeQuery=function(t){var e={},n={},i={};if(W(t)){var a=Ue(t);e.mainType=a.main||null,e.subType=a.sub||null}else{var o=["Index","Name","Id"],s={name:1,dataIndex:1,dataType:1};D(t,function(l,u){for(var f=!1,h=0;h<o.length;h++){var c=o[h],v=u.lastIndexOf(c);if(v>0&&v===u.length-c.length){var d=u.slice(0,v);d!=="data"&&(e.mainType=d,e[c.toLowerCase()]=l,f=!0)}}s.hasOwnProperty(u)&&(n[u]=l,f=!0),f||(i[u]=l)})}return{cptQuery:e,dataQuery:n,otherQuery:i}},r.prototype.filter=function(t,e){var n=this.eventInfo;if(!n)return!0;var i=n.targetEl,a=n.packedEvent,o=n.model,s=n.view;if(!o||!s)return!0;var l=e.cptQuery,u=e.dataQuery;return f(l,o,"mainType")&&f(l,o,"subType")&&f(l,o,"index","componentIndex")&&f(l,o,"name")&&f(l,o,"id")&&f(u,a,"name")&&f(u,a,"dataIndex")&&f(u,a,"dataType")&&(!s.filterForExposedEvent||s.filterForExposedEvent(t,e.otherQuery,i,a));function f(h,c,v,d){return h[v]==null||c[d||v]===h[v]}},r.prototype.afterTrigger=function(){this.eventInfo=null},r})(),Zf=["symbol","symbolSize","symbolRotate","symbolOffset"],ap=Zf.concat(["symbolKeepAspect"]),VD={createOnAllSeries:!0,performRawSeries:!0,reset:function(r,t){var e=r.getData();if(r.legendIcon&&e.setVisual("legendIcon",r.legendIcon),!r.hasSymbolVisual)return;for(var n={},i={},a=!1,o=0;o<Zf.length;o++){var s=Zf[o],l=r.get(s);et(l)?(a=!0,i[s]=l):n[s]=l}if(n.symbol=n.symbol||r.defaultSymbol,e.setVisual(O({legendIcon:r.legendIcon||n.symbol,symbolKeepAspect:r.get("symbolKeepAspect")},n)),t.isSeriesFiltered(r))return;var u=St(i);function f(h,c){for(var v=r.getRawValue(c),d=r.getDataParams(c),p=0;p<u.length;p++){var g=u[p];h.setItemVisual(c,g,i[g](v,d))}}return{dataEach:a?f:null}}},GD={createOnAllSeries:!0,performRawSeries:!0,reset:function(r,t){if(!r.hasSymbolVisual||t.isSeriesFiltered(r))return;var e=r.getData();function n(i,a){for(var o=i.getItemModel(a),s=0;s<ap.length;s++){var l=ap[s],u=o.getShallow(l,!0);u!=null&&i.setItemVisual(a,l,u)}}return{dataEach:e.hasItemOption?n:null}}};function WD(r,t,e){switch(e){case"color":var n=r.getItemVisual(t,"style");return n[r.getVisual("drawType")];case"opacity":return r.getItemVisual(t,"style").opacity;case"symbol":case"symbolSize":case"liftZ":return r.getItemVisual(t,e)}}function UD(r,t){switch(t){case"color":var e=r.getVisual("style");return e[r.getVisual("drawType")];case"opacity":return r.getVisual("style").opacity;case"symbol":case"symbolSize":case"liftZ":return r.getVisual(t)}}function pa(r,t,e){for(var n;r&&!(t(r)&&(n=r,e));)r=r.__hostTarget||r.parent;return n}var YD=Math.round(Math.random()*9),ZD=typeof Object.defineProperty=="function",XD=(function(){function r(){this._id="__ec_inner_"+YD++}return r.prototype.get=function(t){return this._guard(t)[this._id]},r.prototype.set=function(t,e){var n=this._guard(t);return ZD?Object.defineProperty(n,this._id,{value:e,enumerable:!1,configurable:!0}):n[this._id]=e,this},r.prototype.delete=function(t){return this.has(t)?(delete this._guard(t)[this._id],!0):!1},r.prototype.has=function(t){return!!this._guard(t)[this._id]},r.prototype._guard=function(t){if(t!==Object(t))throw TypeError("Value of WeakMap is not a non-null object.");return t},r})();function Mn(r){return isFinite(r)}function $D(r,t,e){var n=t.x==null?0:t.x,i=t.x2==null?1:t.x2,a=t.y==null?0:t.y,o=t.y2==null?0:t.y2;t.global||(n=n*e.width+e.x,i=i*e.width+e.x,a=a*e.height+e.y,o=o*e.height+e.y),n=Mn(n)?n:0,i=Mn(i)?i:1,a=Mn(a)?a:0,o=Mn(o)?o:0;var s=r.createLinearGradient(n,a,i,o);return s}function qD(r,t,e){var n=e.width,i=e.height,a=Math.min(n,i),o=t.x==null?.5:t.x,s=t.y==null?.5:t.y,l=t.r==null?.5:t.r;t.global||(o=o*n+e.x,s=s*i+e.y,l=l*a),o=Mn(o)?o:.5,s=Mn(s)?s:.5,l=l>=0&&Mn(l)?l:.5;var u=r.createRadialGradient(o,s,0,o,s,l);return u}function Xf(r,t,e){for(var n=t.type==="radial"?qD(r,t,e):$D(r,t,e),i=t.colorStops,a=0;a<i.length;a++)n.addColorStop(i[a].offset,i[a].color);return n}function KD(r,t){if(r===t||!r&&!t)return!1;if(!r||!t||r.length!==t.length)return!0;for(var e=0;e<r.length;e++)if(r[e]!==t[e])return!0;return!1}function ko(r){return parseInt(r,10)}function Oo(r,t,e){var n=["width","height"][t],i=["clientWidth","clientHeight"][t],a=["paddingLeft","paddingTop"][t],o=["paddingRight","paddingBottom"][t];if(e[n]!=null&&e[n]!=="auto")return parseFloat(e[n]);var s=document.defaultView.getComputedStyle(r);return(r[i]||ko(s[n])||ko(r.style[n]))-(ko(s[a])||0)-(ko(s[o])||0)|0}function QD(r,t){return!r||r==="solid"||!(t>0)?null:r==="dashed"?[4*t,2*t]:r==="dotted"?[t]:mt(r)?[r]:H(r)?r:null}function Y0(r){var t=r.style,e=t.lineDash&&t.lineWidth>0&&QD(t.lineDash,t.lineWidth),n=t.lineDashOffset;if(e){var i=t.strokeNoScale&&r.getLineScale?r.getLineScale():1;i&&i!==1&&(e=$(e,function(a){return a/i}),n/=i)}return[e,n]}var jD=new vr(!0);function zs(r){var t=r.stroke;return!(t==null||t==="none"||!(r.lineWidth>0))}function op(r){return typeof r=="string"&&r!=="none"}function Hs(r){var t=r.fill;return t!=null&&t!=="none"}function sp(r,t){if(t.fillOpacity!=null&&t.fillOpacity!==1){var e=r.globalAlpha;r.globalAlpha=t.fillOpacity*t.opacity,r.fill(),r.globalAlpha=e}else r.fill()}function lp(r,t){if(t.strokeOpacity!=null&&t.strokeOpacity!==1){var e=r.globalAlpha;r.globalAlpha=t.strokeOpacity*t.opacity,r.stroke(),r.globalAlpha=e}else r.stroke()}function $f(r,t,e){var n=rm(t.image,t.__image,e);if(rl(n)){var i=r.createPattern(n,t.repeat||"repeat");if(typeof DOMMatrix=="function"&&i&&i.setTransform){var a=new DOMMatrix;a.translateSelf(t.x||0,t.y||0),a.rotateSelf(0,0,(t.rotation||0)*B1),a.scaleSelf(t.scaleX||1,t.scaleY||1),i.setTransform(a)}return i}}function JD(r,t,e,n){var i,a=zs(e),o=Hs(e),s=e.strokePercent,l=s<1,u=!t.path;(!t.silent||l)&&u&&t.createPathProxy();var f=t.path||jD,h=t.__dirty;if(!n){var c=e.fill,v=e.stroke,d=o&&!!c.colorStops,p=a&&!!v.colorStops,g=o&&!!c.image,m=a&&!!v.image,y=void 0,_=void 0,S=void 0,w=void 0,b=void 0;(d||p)&&(b=t.getBoundingRect()),d&&(y=h?Xf(r,c,b):t.__canvasFillGradient,t.__canvasFillGradient=y),p&&(_=h?Xf(r,v,b):t.__canvasStrokeGradient,t.__canvasStrokeGradient=_),g&&(S=h||!t.__canvasFillPattern?$f(r,c,t):t.__canvasFillPattern,t.__canvasFillPattern=S),m&&(w=h||!t.__canvasStrokePattern?$f(r,v,t):t.__canvasStrokePattern,t.__canvasStrokePattern=w),d?r.fillStyle=y:g&&(S?r.fillStyle=S:o=!1),p?r.strokeStyle=_:m&&(w?r.strokeStyle=w:a=!1)}var T=t.getGlobalScale();f.setScale(T[0],T[1],t.segmentIgnoreThreshold);var C,x;r.setLineDash&&e.lineDash&&(i=Y0(t),C=i[0],x=i[1]);var M=!0;(u||h&li)&&(f.setDPR(r.dpr),l?f.setContext(null):(f.setContext(r),M=!1),f.reset(),t.buildPath(f,t.shape,n),f.toStatic(),t.pathUpdated()),M&&f.rebuildPath(r,l?s:1),C&&(r.setLineDash(C),r.lineDashOffset=x),n||(e.strokeFirst?(a&&lp(r,e),o&&sp(r,e)):(o&&sp(r,e),a&&lp(r,e))),C&&r.setLineDash([])}function tA(r,t,e){var n=t.__image=rm(e.image,t.__image,t,t.onload);if(!(!n||!rl(n))){var i=e.x||0,a=e.y||0,o=t.getWidth(),s=t.getHeight(),l=n.width/n.height;if(o==null&&s!=null?o=s*l:s==null&&o!=null?s=o/l:o==null&&s==null&&(o=n.width,s=n.height),e.sWidth&&e.sHeight){var u=e.sx||0,f=e.sy||0;r.drawImage(n,u,f,e.sWidth,e.sHeight,i,a,o,s)}else if(e.sx&&e.sy){var u=e.sx,f=e.sy,h=o-u,c=s-f;r.drawImage(n,u,f,h,c,i,a,o,s)}else r.drawImage(n,i,a,o,s)}}function eA(r,t,e){var n,i=e.text;if(i!=null&&(i+=""),i){r.font=e.font||Br,r.textAlign=e.textAlign,r.textBaseline=e.textBaseline;var a=void 0,o=void 0;r.setLineDash&&e.lineDash&&(n=Y0(t),a=n[0],o=n[1]),a&&(r.setLineDash(a),r.lineDashOffset=o),e.strokeFirst?(zs(e)&&r.strokeText(i,e.x,e.y),Hs(e)&&r.fillText(i,e.x,e.y)):(Hs(e)&&r.fillText(i,e.x,e.y),zs(e)&&r.strokeText(i,e.x,e.y)),a&&r.setLineDash([])}}var up=["shadowBlur","shadowOffsetX","shadowOffsetY"],fp=[["lineCap","butt"],["lineJoin","miter"],["miterLimit",10]];function Z0(r,t,e,n,i){var a=!1;if(!n&&(e=e||{},t===e))return!1;if(n||t.opacity!==e.opacity){ne(r,i),a=!0;var o=Math.max(Math.min(t.opacity,1),0);r.globalAlpha=isNaN(o)?Ln.opacity:o}(n||t.blend!==e.blend)&&(a||(ne(r,i),a=!0),r.globalCompositeOperation=t.blend||Ln.blend);for(var s=0;s<up.length;s++){var l=up[s];(n||t[l]!==e[l])&&(a||(ne(r,i),a=!0),r[l]=r.dpr*(t[l]||0))}return(n||t.shadowColor!==e.shadowColor)&&(a||(ne(r,i),a=!0),r.shadowColor=t.shadowColor||Ln.shadowColor),a}function hp(r,t,e,n,i){var a=Ya(t,i.inHover),o=n?null:e&&Ya(e,i.inHover)||{};if(a===o)return!1;var s=Z0(r,a,o,n,i);if((n||a.fill!==o.fill)&&(s||(ne(r,i),s=!0),op(a.fill)&&(r.fillStyle=a.fill)),(n||a.stroke!==o.stroke)&&(s||(ne(r,i),s=!0),op(a.stroke)&&(r.strokeStyle=a.stroke)),(n||a.opacity!==o.opacity)&&(s||(ne(r,i),s=!0),r.globalAlpha=a.opacity==null?1:a.opacity),t.hasStroke()){var l=a.lineWidth,u=l/(a.strokeNoScale&&t.getLineScale?t.getLineScale():1);r.lineWidth!==u&&(s||(ne(r,i),s=!0),r.lineWidth=u)}for(var f=0;f<fp.length;f++){var h=fp[f],c=h[0];(n||a[c]!==o[c])&&(s||(ne(r,i),s=!0),r[c]=a[c]||h[1])}return s}function rA(r,t,e,n,i){return Z0(r,Ya(t,i.inHover),e&&Ya(e,i.inHover),n,i)}function X0(r,t){var e=t.transform,n=r.dpr||1;e?r.setTransform(n*e[0],n*e[1],n*e[2],n*e[3],n*e[4],n*e[5]):r.setTransform(n,0,0,n,0,0)}function nA(r,t,e){for(var n=!1,i=0;i<r.length;i++){var a=r[i];n=n||a.isZeroArea(),X0(t,a),t.beginPath(),a.buildPath(t,a.shape),t.clip()}e.allClipped=n}function iA(r,t){return r&&t?r[0]!==t[0]||r[1]!==t[1]||r[2]!==t[2]||r[3]!==t[3]||r[4]!==t[4]||r[5]!==t[5]:!(!r&&!t)}var vp=1,cp=2,dp=3,pp=4;function aA(r){var t=Hs(r),e=zs(r);return!(r.lineDash||!(+t^+e)||t&&typeof r.fill!="string"||e&&typeof r.stroke!="string"||r.strokePercent<1||r.strokeOpacity<1||r.fillOpacity<1)}function ne(r,t){t.batchFill&&r.fill(),t.batchStroke&&r.stroke(),t.batchFill="",t.batchStroke=""}function Ya(r,t){return t&&r.__hoverStyle||r.style}function $0(r,t){Cn(r,t,{inHover:!1,viewWidth:0,viewHeight:0},!0)}function Cn(r,t,e,n){var i=t.transform;if(!t.shouldBePainted(e.viewWidth,e.viewHeight,!1,!1)){t.__dirty&=~fe,t.__isRendered=!1;return}var a=t.__clipPaths,o=e.prevElClipPaths,s=!1,l=!1;if((!o||KD(a,o))&&(o&&o.length&&(ne(r,e),r.restore(),l=s=!0,e.prevElClipPaths=null,e.allClipped=!1,e.prevEl=null),a&&a.length&&(ne(r,e),r.save(),nA(a,r,e),s=!0),e.prevElClipPaths=a),e.allClipped){t.__isRendered=!1;return}t.beforeBrush&&t.beforeBrush(),t.innerBeforeBrush();var u=e.prevEl;u||(l=s=!0);var f=t instanceof ht&&t.autoBatch&&aA(t.style);s||iA(i,u.transform)?(ne(r,e),X0(r,t)):f||ne(r,e);var h=Ya(t,e.inHover);t instanceof ht?(e.lastDrawType!==vp&&(l=!0,e.lastDrawType=vp),hp(r,t,u,l,e),(!f||!e.batchFill&&!e.batchStroke)&&r.beginPath(),JD(r,t,h,f),f&&(e.batchFill=h.fill||"",e.batchStroke=h.stroke||"")):t instanceof _s?(e.lastDrawType!==dp&&(l=!0,e.lastDrawType=dp),hp(r,t,u,l,e),eA(r,t,h)):t instanceof Wr?(e.lastDrawType!==cp&&(l=!0,e.lastDrawType=cp),rA(r,t,u,l,e),tA(r,t,h)):t.getTemporalDisplayables&&(e.lastDrawType!==pp&&(l=!0,e.lastDrawType=pp),oA(r,t,e)),f&&n&&ne(r,e),t.innerAfterBrush(),t.afterBrush&&t.afterBrush(),e.prevEl=t,t.__dirty=0,t.__isRendered=!0}function oA(r,t,e){var n=t.getDisplayables(),i=t.getTemporalDisplayables();r.save();var a={prevElClipPaths:null,prevEl:null,allClipped:!1,viewWidth:e.viewWidth,viewHeight:e.viewHeight,inHover:e.inHover},o,s;for(o=t.getCursor(),s=n.length;o<s;o++){var l=n[o];l.beforeBrush&&l.beforeBrush(),l.innerBeforeBrush(),Cn(r,l,a,o===s-1),l.innerAfterBrush(),l.afterBrush&&l.afterBrush(),a.prevEl=l}for(var u=0,f=i.length;u<f;u++){var l=i[u];l.beforeBrush&&l.beforeBrush(),l.innerBeforeBrush(),Cn(r,l,a,u===f-1),l.innerAfterBrush(),l.afterBrush&&l.afterBrush(),a.prevEl=l}t.clearTemporalDisplayables(),t.notClear=!0,r.restore()}var Mu=new XD,gp=new Ti(100),mp=["symbol","symbolSize","symbolKeepAspect","color","backgroundColor","dashArrayX","dashArrayY","maxTileWidth","maxTileHeight"];function yp(r,t){if(r==="none")return null;var e=t.getDevicePixelRatio(),n=t.getZr(),i=n.painter.type==="svg";r.dirty&&Mu.delete(r);var a=Mu.get(r);if(a)return a;var o=at(r,{symbol:"rect",symbolSize:1,symbolKeepAspect:!0,color:"rgba(0, 0, 0, 0.2)",backgroundColor:null,dashArrayX:5,dashArrayY:5,rotation:0,maxTileWidth:512,maxTileHeight:512});o.backgroundColor==="none"&&(o.backgroundColor=null);var s={repeat:"repeat"};return l(s),s.rotation=o.rotation,s.scaleX=s.scaleY=i?1:1/e,Mu.set(r,s),r.dirty=!1,s;function l(u){for(var f=[e],h=!0,c=0;c<mp.length;++c){var v=o[mp[c]];if(v!=null&&!H(v)&&!W(v)&&!mt(v)&&typeof v!="boolean"){h=!1;break}f.push(v)}var d;if(h){d=f.join(",")+(i?"-svg":"");var p=gp.get(d);p&&(i?u.svgElement=p:u.image=p)}var g=K0(o.dashArrayX),m=sA(o.dashArrayY),y=q0(o.symbol),_=lA(g),S=Q0(m),w=!i&&fr.createCanvas(),b=i&&{tag:"g",attrs:{},key:"dcl",children:[]},T=x(),C;w&&(w.width=T.width*e,w.height=T.height*e,C=w.getContext("2d")),M(),h&&gp.put(d,w||b),u.image=w,u.svgElement=b,u.svgWidth=T.width,u.svgHeight=T.height;function x(){for(var A=1,P=0,L=_.length;P<L;++P)A=yc(A,_[P]);for(var I=1,P=0,L=y.length;P<L;++P)I=yc(I,y[P].length);A*=I;var R=S*_.length*y.length;return{width:Math.max(1,Math.min(A,o.maxTileWidth)),height:Math.max(1,Math.min(R,o.maxTileHeight))}}function M(){C&&(C.clearRect(0,0,w.width,w.height),o.backgroundColor&&(C.fillStyle=o.backgroundColor,C.fillRect(0,0,w.width,w.height)));for(var A=0,P=0;P<m.length;++P)A+=m[P];if(A<=0)return;for(var L=-S,I=0,R=0,E=0;L<T.height;){if(I%2===0){for(var V=R/2%y.length,B=0,k=0,G=0;B<T.width*2;){for(var U=0,P=0;P<g[E].length;++P)U+=g[E][P];if(U<=0)break;if(k%2===0){var Z=(1-o.symbolSize)*.5,j=B+g[E][k]*Z,ot=L+m[I]*Z,yt=g[E][k]*o.symbolSize,Ht=m[I]*o.symbolSize,de=G/2%y[V].length;pe(j,ot,yt,Ht,y[V][de])}B+=g[E][k],++G,++k,k===g[E].length&&(k=0)}++E,E===g.length&&(E=0)}L+=m[I],++R,++I,I===m.length&&(I=0)}function pe(Vt,Dt,rt,lt,Yr){var Zt=i?1:e,Av=Nn(Yr,Vt*Zt,Dt*Zt,rt*Zt,lt*Zt,o.color,o.symbolKeepAspect);if(i){var Lv=n.painter.renderOneToVNode(Av);Lv&&b.children.push(Lv)}else $0(C,Av)}}}}function q0(r){if(!r||r.length===0)return[["rect"]];if(W(r))return[[r]];for(var t=!0,e=0;e<r.length;++e)if(!W(r[e])){t=!1;break}if(t)return q0([r]);for(var n=[],e=0;e<r.length;++e)W(r[e])?n.push([r[e]]):n.push(r[e]);return n}function K0(r){if(!r||r.length===0)return[[0,0]];if(mt(r)){var t=Math.ceil(r);return[[t,t]]}for(var e=!0,n=0;n<r.length;++n)if(!mt(r[n])){e=!1;break}if(e)return K0([r]);for(var i=[],n=0;n<r.length;++n)if(mt(r[n])){var t=Math.ceil(r[n]);i.push([t,t])}else{var t=$(r[n],function(s){return Math.ceil(s)});t.length%2===1?i.push(t.concat(t)):i.push(t)}return i}function sA(r){if(!r||typeof r=="object"&&r.length===0)return[0,0];if(mt(r)){var t=Math.ceil(r);return[t,t]}var e=$(r,function(n){return Math.ceil(n)});return r.length%2?e.concat(e):e}function lA(r){return $(r,function(t){return Q0(t)})}function Q0(r){for(var t=0,e=0;e<r.length;++e)t+=r[e];return r.length%2===1?t*2:t}function uA(r,t){r.eachRawSeries(function(e){if(!r.isSeriesFiltered(e)){var n=e.getData();n.hasItemVisual()&&n.each(function(o){var s=n.getItemVisual(o,"decal");if(s){var l=n.ensureUniqueItemVisual(o,"style");l.decal=yp(s,t)}});var i=n.getVisual("decal");if(i){var a=n.getVisual("style");a.decal=yp(i,t)}}})}var Ie=new ke,j0={};function fA(r,t){j0[r]=t}function hA(r){return j0[r]}var vA=1,cA=800,dA=900,pA=1e3,gA=2e3,mA=5e3,J0=1e3,yA=1100,cv=2e3,t_=3e3,_A=4e3,Sl=4500,SA=4600,bA=5e3,wA=6e3,e_=7e3,xA={PROCESSOR:{FILTER:pA,SERIES_FILTER:cA,STATISTIC:mA},VISUAL:{LAYOUT:J0,PROGRESSIVE_LAYOUT:yA,GLOBAL:cv,CHART:t_,POST_CHART_LAYOUT:SA,COMPONENT:_A,BRUSH:bA,CHART_ITEM:Sl,ARIA:wA,DECAL:e_}},At="__flagInMainProcess",Bo="__mainProcessVersion",Pt="__pendingUpdate",Cu="__needsUpdateStatus",_p=/^[a-zA-Z0-9_]+$/,Du="__connectUpdateStatus",Sp=0,TA=1,MA=2;function r_(r){return function(){for(var t=[],e=0;e<arguments.length;e++)t[e]=arguments[e];if(this.isDisposed()){this.id;return}return i_(this,r,t)}}function n_(r){return function(){for(var t=[],e=0;e<arguments.length;e++)t[e]=arguments[e];return i_(this,r,t)}}function i_(r,t,e){return e[0]=e[0]&&e[0].toLowerCase(),ke.prototype[t].apply(r,e)}var a_=(function(r){z(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t})(ke),o_=a_.prototype;o_.on=n_("on");o_.off=n_("off");var mn,Au,No,er,Fo,Lu,Iu,ei,ri,bp,wp,Pu,xp,zo,Tp,s_,ge,Mp,ni,l_=(function(r){z(t,r);function t(e,n,i){var a=r.call(this,new HD)||this;a._chartsViews=[],a._chartsMap={},a._componentsViews=[],a._componentsMap={},a._pendingActions=[],i=i||{},a._dom=e;var o="canvas",s="auto",l=!1;a[Bo]=1,i.ssr;var u=a._zr=Yd(e,{renderer:i.renderer||o,devicePixelRatio:i.devicePixelRatio,width:i.width,height:i.height,ssr:i.ssr,useDirtyRect:q(i.useDirtyRect,l),useCoarsePointer:q(i.useCoarsePointer,s),pointerSize:i.pointerSize});a._ssr=i.ssr,a._throttledZrFlush=w0(Q(u.flush,u),17),a._updateTheme(n),a._locale=yT(i.locale||Yy),a._coordSysMgr=new $h;var f=a._api=Tp(a);function h(c,v){return c.__prio-v.__prio}return os(Gs,h),os(Qf,h),a._scheduler=new H0(a,f,Qf,Gs),a._messageCenter=new a_,a._initEvents(),a.resize=Q(a.resize,a),u.animation.on("frame",a._onframe,a),bp(u,a),wp(u,a),cs(a),a}return t.prototype._onframe=function(){if(!this._disposed){Mp(this);var e=this._scheduler;if(this[Pt]){var n=this[Pt].silent;this[At]=!0,ni(this);try{mn(this),er.update.call(this,null,this[Pt].updateParams)}catch(l){throw this[At]=!1,this[Pt]=null,l}this._zr.flush(),this[At]=!1,this[Pt]=null,ei.call(this,n),ri.call(this,n)}else if(e.unfinished){var i=vA,a=this._model,o=this._api;e.unfinished=!1;do{var s=+new Date;e.performSeriesTasks(a),e.performDataProcessorTasks(a),Lu(this,a),e.performVisualTasks(a),zo(this,this._model,o,"remain",{}),i-=+new Date-s}while(i>0&&e.unfinished);e.unfinished||this._zr.flush()}}},t.prototype.getDom=function(){return this._dom},t.prototype.getId=function(){return this.id},t.prototype.getZr=function(){return this._zr},t.prototype.isSSR=function(){return this._ssr},t.prototype.setOption=function(e,n,i){if(!this[At]){if(this._disposed){this.id;return}var a,o,s;if(X(n)&&(i=n.lazyUpdate,a=n.silent,o=n.replaceMerge,s=n.transition,n=n.notMerge),this[At]=!0,ni(this),!this._model||n){var l=new hD(this._api),u=this._theme,f=this._model=new vv;f.scheduler=this._scheduler,f.ssr=this._ssr,f.init(null,null,null,u,this._locale,l)}this._model.setOption(e,{replaceMerge:o},jf);var h={seriesTransition:s,optionChanged:!0};if(i)this[Pt]={silent:a,updateParams:h},this[At]=!1,this.getZr().wakeUp();else{try{mn(this),er.update.call(this,null,h)}catch(c){throw this[Pt]=null,this[At]=!1,c}this._ssr||this._zr.flush(),this[Pt]=null,this[At]=!1,ei.call(this,a),ri.call(this,a)}}},t.prototype.setTheme=function(e,n){if(!this[At]){if(this._disposed){this.id;return}var i=this._model;if(i){var a=n&&n.silent,o=null;this[Pt]&&(a==null&&(a=this[Pt].silent),o=this[Pt].updateParams,this[Pt]=null),this[At]=!0,ni(this);try{this._updateTheme(e),i.setTheme(this._theme),mn(this),er.update.call(this,{type:"setTheme"},o)}catch(s){throw this[At]=!1,s}this[At]=!1,ei.call(this,a),ri.call(this,a)}}},t.prototype._updateTheme=function(e){W(e)&&(e=u_[e]),e&&(e=st(e),e&&N0(e,!0),this._theme=e)},t.prototype.getModel=function(){return this._model},t.prototype.getOption=function(){return this._model&&this._model.getOption()},t.prototype.getWidth=function(){return this._zr.getWidth()},t.prototype.getHeight=function(){return this._zr.getHeight()},t.prototype.getDevicePixelRatio=function(){return this._zr.painter.dpr||nt.hasGlobalWindow&&window.devicePixelRatio||1},t.prototype.getRenderedCanvas=function(e){return this.renderToCanvas(e)},t.prototype.renderToCanvas=function(e){e=e||{};var n=this._zr.painter;return n.getRenderedCanvas({backgroundColor:e.backgroundColor||this._model.get("backgroundColor"),pixelRatio:e.pixelRatio||this.getDevicePixelRatio()})},t.prototype.renderToSVGString=function(e){e=e||{};var n=this._zr.painter;return n.renderToString({useViewBox:e.useViewBox})},t.prototype.getSvgDataURL=function(){var e=this._zr,n=e.storage.getDisplayList();return D(n,function(i){i.stopAnimation(null,!0)}),e.painter.toDataURL()},t.prototype.getDataURL=function(e){if(this._disposed){this.id;return}e=e||{};var n=e.excludeComponents,i=this._model,a=[],o=this;D(n,function(l){i.eachComponent({mainType:l},function(u){var f=o._componentsMap[u.__viewId];f.group.ignore||(a.push(f),f.group.ignore=!0)})});var s=this._zr.painter.getType()==="svg"?this.getSvgDataURL():this.renderToCanvas(e).toDataURL("image/"+(e&&e.type||"png"));return D(a,function(l){l.group.ignore=!1}),s},t.prototype.getConnectedDataURL=function(e){if(this._disposed){this.id;return}var n=e.type==="svg",i=this.group,a=Math.min,o=Math.max,s=1/0;if(Cp[i]){var l=s,u=s,f=-s,h=-s,c=[],v=e&&e.pixelRatio||this.getDevicePixelRatio();D(Da,function(_,S){if(_.group===i){var w=n?_.getZr().painter.getSvgDom().innerHTML:_.renderToCanvas(st(e)),b=_.getDom().getBoundingClientRect();l=a(b.left,l),u=a(b.top,u),f=o(b.right,f),h=o(b.bottom,h),c.push({dom:w,left:b.left,top:b.top})}}),l*=v,u*=v,f*=v,h*=v;var d=f-l,p=h-u,g=fr.createCanvas(),m=Yd(g,{renderer:n?"svg":"canvas"});if(m.resize({width:d,height:p}),n){var y="";return D(c,function(_){var S=_.left-l,w=_.top-u;y+='<g transform="translate('+S+","+w+')">'+_.dom+"</g>"}),m.painter.getSvgRoot().innerHTML=y,e.connectedBackgroundColor&&m.painter.setBackgroundColor(e.connectedBackgroundColor),m.refreshImmediately(),m.painter.toDataURL()}else return e.connectedBackgroundColor&&m.add(new Tt({shape:{x:0,y:0,width:d,height:p},style:{fill:e.connectedBackgroundColor}})),D(c,function(_){var S=new Wr({style:{x:_.left*v-l,y:_.top*v-u,image:_.dom}});m.add(S)}),m.refreshImmediately(),g.toDataURL("image/"+(e&&e.type||"png"))}else return this.getDataURL(e)},t.prototype.convertToPixel=function(e,n,i){return Fo(this,"convertToPixel",e,n,i)},t.prototype.convertToLayout=function(e,n,i){return Fo(this,"convertToLayout",e,n,i)},t.prototype.convertFromPixel=function(e,n,i){return Fo(this,"convertFromPixel",e,n,i)},t.prototype.containPixel=function(e,n){if(this._disposed){this.id;return}var i=this._model,a,o=Yl(i,e);return D(o,function(s,l){l.indexOf("Models")>=0&&D(s,function(u){var f=u.coordinateSystem;if(f&&f.containPoint)a=a||!!f.containPoint(n);else if(l==="seriesModels"){var h=this._chartsMap[u.__viewId];h&&h.containPoint&&(a=a||h.containPoint(n,u))}},this)},this),!!a},t.prototype.getVisual=function(e,n){var i=this._model,a=Yl(i,e,{defaultMainType:"series"}),o=a.seriesModel,s=o.getData(),l=a.hasOwnProperty("dataIndexInside")?a.dataIndexInside:a.hasOwnProperty("dataIndex")?s.indexOfRawIndex(a.dataIndex):null;return l!=null?WD(s,l,n):UD(s,n)},t.prototype.getViewOfComponentModel=function(e){return this._componentsMap[e.__viewId]},t.prototype.getViewOfSeriesModel=function(e){return this._chartsMap[e.__viewId]},t.prototype._initEvents=function(){var e=this;D(CA,function(i){var a=function(o){var s=e.getModel(),l=o.target,u,f=i==="globalout";if(f?u={}:l&&pa(l,function(p){var g=pt(p);if(g&&g.dataIndex!=null){var m=g.dataModel||s.getSeriesByIndex(g.seriesIndex);return u=m&&m.getDataParams(g.dataIndex,g.dataType,l)||{},!0}else if(g.eventData)return u=O({},g.eventData),!0},!0),u){var h=u.componentType,c=u.componentIndex;(h==="markLine"||h==="markPoint"||h==="markArea")&&(h="series",c=u.seriesIndex);var v=h&&c!=null&&s.getComponent(h,c),d=v&&e[v.mainType==="series"?"_chartsMap":"_componentsMap"][v.__viewId];u.event=o,u.type=i,e._$eventProcessor.eventInfo={targetEl:l,packedEvent:u,model:v,view:d},e.trigger(i,u)}};a.zrEventfulCallAtLast=!0,e._zr.on(i,a,e)});var n=this._messageCenter;D(Kf,function(i,a){n.on(a,function(o){e.trigger(a,o)})}),vC(n,this,this._api)},t.prototype.isDisposed=function(){return this._disposed},t.prototype.clear=function(){if(this._disposed){this.id;return}this.setOption({series:[]},!0)},t.prototype.dispose=function(){if(this._disposed){this.id;return}this._disposed=!0;var e=this.getDom();e&&Fm(this.getDom(),pv,"");var n=this,i=n._api,a=n._model;D(n._componentsViews,function(o){o.dispose(a,i)}),D(n._chartsViews,function(o){o.dispose(a,i)}),n._zr.dispose(),n._dom=n._model=n._chartsMap=n._componentsMap=n._chartsViews=n._componentsViews=n._scheduler=n._api=n._zr=n._throttledZrFlush=n._theme=n._coordSysMgr=n._messageCenter=null,delete Da[n.id]},t.prototype.resize=function(e){if(!this[At]){if(this._disposed){this.id;return}this._zr.resize(e);var n=this._model;if(this._loadingFX&&this._loadingFX.resize(),!!n){var i=n.resetOption("media"),a=e&&e.silent;this[Pt]&&(a==null&&(a=this[Pt].silent),i=!0,this[Pt]=null),this[At]=!0,ni(this);try{i&&mn(this),er.update.call(this,{type:"resize",animation:O({duration:0},e&&e.animation)})}catch(o){throw this[At]=!1,o}this[At]=!1,ei.call(this,a),ri.call(this,a)}}},t.prototype.showLoading=function(e,n){if(this._disposed){this.id;return}if(X(e)&&(n=e,e=""),e=e||"default",this.hideLoading(),!!Jf[e]){var i=Jf[e](this._api,n),a=this._zr;this._loadingFX=i,a.add(i)}},t.prototype.hideLoading=function(){if(this._disposed){this.id;return}this._loadingFX&&this._zr.remove(this._loadingFX),this._loadingFX=null},t.prototype.makeActionFromEvent=function(e){var n=O({},e);return n.type=qf[e.type],n},t.prototype.dispatchAction=function(e,n){if(this._disposed){this.id;return}if(X(n)||(n={silent:!!n}),!!Vs[e.type]&&this._model){if(this[At]){this._pendingActions.push(e);return}var i=n.silent;Iu.call(this,e,i);var a=n.flush;a?this._zr.flush():a!==!1&&nt.browser.weChat&&this._throttledZrFlush(),ei.call(this,i),ri.call(this,i)}},t.prototype.updateLabelLayout=function(){Ie.trigger("series:layoutlabels",this._model,this._api,{updatedSeries:[]})},t.prototype.appendData=function(e){if(this._disposed){this.id;return}var n=e.seriesIndex,i=this.getModel(),a=i.getSeriesByIndex(n);a.appendData(e),this._scheduler.unfinished=!0,this.getZr().wakeUp()},t.internalField=(function(){mn=function(h){var c=h._scheduler;c.restorePipelines(h._model),c.prepareStageTasks(),Au(h,!0),Au(h,!1),c.plan()},Au=function(h,c){for(var v=h._model,d=h._scheduler,p=c?h._componentsViews:h._chartsViews,g=c?h._componentsMap:h._chartsMap,m=h._zr,y=h._api,_=0;_<p.length;_++)p[_].__alive=!1;c?v.eachComponent(function(b,T){b!=="series"&&S(T)}):v.eachSeries(S);function S(b){var T=b.__requireNewView;b.__requireNewView=!1;var C="_ec_"+b.id+"_"+b.type,x=!T&&g[C];if(!x){var M=Ue(b.type),A=c?Me.getClass(M.main,M.sub):qe.getClass(M.sub);x=new A,x.init(v,y),g[C]=x,p.push(x),m.add(x.group)}b.__viewId=x.__id=C,x.__alive=!0,x.__model=b,x.group.__ecComponentInfo={mainType:b.mainType,index:b.componentIndex},!c&&d.prepareView(x,b,v,y)}for(var _=0;_<p.length;){var w=p[_];w.__alive?_++:(!c&&w.renderTask.dispose(),m.remove(w.group),w.dispose(v,y),p.splice(_,1),g[w.__id]===w&&delete g[w.__id],w.__id=w.group.__ecComponentInfo=null)}},No=function(h,c,v,d,p){var g=h._model;if(g.setUpdatePayload(v),!d){D([].concat(h._componentsViews).concat(h._chartsViews),w);return}var m={};m[d+"Id"]=v[d+"Id"],m[d+"Index"]=v[d+"Index"],m[d+"Name"]=v[d+"Name"];var y={mainType:d,query:m};p&&(y.subType=p);var _=v.excludeSeriesId,S;_!=null&&(S=K(),D(Ct(_),function(b){var T=$e(b,null);T!=null&&S.set(T,!0)})),g&&g.eachComponent(y,function(b){var T=S&&S.get(b.id)!=null;if(!T)if(Pc(v))if(b instanceof Vr)v.type===In&&!v.notBlur&&!b.get(["emphasis","disabled"])&&tw(b,v,h._api);else{var C=kh(b.mainType,b.componentIndex,v.name,h._api),x=C.focusSelf,M=C.dispatchers;v.type===In&&x&&!v.notBlur&&wf(b.mainType,b.componentIndex,h._api),M&&D(M,function(A){v.type===In?Ts(A):Ms(A)})}else Mf(v)&&b instanceof Vr&&(nw(b,v,h._api),Ac(b),ge(h))},h),g&&g.eachComponent(y,function(b){var T=S&&S.get(b.id)!=null;T||w(h[d==="series"?"_chartsMap":"_componentsMap"][b.__viewId])},h);function w(b){b&&b.__alive&&b[c]&&b[c](b.__model,g,h._api,v)}},er={prepareAndUpdate:function(h){mn(this),er.update.call(this,h,h&&{optionChanged:h.newOption!=null})},update:function(h,c){var v=this._model,d=this._api,p=this._zr,g=this._coordSysMgr,m=this._scheduler;if(v){v.setUpdatePayload(h),m.restoreData(v,h),m.performSeriesTasks(v),g.create(v,d),m.performDataProcessorTasks(v,h),Lu(this,v),g.update(v,d),n(v),m.performVisualTasks(v,h);var y=v.get("backgroundColor")||"transparent";p.setBackgroundColor(y);var _=v.get("darkMode");_!=null&&_!=="auto"&&p.setDarkMode(_),Pu(this,v,d,h,c),Ie.trigger("afterupdate",v,d)}},updateTransform:function(h){var c=this,v=this._model,d=this._api;if(v){v.setUpdatePayload(h);var p=[];v.eachComponent(function(m,y){if(m!=="series"){var _=c.getViewOfComponentModel(y);if(_&&_.__alive)if(_.updateTransform){var S=_.updateTransform(y,v,d,h);S&&S.update&&p.push(_)}else p.push(_)}});var g=K();v.eachSeries(function(m){var y=c._chartsMap[m.__viewId];if(y.updateTransform){var _=y.updateTransform(m,v,d,h);_&&_.update&&g.set(m.uid,1)}else g.set(m.uid,1)}),n(v),this._scheduler.performVisualTasks(v,h,{setDirty:!0,dirtyMap:g}),zo(this,v,d,h,{},g),Ie.trigger("afterupdate",v,d)}},updateView:function(h){var c=this._model;c&&(c.setUpdatePayload(h),qe.markUpdateMethod(h,"updateView"),n(c),this._scheduler.performVisualTasks(c,h,{setDirty:!0}),Pu(this,c,this._api,h,{}),Ie.trigger("afterupdate",c,this._api))},updateVisual:function(h){var c=this,v=this._model;v&&(v.setUpdatePayload(h),v.eachSeries(function(d){d.getData().clearAllVisual()}),qe.markUpdateMethod(h,"updateVisual"),n(v),this._scheduler.performVisualTasks(v,h,{visualType:"visual",setDirty:!0}),v.eachComponent(function(d,p){if(d!=="series"){var g=c.getViewOfComponentModel(p);g&&g.__alive&&g.updateVisual(p,v,c._api,h)}}),v.eachSeries(function(d){var p=c._chartsMap[d.__viewId];p.updateVisual(d,v,c._api,h)}),Ie.trigger("afterupdate",v,this._api))},updateLayout:function(h){er.update.call(this,h)}};function e(h,c,v,d,p){if(h._disposed){h.id;return}for(var g=h._model,m=h._coordSysMgr.getCoordinateSystems(),y,_=Yl(g,v),S=0;S<m.length;S++){var w=m[S];if(w[c]&&(y=w[c](g,_,d,p))!=null)return y}}Fo=e,Lu=function(h,c){var v=h._chartsMap,d=h._scheduler;c.eachSeries(function(p){d.updateStreamModes(p,v[p.__viewId])})},Iu=function(h,c){var v=this,d=this.getModel(),p=h.type,g=h.escapeConnect,m=Vs[p],y=(m.update||"update").split(":"),_=y.pop(),S=y[0]!=null&&Ue(y[0]);this[At]=!0,ni(this);var w=[h],b=!1;h.batch&&(b=!0,w=$(h.batch,function(E){return E=at(O({},E),h),E.batch=null,E}));var T=[],C,x=[],M=m.nonRefinedEventType,A=Mf(h),P=Pc(h);if(P&&$m(this._api),D(w,function(E){var V=m.action(E,d,v._api);if(m.refineEvent?x.push(V):C=V,C=C||O({},E),C.type=M,T.push(C),P){var B=Lh(h),k=B.queryOptionMap,G=B.mainTypeSpecified,U=G?k.keys()[0]:"series";No(v,_,E,U),ge(v)}else A?(No(v,_,E,"series"),ge(v)):S&&No(v,_,E,S.main,S.sub)}),_!=="none"&&!P&&!A&&!S)try{this[Pt]?(mn(this),er.update.call(this,h),this[Pt]=null):er[_].call(this,h)}catch(E){throw this[At]=!1,E}if(b?C={type:M,escapeConnect:g,batch:T}:C=T[0],this[At]=!1,!c){var L=void 0;if(m.refineEvent){var I=m.refineEvent(x,h,d,this._api).eventContent;hr(X(I)),L=at({type:m.refinedEventType},I),L.fromAction=h.type,L.fromActionPayload=h,L.escapeConnect=!0}var R=this._messageCenter;R.trigger(C.type,C),L&&R.trigger(L.type,L)}},ei=function(h){for(var c=this._pendingActions;c.length;){var v=c.shift();Iu.call(this,v,h)}},ri=function(h){!h&&this.trigger("updated")},bp=function(h,c){h.on("rendered",function(v){c.trigger("rendered",v),h.animation.isFinished()&&!c[Pt]&&!c._scheduler.unfinished&&!c._pendingActions.length&&c.trigger("finished")})},wp=function(h,c){h.on("mouseover",function(v){var d=v.target,p=pa(d,Tf);p&&(ew(p,v,c._api),ge(c))}).on("mouseout",function(v){var d=v.target,p=pa(d,Tf);p&&(rw(p,v,c._api),ge(c))}).on("click",function(v){var d=v.target,p=pa(d,function(y){return pt(y).dataIndex!=null},!0);if(p){var g=p.selected?"unselect":"select",m=pt(p);c._api.dispatchAction({type:g,dataType:m.dataType,dataIndexInside:m.dataIndex,seriesIndex:m.seriesIndex,isFromClick:!0})}})};function n(h){h.clearColorPalette(),h.eachSeries(function(c){c.clearColorPalette()})}function i(h){var c=[],v=[],d=!1;if(h.eachComponent(function(y,_){var S=_.get("zlevel")||0,w=_.get("z")||0,b=_.getZLevelKey();d=d||!!b,(y==="series"?v:c).push({zlevel:S,z:w,idx:_.componentIndex,type:y,key:b})}),d){var p=c.concat(v),g,m;os(p,function(y,_){return y.zlevel===_.zlevel?y.z-_.z:y.zlevel-_.zlevel}),D(p,function(y){var _=h.getComponent(y.type,y.idx),S=y.zlevel,w=y.key;g!=null&&(S=Math.max(g,S)),w?(S===g&&w!==m&&S++,m=w):m&&(S===g&&S++,m=""),g=S,_.setZLevel(S)})}}Pu=function(h,c,v,d,p){i(c),xp(h,c,v,d,p),D(h._chartsViews,function(g){g.__alive=!1}),zo(h,c,v,d,p),D(h._chartsViews,function(g){g.__alive||g.remove(c,v)})},xp=function(h,c,v,d,p,g){D(g||h._componentsViews,function(m){var y=m.__model;u(y,m),m.render(y,c,v,d),l(y,m),f(y,m)})},zo=function(h,c,v,d,p,g){var m=h._scheduler;p=O(p||{},{updatedSeries:c.getSeries()}),Ie.trigger("series:beforeupdate",c,v,p);var y=!1;c.eachSeries(function(_){var S=h._chartsMap[_.__viewId];S.__alive=!0;var w=S.renderTask;m.updatePayload(w,d),u(_,S),g&&g.get(_.uid)&&w.dirty(),w.perform(m.getPerformArgs(w))&&(y=!0),S.group.silent=!!_.get("silent"),s(_,S),Ac(_)}),m.unfinished=y||m.unfinished,Ie.trigger("series:layoutlabels",c,v,p),Ie.trigger("series:transition",c,v,p),c.eachSeries(function(_){var S=h._chartsMap[_.__viewId];l(_,S),f(_,S)}),o(h,c),Ie.trigger("series:afterupdate",c,v,p)},ge=function(h){h[Cu]=!0,h.getZr().wakeUp()},ni=function(h){h[Bo]=(h[Bo]+1)%1e3},Mp=function(h){h[Cu]&&(h.getZr().storage.traverse(function(c){wi(c)||a(c)}),h[Cu]=!1)};function a(h){for(var c=[],v=h.currentStates,d=0;d<v.length;d++){var p=v[d];p==="emphasis"||p==="blur"||p==="select"||c.push(p)}h.selected&&h.states.select&&c.push("select"),h.hoverState===ll&&h.states.emphasis?c.push("emphasis"):h.hoverState===sl&&h.states.blur&&c.push("blur"),h.useStates(c)}function o(h,c){var v=h._zr,d=v.storage,p=0;d.traverse(function(g){g.isGroup||p++}),p>c.get("hoverLayerThreshold")&&!nt.node&&!nt.worker&&c.eachSeries(function(g){if(!g.preventUsingHoverLayer){var m=h._chartsMap[g.__viewId];m.__alive&&m.eachRendered(function(y){y.states.emphasis&&(y.states.emphasis.hoverLayer=!0)})}})}function s(h,c){var v=h.get("blendMode")||null;c.eachRendered(function(d){d.isGroup||(d.style.blend=v)})}function l(h,c){if(!h.preventAutoZ){var v=za(h);c.eachRendered(function(d){return py(d,v.z,v.zlevel),!0})}}function u(h,c){c.eachRendered(function(v){if(!wi(v)){var d=v.getTextContent(),p=v.getTextGuideLine();v.stateTransition&&(v.stateTransition=null),d&&d.stateTransition&&(d.stateTransition=null),p&&p.stateTransition&&(p.stateTransition=null),v.hasState()?(v.prevStates=v.currentStates,v.clearStates()):v.prevStates&&(v.prevStates=null)}})}function f(h,c){var v=h.getModel("stateAnimation"),d=h.isAnimationEnabled(),p=v.get("duration"),g=p>0?{duration:p,delay:v.get("delay"),easing:v.get("easing")}:null;c.eachRendered(function(m){if(m.states&&m.states.emphasis){if(wi(m))return;if(m instanceof ht&&uw(m),m.__dirty){var y=m.prevStates;y&&m.useStates(y)}if(d){m.stateTransition=g;var _=m.getTextContent(),S=m.getTextGuideLine();_&&(_.stateTransition=g),S&&(S.stateTransition=g)}m.__dirty&&a(m)}})}Tp=function(h){return new((function(c){z(v,c);function v(){return c!==null&&c.apply(this,arguments)||this}return v.prototype.getCoordinateSystems=function(){return h._coordSysMgr.getCoordinateSystems()},v.prototype.getComponentByElement=function(d){for(;d;){var p=d.__ecComponentInfo;if(p!=null)return h._model.getComponent(p.mainType,p.index);d=d.parent}},v.prototype.enterEmphasis=function(d,p){Ts(d,p),ge(h)},v.prototype.leaveEmphasis=function(d,p){Ms(d,p),ge(h)},v.prototype.enterBlur=function(d){Jb(d),ge(h)},v.prototype.leaveBlur=function(d){Um(d),ge(h)},v.prototype.enterSelect=function(d){Ym(d),ge(h)},v.prototype.leaveSelect=function(d){Zm(d),ge(h)},v.prototype.getModel=function(){return h.getModel()},v.prototype.getViewOfComponentModel=function(d){return h.getViewOfComponentModel(d)},v.prototype.getViewOfSeriesModel=function(d){return h.getViewOfSeriesModel(d)},v.prototype.getMainProcessVersion=function(){return h[Bo]},v})(O0))(h)},s_=function(h){function c(v,d){for(var p=0;p<v.length;p++){var g=v[p];g[Du]=d}}D(qf,function(v,d){h._messageCenter.on(d,function(p){if(Cp[h.group]&&h[Du]!==Sp){if(p&&p.escapeConnect)return;var g=h.makeActionFromEvent(p),m=[];D(Da,function(y){y!==h&&y.group===h.group&&m.push(y)}),c(m,Sp),D(m,function(y){y[Du]!==TA&&y.dispatchAction(g)}),c(m,MA)}})})}})(),t})(ke),dv=l_.prototype;dv.on=r_("on");dv.off=r_("off");dv.one=function(r,t,e){var n=this;function i(){for(var a=[],o=0;o<arguments.length;o++)a[o]=arguments[o];t&&t.apply&&t.apply(this,a),n.off(r,i)}this.on.call(this,r,i,e)};var CA=["click","dblclick","mouseover","mouseout","mousemove","mousedown","mouseup","globalout","contextmenu"];var Vs={},qf={},Kf={},Qf=[],jf=[],Gs=[],u_={},Jf={},Da={},Cp={},DA=+new Date-0,pv="_echarts_instance_";function AA(r,t,e){{var n=LA(r);if(n)return n}var i=new l_(r,t,e);return i.id="ec_"+DA++,Da[i.id]=i,Fm(r,pv,i.id),s_(i),Ie.trigger("afterinit",i),i}function LA(r){return Da[Vb(r,pv)]}function f_(r,t){u_[r]=t}function h_(r){ft(jf,r)<0&&jf.push(r)}function v_(r,t){mv(Qf,r,t,gA)}function IA(r){gv("afterinit",r)}function PA(r){gv("afterupdate",r)}function gv(r,t){Ie.on(r,t)}function Hn(r,t,e){var n,i,a,o,s;et(t)&&(e=t,t=""),X(r)?(n=r.type,i=r.event,o=r.update,s=r.publishNonRefinedEvent,e||(e=r.action),a=r.refineEvent):(n=r,i=t);function l(f){return f.toLowerCase()}i=l(i||n);var u=a?l(n):i;Vs[n]||(hr(_p.test(n)&&_p.test(i)),a&&hr(i!==n),Vs[n]={actionType:n,refinedEventType:i,nonRefinedEventType:u,update:o,action:e,refineEvent:a},Kf[i]=1,a&&s&&(Kf[u]=1),qf[u]=n)}function RA(r,t){$h.register(r,t)}function EA(r,t){mv(Gs,r,t,J0,"layout")}function Vn(r,t){mv(Gs,r,t,t_,"visual")}var Dp=[];function mv(r,t,e,n,i){if((et(t)||X(t))&&(e=t,t=n),!(ft(Dp,e)>=0)){Dp.push(e);var a=H0.wrapStageHandler(e,i);a.__prio=t,a.__raw=e,r.push(a)}}function c_(r,t){Jf[r]=t}function kA(r,t,e){var n=hA("registerMap");n&&n(r,t,e)}var OA=qT;Vn(cv,CD);Vn(Sl,DD);Vn(Sl,AD);Vn(cv,VD);Vn(Sl,GD);Vn(e_,uA);h_(N0);v_(dA,xD);c_("default",LD);Hn({type:In,event:In,update:In},Kt);Hn({type:jo,event:jo,update:jo},Kt);Hn({type:ws,event:Rh,update:ws,action:Kt,refineEvent:yv,publishNonRefinedEvent:!0});Hn({type:Sf,event:Rh,update:Sf,action:Kt,refineEvent:yv,publishNonRefinedEvent:!0});Hn({type:xs,event:Rh,update:xs,action:Kt,refineEvent:yv,publishNonRefinedEvent:!0});function yv(r,t,e,n){return{eventContent:{selected:iw(e),isFromClick:t.isFromClick||!1}}}f_("default",{});f_("dark",U0);var Ap=[],BA={registerPreprocessor:h_,registerProcessor:v_,registerPostInit:IA,registerPostUpdate:PA,registerUpdateLifecycle:gv,registerAction:Hn,registerCoordinateSystem:RA,registerLayout:EA,registerVisual:Vn,registerTransform:OA,registerLoading:c_,registerMap:kA,registerImpl:fA,PRIORITY:xA,ComponentModel:dt,ComponentView:Me,SeriesModel:Vr,ChartView:qe,registerComponentModel:function(r){dt.registerClass(r)},registerComponentView:function(r){Me.registerClass(r)},registerSeriesModel:function(r){Vr.registerClass(r)},registerChartView:function(r){qe.registerClass(r)},registerCustomSeries:function(r,t){},registerSubTypeDefaulter:function(r,t){dt.registerSubTypeDefaulter(r,t)},registerPainter:function(r,t){eD(r,t)}};function Fn(r){if(H(r)){D(r,function(t){Fn(t)});return}ft(Ap,r)>=0||(Ap.push(r),et(r)&&(r={install:r}),r.install(BA))}var d_={left:0,right:0,top:0,bottom:0},Ws=["25%","25%"],NA=(function(r){z(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.mergeDefaultAndTheme=function(e,n){var i=no(e.outerBounds);r.prototype.mergeDefaultAndTheme.apply(this,arguments),i&&e.outerBounds&&Bn(e.outerBounds,i)},t.prototype.mergeOption=function(e,n){r.prototype.mergeOption.apply(this,arguments),this.option.outerBounds&&e.outerBounds&&Bn(this.option.outerBounds,e.outerBounds)},t.type="grid",t.dependencies=["xAxis","yAxis"],t.layoutMode="box",t.defaultOption={show:!1,z:0,left:"15%",top:65,right:"10%",bottom:80,containLabel:!1,outerBoundsMode:"auto",outerBounds:d_,outerBoundsContain:"all",outerBoundsClampWidth:Ws[0],outerBoundsClampHeight:Ws[1],backgroundColor:Y.color.transparent,borderWidth:1,borderColor:Y.color.neutral30},t})(dt),FA=(function(){function r(){}return r.prototype.getNeedCrossZero=function(){var t=this.option;return!t.scale},r.prototype.getCoordSysModel=function(){},r})(),th=(function(r){z(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.getCoordSysModel=function(){return this.getReferringComponents("grid",qt).models[0]},t.type="cartesian2dAxis",t})(dt);Qe(th,FA);var p_={show:!0,z:0,inverse:!1,name:"",nameLocation:"end",nameRotate:null,nameTruncate:{maxWidth:null,ellipsis:"...",placeholder:"."},nameTextStyle:{},nameGap:15,silent:!1,triggerEvent:!1,tooltip:{show:!1},axisPointer:{},axisLine:{show:!0,onZero:!0,onZeroAxisIndex:null,lineStyle:{color:Y.color.axisLine,width:1,type:"solid"},symbol:["none","none"],symbolSize:[10,15],breakLine:!0},axisTick:{show:!0,inside:!1,length:5,lineStyle:{width:1}},axisLabel:{show:!0,inside:!1,rotate:0,showMinLabel:null,showMaxLabel:null,margin:8,fontSize:12,color:Y.color.axisLabel,textMargin:[0,3]},splitLine:{show:!0,showMinLine:!0,showMaxLine:!0,lineStyle:{color:Y.color.axisSplitLine,width:1,type:"solid"}},splitArea:{show:!1,areaStyle:{color:[Y.color.backgroundTint,Y.color.backgroundTransparent]}},breakArea:{show:!0,itemStyle:{color:Y.color.neutral00,borderColor:Y.color.border,borderWidth:1,borderType:[3,3],opacity:.6},zigzagAmplitude:4,zigzagMinSpan:4,zigzagMaxSpan:20,zigzagZ:100,expandOnClick:!0},breakLabelLayout:{moveOverlap:"auto"}},zA=vt({boundaryGap:!0,deduplication:null,jitter:0,jitterOverlap:!0,jitterMargin:2,splitLine:{show:!1},axisTick:{alignWithLabel:!1,interval:"auto",show:"auto"},axisLabel:{interval:"auto"}},p_),_v=vt({boundaryGap:[0,0],axisLine:{show:"auto"},axisTick:{show:"auto"},splitNumber:5,minorTick:{show:!1,splitNumber:5,length:3,lineStyle:{}},minorSplitLine:{show:!1,lineStyle:{color:Y.color.axisMinorSplitLine,width:1}}},p_),HA=vt({splitNumber:6,axisLabel:{showMinLabel:!1,showMaxLabel:!1,rich:{primary:{fontWeight:"bold"}}},splitLine:{show:!1}},_v),VA=at({logBase:10},_v);const GA={category:zA,value:_v,time:HA,log:VA};var WA=0,eh=(function(){function r(t){this.categories=t.categories||[],this._needCollect=t.needCollect,this._deduplication=t.deduplication,this.uid=++WA,this._onCollect=t.onCollect}return r.createByAxisModel=function(t){var e=t.option,n=e.data,i=n&&$(n,UA);return new r({categories:i,needCollect:!i,deduplication:e.dedplication!==!1})},r.prototype.getOrdinal=function(t){return this._getOrCreateMap().get(t)},r.prototype.parseAndCollect=function(t){var e,n=this._needCollect;if(!W(t)&&!n)return t;if(n&&!this._deduplication)return e=this.categories.length,this.categories[e]=t,this._onCollect&&this._onCollect(t,e),e;var i=this._getOrCreateMap();return e=i.get(t),e==null&&(n?(e=this.categories.length,this.categories[e]=t,i.set(t,e),this._onCollect&&this._onCollect(t,e)):e=NaN),e},r.prototype._getOrCreateMap=function(){return this._map||(this._map=K(this.categories))},r})();function UA(r){return X(r)&&r.value!=null?r.value:r+""}var YA={value:1,category:1,time:1,log:1},ZA=null;function XA(){return ZA}function Lp(r,t,e,n){D(YA,function(i,a){var o=vt(vt({},GA[a],!0),n,!0),s=(function(l){z(u,l);function u(){var f=l!==null&&l.apply(this,arguments)||this;return f.type=t+"Axis."+a,f}return u.prototype.mergeDefaultAndTheme=function(f,h){var c=Va(this),v=c?no(f):{},d=h.getTheme();vt(f,d.get(a+"Axis")),vt(f,this.getDefaultOption()),f.type=Ip(f),c&&Bn(f,v,c)},u.prototype.optionUpdated=function(){var f=this.option;f.type==="category"&&(this.__ordinalMeta=eh.createByAxisModel(this))},u.prototype.getCategories=function(f){var h=this.option;if(h.type==="category")return f?h.data:this.__ordinalMeta.categories},u.prototype.getOrdinalMeta=function(){return this.__ordinalMeta},u.prototype.updateAxisBreaks=function(f){return{breaks:[]}},u.type=t+"Axis."+a,u.defaultOption=o,u})(e);r.registerComponentModel(s)}),r.registerSubTypeDefaulter(t+"Axis",Ip)}function Ip(r){return r.type||(r.data?"category":"value")}function rh(r){return r.type==="interval"||r.type==="log"}function $A(r,t,e,n,i){var a={},o=a.interval=Pm(t/e);n!=null&&o<n&&(o=a.interval=n),i!=null&&o>i&&(o=a.interval=i);var s=a.intervalPrecision=Za(o),l=a.niceTickExtent=[Nt(Math.ceil(r[0]/o)*o,s),Nt(Math.floor(r[1]/o)*o,s)];return qA(l,r),a}function Ru(r){var t=Math.pow(10,Ah(r)),e=r/t;return e?e===2?e=3:e===3?e=5:e*=2:e=1,Nt(e*t)}function Za(r){return or(r)+2}function Pp(r,t,e){r[t]=Math.max(Math.min(r[t],e[1]),e[0])}function qA(r,t){!isFinite(r[0])&&(r[0]=t[0]),!isFinite(r[1])&&(r[1]=t[1]),Pp(r,0,t),Pp(r,1,t),r[0]>r[1]&&(r[0]=r[1])}function Sv(r,t){return r>=t[0]&&r<=t[1]}var KA=(function(){function r(){this.normalize=Rp,this.scale=Ep}return r.prototype.updateMethods=function(t){t.hasBreaks()?(this.normalize=Q(t.normalize,t),this.scale=Q(t.scale,t)):(this.normalize=Rp,this.scale=Ep)},r})();function Rp(r,t){return t[1]===t[0]?.5:(r-t[0])/(t[1]-t[0])}function Ep(r,t){return r*(t[1]-t[0])+t[0]}function nh(r,t,e){var n=Math.log(r);return[Math.log(e?t[0]:Math.max(0,t[0]))/n,Math.log(e?t[1]:Math.max(0,t[1]))/n]}var Ur=(function(){function r(t){this._calculator=new KA,this._setting=t||{},this._extent=[1/0,-1/0]}return r.prototype.getSetting=function(t){return this._setting[t]},r.prototype._innerUnionExtent=function(t){var e=this._extent;this._innerSetExtent(t[0]<e[0]?t[0]:e[0],t[1]>e[1]?t[1]:e[1])},r.prototype.unionExtentFromData=function(t,e){this._innerUnionExtent(t.getApproximateExtent(e))},r.prototype.getExtent=function(){return this._extent.slice()},r.prototype.setExtent=function(t,e){this._innerSetExtent(t,e)},r.prototype._innerSetExtent=function(t,e){var n=this._extent;isNaN(t)||(n[0]=t),isNaN(e)||(n[1]=e),this._brkCtx&&this._brkCtx.update(n)},r.prototype.setBreaksFromOption=function(t){},r.prototype._innerSetBreak=function(t){this._brkCtx&&(this._brkCtx.setBreaks(t),this._calculator.updateMethods(this._brkCtx),this._brkCtx.update(this._extent))},r.prototype._innerGetBreaks=function(){return this._brkCtx?this._brkCtx.breaks:[]},r.prototype.hasBreaks=function(){return this._brkCtx?this._brkCtx.hasBreaks():!1},r.prototype._getExtentSpanWithBreaks=function(){return this._brkCtx&&this._brkCtx.hasBreaks()?this._brkCtx.getExtentSpan():this._extent[1]-this._extent[0]},r.prototype.isInExtentRange=function(t){return this._extent[0]<=t&&this._extent[1]>=t},r.prototype.isBlank=function(){return this._isBlank},r.prototype.setBlank=function(t){this._isBlank=t},r})();el(Ur);var g_=(function(r){z(t,r);function t(e){var n=r.call(this,e)||this;n.type="ordinal";var i=n.getSetting("ordinalMeta");return i||(i=new eh({})),H(i)&&(i=new eh({categories:$(i,function(a){return X(a)?a.value:a})})),n._ordinalMeta=i,n._extent=n.getSetting("extent")||[0,i.categories.length-1],n}return t.prototype.parse=function(e){return e==null?NaN:W(e)?this._ordinalMeta.getOrdinal(e):Math.round(e)},t.prototype.contain=function(e){return Sv(e,this._extent)&&e>=0&&e<this._ordinalMeta.categories.length},t.prototype.normalize=function(e){return e=this._getTickNumber(e),this._calculator.normalize(e,this._extent)},t.prototype.scale=function(e){return e=Math.round(this._calculator.scale(e,this._extent)),this.getRawOrdinalNumber(e)},t.prototype.getTicks=function(){for(var e=[],n=this._extent,i=n[0];i<=n[1];)e.push({value:i}),i++;return e},t.prototype.getMinorTicks=function(e){},t.prototype.setSortInfo=function(e){if(e==null){this._ordinalNumbersByTick=this._ticksByOrdinalNumber=null;return}for(var n=e.ordinalNumbers,i=this._ordinalNumbersByTick=[],a=this._ticksByOrdinalNumber=[],o=0,s=this._ordinalMeta.categories.length,l=Math.min(s,n.length);o<l;++o){var u=n[o];i[o]=u,a[u]=o}for(var f=0;o<s;++o){for(;a[f]!=null;)f++;i.push(f),a[f]=o}},t.prototype._getTickNumber=function(e){var n=this._ticksByOrdinalNumber;return n&&e>=0&&e<n.length?n[e]:e},t.prototype.getRawOrdinalNumber=function(e){var n=this._ordinalNumbersByTick;return n&&e>=0&&e<n.length?n[e]:e},t.prototype.getLabel=function(e){if(!this.isBlank()){var n=this.getRawOrdinalNumber(e.value),i=this._ordinalMeta.categories[n];return i==null?"":i+""}},t.prototype.count=function(){return this._extent[1]-this._extent[0]+1},t.prototype.isInExtentRange=function(e){return e=this._getTickNumber(e),this._extent[0]<=e&&this._extent[1]>=e},t.prototype.getOrdinalMeta=function(){return this._ordinalMeta},t.prototype.calcNiceTicks=function(){},t.prototype.calcNiceExtent=function(){},t.type="ordinal",t})(Ur);Ur.registerClass(g_);var xr=Nt,Ii=(function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type="interval",e._interval=0,e._intervalPrecision=2,e}return t.prototype.parse=function(e){return e==null||e===""?NaN:Number(e)},t.prototype.contain=function(e){return Sv(e,this._extent)},t.prototype.normalize=function(e){return this._calculator.normalize(e,this._extent)},t.prototype.scale=function(e){return this._calculator.scale(e,this._extent)},t.prototype.getInterval=function(){return this._interval},t.prototype.setInterval=function(e){this._interval=e,this._niceExtent=this._extent.slice(),this._intervalPrecision=Za(e)},t.prototype.getTicks=function(e){e=e||{};var n=this._interval,i=this._extent,a=this._niceExtent,o=this._intervalPrecision,s=Is(),l=[];if(!n)return l;e.breakTicks;var u=1e4;i[0]<a[0]&&(e.expandToNicedExtent?l.push({value:xr(a[0]-n,o)}):l.push({value:i[0]}));for(var f=function(d,p){return Math.round((p-d)/n)},h=a[0];h<=a[1];){if(l.push({value:h}),h=xr(h+n,o),this._brkCtx){var c=this._brkCtx.calcNiceTickMultiple(h,f);c>=0&&(h=xr(h+c*n,o))}if(l.length>0&&h===l[l.length-1].value)break;if(l.length>u)return[]}var v=l.length?l[l.length-1].value:a[1];return i[1]>v&&(e.expandToNicedExtent?l.push({value:xr(v+n,o)}):l.push({value:i[1]})),e.breakTicks,l},t.prototype.getMinorTicks=function(e){for(var n=this.getTicks({expandToNicedExtent:!0}),i=[],a=this.getExtent(),o=1;o<n.length;o++){var s=n[o],l=n[o-1];if(!(l.break||s.break)){for(var u=0,f=[],h=s.value-l.value,c=h/e,v=Za(c);u<e-1;){var d=xr(l.value+(u+1)*c,v);d>a[0]&&d<a[1]&&f.push(d),u++}var p=Is();p&&p.pruneTicksByBreak("auto",f,this._getNonTransBreaks(),function(g){return g},this._interval,a),i.push(f)}}return i},t.prototype._getNonTransBreaks=function(){return this._brkCtx?this._brkCtx.breaks:[]},t.prototype.getLabel=function(e,n){if(e==null)return"";var i=n&&n.precision;i==null?i=or(e.value)||0:i==="auto"&&(i=this._intervalPrecision);var a=xr(e.value,i,!0);return t0(a)},t.prototype.calcNiceTicks=function(e,n,i){e=e||5;var a=this._extent.slice(),o=this._getExtentSpanWithBreaks();if(isFinite(o)){o<0&&(o=-o,a.reverse(),this._innerSetExtent(a[0],a[1]),a=this._extent.slice());var s=$A(a,o,e,n,i);this._intervalPrecision=s.intervalPrecision,this._interval=s.interval,this._niceExtent=s.niceTickExtent}},t.prototype.calcNiceExtent=function(e){var n=this._extent.slice();if(n[0]===n[1])if(n[0]!==0){var i=Math.abs(n[0]);e.fixMax||(n[1]+=i/2),n[0]-=i/2}else n[1]=1;var a=n[1]-n[0];isFinite(a)||(n[0]=0,n[1]=1),this._innerSetExtent(n[0],n[1]),n=this._extent.slice(),this.calcNiceTicks(e.splitNumber,e.minInterval,e.maxInterval);var o=this._interval,s=this._intervalPrecision;e.fixMin||(n[0]=xr(Math.floor(n[0]/o)*o,s)),e.fixMax||(n[1]=xr(Math.ceil(n[1]/o)*o,s)),this._innerSetExtent(n[0],n[1])},t.prototype.setNiceExtent=function(e,n){this._niceExtent=[e,n]},t.type="interval",t})(Ur);Ur.registerClass(Ii);var QA=function(r,t,e,n){for(;e<n;){var i=e+n>>>1;r[i][1]<t?e=i+1:n=i}return e},m_=(function(r){z(t,r);function t(e){var n=r.call(this,e)||this;return n.type="time",n}return t.prototype.getLabel=function(e){var n=this.getSetting("useUTC");return yl(e.value,od[AT(Ma(this._minLevelUnit))]||od.second,n,this.getSetting("locale"))},t.prototype.getFormattedLabel=function(e,n,i){var a=this.getSetting("useUTC"),o=this.getSetting("locale");return LT(e,n,i,o,a)},t.prototype.getTicks=function(e){var n=this._interval,i=this._extent,a=[];if(!n)return a;var o=this.getSetting("useUTC"),s=Ps(i[1],o);a.push({value:i[0],time:{level:0,upperTimeUnit:s,lowerTimeUnit:s}});var l=aL(this._minLevelUnit,this._approxInterval,o,i,this._getExtentSpanWithBreaks(),this._brkCtx);a=a.concat(l);var u=Ps(i[1],o);a.push({value:i[1],time:{level:0,upperTimeUnit:u,lowerTimeUnit:u}}),this.getSetting("useUTC");var f=Pn.length-1,h=0;return D(a,function(c){f=Math.min(f,ft(Pn,c.time.upperTimeUnit)),h=Math.max(h,c.time.level)}),a},t.prototype.calcNiceExtent=function(e){var n=this.getExtent();if(n[0]===n[1]&&(n[0]-=we,n[1]+=we),n[1]===-1/0&&n[0]===1/0){var i=new Date;n[1]=+new Date(i.getFullYear(),i.getMonth(),i.getDate()),n[0]=n[1]-we}this._innerSetExtent(n[0],n[1]),this.calcNiceTicks(e.splitNumber,e.minInterval,e.maxInterval)},t.prototype.calcNiceTicks=function(e,n,i){e=e||10;var a=this._getExtentSpanWithBreaks();this._approxInterval=a/e,n!=null&&this._approxInterval<n&&(this._approxInterval=n),i!=null&&this._approxInterval>i&&(this._approxInterval=i);var o=Ho.length,s=Math.min(QA(Ho,this._approxInterval,0,o),o-1);this._interval=Ho[s][1],this._intervalPrecision=Za(this._interval),this._minLevelUnit=Ho[Math.max(s-1,0)][0]},t.prototype.parse=function(e){return mt(e)?e:+Ni(e)},t.prototype.contain=function(e){return Sv(e,this._extent)},t.prototype.normalize=function(e){return this._calculator.normalize(e,this._extent)},t.prototype.scale=function(e){return this._calculator.scale(e,this._extent)},t.type="time",t})(Ii),Ho=[["second",Qh],["minute",jh],["hour",Ta],["quarter-day",Ta*6],["half-day",Ta*12],["day",we*1.2],["half-week",we*3.5],["week",we*7],["month",we*31],["quarter",we*95],["half-year",ad/2],["year",ad]];function jA(r,t,e,n){return Of(new Date(t),r,n).getTime()===Of(new Date(e),r,n).getTime()}function JA(r,t){return r/=we,r>16?16:r>7.5?7:r>3.5?4:r>1.5?2:1}function tL(r){var t=30*we;return r/=t,r>6?6:r>3?3:r>2?2:1}function eL(r){return r/=Ta,r>12?12:r>6?6:r>3.5?4:r>2?2:1}function kp(r,t){return r/=t?jh:Qh,r>30?30:r>20?20:r>15?15:r>10?10:r>5?5:r>2?2:1}function rL(r){return Pm(r)}function nL(r,t,e){var n=Math.max(0,ft(Pn,t)-1);return Of(new Date(r),Pn[n],e).getTime()}function iL(r,t){var e=new Date(0);e[r](1);var n=e.getTime();e[r](1+t);var i=e.getTime()-n;return function(a,o){return Math.max(0,Math.round((o-a)/i))}}function aL(r,t,e,n,i,a){var o=1e4,s=TT,l=0;function u(L,I,R,E,V,B,k){for(var G=iL(V,L),U=I,Z=new Date(U);U<R&&U<=n[1]&&(k.push({value:U}),!(l++>o));)if(Z[V](Z[E]()+L),U=Z.getTime(),a){var j=a.calcNiceTickMultiple(U,G);j>0&&(Z[V](Z[E]()+j*L),U=Z.getTime())}k.push({value:U,notAdd:!0})}function f(L,I,R){var E=[],V=!I.length;if(!jA(Ma(L),n[0],n[1],e)){V&&(I=[{value:nL(n[0],L,e)},{value:n[1]}]);for(var B=0;B<I.length-1;B++){var k=I[B].value,G=I[B+1].value;if(k!==G){var U=void 0,Z=void 0,j=void 0,ot=!1;switch(L){case"year":U=Math.max(1,Math.round(t/we/365)),Z=Xy(e),j=IT(e);break;case"half-year":case"quarter":case"month":U=tL(t),Z=Jh(e),j=$y(e);break;case"week":case"half-week":case"day":U=JA(t),Z=tv(e),j=qy(e),ot=!0;break;case"half-day":case"quarter-day":case"hour":U=eL(t),Z=ev(e),j=Ky(e);break;case"minute":U=kp(t,!0),Z=rv(e),j=Qy(e);break;case"second":U=kp(t,!1),Z=nv(e),j=jy(e);break;case"millisecond":U=rL(t),Z=iv(e),j=Jy(e);break}G>=n[0]&&k<=n[1]&&u(U,k,G,Z,j,ot,E),L==="year"&&R.length>1&&B===0&&R.unshift({value:R[0].value-U})}}for(var B=0;B<E.length;B++)R.push(E[B])}}for(var h=[],c=[],v=0,d=0,p=0;p<s.length;++p){var g=Ma(s[p]);if(DT(s[p])){f(s[p],h[h.length-1]||[],c);var m=s[p+1]?Ma(s[p+1]):null;if(g!==m){if(c.length){d=v,c.sort(function(L,I){return L.value-I.value});for(var y=[],_=0;_<c.length;++_){var S=c[_].value;(_===0||c[_-1].value!==S)&&(y.push(c[_]),S>=n[0]&&S<=n[1]&&v++)}var w=i/t;if(v>w*1.5&&d>w/1.5||(h.push(y),v>w||r===s[p]))break}c=[]}}}for(var b=wt($(h,function(L){return wt(L,function(I){return I.value>=n[0]&&I.value<=n[1]&&!I.notAdd})}),function(L){return L.length>0}),T=[],C=b.length-1,p=0;p<b.length;++p)for(var x=b[p],M=0;M<x.length;++M){var A=Ps(x[M].value,e);T.push({value:x[M].value,time:{level:C-p,upperTimeUnit:A,lowerTimeUnit:A}})}T.sort(function(L,I){return L.value-I.value});for(var P=[],p=0;p<T.length;++p)(p===0||T[p].value!==T[p-1].value)&&P.push(T[p]);return P}Ur.registerClass(m_);var ih=Nt,oL=Math.floor,sL=Math.ceil,Vo=Math.pow,Go=Math.log,y_=(function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type="log",e.base=10,e._originalScale=new Ii,e}return t.prototype.getTicks=function(e){e=e||{};var n=this._extent.slice(),i=this._originalScale.getExtent(),a=r.prototype.getTicks.call(this,e),o=this.base;return this._originalScale._innerGetBreaks(),$(a,function(s){var l=s.value,u=null,f=Vo(o,l);l===n[0]&&this._fixMin?u=i[0]:l===n[1]&&this._fixMax&&(u=i[1]);var h;return u!=null&&(f=Eu(f,u)),{value:f,break:h}},this)},t.prototype._getNonTransBreaks=function(){return this._originalScale._innerGetBreaks()},t.prototype.setExtent=function(e,n){this._originalScale.setExtent(e,n);var i=nh(this.base,[e,n]);r.prototype.setExtent.call(this,i[0],i[1])},t.prototype.getExtent=function(){var e=this.base,n=r.prototype.getExtent.call(this);n[0]=Vo(e,n[0]),n[1]=Vo(e,n[1]);var i=this._originalScale.getExtent();return this._fixMin&&(n[0]=Eu(n[0],i[0])),this._fixMax&&(n[1]=Eu(n[1],i[1])),n},t.prototype.unionExtentFromData=function(e,n){this._originalScale.unionExtentFromData(e,n);var i=nh(this.base,e.getApproximateExtent(n),!0);this._innerUnionExtent(i)},t.prototype.calcNiceTicks=function(e){e=e||10;var n=this._extent.slice(),i=this._getExtentSpanWithBreaks();if(!(!isFinite(i)||i<=0)){var a=xb(i),o=e/i*a;for(o<=.5&&(a*=10);!isNaN(a)&&Math.abs(a)<1&&Math.abs(a)>0;)a*=10;var s=[ih(sL(n[0]/a)*a),ih(oL(n[1]/a)*a)];this._interval=a,this._intervalPrecision=Za(a),this._niceExtent=s}},t.prototype.calcNiceExtent=function(e){r.prototype.calcNiceExtent.call(this,e),this._fixMin=e.fixMin,this._fixMax=e.fixMax},t.prototype.contain=function(e){return e=Go(e)/Go(this.base),r.prototype.contain.call(this,e)},t.prototype.normalize=function(e){return e=Go(e)/Go(this.base),r.prototype.normalize.call(this,e)},t.prototype.scale=function(e){return e=r.prototype.scale.call(this,e),Vo(this.base,e)},t.prototype.setBreaksFromOption=function(e){},t.type="log",t})(Ii);function Eu(r,t){return ih(r,or(t))}Ur.registerClass(y_);var lL=(function(){function r(t,e,n){this._prepareParams(t,e,n)}return r.prototype._prepareParams=function(t,e,n){n[1]<n[0]&&(n=[NaN,NaN]),this._dataMin=n[0],this._dataMax=n[1];var i=this._isOrdinal=t.type==="ordinal";this._needCrossZero=t.type==="interval"&&e.getNeedCrossZero&&e.getNeedCrossZero();var a=e.get("min",!0);a==null&&(a=e.get("startValue",!0));var o=this._modelMinRaw=a;et(o)?this._modelMinNum=Wo(t,o({min:n[0],max:n[1]})):o!=="dataMin"&&(this._modelMinNum=Wo(t,o));var s=this._modelMaxRaw=e.get("max",!0);if(et(s)?this._modelMaxNum=Wo(t,s({min:n[0],max:n[1]})):s!=="dataMax"&&(this._modelMaxNum=Wo(t,s)),i)this._axisDataLen=e.getCategories().length;else{var l=e.get("boundaryGap"),u=H(l)?l:[l||0,l||0];typeof u[0]=="boolean"||typeof u[1]=="boolean"?this._boundaryGapInner=[0,0]:this._boundaryGapInner=[En(u[0],1),En(u[1],1)]}},r.prototype.calculate=function(){var t=this._isOrdinal,e=this._dataMin,n=this._dataMax,i=this._axisDataLen,a=this._boundaryGapInner,o=t?null:n-e||Math.abs(e),s=this._modelMinRaw==="dataMin"?e:this._modelMinNum,l=this._modelMaxRaw==="dataMax"?n:this._modelMaxNum,u=s!=null,f=l!=null;s==null&&(s=t?i?0:NaN:e-a[0]*o),l==null&&(l=t?i?i-1:NaN:n+a[1]*o),(s==null||!isFinite(s))&&(s=NaN),(l==null||!isFinite(l))&&(l=NaN);var h=Pa(s)||Pa(l)||t&&!i;this._needCrossZero&&(s>0&&l>0&&!u&&(s=0),s<0&&l<0&&!f&&(l=0));var c=this._determinedMin,v=this._determinedMax;return c!=null&&(s=c,u=!0),v!=null&&(l=v,f=!0),{min:s,max:l,minFixed:u,maxFixed:f,isBlank:h}},r.prototype.modifyDataMinMax=function(t,e){this[fL[t]]=e},r.prototype.setDeterminedMinMax=function(t,e){var n=uL[t];this[n]=e},r.prototype.freeze=function(){this.frozen=!0},r})(),uL={min:"_determinedMin",max:"_determinedMax"},fL={min:"_dataMin",max:"_dataMax"};function __(r,t,e){var n=r.rawExtentInfo;return n||(n=new lL(r,t,e),r.rawExtentInfo=n,n)}function Wo(r,t){return t==null?null:Pa(t)?NaN:r.parse(t)}function S_(r,t){var e=r.type,n=__(r,t,r.getExtent()).calculate();r.setBlank(n.isBlank);var i=n.min,a=n.max,o=t.ecModel;if(o&&e==="time"){var s=aC("bar",o),l=!1;if(D(s,function(h){l=l||h.getBaseAxis()===t.axis}),l){var u=sC(s),f=hL(i,a,t,u);i=f.min,a=f.max}}return{extent:[i,a],fixMin:n.minFixed,fixMax:n.maxFixed}}function hL(r,t,e,n){var i=e.axis.getExtent(),a=Math.abs(i[1]-i[0]),o=uC(n,e.axis);if(o===void 0)return{min:r,max:t};var s=1/0;D(o,function(v){s=Math.min(v.offset,s)});var l=-1/0;D(o,function(v){l=Math.max(v.offset+v.width,l)}),s=Math.abs(s),l=Math.abs(l);var u=s+l,f=t-r,h=1-(s+l)/a,c=f/h-f;return t+=c*(l/u),r-=c*(s/u),{min:r,max:t}}function Op(r,t){var e=t,n=S_(r,e),i=n.extent,a=e.get("splitNumber");r instanceof y_&&(r.base=e.get("logBase"));var o=r.type,s=e.get("interval"),l=o==="interval"||o==="time";r.setBreaksFromOption(x_(e)),r.setExtent(i[0],i[1]),r.calcNiceExtent({splitNumber:a,fixMin:n.fixMin,fixMax:n.fixMax,minInterval:l?e.get("minInterval"):null,maxInterval:l?e.get("maxInterval"):null}),s!=null&&r.setInterval&&r.setInterval(s)}function vL(r,t){if(t=t||r.get("type"),t)switch(t){case"category":return new g_({ordinalMeta:r.getOrdinalMeta?r.getOrdinalMeta():r.getCategories(),extent:[1/0,-1/0]});case"time":return new m_({locale:r.ecModel.getLocaleModel(),useUTC:r.ecModel.get("useUTC")});default:return new(Ur.getClass(t)||Ii)}}function cL(r){var t=r.scale.getExtent(),e=t[0],n=t[1];return!(e>0&&n>0||e<0&&n<0)}function io(r){var t=r.getLabelModel().get("formatter");if(r.type==="time"){var e=MT(t);return function(i,a){return r.scale.getFormattedLabel(i,a,e)}}else{if(W(t))return function(i){var a=r.scale.getLabel(i),o=t.replace("{value}",a??"");return o};if(et(t)){if(r.type==="category")return function(i,a){return t(Us(r,i),i.value-r.scale.getExtent()[0],null)};var n=Is();return function(i,a){var o=null;return n&&(o=n.makeAxisLabelFormatterParamBreak(o,i.break)),t(Us(r,i),a,o)}}else return function(i){return r.scale.getLabel(i)}}}function Us(r,t){return r.type==="category"?r.scale.getLabel(t):t.value}function bv(r){var t=r.get("interval");return t??"auto"}function b_(r){return r.type==="category"&&bv(r.getLabelModel())===0}function w_(r,t){var e={};return D(r.mapDimensionsAll(t),function(n){e[tT(r,n)]=!0}),St(e)}function dL(r,t,e){t&&D(w_(t,e),function(n){var i=t.getApproximateExtent(n);i[0]<r[0]&&(r[0]=i[0]),i[1]>r[1]&&(r[1]=i[1])})}function Pi(r){return r==="middle"||r==="center"}function Xa(r){return r.getShallow("show")}function x_(r){var t=r.get("breaks",!0);t==null}var pL=(function(){function r(t){this.type="cartesian",this._dimList=[],this._axes={},this.name=t||""}return r.prototype.getAxis=function(t){return this._axes[t]},r.prototype.getAxes=function(){return $(this._dimList,function(t){return this._axes[t]},this)},r.prototype.getAxesByScale=function(t){return t=t.toLowerCase(),wt(this.getAxes(),function(e){return e.scale.type===t})},r.prototype.addAxis=function(t){var e=t.dim;this._axes[e]=t,this._dimList.push(e)},r})(),ah=["x","y"];function Bp(r){return(r.type==="interval"||r.type==="time")&&!r.hasBreaks()}var gL=(function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type="cartesian2d",e.dimensions=ah,e}return t.prototype.calcAffineTransform=function(){this._transform=this._invTransform=null;var e=this.getAxis("x").scale,n=this.getAxis("y").scale;if(!(!Bp(e)||!Bp(n))){var i=e.getExtent(),a=n.getExtent(),o=this.dataToPoint([i[0],a[0]]),s=this.dataToPoint([i[1],a[1]]),l=i[1]-i[0],u=a[1]-a[0];if(!(!l||!u)){var f=(s[0]-o[0])/l,h=(s[1]-o[1])/u,c=o[0]-i[0]*f,v=o[1]-a[0]*h,d=this._transform=[f,0,0,h,c,v];this._invTransform=ki([],d)}}},t.prototype.getBaseAxis=function(){return this.getAxesByScale("ordinal")[0]||this.getAxesByScale("time")[0]||this.getAxis("x")},t.prototype.containPoint=function(e){var n=this.getAxis("x"),i=this.getAxis("y");return n.contain(n.toLocalCoord(e[0]))&&i.contain(i.toLocalCoord(e[1]))},t.prototype.containData=function(e){return this.getAxis("x").containData(e[0])&&this.getAxis("y").containData(e[1])},t.prototype.containZone=function(e,n){var i=this.dataToPoint(e),a=this.dataToPoint(n),o=this.getArea(),s=new it(i[0],i[1],a[0]-i[0],a[1]-i[1]);return o.intersect(s)},t.prototype.dataToPoint=function(e,n,i){i=i||[];var a=e[0],o=e[1];if(this._transform&&a!=null&&isFinite(a)&&o!=null&&isFinite(o))return xe(i,e,this._transform);var s=this.getAxis("x"),l=this.getAxis("y");return i[0]=s.toGlobalCoord(s.dataToCoord(a,n)),i[1]=l.toGlobalCoord(l.dataToCoord(o,n)),i},t.prototype.clampData=function(e,n){var i=this.getAxis("x").scale,a=this.getAxis("y").scale,o=i.getExtent(),s=a.getExtent(),l=i.parse(e[0]),u=a.parse(e[1]);return n=n||[],n[0]=Math.min(Math.max(Math.min(o[0],o[1]),l),Math.max(o[0],o[1])),n[1]=Math.min(Math.max(Math.min(s[0],s[1]),u),Math.max(s[0],s[1])),n},t.prototype.pointToData=function(e,n,i){if(i=i||[],this._invTransform)return xe(i,e,this._invTransform);var a=this.getAxis("x"),o=this.getAxis("y");return i[0]=a.coordToData(a.toLocalCoord(e[0]),n),i[1]=o.coordToData(o.toLocalCoord(e[1]),n),i},t.prototype.getOtherAxis=function(e){return this.getAxis(e.dim==="x"?"y":"x")},t.prototype.getArea=function(e){e=e||0;var n=this.getAxis("x").getGlobalExtent(),i=this.getAxis("y").getGlobalExtent(),a=Math.min(n[0],n[1])-e,o=Math.min(i[0],i[1])-e,s=Math.max(n[0],n[1])-a+e,l=Math.max(i[0],i[1])-o+e;return new it(a,o,s,l)},t})(pL),mL=gt(),Aa=gt(),Ee={estimate:1,determine:2};function Ys(r){return{out:{noPxChangeTryDetermine:[]},kind:r}}function T_(r,t){var e=$(t,function(n){return r.scale.parse(n)});return r.type==="time"&&e.length>0&&(e.sort(),e.unshift(e[0]),e.push(e[e.length-1])),e}function yL(r,t){var e=r.getLabelModel().get("customValues");if(e){var n=io(r),i=r.scale.getExtent(),a=T_(r,e),o=wt(a,function(s){return s>=i[0]&&s<=i[1]});return{labels:$(o,function(s){var l={value:s};return{formattedLabel:n(l),rawLabel:r.scale.getLabel(l),tickValue:s,time:void 0,break:void 0}})}}return r.type==="category"?SL(r,t):wL(r)}function _L(r,t,e){var n=r.getTickModel().get("customValues");if(n){var i=r.scale.getExtent(),a=T_(r,n);return{ticks:wt(a,function(o){return o>=i[0]&&o<=i[1]})}}return r.type==="category"?bL(r,t):{ticks:$(r.scale.getTicks(e),function(o){return o.value})}}function SL(r,t){var e=r.getLabelModel(),n=M_(r,e,t);return!e.get("show")||r.scale.isBlank()?{labels:[]}:n}function M_(r,t,e){var n=TL(r),i=bv(t),a=e.kind===Ee.estimate;if(!a){var o=D_(n,i);if(o)return o}var s,l;et(i)?s=I_(r,i):(l=i==="auto"?ML(r,e):i,s=L_(r,l));var u={labels:s,labelCategoryInterval:l};return a?e.out.noPxChangeTryDetermine.push(function(){return oh(n,i,u),!0}):oh(n,i,u),u}function bL(r,t){var e=xL(r),n=bv(t),i=D_(e,n);if(i)return i;var a,o;if((!t.get("show")||r.scale.isBlank())&&(a=[]),et(n))a=I_(r,n,!0);else if(n==="auto"){var s=M_(r,r.getLabelModel(),Ys(Ee.determine));o=s.labelCategoryInterval,a=$(s.labels,function(l){return l.tickValue})}else o=n,a=L_(r,o,!0);return oh(e,n,{ticks:a,tickCategoryInterval:o})}function wL(r){var t=r.scale.getTicks(),e=io(r);return{labels:$(t,function(n,i){return{formattedLabel:e(n,i),rawLabel:r.scale.getLabel(n),tickValue:n.value,time:n.time,break:n.break}})}}var xL=C_("axisTick"),TL=C_("axisLabel");function C_(r){return function(e){return Aa(e)[r]||(Aa(e)[r]={list:[]})}}function D_(r,t){for(var e=0;e<r.list.length;e++)if(r.list[e].key===t)return r.list[e].value}function oh(r,t,e){return r.list.push({key:t,value:e}),e}function ML(r,t){if(t.kind===Ee.estimate){var e=r.calculateCategoryInterval(t);return t.out.noPxChangeTryDetermine.push(function(){return Aa(r).autoInterval=e,!0}),e}var n=Aa(r).autoInterval;return n??(Aa(r).autoInterval=r.calculateCategoryInterval(t))}function CL(r,t){var e=t.kind,n=AL(r),i=io(r),a=(n.axisRotate-n.labelRotate)/180*Math.PI,o=r.scale,s=o.getExtent(),l=o.count();if(s[1]-s[0]<1)return 0;var u=1,f=40;l>f&&(u=Math.max(1,Math.floor(l/f)));for(var h=s[0],c=r.dataToCoord(h+1)-r.dataToCoord(h),v=Math.abs(c*Math.cos(a)),d=Math.abs(c*Math.sin(a)),p=0,g=0;h<=s[1];h+=u){var m=0,y=0,_=om(i({value:h}),n.font,"center","top");m=_.width*1.3,y=_.height*1.3,p=Math.max(p,m,7),g=Math.max(g,y,7)}var S=p/v,w=g/d;isNaN(S)&&(S=1/0),isNaN(w)&&(w=1/0);var b=Math.max(0,Math.floor(Math.min(S,w)));if(e===Ee.estimate)return t.out.noPxChangeTryDetermine.push(Q(DL,null,r,b,l)),b;var T=A_(r,b,l);return T??b}function DL(r,t,e){return A_(r,t,e)==null}function A_(r,t,e){var n=mL(r.model),i=r.getExtent(),a=n.lastAutoInterval,o=n.lastTickCount;if(a!=null&&o!=null&&Math.abs(a-t)<=1&&Math.abs(o-e)<=1&&a>t&&n.axisExtent0===i[0]&&n.axisExtent1===i[1])return a;n.lastTickCount=e,n.lastAutoInterval=t,n.axisExtent0=i[0],n.axisExtent1=i[1]}function AL(r){var t=r.getLabelModel();return{axisRotate:r.getRotate?r.getRotate():r.isHorizontal&&!r.isHorizontal()?90:0,labelRotate:t.get("rotate")||0,font:t.getFont()}}function L_(r,t,e){var n=io(r),i=r.scale,a=i.getExtent(),o=r.getLabelModel(),s=[],l=Math.max((t||0)+1,1),u=a[0],f=i.count();u!==0&&l>1&&f/l>2&&(u=Math.round(Math.ceil(u/l)*l));var h=b_(r),c=o.get("showMinLabel")||h,v=o.get("showMaxLabel")||h;c&&u!==a[0]&&p(a[0]);for(var d=u;d<=a[1];d+=l)p(d);v&&d-l!==a[1]&&p(a[1]);function p(g){var m={value:g};s.push(e?g:{formattedLabel:n(m),rawLabel:i.getLabel(m),tickValue:g,time:void 0,break:void 0})}return s}function I_(r,t,e){var n=r.scale,i=io(r),a=[];return D(n.getTicks(),function(o){var s=n.getLabel(o),l=o.value;t(o.value,s)&&a.push(e?l:{formattedLabel:i(o),rawLabel:s,tickValue:l,time:void 0,break:void 0})}),a}var Np=[0,1],LL=(function(){function r(t,e,n){this.onBand=!1,this.inverse=!1,this.dim=t,this.scale=e,this._extent=n||[0,0]}return r.prototype.contain=function(t){var e=this._extent,n=Math.min(e[0],e[1]),i=Math.max(e[0],e[1]);return t>=n&&t<=i},r.prototype.containData=function(t){return this.scale.contain(this.scale.parse(t))},r.prototype.getExtent=function(){return this._extent.slice()},r.prototype.getPixelPrecision=function(t){return Lm(t||this.scale.getExtent(),this._extent)},r.prototype.setExtent=function(t,e){var n=this._extent;n[0]=t,n[1]=e},r.prototype.dataToCoord=function(t,e){var n=this._extent,i=this.scale;return t=i.normalize(i.parse(t)),this.onBand&&i.type==="ordinal"&&(n=n.slice(),Fp(n,i.count())),Et(t,Np,n,e)},r.prototype.coordToData=function(t,e){var n=this._extent,i=this.scale;this.onBand&&i.type==="ordinal"&&(n=n.slice(),Fp(n,i.count()));var a=Et(t,n,Np,e);return this.scale.scale(a)},r.prototype.pointToData=function(t,e){},r.prototype.getTicksCoords=function(t){t=t||{};var e=t.tickModel||this.getTickModel(),n=_L(this,e,{breakTicks:t.breakTicks,pruneByBreak:t.pruneByBreak}),i=n.ticks,a=$(i,function(s){return{coord:this.dataToCoord(this.scale.type==="ordinal"?this.scale.getRawOrdinalNumber(s):s),tickValue:s}},this),o=e.get("alignWithLabel");return IL(this,a,o,t.clamp),a},r.prototype.getMinorTicksCoords=function(){if(this.scale.type==="ordinal")return[];var t=this.model.getModel("minorTick"),e=t.get("splitNumber");e>0&&e<100||(e=5);var n=this.scale.getMinorTicks(e),i=$(n,function(a){return $(a,function(o){return{coord:this.dataToCoord(o),tickValue:o}},this)},this);return i},r.prototype.getViewLabels=function(t){return t=t||Ys(Ee.determine),yL(this,t).labels},r.prototype.getLabelModel=function(){return this.model.getModel("axisLabel")},r.prototype.getTickModel=function(){return this.model.getModel("axisTick")},r.prototype.getBandWidth=function(){var t=this._extent,e=this.scale.getExtent(),n=e[1]-e[0]+(this.onBand?1:0);n===0&&(n=1);var i=Math.abs(t[1]-t[0]);return Math.abs(i)/n},r.prototype.calculateCategoryInterval=function(t){return t=t||Ys(Ee.determine),CL(this,t)},r})();function Fp(r,t){var e=r[1]-r[0],n=t,i=e/n/2;r[0]+=i,r[1]-=i}function IL(r,t,e,n){var i=t.length;if(!r.onBand||e||!i)return;var a=r.getExtent(),o,s;if(i===1)t[0].coord=a[0],t[0].onBand=!0,o=t[1]={coord:a[1],tickValue:t[0].tickValue,onBand:!0};else{var l=t[i-1].tickValue-t[0].tickValue,u=(t[i-1].coord-t[0].coord)/l;D(t,function(v){v.coord-=u/2,v.onBand=!0});var f=r.scale.getExtent();s=1+f[1]-t[i-1].tickValue,o={coord:t[i-1].coord+u*s,tickValue:f[1]+1,onBand:!0},t.push(o)}var h=a[0]>a[1];c(t[0].coord,a[0])&&(n?t[0].coord=a[0]:t.shift()),n&&c(a[0],t[0].coord)&&t.unshift({coord:a[0],onBand:!0}),c(a[1],o.coord)&&(n?o.coord=a[1]:t.pop()),n&&c(o.coord,a[1])&&t.push({coord:a[1],onBand:!0});function c(v,d){return v=Nt(v),d=Nt(d),h?v>d:v<d}}var PL=(function(r){z(t,r);function t(e,n,i,a,o){var s=r.call(this,e,n,i)||this;return s.index=0,s.type=a||"value",s.position=o||"bottom",s}return t.prototype.isHorizontal=function(){var e=this.position;return e==="top"||e==="bottom"},t.prototype.getGlobalExtent=function(e){var n=this.getExtent();return n[0]=this.toGlobalCoord(n[0]),n[1]=this.toGlobalCoord(n[1]),e&&n[0]>n[1]&&n.reverse(),n},t.prototype.pointToData=function(e,n){return this.coordToData(this.toLocalCoord(e[this.dim==="x"?0:1]),n)},t.prototype.setCategorySortInfo=function(e){if(this.type!=="category")return!1;this.model.option.categorySortInfo=e,this.scale.setSortInfo(e)},t})(LL),RL="expandAxisBreak",Ir=Math.PI,EL=[[1,2,1,2],[5,3,5,3],[8,3,8,3]],kL=[[0,1,0,1],[0,3,0,3],[0,3,0,3]],$a=gt(),P_=gt(),R_=(function(){function r(t){this.recordMap={},this.resolveAxisNameOverlap=t}return r.prototype.ensureRecord=function(t){var e=t.axis.dim,n=t.componentIndex,i=this.recordMap,a=i[e]||(i[e]=[]);return a[n]||(a[n]={ready:{}})},r})();function OL(r,t,e,n){var i=e.axis,a=t.ensureRecord(e),o=[],s,l=wv(r.axisName)&&Pi(r.nameLocation);D(n,function(d){var p=Gr(d);if(!(!p||p.label.ignore)){o.push(p);var g=a.transGroup;l&&(g.transform?ki(ra,g.transform):Th(ra),p.transform&&_a(ra,ra,p.transform),it.copy(Uo,p.localRect),Uo.applyTransform(ra),s?s.union(Uo):it.copy(s=new it(0,0,0,0),Uo))}});var u=Math.abs(a.dirVec.x)>.1?"x":"y",f=a.transGroup[u];if(o.sort(function(d,p){return Math.abs(d.label[u]-f)-Math.abs(p.label[u]-f)}),l&&s){var h=i.getExtent(),c=Math.min(h[0],h[1]),v=Math.max(h[0],h[1])-c;s.union(new it(c,0,v,1))}a.stOccupiedRect=s,a.labelInfoList=o}var ra=lr(),Uo=new it(0,0,0,0),E_=function(r,t,e,n,i,a){if(Pi(r.nameLocation)){var o=a.stOccupiedRect;o&&k_(TC({},o,a.transGroup.transform),n,i)}else O_(a.labelInfoList,a.dirVec,n,i)};function k_(r,t,e){var n=new tt;fv(r,t,n,{direction:Math.atan2(e.y,e.x),bidirectional:!1,touchThreshold:.05})&&MC(t,n)}function O_(r,t,e,n){for(var i=tt.dot(n,t)>=0,a=0,o=r.length;a<o;a++){var s=r[i?a:o-1-a];s.label.ignore||k_(s,e,n)}}var Or=(function(){function r(t,e,n,i){this.group=new Ft,this._axisModel=t,this._api=e,this._local={},this._shared=i||new R_(E_),this._resetCfgDetermined(n)}return r.prototype.updateCfg=function(t){var e=this._cfg.raw;e.position=t.position,e.labelOffset=t.labelOffset,this._resetCfgDetermined(e)},r.prototype.__getRawCfg=function(){return this._cfg.raw},r.prototype._resetCfgDetermined=function(t){var e=this._axisModel,n=e.getDefaultOption?e.getDefaultOption():{},i=q(t.axisName,e.get("name")),a=e.get("nameMoveOverlap");(a==null||a==="auto")&&(a=q(t.defaultNameMoveOverlap,!0));var o={raw:t,position:t.position,rotation:t.rotation,nameDirection:q(t.nameDirection,1),tickDirection:q(t.tickDirection,1),labelDirection:q(t.labelDirection,1),labelOffset:q(t.labelOffset,0),silent:q(t.silent,!0),axisName:i,nameLocation:_i(e.get("nameLocation"),n.nameLocation,"end"),shouldNameMoveOverlap:wv(i)&&a,optionHideOverlap:e.get(["axisLabel","hideOverlap"]),showMinorTicks:e.get(["minorTick","show"])};this._cfg=o;var s=new Ft({x:o.position[0],y:o.position[1],rotation:o.rotation});s.updateTransform(),this._transformGroup=s;var l=this._shared.ensureRecord(e);l.transGroup=this._transformGroup,l.dirVec=new tt(Math.cos(-o.rotation),Math.sin(-o.rotation))},r.prototype.build=function(t,e){var n=this;return t||(t={axisLine:!0,axisTickLabelEstimate:!1,axisTickLabelDetermine:!0,axisName:!0}),D(BL,function(i){t[i]&&NL[i](n._cfg,n._local,n._shared,n._axisModel,n.group,n._transformGroup,n._api,e||{})}),this},r.innerTextLayout=function(t,e,n){var i=Im(e-t),a,o;return Ss(i)?(o=n>0?"top":"bottom",a="center"):Ss(i-Ir)?(o=n>0?"bottom":"top",a="center"):(o="middle",i>0&&i<Ir?a=n>0?"right":"left":a=n>0?"left":"right"),{rotation:i,textAlign:a,textVerticalAlign:o}},r.makeAxisEventDataBase=function(t){var e={componentType:t.mainType,componentIndex:t.componentIndex};return e[t.mainType+"Index"]=t.componentIndex,e},r.isLabelSilent=function(t){var e=t.get("tooltip");return t.get("silent")||!(t.get("triggerEvent")||e&&e.show)},r})(),BL=["axisLine","axisTickLabelEstimate","axisTickLabelDetermine","axisName"],NL={axisLine:function(r,t,e,n,i,a,o){var s=n.get(["axisLine","show"]);if(s==="auto"&&(s=!0,r.raw.axisLineAutoShow!=null&&(s=!!r.raw.axisLineAutoShow)),!!s){var l=n.axis.getExtent(),u=a.transform,f=[l[0],0],h=[l[1],0],c=f[0]>h[0];u&&(xe(f,f,u),xe(h,h,u));var v=O({lineCap:"round"},n.getModel(["axisLine","lineStyle"]).getLineStyle()),d={strokeContainThreshold:r.raw.strokeContainThreshold||5,silent:!0,z2:1,style:v};if(n.get(["axisLine","breakLine"])&&n.axis.scale.hasBreaks())XA().buildAxisBreakLine(n,i,a,d);else{var p=new zr(O({shape:{x1:f[0],y1:f[1],x2:h[0],y2:h[1]}},d));Ba(p.shape,p.style.lineWidth),p.anid="line",i.add(p)}var g=n.get(["axisLine","symbol"]);if(g!=null){var m=n.get(["axisLine","symbolSize"]);W(g)&&(g=[g,g]),(W(m)||mt(m))&&(m=[m,m]);var y=v0(n.get(["axisLine","symbolOffset"])||0,m),_=m[0],S=m[1];D([{rotate:r.rotation+Math.PI/2,offset:y[0],r:0},{rotate:r.rotation-Math.PI/2,offset:y[1],r:Math.sqrt((f[0]-h[0])*(f[0]-h[0])+(f[1]-h[1])*(f[1]-h[1]))}],function(w,b){if(g[b]!=="none"&&g[b]!=null){var T=Nn(g[b],-_/2,-S/2,_,S,v.stroke,!0),C=w.r+w.offset,x=c?h:f;T.attr({rotation:w.rotate,x:x[0]+C*Math.cos(r.rotation),y:x[1]-C*Math.sin(r.rotation),silent:!0,z2:11}),i.add(T)}})}}},axisTickLabelEstimate:function(r,t,e,n,i,a,o,s){var l=Hp(t,i,s);l&&zp(r,t,e,n,i,a,o,Ee.estimate)},axisTickLabelDetermine:function(r,t,e,n,i,a,o,s){var l=Hp(t,i,s);l&&zp(r,t,e,n,i,a,o,Ee.determine);var u=VL(r,i,a,n);HL(r,t.labelLayoutList,u),GL(r,i,a,n,r.tickDirection)},axisName:function(r,t,e,n,i,a,o,s){var l=e.ensureRecord(n);t.nameEl&&(i.remove(t.nameEl),t.nameEl=l.nameLayout=l.nameLocation=null);var u=r.axisName;if(wv(u)){var f=r.nameLocation,h=r.nameDirection,c=n.getModel("nameTextStyle"),v=n.get("nameGap")||0,d=n.axis.getExtent(),p=n.axis.inverse?-1:1,g=new tt(0,0),m=new tt(0,0);f==="start"?(g.x=d[0]-p*v,m.x=-p):f==="end"?(g.x=d[1]+p*v,m.x=p):(g.x=(d[0]+d[1])/2,g.y=r.labelOffset+h*v,m.y=h);var y=lr();m.transform(Mh(y,y,r.rotation));var _=n.get("nameRotate");_!=null&&(_=_*Ir/180);var S,w;Pi(f)?S=Or.innerTextLayout(r.rotation,_??r.rotation,h):(S=FL(r.rotation,f,_||0,d),w=r.raw.axisNameAvailableWidth,w!=null&&(w=Math.abs(w/Math.sin(S.rotation)),!isFinite(w)&&(w=null)));var b=c.getFont(),T=n.get("nameTruncate",!0)||{},C=T.ellipsis,x=vs(r.raw.nameTruncateMaxWidth,T.maxWidth,w),M=s.nameMarginLevel||0,A=new oe({x:g.x,y:g.y,rotation:S.rotation,silent:Or.isLabelSilent(n),style:Hr(c,{text:u,font:b,overflow:"truncate",width:x,ellipsis:C,fill:c.getTextColor()||n.get(["axisLine","lineStyle","color"]),align:c.get("align")||S.textAlign,verticalAlign:c.get("verticalAlign")||S.textVerticalAlign}),z2:1});if(Vh({el:A,componentModel:n,itemName:u}),A.__fullText=u,A.anid="name",n.get("triggerEvent")){var P=Or.makeAxisEventDataBase(n);P.targetType="axisName",P.name=u,pt(A).eventData=P}a.add(A),A.updateTransform(),t.nameEl=A;var L=l.nameLayout=Gr({label:A,priority:A.z2,defaultAttr:{ignore:A.ignore},marginDefault:Pi(f)?EL[M]:kL[M]});if(l.nameLocation=f,i.add(A),A.decomposeTransform(),r.shouldNameMoveOverlap&&L){var I=e.ensureRecord(n);e.resolveAxisNameOverlap(r,e,n,L,m,I)}}}};function zp(r,t,e,n,i,a,o,s){N_(t)||WL(r,t,i,s,n,o);var l=t.labelLayoutList;UL(r,n,l,a),r.rotation;var u=r.optionHideOverlap;zL(n,l,u),u&&C0(wt(l,function(f){return f&&!f.label.ignore})),OL(r,e,n,l)}function FL(r,t,e,n){var i=Im(e-r),a,o,s=n[0]>n[1],l=t==="start"&&!s||t!=="start"&&s;return Ss(i-Ir/2)?(o=l?"bottom":"top",a="center"):Ss(i-Ir*1.5)?(o=l?"top":"bottom",a="center"):(o="middle",i<Ir*1.5&&i>Ir/2?a=l?"left":"right":a=l?"right":"left"),{rotation:i,textAlign:a,textVerticalAlign:o}}function zL(r,t,e){if(b_(r.axis))return;function n(s,l,u){var f=Gr(t[l]),h=Gr(t[u]);if(!(!f||!h)){if(s===!1||f.suggestIgnore){ga(f.label);return}if(h.suggestIgnore){ga(h.label);return}var c=.1;if(!e){var v=[0,0,0,0];f=Gf({marginForce:v},f),h=Gf({marginForce:v},h)}fv(f,h,null,{touchThreshold:c})&&ga(s?h.label:f.label)}}var i=r.get(["axisLabel","showMinLabel"]),a=r.get(["axisLabel","showMaxLabel"]),o=t.length;n(i,0,1),n(a,o-1,o-2)}function HL(r,t,e){r.showMinorTicks||D(t,function(n){if(n&&n.label.ignore)for(var i=0;i<e.length;i++){var a=e[i],o=P_(a),s=$a(n.label);if(o.tickValue!=null&&!o.onBand&&o.tickValue===s.tickValue){ga(a);return}}})}function ga(r){r&&(r.ignore=!0)}function B_(r,t,e,n,i){for(var a=[],o=[],s=[],l=0;l<r.length;l++){var u=r[l].coord;o[0]=u,o[1]=0,s[0]=u,s[1]=e,t&&(xe(o,o,t),xe(s,s,t));var f=new zr({shape:{x1:o[0],y1:o[1],x2:s[0],y2:s[1]},style:n,z2:2,autoBatch:!0,silent:!0});Ba(f.shape,f.style.lineWidth),f.anid=i+"_"+r[l].tickValue,a.push(f);var h=P_(f);h.onBand=!!r[l].onBand,h.tickValue=r[l].tickValue}return a}function VL(r,t,e,n){var i=n.axis,a=n.getModel("axisTick"),o=a.get("show");if(o==="auto"&&(o=!0,r.raw.axisTickAutoShow!=null&&(o=!!r.raw.axisTickAutoShow)),!o||i.scale.isBlank())return[];for(var s=a.getModel("lineStyle"),l=r.tickDirection*a.get("length"),u=i.getTicksCoords(),f=B_(u,e.transform,l,at(s.getLineStyle(),{stroke:n.get(["axisLine","lineStyle","color"])}),"ticks"),h=0;h<f.length;h++)t.add(f[h]);return f}function GL(r,t,e,n,i){var a=n.axis,o=n.getModel("minorTick");if(!(!r.showMinorTicks||a.scale.isBlank())){var s=a.getMinorTicksCoords();if(s.length)for(var l=o.getModel("lineStyle"),u=i*o.get("length"),f=at(l.getLineStyle(),at(n.getModel("axisTick").getLineStyle(),{stroke:n.get(["axisLine","lineStyle","color"])})),h=0;h<s.length;h++)for(var c=B_(s[h],e.transform,u,f,"minorticks_"+h),v=0;v<c.length;v++)t.add(c[v])}}function Hp(r,t,e){if(N_(r)){var n=r.axisLabelsCreationContext,i=n.out.noPxChangeTryDetermine;if(e.noPxChange){for(var a=!0,o=0;o<i.length;o++)a=a&&i[o]();if(a)return!1}i.length&&(t.remove(r.labelGroup),sh(r,null,null,null))}return!0}function WL(r,t,e,n,i,a){var o=i.axis,s=vs(r.raw.axisLabelShow,i.get(["axisLabel","show"])),l=new Ft;e.add(l);var u=Ys(n);if(!s||o.scale.isBlank()){sh(t,[],l,u);return}var f=i.getModel("axisLabel"),h=o.getViewLabels(u),c=(vs(r.raw.labelRotate,f.get("rotate"))||0)*Ir/180,v=Or.innerTextLayout(r.rotation,c,r.labelDirection),d=i.getCategories&&i.getCategories(!0),p=[],g=i.get("triggerEvent"),m=1/0,y=-1/0;D(h,function(S,w){var b,T=o.scale.type==="ordinal"?o.scale.getRawOrdinalNumber(S.tickValue):S.tickValue,C=S.formattedLabel,x=S.rawLabel,M=f;if(d&&d[T]){var A=d[T];X(A)&&A.textStyle&&(M=new xt(A.textStyle,f,i.ecModel))}var P=M.getTextColor()||i.get(["axisLine","lineStyle","color"]),L=M.getShallow("align",!0)||v.textAlign,I=q(M.getShallow("alignMinLabel",!0),L),R=q(M.getShallow("alignMaxLabel",!0),L),E=M.getShallow("verticalAlign",!0)||M.getShallow("baseline",!0)||v.textVerticalAlign,V=q(M.getShallow("verticalAlignMinLabel",!0),E),B=q(M.getShallow("verticalAlignMaxLabel",!0),E),k=10+(((b=S.time)===null||b===void 0?void 0:b.level)||0);m=Math.min(m,k),y=Math.max(y,k);var G=new oe({x:0,y:0,rotation:0,silent:Or.isLabelSilent(i),z2:k,style:Hr(M,{text:C,align:w===0?I:w===h.length-1?R:L,verticalAlign:w===0?V:w===h.length-1?B:E,fill:et(P)?P(o.type==="category"?x:o.type==="value"?T+"":T,w):P})});G.anid="label_"+T;var U=$a(G);if(U.break=S.break,U.tickValue=T,U.layoutRotation=v.rotation,Vh({el:G,componentModel:i,itemName:C,formatterParamsExtra:{isTruncated:function(){return G.isTruncated},value:x,tickIndex:w}}),g){var Z=Or.makeAxisEventDataBase(i);Z.targetType="axisLabel",Z.value=x,Z.tickIndex=w,S.break&&(Z.break={start:S.break.parsedBreak.vmin,end:S.break.parsedBreak.vmax}),o.type==="category"&&(Z.dataIndex=T),pt(G).eventData=Z,S.break&&ZL(i,a,G,S.break)}p.push(G),l.add(G)});var _=$(p,function(S){return{label:S,priority:$a(S).break?S.z2+(y-m+1):S.z2,defaultAttr:{ignore:S.ignore}}});sh(t,_,l,u)}function N_(r){return!!r.labelLayoutList}function sh(r,t,e,n){r.labelLayoutList=t,r.labelGroup=e,r.axisLabelsCreationContext=n}function UL(r,t,e,n){var i=t.get(["axisLabel","margin"]);D(e,function(a,o){var s=Gr(a);if(s){var l=s.label,u=$a(l);s.suggestIgnore=l.ignore,l.ignore=!1,of(rr,YL),rr.x=t.axis.dataToCoord(u.tickValue),rr.y=r.labelOffset+r.labelDirection*i,rr.rotation=u.layoutRotation,n.add(rr),rr.updateTransform(),n.remove(rr),rr.decomposeTransform(),of(l,rr),l.markRedraw(),Bs(s,!0),Gr(s)}})}var rr=new Tt,YL=new Tt;function wv(r){return!!r}function ZL(r,t,e,n){e.on("click",function(i){var a={type:RL,breaks:[{start:n.parsedBreak.breakOption.start,end:n.parsedBreak.breakOption.end}]};a[r.axis.dim+"AxisIndex"]=r.componentIndex,t.dispatchAction(a)})}function Zs(r,t,e){e=e||{};var n=t.axis,i={},a=n.getAxesOnZeroOf()[0],o=n.position,s=a?"onZero":o,l=n.dim,u=[r.x,r.x+r.width,r.y,r.y+r.height],f={left:0,right:1,top:0,bottom:1,onZero:2},h=t.get("offset")||0,c=l==="x"?[u[2]-h,u[3]+h]:[u[0]-h,u[1]+h];if(a){var v=a.toGlobalCoord(a.dataToCoord(0));c[f.onZero]=Math.max(Math.min(v,c[1]),c[0])}i.position=[l==="y"?c[f[s]]:u[0],l==="x"?c[f[s]]:u[3]],i.rotation=Math.PI/2*(l==="x"?0:1);var d={top:-1,bottom:1,left:-1,right:1};i.labelDirection=i.tickDirection=i.nameDirection=d[o],i.labelOffset=a?c[f[o]]-c[f.onZero]:0,t.get(["axisTick","inside"])&&(i.tickDirection=-i.tickDirection),vs(e.labelInside,t.get(["axisLabel","inside"]))&&(i.labelDirection=-i.labelDirection);var p=t.get(["axisLabel","rotate"]);return i.labelRotate=s==="top"?-p:p,i.z2=1,i}function XL(r){return r.coordinateSystem&&r.coordinateSystem.type==="cartesian2d"}function Vp(r){var t={xAxisModel:null,yAxisModel:null};return D(t,function(e,n){var i=n.replace(/Model$/,""),a=r.getReferringComponents(i,qt).models[0];t[n]=a}),t}function $L(r,t,e,n,i,a){for(var o=Zs(r,e),s=!1,l=!1,u=0;u<t.length;u++)rh(t[u].getOtherAxis(e.axis).scale)&&(s=l=!0,e.axis.type==="category"&&e.axis.onBand&&(l=!1));return o.axisLineAutoShow=s,o.axisTickAutoShow=l,o.defaultNameMoveOverlap=a,new Or(e,n,o,i)}function qL(r,t,e){var n=Zs(t,e);r.updateCfg(n)}function KL(r,t,e){var n=Ii.prototype,i=n.getTicks.call(e),a=n.getTicks.call(e,{expandToNicedExtent:!0}),o=i.length-1,s=n.getInterval.call(e),l=S_(r,t),u=l.extent,f=l.fixMin,h=l.fixMax;r.type==="log"&&(u=nh(r.base,u,!0)),r.setBreaksFromOption(x_(t)),r.setExtent(u[0],u[1]),r.calcNiceExtent({splitNumber:o,fixMin:f,fixMax:h});var c=n.getExtent.call(r);f&&(u[0]=c[0]),h&&(u[1]=c[1]);var v=n.getInterval.call(r),d=u[0],p=u[1];if(f&&h)v=(p-d)/o;else if(f)for(p=u[0]+v*o;p<u[1]&&isFinite(p)&&isFinite(u[1]);)v=Ru(v),p=u[0]+v*o;else if(h)for(d=u[1]-v*o;d>u[0]&&isFinite(d)&&isFinite(u[0]);)v=Ru(v),d=u[1]-v*o;else{var g=r.getTicks().length-1;g>o&&(v=Ru(v));var m=v*o;p=Math.ceil(u[1]/v)*v,d=Nt(p-m),d<0&&u[0]>=0?(d=0,p=Nt(m)):p>0&&u[1]<=0&&(p=0,d=-Nt(m))}var y=(i[0].value-a[0].value)/s,_=(i[o].value-a[o].value)/s;n.setExtent.call(r,d+v*y,p+v*_),n.setInterval.call(r,v),(y||_)&&n.setNiceExtent.call(r,d+v,p-v)}var Gp=[[3,1],[0,2]],QL=(function(){function r(t,e,n){this.type="grid",this._coordsMap={},this._coordsList=[],this._axesMap={},this._axesList=[],this.axisPointerEnabled=!0,this.dimensions=ah,this._initCartesian(t,e,n),this.model=t}return r.prototype.getRect=function(){return this._rect},r.prototype.update=function(t,e){var n=this._axesMap;this._updateScale(t,this.model);function i(o){var s,l=St(o),u=l.length;if(u){for(var f=[],h=u-1;h>=0;h--){var c=+l[h],v=o[c],d=v.model,p=v.scale;rh(p)&&d.get("alignTicks")&&d.get("interval")==null?f.push(v):(Op(p,d),rh(p)&&(s=v))}f.length&&(s||(s=f.pop(),Op(s.scale,s.model)),D(f,function(g){KL(g.scale,g.model,s.scale)}))}}i(n.x),i(n.y);var a={};D(n.x,function(o){Wp(n,"y",o,a)}),D(n.y,function(o){Wp(n,"x",o,a)}),this.resize(this.model,e)},r.prototype.resize=function(t,e,n){var i=ov(t,e),a=this._rect=ro(t.getBoxLayoutParams(),i.refContainer),o=this._axesMap,s=this._coordsList,l=t.get("containLabel");if(F_(o,a),!n){var u=JL(a,s,o,l,e),f=void 0;if(l)f=Zp(a.clone(),"axisLabel",null,a,o,u,i);else{var h=t2(t,a,i),c=h.outerBoundsRect,v=h.parsedOuterBoundsContain,d=h.outerBoundsClamp;c&&(f=Zp(c,v,d,a,o,u,i))}z_(a,o,Ee.determine,null,f,i)}D(this._coordsList,function(p){p.calcAffineTransform()})},r.prototype.getAxis=function(t,e){var n=this._axesMap[t];if(n!=null)return n[e||0]},r.prototype.getAxes=function(){return this._axesList.slice()},r.prototype.getCartesian=function(t,e){if(t!=null&&e!=null){var n="x"+t+"y"+e;return this._coordsMap[n]}X(t)&&(e=t.yAxisIndex,t=t.xAxisIndex);for(var i=0,a=this._coordsList;i<a.length;i++)if(a[i].getAxis("x").index===t||a[i].getAxis("y").index===e)return a[i]},r.prototype.getCartesians=function(){return this._coordsList.slice()},r.prototype.convertToPixel=function(t,e,n){var i=this._findConvertTarget(e);return i.cartesian?i.cartesian.dataToPoint(n):i.axis?i.axis.toGlobalCoord(i.axis.dataToCoord(n)):null},r.prototype.convertFromPixel=function(t,e,n){var i=this._findConvertTarget(e);return i.cartesian?i.cartesian.pointToData(n):i.axis?i.axis.coordToData(i.axis.toLocalCoord(n)):null},r.prototype._findConvertTarget=function(t){var e=t.seriesModel,n=t.xAxisModel||e&&e.getReferringComponents("xAxis",qt).models[0],i=t.yAxisModel||e&&e.getReferringComponents("yAxis",qt).models[0],a=t.gridModel,o=this._coordsList,s,l;if(e)s=e.coordinateSystem,ft(o,s)<0&&(s=null);else if(n&&i)s=this.getCartesian(n.componentIndex,i.componentIndex);else if(n)l=this.getAxis("x",n.componentIndex);else if(i)l=this.getAxis("y",i.componentIndex);else if(a){var u=a.coordinateSystem;u===this&&(s=this._coordsList[0])}return{cartesian:s,axis:l}},r.prototype.containPoint=function(t){var e=this._coordsList[0];if(e)return e.containPoint(t)},r.prototype._initCartesian=function(t,e,n){var i=this,a=this,o={left:!1,right:!1,top:!1,bottom:!1},s={x:{},y:{}},l={x:0,y:0};if(e.eachComponent("xAxis",u("x"),this),e.eachComponent("yAxis",u("y"),this),!l.x||!l.y){this._axesMap={},this._axesList=[];return}this._axesMap=s,D(s.x,function(f,h){D(s.y,function(c,v){var d="x"+h+"y"+v,p=new gL(d);p.master=i,p.model=t,i._coordsMap[d]=p,i._coordsList.push(p),p.addAxis(f),p.addAxis(c)})});function u(f){return function(h,c){if(ku(h,t)){var v=h.get("position");f==="x"?v!=="top"&&v!=="bottom"&&(v=o.bottom?"top":"bottom"):v!=="left"&&v!=="right"&&(v=o.left?"right":"left"),o[v]=!0;var d=new PL(f,vL(h),[0,0],h.get("type"),v),p=d.type==="category";d.onBand=p&&h.get("boundaryGap"),d.inverse=h.get("inverse"),h.axis=d,d.model=h,d.grid=a,d.index=c,a._axesList.push(d),s[f][c]=d,l[f]++}}}},r.prototype._updateScale=function(t,e){D(this._axesList,function(i){if(i.scale.setExtent(1/0,-1/0),i.type==="category"){var a=i.model.get("categorySortInfo");i.scale.setSortInfo(a)}}),t.eachSeries(function(i){if(XL(i)){var a=Vp(i),o=a.xAxisModel,s=a.yAxisModel;if(!ku(o,e)||!ku(s,e))return;var l=this.getCartesian(o.componentIndex,s.componentIndex),u=i.getData(),f=l.getAxis("x"),h=l.getAxis("y");n(u,f),n(u,h)}},this);function n(i,a){D(w_(i,a.dim),function(o){a.scale.unionExtentFromData(i,o)})}},r.prototype.getTooltipAxes=function(t){var e=[],n=[];return D(this.getCartesians(),function(i){var a=t!=null&&t!=="auto"?i.getAxis(t):i.getBaseAxis(),o=i.getOtherAxis(a);ft(e,a)<0&&e.push(a),ft(n,o)<0&&n.push(o)}),{baseAxes:e,otherAxes:n}},r.create=function(t,e){var n=[];return t.eachComponent("grid",function(i,a){var o=new r(i,t,e);o.name="grid_"+a,o.resize(i,e,!0),i.coordinateSystem=o,n.push(o)}),t.eachSeries(function(i){$x({targetModel:i,coordSysType:"cartesian2d",coordSysProvider:a});function a(){var o=Vp(i),s=o.xAxisModel,l=o.yAxisModel,u=s.getCoordSysModel(),f=u.coordinateSystem;return f.getCartesian(s.componentIndex,l.componentIndex)}}),n},r.dimensions=ah,r})();function ku(r,t){return r.getCoordSysModel()===t}function Wp(r,t,e,n){e.getAxesOnZeroOf=function(){return a?[a]:[]};var i=r[t],a,o=e.model,s=o.get(["axisLine","onZero"]),l=o.get(["axisLine","onZeroAxisIndex"]);if(!s)return;if(l!=null)Up(i[l])&&(a=i[l]);else for(var u in i)if(i.hasOwnProperty(u)&&Up(i[u])&&!n[f(i[u])]){a=i[u];break}a&&(n[f(a)]=!0);function f(h){return h.dim+"_"+h.index}}function Up(r){return r&&r.type!=="category"&&r.type!=="time"&&cL(r)}function jL(r,t){var e=r.getExtent(),n=e[0]+e[1];r.toGlobalCoord=r.dim==="x"?function(i){return i+t}:function(i){return n-i+t},r.toLocalCoord=r.dim==="x"?function(i){return i-t}:function(i){return n-i+t}}function F_(r,t){D(r.x,function(e){return Yp(e,t.x,t.width)}),D(r.y,function(e){return Yp(e,t.y,t.height)})}function Yp(r,t,e){var n=[0,e],i=r.inverse?1:0;r.setExtent(n[i],n[1-i]),jL(r,t)}function Zp(r,t,e,n,i,a,o){z_(n,i,Ee.estimate,t,!1,o);var s=[0,0,0,0];u(0),u(1),f(n,0,NaN),f(n,1,NaN);var l=A1(s,function(c){return c>0})==null;return Ds(n,s,!0,!0,e),F_(i,n),l;function u(c){D(i[Dr[c]],function(v){if(Xa(v.model)){var d=a.ensureRecord(v.model),p=d.labelInfoList;if(p)for(var g=0;g<p.length;g++){var m=p[g],y=v.scale.normalize($a(m.label).tickValue);y=c===1?1-y:y,f(m.rect,c,y),f(m.rect,1-c,NaN)}var _=d.nameLayout;if(_){var y=Pi(d.nameLocation)?.5:NaN;f(_.rect,c,y),f(_.rect,1-c,NaN)}}})}function f(c,v,d){var p=r[Dr[v]]-c[Dr[v]],g=c[Di[v]]+c[Dr[v]]-(r[Di[v]]+r[Dr[v]]);p=h(p,1-d),g=h(g,d);var m=Gp[v][0],y=Gp[v][1];s[m]=he(s[m],p),s[y]=he(s[y],g)}function h(c,v){return c>0&&!Pa(v)&&v>1e-4&&(c/=v),c}}function JL(r,t,e,n,i){var a=new R_(e2);return D(e,function(o){return D(o,function(s){if(Xa(s.model)){var l=!n;s.axisBuilder=$L(r,t,s.model,i,a,l)}})}),a}function z_(r,t,e,n,i,a){var o=e===Ee.determine;D(t,function(u){return D(u,function(f){Xa(f.model)&&(qL(f.axisBuilder,r,f.model),f.axisBuilder.build(o?{axisTickLabelDetermine:!0}:{axisTickLabelEstimate:!0},{noPxChange:i}))})});var s={x:0,y:0};l(0),l(1);function l(u){s[Dr[1-u]]=r[Di[u]]<=a.refContainer[Di[u]]*.5?0:1-u===1?2:1}D(t,function(u,f){return D(u,function(h){Xa(h.model)&&((n==="all"||o)&&h.axisBuilder.build({axisName:!0},{nameMarginLevel:s[f]}),o&&h.axisBuilder.build({axisLine:!0}))})})}function t2(r,t,e){var n,i=r.get("outerBoundsMode",!0);i==="same"?n=t.clone():(i==null||i==="auto")&&(n=ro(r.get("outerBounds",!0)||d_,e.refContainer));var a=r.get("outerBoundsContain",!0),o;a==null||a==="auto"||ft(["all","axisLabel"],a)<0?o="all":o=a;var s=[_f(q(r.get("outerBoundsClampWidth",!0),Ws[0]),t.width),_f(q(r.get("outerBoundsClampHeight",!0),Ws[1]),t.height)];return{outerBoundsRect:n,parsedOuterBoundsContain:o,outerBoundsClamp:s}}var e2=function(r,t,e,n,i,a){var o=e.axis.dim==="x"?"y":"x";E_(r,t,e,n,i,a),Pi(r.nameLocation)||D(t.recordMap[o],function(s){s&&s.labelInfoList&&s.dirVec&&O_(s.labelInfoList,s.dirVec,n,i)})};function r2(r,t){var e={axesInfo:{},seriesInvolved:!1,coordSysAxesInfo:{},coordSysMap:{}};return n2(e,r,t),e.seriesInvolved&&a2(e,r),e}function n2(r,t,e){var n=t.getComponent("tooltip"),i=t.getComponent("axisPointer"),a=i.get("link",!0)||[],o=[];D(e.getCoordinateSystems(),function(s){if(!s.axisPointerEnabled)return;var l=qa(s.model),u=r.coordSysAxesInfo[l]={};r.coordSysMap[l]=s;var f=s.model,h=f.getModel("tooltip",n);if(D(s.getAxes(),ie(p,!1,null)),s.getTooltipAxes&&n&&h.get("show")){var c=h.get("trigger")==="axis",v=h.get(["axisPointer","type"])==="cross",d=s.getTooltipAxes(h.get(["axisPointer","axis"]));(c||v)&&D(d.baseAxes,ie(p,v?"cross":!0,c)),v&&D(d.otherAxes,ie(p,"cross",!1))}function p(g,m,y){var _=y.model.getModel("axisPointer",i),S=_.get("show");if(!(!S||S==="auto"&&!g&&!lh(_))){m==null&&(m=_.get("triggerTooltip")),_=g?i2(y,h,i,t,g,m):_;var w=_.get("snap"),b=_.get("triggerEmphasis"),T=qa(y.model),C=m||w||y.type==="category",x=r.axesInfo[T]={key:T,axis:y,coordSys:s,axisPointerModel:_,triggerTooltip:m,triggerEmphasis:b,involveSeries:C,snap:w,useHandle:lh(_),seriesModels:[],linkGroup:null};u[T]=x,r.seriesInvolved=r.seriesInvolved||C;var M=o2(a,y);if(M!=null){var A=o[M]||(o[M]={axesInfo:{}});A.axesInfo[T]=x,A.mapper=a[M].mapper,x.linkGroup=A}}}})}function i2(r,t,e,n,i,a){var o=t.getModel("axisPointer"),s=["type","snap","lineStyle","shadowStyle","label","animation","animationDurationUpdate","animationEasingUpdate","z"],l={};D(s,function(c){l[c]=st(o.get(c))}),l.snap=r.type!=="category"&&!!a,o.get("type")==="cross"&&(l.type="line");var u=l.label||(l.label={});if(u.show==null&&(u.show=!1),i==="cross"){var f=o.get(["label","show"]);if(u.show=f??!0,!a){var h=l.lineStyle=o.get("crossStyle");h&&at(u,h.textStyle)}}return r.model.getModel("axisPointer",new xt(l,e,n))}function a2(r,t){t.eachSeries(function(e){var n=e.coordinateSystem,i=e.get(["tooltip","trigger"],!0),a=e.get(["tooltip","show"],!0);!n||!n.model||i==="none"||i===!1||i==="item"||a===!1||e.get(["axisPointer","show"],!0)===!1||D(r.coordSysAxesInfo[qa(n.model)],function(o){var s=o.axis;n.getAxis(s.dim)===s&&(o.seriesModels.push(e),o.seriesDataCount==null&&(o.seriesDataCount=0),o.seriesDataCount+=e.getData().count())})})}function o2(r,t){for(var e=t.model,n=t.dim,i=0;i<r.length;i++){var a=r[i]||{};if(Ou(a[n+"AxisId"],e.id)||Ou(a[n+"AxisIndex"],e.componentIndex)||Ou(a[n+"AxisName"],e.name))return i}}function Ou(r,t){return r==="all"||H(r)&&ft(r,t)>=0||r===t}function s2(r){var t=xv(r);if(t){var e=t.axisPointerModel,n=t.axis.scale,i=e.option,a=e.get("status"),o=e.get("value");o!=null&&(o=n.parse(o));var s=lh(e);a==null&&(i.status=s?"show":"hide");var l=n.getExtent().slice();l[0]>l[1]&&l.reverse(),(o==null||o>l[1])&&(o=l[1]),o<l[0]&&(o=l[0]),i.value=o,s&&(i.status=t.axis.scale.isBlank()?"hide":"show")}}function xv(r){var t=(r.ecModel.getComponent("axisPointer")||{}).coordSysAxesInfo;return t&&t.axesInfo[qa(r)]}function l2(r){var t=xv(r);return t&&t.axisPointerModel}function lh(r){return!!r.get(["handle","show"])}function qa(r){return r.type+"||"+r.id}var Xp={},H_=(function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.render=function(e,n,i,a){this.axisPointerClass&&s2(e),r.prototype.render.apply(this,arguments),this._doUpdateAxisPointerClass(e,i,!0)},t.prototype.updateAxisPointer=function(e,n,i,a){this._doUpdateAxisPointerClass(e,i,!1)},t.prototype.remove=function(e,n){var i=this._axisPointer;i&&i.remove(n)},t.prototype.dispose=function(e,n){this._disposeAxisPointer(n),r.prototype.dispose.apply(this,arguments)},t.prototype._doUpdateAxisPointerClass=function(e,n,i){var a=t.getAxisPointerClass(this.axisPointerClass);if(a){var o=l2(e);o?(this._axisPointer||(this._axisPointer=new a)).render(e,o,n,i):this._disposeAxisPointer(n)}},t.prototype._disposeAxisPointer=function(e){this._axisPointer&&this._axisPointer.dispose(e),this._axisPointer=null},t.registerAxisPointerClass=function(e,n){Xp[e]=n},t.getAxisPointerClass=function(e){return e&&Xp[e]},t.type="axis",t})(Me),uh=gt();function u2(r,t,e,n){var i=e.axis;if(!i.scale.isBlank()){var a=e.getModel("splitArea"),o=a.getModel("areaStyle"),s=o.get("color"),l=n.coordinateSystem.getRect(),u=i.getTicksCoords({tickModel:a,clamp:!0,breakTicks:"none",pruneByBreak:"preserve_extent_bound"});if(u.length){var f=s.length,h=uh(r).splitAreaColors,c=K(),v=0;if(h)for(var d=0;d<u.length;d++){var p=h.get(u[d].tickValue);if(p!=null){v=(p+(f-1)*d)%f;break}}var g=i.toGlobalCoord(u[0].coord),m=o.getAreaStyle();s=H(s)?s:[s];for(var d=1;d<u.length;d++){var y=i.toGlobalCoord(u[d].coord),_=void 0,S=void 0,w=void 0,b=void 0;i.isHorizontal()?(_=g,S=l.y,w=y-_,b=l.height,g=_+w):(_=l.x,S=g,w=l.width,b=y-S,g=S+b);var T=u[d-1].tickValue;T!=null&&c.set(T,v),t.add(new Tt({anid:T!=null?"area_"+T:null,shape:{x:_,y:S,width:w,height:b},style:at({fill:s[v]},m),autoBatch:!0,silent:!0})),v=(v+1)%f}uh(r).splitAreaColors=c}}}function f2(r){uh(r).splitAreaColors=null}var h2=["splitArea","splitLine","minorSplitLine","breakArea"],V_=(function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.axisPointerClass="CartesianAxisPointer",e}return t.prototype.render=function(e,n,i,a){this.group.removeAll();var o=this._axisGroup;if(this._axisGroup=new Ft,this.group.add(this._axisGroup),!!Xa(e)){this._axisGroup.add(e.axis.axisBuilder.group),D(h2,function(l){e.get([l,"show"])&&v2[l](this,this._axisGroup,e,e.getCoordSysModel(),i)},this);var s=a&&a.type==="changeAxisOrder"&&a.isInitSort;s||vy(o,this._axisGroup,e),r.prototype.render.call(this,e,n,i,a)}},t.prototype.remove=function(){f2(this)},t.type="cartesianAxis",t})(H_),v2={splitLine:function(r,t,e,n,i){var a=e.axis;if(!a.scale.isBlank()){var o=e.getModel("splitLine"),s=o.getModel("lineStyle"),l=s.get("color"),u=o.get("showMinLine")!==!1,f=o.get("showMaxLine")!==!1;l=H(l)?l:[l];for(var h=n.coordinateSystem.getRect(),c=a.isHorizontal(),v=0,d=a.getTicksCoords({tickModel:o,breakTicks:"none",pruneByBreak:"preserve_extent_bound"}),p=[],g=[],m=s.getLineStyle(),y=0;y<d.length;y++){var _=a.toGlobalCoord(d[y].coord);if(!(y===0&&!u||y===d.length-1&&!f)){var S=d[y].tickValue;c?(p[0]=_,p[1]=h.y,g[0]=_,g[1]=h.y+h.height):(p[0]=h.x,p[1]=_,g[0]=h.x+h.width,g[1]=_);var w=v++%l.length,b=new zr({anid:S!=null?"line_"+S:null,autoBatch:!0,shape:{x1:p[0],y1:p[1],x2:g[0],y2:g[1]},style:at({stroke:l[w]},m),silent:!0});Ba(b.shape,m.lineWidth),t.add(b)}}}},minorSplitLine:function(r,t,e,n,i){var a=e.axis,o=e.getModel("minorSplitLine"),s=o.getModel("lineStyle"),l=n.coordinateSystem.getRect(),u=a.isHorizontal(),f=a.getMinorTicksCoords();if(f.length)for(var h=[],c=[],v=s.getLineStyle(),d=0;d<f.length;d++)for(var p=0;p<f[d].length;p++){var g=a.toGlobalCoord(f[d][p].coord);u?(h[0]=g,h[1]=l.y,c[0]=g,c[1]=l.y+l.height):(h[0]=l.x,h[1]=g,c[0]=l.x+l.width,c[1]=g);var m=new zr({anid:"minor_line_"+f[d][p].tickValue,autoBatch:!0,shape:{x1:h[0],y1:h[1],x2:c[0],y2:c[1]},style:v,silent:!0});Ba(m.shape,v.lineWidth),t.add(m)}},splitArea:function(r,t,e,n,i){u2(r,t,e,n)},breakArea:function(r,t,e,n,i){e.axis.scale}},G_=(function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.type="xAxis",t})(V_),c2=(function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=G_.type,e}return t.type="yAxis",t})(V_),d2=(function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type="grid",e}return t.prototype.render=function(e,n){this.group.removeAll(),e.get("show")&&this.group.add(new Tt({shape:e.coordinateSystem.getRect(),style:at({fill:e.get("backgroundColor")},e.getItemStyle()),silent:!0,z2:-1}))},t.type="grid",t})(Me),$p={offset:0};function p2(r){r.registerComponentView(d2),r.registerComponentModel(NA),r.registerCoordinateSystem("cartesian2d",QL),Lp(r,"x",th,$p),Lp(r,"y",th,$p),r.registerComponentView(G_),r.registerComponentView(c2),r.registerPreprocessor(function(t){t.xAxis&&t.yAxis&&!t.grid&&(t.grid={})})}var g2=gt();function qp(r,t){return!!g2(r)[t]}Hn({type:"takeGlobalCursor",event:"globalCursorTaken",update:"update"},Kt);var m2={axisPointer:1,tooltip:1,brush:1};function y2(r,t,e){var n=t.getComponentByElement(r.topTarget);if(!n||n===e||m2.hasOwnProperty(n.mainType))return!1;var i=n.coordinateSystem;if(!i||i.model===e)return!1;var a=za(n),o=za(e);return!((a.zlevel-o.zlevel||a.z-o.z)<=0)}var _2=(function(r){z(t,r);function t(e){var n=r.call(this)||this;n._zr=e;var i=Q(n._mousedownHandler,n),a=Q(n._mousemoveHandler,n),o=Q(n._mouseupHandler,n),s=Q(n._mousewheelHandler,n),l=Q(n._pinchHandler,n);return n.enable=function(u,f){var h=f.zInfo,c=za(h.component),v=c.z,d=c.zlevel,p={component:h.component,z:v,zlevel:d,z2:q(h.z2,-1/0)},g=O({},f.triggerInfo);this._opt=at(O({},f),{zoomOnMouseWheel:!0,moveOnMouseMove:!0,moveOnMouseWheel:!1,preventDefaultMouseMove:!0,zInfoParsed:p,triggerInfo:g}),u==null&&(u=!0),(!this._enabled||this._controlType!==u)&&(this._enabled=!0,this.disable(),(u===!0||u==="move"||u==="pan")&&(ia(e,"mousedown",i,p),ia(e,"mousemove",a,p),ia(e,"mouseup",o,p)),(u===!0||u==="scale"||u==="zoom")&&(ia(e,"mousewheel",s,p),ia(e,"pinch",l,p)))},n.disable=function(){this._enabled=!1,aa(e,"mousedown",i),aa(e,"mousemove",a),aa(e,"mouseup",o),aa(e,"mousewheel",s),aa(e,"pinch",l)},n}return t.prototype.isDragging=function(){return this._dragging},t.prototype.isPinching=function(){return this._pinching},t.prototype._checkPointer=function(e,n,i){var a=this._opt,o=a.zInfoParsed;if(y2(e,a.api,o.component))return!1;var s=a.triggerInfo,l=s.roamTrigger,u=!1;return l==="global"&&(u=!0),u||(u=s.isInSelf(e,n,i)),u&&s.isInClip&&!s.isInClip(e,n,i)&&(u=!1),u},t.prototype._decideCursorStyle=function(e,n,i,a){var o=e.target;if(!o&&this._checkPointer(e,n,i))return"grab";if(a)return o&&o.cursor||"default"},t.prototype.dispose=function(){this.disable()},t.prototype._mousedownHandler=function(e){if(!(Od(e)||na(e))){for(var n=e.target;n;){if(n.draggable)return;n=n.__hostTarget||n.parent}var i=e.offsetX,a=e.offsetY;this._checkPointer(e,i,a)&&(this._x=i,this._y=a,this._dragging=!0)}},t.prototype._mousemoveHandler=function(e){var n=this._zr;if(!(e.gestureEvent==="pinch"||qp(n,"globalPan")||na(e))){var i=e.offsetX,a=e.offsetY;if(!this._dragging||!us("moveOnMouseMove",e,this._opt)){var o=this._decideCursorStyle(e,i,a,!1);o&&n.setCursorStyle(o);return}n.setCursorStyle("grabbing");var s=this._x,l=this._y,u=i-s,f=a-l;this._x=i,this._y=a,this._opt.preventDefaultMouseMove&&Li(e.event),e.__ecRoamConsumed=!0,Kp(this,"pan","moveOnMouseMove",e,{dx:u,dy:f,oldX:s,oldY:l,newX:i,newY:a,isAvailableBehavior:null})}},t.prototype._mouseupHandler=function(e){if(!na(e)){var n=this._zr;if(!Od(e)){this._dragging=!1;var i=this._decideCursorStyle(e,e.offsetX,e.offsetY,!0);i&&n.setCursorStyle(i)}}},t.prototype._mousewheelHandler=function(e){if(!na(e)){var n=us("zoomOnMouseWheel",e,this._opt),i=us("moveOnMouseWheel",e,this._opt),a=e.wheelDelta,o=Math.abs(a),s=e.offsetX,l=e.offsetY;if(!(a===0||!n&&!i)){if(n){var u=o>3?1.4:o>1?1.2:1.1,f=a>0?u:1/u;this._checkTriggerMoveZoom(this,"zoom","zoomOnMouseWheel",e,{scale:f,originX:s,originY:l,isAvailableBehavior:null})}if(i){var h=Math.abs(a),c=(a>0?1:-1)*(h>3?.4:h>1?.15:.05);this._checkTriggerMoveZoom(this,"scrollMove","moveOnMouseWheel",e,{scrollDelta:c,originX:s,originY:l,isAvailableBehavior:null})}}}},t.prototype._pinchHandler=function(e){if(!(qp(this._zr,"globalPan")||na(e))){var n=e.pinchScale>1?1.1:1/1.1;this._checkTriggerMoveZoom(this,"zoom",null,e,{scale:n,originX:e.pinchX,originY:e.pinchY,isAvailableBehavior:null})}},t.prototype._checkTriggerMoveZoom=function(e,n,i,a,o){e._checkPointer(a,o.originX,o.originY)&&(Li(a.event),a.__ecRoamConsumed=!0,Kp(e,n,i,a,o))},t})(ke);function na(r){return r.__ecRoamConsumed}var S2=gt();function bl(r){var t=S2(r);return t.roam=t.roam||{},t.uniform=t.uniform||{},t}function ia(r,t,e,n){for(var i=bl(r),a=i.roam,o=a[t]=a[t]||[],s=0;s<o.length;s++){var l=o[s].zInfoParsed;if((l.zlevel-n.zlevel||l.z-n.z||l.z2-n.z2)<=0)break}o.splice(s,0,{listener:e,zInfoParsed:n}),b2(r,t)}function aa(r,t,e){for(var n=bl(r),i=n.roam[t]||[],a=0;a<i.length;a++)if(i[a].listener===e){i.splice(a,1),i.length||w2(r,t);return}}function b2(r,t){var e=bl(r);e.uniform[t]||r.on(t,e.uniform[t]=function(n){var i=e.roam[t];if(i)for(var a=0;a<i.length;a++)i[a].listener(n)})}function w2(r,t){var e=bl(r),n=e.uniform;n[t]&&(r.off(t,n[t]),n[t]=null)}function Kp(r,t,e,n,i){i.isAvailableBehavior=Q(us,null,e,n),r.trigger(t,i)}function us(r,t,e){var n=e[r];return!r||n&&(!W(n)||t.event[n+"Key"])}function Ka(r,t,e,n,i,a){r=r||0;var o=e[1]-e[0];if(i!=null&&(i=ii(i,[0,o])),a!=null&&(a=Math.max(a,i??0)),n==="all"){var s=Math.abs(t[1]-t[0]);s=ii(s,[0,o]),i=a=ii(s,[i,a]),n=0}t[0]=ii(t[0],e),t[1]=ii(t[1],e);var l=Bu(t,n);t[n]+=r;var u=i||0,f=e.slice();l.sign<0?f[0]+=u:f[1]-=u,t[n]=ii(t[n],f);var h;return h=Bu(t,n),i!=null&&(h.sign!==l.sign||h.span<i)&&(t[1-n]=t[n]+l.sign*i),h=Bu(t,n),a!=null&&h.span>a&&(t[1-n]=t[n]+h.sign*a),t}function Bu(r,t){var e=r[t]-r[1-t];return{span:Math.abs(e),sign:e>0?-1:e<0?1:t?-1:1}}function ii(r,t){return Math.min(t[1]!=null?t[1]:1/0,Math.max(t[0]!=null?t[0]:-1/0,r))}var bn=gt(),Qp=st,Nu=Q,x2=(function(){function r(){this._dragging=!1,this.animationThreshold=15}return r.prototype.render=function(t,e,n,i){var a=e.get("value"),o=e.get("status");if(this._axisModel=t,this._axisPointerModel=e,this._api=n,!(!i&&this._lastValue===a&&this._lastStatus===o)){this._lastValue=a,this._lastStatus=o;var s=this._group,l=this._handle;if(!o||o==="hide"){s&&s.hide(),l&&l.hide();return}s&&s.show(),l&&l.show();var u={};this.makeElOption(u,a,t,e,n);var f=u.graphicKey;f!==this._lastGraphicKey&&this.clear(n),this._lastGraphicKey=f;var h=this._moveAnimation=this.determineAnimation(t,e);if(!s)s=this._group=new Ft,this.createPointerEl(s,u,t,e),this.createLabelEl(s,u,t,e),n.getZr().add(s);else{var c=ie(jp,e,h);this.updatePointerEl(s,u,c),this.updateLabelEl(s,u,c,e)}tg(s,e,!0),this._renderHandle(a)}},r.prototype.remove=function(t){this.clear(t)},r.prototype.dispose=function(t){this.clear(t)},r.prototype.determineAnimation=function(t,e){var n=e.get("animation"),i=t.axis,a=i.type==="category",o=e.get("snap");if(!o&&!a)return!1;if(n==="auto"||n==null){var s=this.animationThreshold;if(a&&i.getBandWidth()>s)return!0;if(o){var l=xv(t).seriesDataCount,u=i.getExtent();return Math.abs(u[0]-u[1])/l>s}return!1}return n===!0},r.prototype.makeElOption=function(t,e,n,i,a){},r.prototype.createPointerEl=function(t,e,n,i){var a=e.pointer;if(a){var o=bn(t).pointerEl=new tx[a.type](Qp(e.pointer));t.add(o)}},r.prototype.createLabelEl=function(t,e,n,i){if(e.label){var a=bn(t).labelEl=new oe(Qp(e.label));t.add(a),Jp(a,i)}},r.prototype.updatePointerEl=function(t,e,n){var i=bn(t).pointerEl;i&&e.pointer&&(i.setStyle(e.pointer.style),n(i,{shape:e.pointer.shape}))},r.prototype.updateLabelEl=function(t,e,n,i){var a=bn(t).labelEl;a&&(a.setStyle(e.label.style),n(a,{x:e.label.x,y:e.label.y}),Jp(a,i))},r.prototype._renderHandle=function(t){if(!(this._dragging||!this.updateHandleTransform)){var e=this._axisPointerModel,n=this._api.getZr(),i=this._handle,a=e.getModel("handle"),o=e.get("status");if(!a.get("show")||!o||o==="hide"){i&&n.remove(i),this._handle=null;return}var s;this._handle||(s=!0,i=this._handle=cy(a.get("icon"),{cursor:"move",draggable:!0,onmousemove:function(u){Li(u.event)},onmousedown:Nu(this._onHandleDragMove,this,0,0),drift:Nu(this._onHandleDragMove,this),ondragend:Nu(this._onHandleDragEnd,this)}),n.add(i)),tg(i,e,!1),i.setStyle(a.getItemStyle(null,["color","borderColor","borderWidth","opacity","shadowColor","shadowBlur","shadowOffsetX","shadowOffsetY"]));var l=a.get("size");H(l)||(l=[l,l]),i.scaleX=l[0]/2,i.scaleY=l[1]/2,_l(this,"_doDispatchAxisPointer",a.get("throttle")||0,"fixRate"),this._moveHandleToValue(t,s)}},r.prototype._moveHandleToValue=function(t,e){jp(this._axisPointerModel,!e&&this._moveAnimation,this._handle,Fu(this.getHandleTransform(t,this._axisModel,this._axisPointerModel)))},r.prototype._onHandleDragMove=function(t,e){var n=this._handle;if(n){this._dragging=!0;var i=this.updateHandleTransform(Fu(n),[t,e],this._axisModel,this._axisPointerModel);this._payloadInfo=i,n.stopAnimation(),n.attr(Fu(i)),bn(n).lastProp=null,this._doDispatchAxisPointer()}},r.prototype._doDispatchAxisPointer=function(){var t=this._handle;if(t){var e=this._payloadInfo,n=this._axisModel;this._api.dispatchAction({type:"updateAxisPointer",x:e.cursorPoint[0],y:e.cursorPoint[1],tooltipOption:e.tooltipOption,axesInfo:[{axisDim:n.axis.dim,axisIndex:n.componentIndex}]})}},r.prototype._onHandleDragEnd=function(){this._dragging=!1;var t=this._handle;if(t){var e=this._axisPointerModel.get("value");this._moveHandleToValue(e),this._api.dispatchAction({type:"hideTip"})}},r.prototype.clear=function(t){this._lastValue=null,this._lastStatus=null;var e=t.getZr(),n=this._group,i=this._handle;e&&n&&(this._lastGraphicKey=null,n&&e.remove(n),i&&e.remove(i),this._group=null,this._handle=null,this._payloadInfo=null),ks(this,"_doDispatchAxisPointer")},r.prototype.doClear=function(){},r.prototype.buildLabel=function(t,e,n){return n=n||0,{x:t[n],y:t[1-n],width:e[n],height:e[1-n]}},r})();function jp(r,t,e,n){W_(bn(e).lastProp,n)||(bn(e).lastProp=n,t?Ke(e,n,r):(e.stopAnimation(),e.attr(n)))}function W_(r,t){if(X(r)&&X(t)){var e=!0;return D(t,function(n,i){e=e&&W_(r[i],n)}),!!e}else return r===t}function Jp(r,t){r[t.get(["label","show"])?"show":"hide"]()}function Fu(r){return{x:r.x||0,y:r.y||0,rotation:r.rotation||0}}function tg(r,t,e){var n=t.get("z"),i=t.get("zlevel");r&&r.traverse(function(a){a.type!=="group"&&(n!=null&&(a.z=n),i!=null&&(a.zlevel=i),a.silent=e)})}function T2(r){var t=r.get("type"),e=r.getModel(t+"Style"),n;return t==="line"?(n=e.getLineStyle(),n.fill=null):t==="shadow"&&(n=e.getAreaStyle(),n.stroke=null),n}function M2(r,t,e,n,i){var a=e.get("value"),o=U_(a,t.axis,t.ecModel,e.get("seriesDataIndices"),{precision:e.get(["label","precision"]),formatter:e.get(["label","formatter"])}),s=e.getModel("label"),l=av(s.get("padding")||0),u=s.getFont(),f=om(o,u),h=i.position,c=f.width+l[1]+l[3],v=f.height+l[0]+l[2],d=i.align;d==="right"&&(h[0]-=c),d==="center"&&(h[0]-=c/2);var p=i.verticalAlign;p==="bottom"&&(h[1]-=v),p==="middle"&&(h[1]-=v/2),C2(h,c,v,n);var g=s.get("backgroundColor");(!g||g==="auto")&&(g=t.get(["axisLine","lineStyle","color"])),r.label={x:h[0],y:h[1],style:Hr(s,{text:o,font:u,fill:s.getTextColor(),padding:l,backgroundColor:g}),z2:10}}function C2(r,t,e,n){var i=n.getWidth(),a=n.getHeight();r[0]=Math.min(r[0]+t,i)-t,r[1]=Math.min(r[1]+e,a)-e,r[0]=Math.max(r[0],0),r[1]=Math.max(r[1],0)}function U_(r,t,e,n,i){r=t.scale.parse(r);var a=t.scale.getLabel({value:r},{precision:i.precision}),o=i.formatter;if(o){var s={value:Us(t,{value:r}),axisDimension:t.dim,axisIndex:t.index,seriesData:[]};D(n,function(l){var u=e.getSeriesByIndex(l.seriesIndex),f=l.dataIndexInside,h=u&&u.getDataParams(f);h&&s.seriesData.push(h)}),W(o)?a=o.replace("{value}",a):et(o)&&(a=o(s))}return a}function Y_(r,t,e){var n=lr();return Mh(n,n,e.rotation),Ju(n,n,e.position),Na([r.dataToCoord(t),(e.labelOffset||0)+(e.labelDirection||1)*(e.labelMargin||0)],n)}function D2(r,t,e,n,i,a){var o=Or.innerTextLayout(e.rotation,0,e.labelDirection);e.labelMargin=i.get(["label","margin"]),M2(t,n,i,a,{position:Y_(n.axis,r,e),align:o.textAlign,verticalAlign:o.textVerticalAlign})}function A2(r,t,e){return e=e||0,{x1:r[e],y1:r[1-e],x2:t[e],y2:t[1-e]}}function L2(r,t,e){return e=e||0,{x:r[e],y:r[1-e],width:t[e],height:t[1-e]}}var I2=(function(r){z(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.makeElOption=function(e,n,i,a,o){var s=i.axis,l=s.grid,u=a.get("type"),f=eg(l,s).getOtherAxis(s).getGlobalExtent(),h=s.toGlobalCoord(s.dataToCoord(n,!0));if(u&&u!=="none"){var c=T2(a),v=P2[u](s,h,f);v.style=c,e.graphicKey=v.type,e.pointer=v}var d=Zs(l.getRect(),i);D2(n,e,d,i,a,o)},t.prototype.getHandleTransform=function(e,n,i){var a=Zs(n.axis.grid.getRect(),n,{labelInside:!1});a.labelMargin=i.get(["handle","margin"]);var o=Y_(n.axis,e,a);return{x:o[0],y:o[1],rotation:a.rotation+(a.labelDirection<0?Math.PI:0)}},t.prototype.updateHandleTransform=function(e,n,i,a){var o=i.axis,s=o.grid,l=o.getGlobalExtent(!0),u=eg(s,o).getOtherAxis(o).getGlobalExtent(),f=o.dim==="x"?0:1,h=[e.x,e.y];h[f]+=n[f],h[f]=Math.min(l[1],h[f]),h[f]=Math.max(l[0],h[f]);var c=(u[1]+u[0])/2,v=[c,c];v[f]=h[f];var d=[{verticalAlign:"middle"},{align:"center"}];return{x:h[0],y:h[1],rotation:e.rotation,cursorPoint:v,tooltipOption:d[f]}},t})(x2);function eg(r,t){var e={};return e[t.dim+"AxisIndex"]=t.index,r.getCartesian(e)}var P2={line:function(r,t,e){var n=A2([t,e[0]],[t,e[1]],rg(r));return{type:"Line",subPixelOptimize:!0,shape:n}},shadow:function(r,t,e){var n=Math.max(1,r.getBandWidth()),i=e[1]-e[0];return{type:"Rect",shape:L2([t-n/2,e[0]],[n,i],rg(r))}}};function rg(r){return r.dim==="x"?0:1}var R2=(function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.type="axisPointer",t.defaultOption={show:"auto",z:50,type:"line",snap:!1,triggerTooltip:!0,triggerEmphasis:!0,value:null,status:null,link:[],animation:null,animationDurationUpdate:200,lineStyle:{color:Y.color.border,width:1,type:"dashed"},shadowStyle:{color:Y.color.shadowTint},label:{show:!0,formatter:null,precision:"auto",margin:3,color:Y.color.neutral00,padding:[5,7,5,7],backgroundColor:Y.color.accent60,borderColor:null,borderWidth:0,borderRadius:3},handle:{show:!1,icon:"M10.7,11.9v-1.3H9.3v1.3c-4.9,0.3-8.8,4.4-8.8,9.4c0,5,3.9,9.1,8.8,9.4h1.3c4.9-0.3,8.8-4.4,8.8-9.4C19.5,16.3,15.6,12.2,10.7,11.9z M13.3,24.4H6.7v-1.2h6.6z M13.3,22H6.7v-1.2h6.6z M13.3,19.6H6.7v-1.2h6.6z",size:45,margin:50,color:Y.color.accent40,throttle:40}},t})(dt),sr=gt(),E2=D;function Z_(r,t,e){if(!nt.node){var n=t.getZr();sr(n).records||(sr(n).records={}),k2(n,t);var i=sr(n).records[r]||(sr(n).records[r]={});i.handler=e}}function k2(r,t){if(sr(r).initialized)return;sr(r).initialized=!0,e("click",ie(ng,"click")),e("mousemove",ie(ng,"mousemove")),e("globalout",B2);function e(n,i){r.on(n,function(a){var o=N2(t);E2(sr(r).records,function(s){s&&i(s,a,o.dispatchAction)}),O2(o.pendings,t)})}}function O2(r,t){var e=r.showTip.length,n=r.hideTip.length,i;e?i=r.showTip[e-1]:n&&(i=r.hideTip[n-1]),i&&(i.dispatchAction=null,t.dispatchAction(i))}function B2(r,t,e){r.handler("leave",null,e)}function ng(r,t,e,n){t.handler(r,e,n)}function N2(r){var t={showTip:[],hideTip:[]},e=function(n){var i=t[n.type];i?i.push(n):(n.dispatchAction=e,r.dispatchAction(n))};return{dispatchAction:e,pendings:t}}function fh(r,t){if(!nt.node){var e=t.getZr(),n=(sr(e).records||{})[r];n&&(sr(e).records[r]=null)}}var F2=(function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.render=function(e,n,i){var a=n.getComponent("tooltip"),o=e.get("triggerOn")||a&&a.get("triggerOn")||"mousemove|click";Z_("axisPointer",i,function(s,l,u){o!=="none"&&(s==="leave"||o.indexOf(s)>=0)&&u({type:"updateAxisPointer",currTrigger:s,x:l&&l.offsetX,y:l&&l.offsetY})})},t.prototype.remove=function(e,n){fh("axisPointer",n)},t.prototype.dispose=function(e,n){fh("axisPointer",n)},t.type="axisPointer",t})(Me);function X_(r,t){var e=[],n=r.seriesIndex,i;if(n==null||!(i=t.getSeriesByIndex(n)))return{point:[]};var a=i.getData(),o=kn(a,r);if(o==null||o<0||H(o))return{point:[]};var s=a.getItemGraphicEl(o),l=i.coordinateSystem;if(i.getTooltipPosition)e=i.getTooltipPosition(o)||[];else if(l&&l.dataToPoint)if(r.isStacked){var u=l.getBaseAxis(),f=l.getOtherAxis(u),h=f.dim,c=u.dim,v=h==="x"||h==="radius"?1:0,d=a.mapDimension(c),p=[];p[v]=a.get(d,o),p[1-v]=a.get(a.getCalculationInfo("stackResultDimension"),o),e=l.dataToPoint(p)||[]}else e=l.dataToPoint(a.getValues($(l.dimensions,function(m){return a.mapDimension(m)}),o))||[];else if(s){var g=s.getBoundingRect().clone();g.applyTransform(s.transform),e=[g.x+g.width/2,g.y+g.height/2]}return{point:e,el:s}}var ig=gt();function z2(r,t,e){var n=r.currTrigger,i=[r.x,r.y],a=r,o=r.dispatchAction||Q(e.dispatchAction,e),s=t.getComponent("axisPointer").coordSysAxesInfo;if(s){fs(i)&&(i=X_({seriesIndex:a.seriesIndex,dataIndex:a.dataIndex},t).point);var l=fs(i),u=a.axesInfo,f=s.axesInfo,h=n==="leave"||fs(i),c={},v={},d={list:[],map:{}},p={showPointer:ie(V2,v),showTooltip:ie(G2,d)};D(s.coordSysMap,function(m,y){var _=l||m.containPoint(i);D(s.coordSysAxesInfo[y],function(S,w){var b=S.axis,T=Z2(u,S);if(!h&&_&&(!u||T)){var C=T&&T.value;C==null&&!l&&(C=b.pointToData(i)),C!=null&&ag(S,C,p,!1,c)}})});var g={};return D(f,function(m,y){var _=m.linkGroup;_&&!v[y]&&D(_.axesInfo,function(S,w){var b=v[w];if(S!==m&&b){var T=b.value;_.mapper&&(T=m.axis.scale.parse(_.mapper(T,og(S),og(m)))),g[m.key]=T}})}),D(g,function(m,y){ag(f[y],m,p,!0,c)}),W2(v,f,c),U2(d,i,r,o),Y2(f,o,e),c}}function ag(r,t,e,n,i){var a=r.axis;if(!(a.scale.isBlank()||!a.containData(t))){if(!r.involveSeries){e.showPointer(r,t);return}var o=H2(t,r),s=o.payloadBatch,l=o.snapToValue;s[0]&&i.seriesIndex==null&&O(i,s[0]),!n&&r.snap&&a.containData(l)&&l!=null&&(t=l),e.showPointer(r,t,s),e.showTooltip(r,o,l)}}function H2(r,t){var e=t.axis,n=e.dim,i=r,a=[],o=Number.MAX_VALUE,s=-1;return D(t.seriesModels,function(l,u){var f=l.getData().mapDimensionsAll(n),h,c;if(l.getAxisTooltipData){var v=l.getAxisTooltipData(f,r,e);c=v.dataIndices,h=v.nestestValue}else{if(c=l.indicesOfNearest(n,f[0],r,e.type==="category"?.5:null),!c.length)return;h=l.getData().get(f[0],c[0])}if(!(h==null||!isFinite(h))){var d=r-h,p=Math.abs(d);p<=o&&((p<o||d>=0&&s<0)&&(o=p,s=d,i=h,a.length=0),D(c,function(g){a.push({seriesIndex:l.seriesIndex,dataIndexInside:g,dataIndex:l.getData().getRawIndex(g)})}))}}),{payloadBatch:a,snapToValue:i}}function V2(r,t,e,n){r[t.key]={value:e,payloadBatch:n}}function G2(r,t,e,n){var i=e.payloadBatch,a=t.axis,o=a.model,s=t.axisPointerModel;if(!(!t.triggerTooltip||!i.length)){var l=t.coordSys.model,u=qa(l),f=r.map[u];f||(f=r.map[u]={coordSysId:l.id,coordSysIndex:l.componentIndex,coordSysType:l.type,coordSysMainType:l.mainType,dataByAxis:[]},r.list.push(f)),f.dataByAxis.push({axisDim:a.dim,axisIndex:o.componentIndex,axisType:o.type,axisId:o.id,value:n,valueLabelOpt:{precision:s.get(["label","precision"]),formatter:s.get(["label","formatter"])},seriesDataIndices:i.slice()})}}function W2(r,t,e){var n=e.axesInfo=[];D(t,function(i,a){var o=i.axisPointerModel.option,s=r[a];s?(!i.useHandle&&(o.status="show"),o.value=s.value,o.seriesDataIndices=(s.payloadBatch||[]).slice()):!i.useHandle&&(o.status="hide"),o.status==="show"&&n.push({axisDim:i.axis.dim,axisIndex:i.axis.model.componentIndex,value:o.value})})}function U2(r,t,e,n){if(fs(t)||!r.list.length){n({type:"hideTip"});return}var i=((r.list[0].dataByAxis[0]||{}).seriesDataIndices||[])[0]||{};n({type:"showTip",escapeConnect:!0,x:t[0],y:t[1],tooltipOption:e.tooltipOption,position:e.position,dataIndexInside:i.dataIndexInside,dataIndex:i.dataIndex,seriesIndex:i.seriesIndex,dataByCoordSys:r.list})}function Y2(r,t,e){var n=e.getZr(),i="axisPointerLastHighlights",a=ig(n)[i]||{},o=ig(n)[i]={};D(r,function(u,f){var h=u.axisPointerModel.option;h.status==="show"&&u.triggerEmphasis&&D(h.seriesDataIndices,function(c){var v=c.seriesIndex+" | "+c.dataIndex;o[v]=c})});var s=[],l=[];D(a,function(u,f){!o[f]&&l.push(u)}),D(o,function(u,f){!a[f]&&s.push(u)}),l.length&&e.dispatchAction({type:"downplay",escapeConnect:!0,notBlur:!0,batch:l}),s.length&&e.dispatchAction({type:"highlight",escapeConnect:!0,notBlur:!0,batch:s})}function Z2(r,t){for(var e=0;e<(r||[]).length;e++){var n=r[e];if(t.axis.dim===n.axisDim&&t.axis.model.componentIndex===n.axisIndex)return n}}function og(r){var t=r.axis.model,e={},n=e.axisDim=r.axis.dim;return e.axisIndex=e[n+"AxisIndex"]=t.componentIndex,e.axisName=e[n+"AxisName"]=t.name,e.axisId=e[n+"AxisId"]=t.id,e}function fs(r){return!r||r[0]==null||isNaN(r[0])||r[1]==null||isNaN(r[1])}function $_(r){H_.registerAxisPointerClass("CartesianAxisPointer",I2),r.registerComponentModel(R2),r.registerComponentView(F2),r.registerPreprocessor(function(t){if(t){(!t.axisPointer||t.axisPointer.length===0)&&(t.axisPointer={});var e=t.axisPointer.link;e&&!H(e)&&(t.axisPointer.link=[e])}}),r.registerProcessor(r.PRIORITY.PROCESSOR.STATISTIC,function(t,e){t.getComponent("axisPointer").coordSysAxesInfo=r2(t,e)}),r.registerAction({type:"updateAxisPointer",event:"updateAxisPointer",update:":updateAxisPointer"},z2)}function X2(r){Fn(p2),Fn($_)}var sg=["x","y","radius","angle","single"],$2=["cartesian2d","polar","singleAxis"];function q2(r){var t=r.get("coordinateSystem");return ft($2,t)>=0}function Pr(r){return r+"Axis"}function K2(r,t){var e=K(),n=[],i=K();r.eachComponent({mainType:"dataZoom",query:t},function(f){i.get(f.uid)||s(f)});var a;do a=!1,r.eachComponent("dataZoom",o);while(a);function o(f){!i.get(f.uid)&&l(f)&&(s(f),a=!0)}function s(f){i.set(f.uid,!0),n.push(f),u(f)}function l(f){var h=!1;return f.eachTargetAxis(function(c,v){var d=e.get(c);d&&d[v]&&(h=!0)}),h}function u(f){f.eachTargetAxis(function(h,c){(e.get(h)||e.set(h,[]))[c]=!0})}return n}function q_(r){var t=r.ecModel,e={infoList:[],infoMap:K()};return r.eachTargetAxis(function(n,i){var a=t.getComponent(Pr(n),i);if(a){var o=a.getCoordSysModel();if(o){var s=o.uid,l=e.infoMap.get(s);l||(l={model:o,axisModels:[]},e.infoList.push(l),e.infoMap.set(s,l)),l.axisModels.push(a)}}}),e}var zu=(function(){function r(){this.indexList=[],this.indexMap=[]}return r.prototype.add=function(t){this.indexMap[t]||(this.indexList.push(t),this.indexMap[t]=!0)},r})(),Xs=(function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e._autoThrottle=!0,e._noTarget=!0,e._rangePropMode=["percent","percent"],e}return t.prototype.init=function(e,n,i){var a=lg(e);this.settledOption=a,this.mergeDefaultAndTheme(e,i),this._doInit(a)},t.prototype.mergeOption=function(e){var n=lg(e);vt(this.option,e,!0),vt(this.settledOption,n,!0),this._doInit(n)},t.prototype._doInit=function(e){var n=this.option;this._setDefaultThrottle(e),this._updateRangeUse(e);var i=this.settledOption;D([["start","startValue"],["end","endValue"]],function(a,o){this._rangePropMode[o]==="value"&&(n[a[0]]=i[a[0]]=null)},this),this._resetTarget()},t.prototype._resetTarget=function(){var e=this.get("orient",!0),n=this._targetAxisInfoMap=K(),i=this._fillSpecifiedTargetAxis(n);i?this._orient=e||this._makeAutoOrientByTargetAxis():(this._orient=e||"horizontal",this._fillAutoTargetAxisByOrient(n,this._orient)),this._noTarget=!0,n.each(function(a){a.indexList.length&&(this._noTarget=!1)},this)},t.prototype._fillSpecifiedTargetAxis=function(e){var n=!1;return D(sg,function(i){var a=this.getReferringComponents(Pr(i),Hb);if(a.specified){n=!0;var o=new zu;D(a.models,function(s){o.add(s.componentIndex)}),e.set(i,o)}},this),n},t.prototype._fillAutoTargetAxisByOrient=function(e,n){var i=this.ecModel,a=!0;if(a){var o=n==="vertical"?"y":"x",s=i.findComponents({mainType:o+"Axis"});l(s,o)}if(a){var s=i.findComponents({mainType:"singleAxis",filter:function(f){return f.get("orient",!0)===n}});l(s,"single")}function l(u,f){var h=u[0];if(h){var c=new zu;if(c.add(h.componentIndex),e.set(f,c),a=!1,f==="x"||f==="y"){var v=h.getReferringComponents("grid",qt).models[0];v&&D(u,function(d){h.componentIndex!==d.componentIndex&&v===d.getReferringComponents("grid",qt).models[0]&&c.add(d.componentIndex)})}}}a&&D(sg,function(u){if(a){var f=i.findComponents({mainType:Pr(u),filter:function(c){return c.get("type",!0)==="category"}});if(f[0]){var h=new zu;h.add(f[0].componentIndex),e.set(u,h),a=!1}}},this)},t.prototype._makeAutoOrientByTargetAxis=function(){var e;return this.eachTargetAxis(function(n){!e&&(e=n)},this),e==="y"?"vertical":"horizontal"},t.prototype._setDefaultThrottle=function(e){if(e.hasOwnProperty("throttle")&&(this._autoThrottle=!1),this._autoThrottle){var n=this.ecModel.option;this.option.throttle=n.animation&&n.animationDurationUpdate>0?100:20}},t.prototype._updateRangeUse=function(e){var n=this._rangePropMode,i=this.get("rangeMode");D([["start","startValue"],["end","endValue"]],function(a,o){var s=e[a[0]]!=null,l=e[a[1]]!=null;s&&!l?n[o]="percent":!s&&l?n[o]="value":i?n[o]=i[o]:s&&(n[o]="percent")})},t.prototype.noTarget=function(){return this._noTarget},t.prototype.getFirstTargetAxisModel=function(){var e;return this.eachTargetAxis(function(n,i){e==null&&(e=this.ecModel.getComponent(Pr(n),i))},this),e},t.prototype.eachTargetAxis=function(e,n){this._targetAxisInfoMap.each(function(i,a){D(i.indexList,function(o){e.call(n,a,o)})})},t.prototype.getAxisProxy=function(e,n){var i=this.getAxisModel(e,n);if(i)return i.__dzAxisProxy},t.prototype.getAxisModel=function(e,n){var i=this._targetAxisInfoMap.get(e);if(i&&i.indexMap[n])return this.ecModel.getComponent(Pr(e),n)},t.prototype.setRawRange=function(e){var n=this.option,i=this.settledOption;D([["start","startValue"],["end","endValue"]],function(a){(e[a[0]]!=null||e[a[1]]!=null)&&(n[a[0]]=i[a[0]]=e[a[0]],n[a[1]]=i[a[1]]=e[a[1]])},this),this._updateRangeUse(e)},t.prototype.setCalculatedRange=function(e){var n=this.option;D(["start","startValue","end","endValue"],function(i){n[i]=e[i]})},t.prototype.getPercentRange=function(){var e=this.findRepresentativeAxisProxy();if(e)return e.getDataPercentWindow()},t.prototype.getValueRange=function(e,n){if(e==null&&n==null){var i=this.findRepresentativeAxisProxy();if(i)return i.getDataValueWindow()}else return this.getAxisProxy(e,n).getDataValueWindow()},t.prototype.findRepresentativeAxisProxy=function(e){if(e)return e.__dzAxisProxy;for(var n,i=this._targetAxisInfoMap.keys(),a=0;a<i.length;a++)for(var o=i[a],s=this._targetAxisInfoMap.get(o),l=0;l<s.indexList.length;l++){var u=this.getAxisProxy(o,s.indexList[l]);if(u.hostedBy(this))return u;n||(n=u)}return n},t.prototype.getRangePropMode=function(){return this._rangePropMode.slice()},t.prototype.getOrient=function(){return this._orient},t.type="dataZoom",t.dependencies=["xAxis","yAxis","radiusAxis","angleAxis","singleAxis","series","toolbox"],t.defaultOption={z:4,filterMode:"filter",start:0,end:100},t})(dt);function lg(r){var t={};return D(["start","end","startValue","endValue","throttle"],function(e){r.hasOwnProperty(e)&&(t[e]=r[e])}),t}var K_=(function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.render=function(e,n,i,a){this.dataZoomModel=e,this.ecModel=n,this.api=i},t.type="dataZoom",t})(Me),ui=D,ug=va,Q2=(function(){function r(t,e,n,i){this._dimName=t,this._axisIndex=e,this.ecModel=i,this._dataZoomModel=n}return r.prototype.hostedBy=function(t){return this._dataZoomModel===t},r.prototype.getDataValueWindow=function(){return this._valueWindow.slice()},r.prototype.getDataPercentWindow=function(){return this._percentWindow.slice()},r.prototype.getTargetSeriesModels=function(){var t=[];return this.ecModel.eachSeries(function(e){if(q2(e)){var n=Pr(this._dimName),i=e.getReferringComponents(n,qt).models[0];i&&this._axisIndex===i.componentIndex&&t.push(e)}},this),t},r.prototype.getAxisModel=function(){return this.ecModel.getComponent(this._dimName+"Axis",this._axisIndex)},r.prototype.getMinMaxSpan=function(){return st(this._minMaxSpan)},r.prototype.calculateDataWindow=function(t){var e=this._dataExtent,n=this.getAxisModel(),i=n.axis.scale,a=this._dataZoomModel.getRangePropMode(),o=[0,100],s=[],l=[],u;ui(["start","end"],function(c,v){var d=t[c],p=t[c+"Value"];a[v]==="percent"?(d==null&&(d=o[v]),p=i.parse(Et(d,o,e))):(u=!0,p=p==null?e[v]:i.parse(p),d=Et(p,e,o)),l[v]=p==null||isNaN(p)?e[v]:p,s[v]=d==null||isNaN(d)?o[v]:d}),ug(l),ug(s);var f=this._minMaxSpan;u?h(l,s,e,o,!1):h(s,l,o,e,!0);function h(c,v,d,p,g){var m=g?"Span":"ValueSpan";Ka(0,c,d,"all",f["min"+m],f["max"+m]);for(var y=0;y<2;y++)v[y]=Et(c[y],d,p,!0),g&&(v[y]=i.parse(v[y]))}return{valueWindow:l,percentWindow:s}},r.prototype.reset=function(t){if(t===this._dataZoomModel){var e=this.getTargetSeriesModels();this._dataExtent=j2(this,this._dimName,e),this._updateMinMaxSpan();var n=this.calculateDataWindow(t.settledOption);this._valueWindow=n.valueWindow,this._percentWindow=n.percentWindow,this._setAxisModel()}},r.prototype.filterData=function(t,e){if(t!==this._dataZoomModel)return;var n=this._dimName,i=this.getTargetSeriesModels(),a=t.get("filterMode"),o=this._valueWindow;if(a==="none")return;ui(i,function(l){var u=l.getData(),f=u.mapDimensionsAll(n);if(f.length){if(a==="weakFilter"){var h=u.getStore(),c=$(f,function(v){return u.getDimensionIndex(v)},u);u.filterSelf(function(v){for(var d,p,g,m=0;m<f.length;m++){var y=h.get(c[m],v),_=!isNaN(y),S=y<o[0],w=y>o[1];if(_&&!S&&!w)return!0;_&&(g=!0),S&&(d=!0),w&&(p=!0)}return g&&d&&p})}else ui(f,function(v){if(a==="empty")l.setData(u=u.map(v,function(p){return s(p)?p:NaN}));else{var d={};d[v]=o,u.selectRange(d)}});ui(f,function(v){u.setApproximateExtent(o,v)})}});function s(l){return l>=o[0]&&l<=o[1]}},r.prototype._updateMinMaxSpan=function(){var t=this._minMaxSpan={},e=this._dataZoomModel,n=this._dataExtent;ui(["min","max"],function(i){var a=e.get(i+"Span"),o=e.get(i+"ValueSpan");o!=null&&(o=this.getAxisModel().axis.scale.parse(o)),o!=null?a=Et(n[0]+o,n,[0,100],!0):a!=null&&(o=Et(a,[0,100],n,!0)-n[0]),t[i+"Span"]=a,t[i+"ValueSpan"]=o},this)},r.prototype._setAxisModel=function(){var t=this.getAxisModel(),e=this._percentWindow,n=this._valueWindow;if(e){var i=Lm(n,[0,500]);i=Math.min(i,20);var a=t.axis.scale.rawExtentInfo;e[0]!==0&&a.setDeterminedMinMax("min",+n[0].toFixed(i)),e[1]!==100&&a.setDeterminedMinMax("max",+n[1].toFixed(i)),a.freeze()}},r})();function j2(r,t,e){var n=[1/0,-1/0];ui(e,function(o){dL(n,o.getData(),t)});var i=r.getAxisModel(),a=__(i.axis.scale,i,n).calculate();return[a.min,a.max]}var J2={getTargetSeries:function(r){function t(i){r.eachComponent("dataZoom",function(a){a.eachTargetAxis(function(o,s){var l=r.getComponent(Pr(o),s);i(o,s,l,a)})})}t(function(i,a,o,s){o.__dzAxisProxy=null});var e=[];t(function(i,a,o,s){o.__dzAxisProxy||(o.__dzAxisProxy=new Q2(i,a,s,r),e.push(o.__dzAxisProxy))});var n=K();return D(e,function(i){D(i.getTargetSeriesModels(),function(a){n.set(a.uid,a)})}),n},overallReset:function(r,t){r.eachComponent("dataZoom",function(e){e.eachTargetAxis(function(n,i){e.getAxisProxy(n,i).reset(e)}),e.eachTargetAxis(function(n,i){e.getAxisProxy(n,i).filterData(e,t)})}),r.eachComponent("dataZoom",function(e){var n=e.findRepresentativeAxisProxy();if(n){var i=n.getDataPercentWindow(),a=n.getDataValueWindow();e.setCalculatedRange({start:i[0],end:i[1],startValue:a[0],endValue:a[1]})}})}};function tI(r){r.registerAction("dataZoom",function(t,e){var n=K2(e,t);D(n,function(i){i.setRawRange({start:t.start,end:t.end,startValue:t.startValue,endValue:t.endValue})})})}var fg=!1;function Q_(r){fg||(fg=!0,r.registerProcessor(r.PRIORITY.PROCESSOR.FILTER,J2),tI(r),r.registerSubTypeDefaulter("dataZoom",function(){return"slider"}))}var eI=(function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.type="tooltip",t.dependencies=["axisPointer"],t.defaultOption={z:60,show:!0,showContent:!0,trigger:"item",triggerOn:"mousemove|click",alwaysShowContent:!1,renderMode:"auto",confine:null,showDelay:0,hideDelay:100,transitionDuration:.4,displayTransition:!0,enterable:!1,backgroundColor:Y.color.neutral00,shadowBlur:10,shadowColor:"rgba(0, 0, 0, .2)",shadowOffsetX:1,shadowOffsetY:2,borderRadius:4,borderWidth:1,defaultBorderColor:Y.color.border,padding:null,extraCssText:"",axisPointer:{type:"line",axis:"auto",animation:"auto",animationDurationUpdate:200,animationEasingUpdate:"exponentialOut",crossStyle:{color:Y.color.borderShade,width:1,type:"dashed",textStyle:{}}},textStyle:{color:Y.color.tertiary,fontSize:14}},t})(dt);function j_(r){var t=r.get("confine");return t!=null?!!t:r.get("renderMode")==="richText"}function J_(r){if(nt.domSupported){for(var t=document.documentElement.style,e=0,n=r.length;e<n;e++)if(r[e]in t)return r[e]}}var t1=J_(["transform","webkitTransform","OTransform","MozTransform","msTransform"]),rI=J_(["webkitTransition","transition","OTransition","MozTransition","msTransition"]);function e1(r,t){if(!r)return t;t=e0(t,!0);var e=r.indexOf(t);return r=e===-1?t:"-"+r.slice(0,e)+"-"+t,r.toLowerCase()}function nI(r,t){var e=r.currentStyle||document.defaultView&&document.defaultView.getComputedStyle(r);return e?e[t]:null}var iI=e1(rI,"transition"),Tv=e1(t1,"transform"),aI="position:absolute;display:block;border-style:solid;white-space:nowrap;z-index:9999999;"+(nt.transform3dSupported?"will-change:transform;":"");function oI(r){return r=r==="left"?"right":r==="right"?"left":r==="top"?"bottom":"top",r}function sI(r,t,e){if(!W(e)||e==="inside")return"";var n=r.get("backgroundColor"),i=r.get("borderWidth");t=On(t);var a=oI(e),o=Math.max(Math.round(i)*1.5,6),s="",l=Tv+":",u;ft(["left","right"],a)>-1?(s+="top:50%",l+="translateY(-50%) rotate("+(u=a==="left"?-225:-45)+"deg)"):(s+="left:50%",l+="translateX(-50%) rotate("+(u=a==="top"?225:45)+"deg)");var f=u*Math.PI/180,h=o+i,c=h*Math.abs(Math.cos(f))+h*Math.abs(Math.sin(f)),v=Math.round(((c-Math.SQRT2*i)/2+Math.SQRT2*i-(c-h)/2)*100)/100;s+=";"+a+":-"+v+"px";var d=t+" solid "+i+"px;",p=["position:absolute;width:"+o+"px;height:"+o+"px;z-index:-1;",s+";"+l+";","border-bottom:"+d,"border-right:"+d,"background-color:"+n+";"];return'<div style="'+p.join("")+'"></div>'}function lI(r,t,e){var n="cubic-bezier(0.23,1,0.32,1)",i="",a="";return e&&(i=" "+r/2+"s "+n,a="opacity"+i+",visibility"+i),t||(i=" "+r+"s "+n,a+=(a.length?",":"")+(nt.transformSupported?""+Tv+i:",left"+i+",top"+i)),iI+":"+a}function hg(r,t,e){var n=r.toFixed(0)+"px",i=t.toFixed(0)+"px";if(!nt.transformSupported)return e?"top:"+i+";left:"+n+";":[["top",i],["left",n]];var a=nt.transform3dSupported,o="translate"+(a?"3d":"")+"("+n+","+i+(a?",0":"")+")";return e?"top:0;left:0;"+Tv+":"+o+";":[["top",0],["left",0],[t1,o]]}function uI(r){var t=[],e=r.get("fontSize"),n=r.getTextColor();n&&t.push("color:"+n),t.push("font:"+r.getFont());var i=q(r.get("lineHeight"),Math.round(e*3/2));e&&t.push("line-height:"+i+"px");var a=r.get("textShadowColor"),o=r.get("textShadowBlur")||0,s=r.get("textShadowOffsetX")||0,l=r.get("textShadowOffsetY")||0;return a&&o&&t.push("text-shadow:"+s+"px "+l+"px "+o+"px "+a),D(["decoration","align"],function(u){var f=r.get(u);f&&t.push("text-"+u+":"+f)}),t.join(";")}function fI(r,t,e,n){var i=[],a=r.get("transitionDuration"),o=r.get("backgroundColor"),s=r.get("shadowBlur"),l=r.get("shadowColor"),u=r.get("shadowOffsetX"),f=r.get("shadowOffsetY"),h=r.getModel("textStyle"),c=h0(r,"html"),v=u+"px "+f+"px "+s+"px "+l;return i.push("box-shadow:"+v),t&&a>0&&i.push(lI(a,e,n)),o&&i.push("background-color:"+o),D(["width","color","radius"],function(d){var p="border-"+d,g=e0(p),m=r.get(g);m!=null&&i.push(p+":"+m+(d==="color"?"":"px"))}),i.push(uI(h)),c!=null&&i.push("padding:"+av(c).join("px ")+"px"),i.join(";")+";"}function vg(r,t,e,n,i){var a=t&&t.painter;if(e){var o=a&&a.getViewportRoot();o&&fT(r,o,e,n,i)}else{r[0]=n,r[1]=i;var s=a&&a.getViewportRootOffset();s&&(r[0]+=s.offsetLeft,r[1]+=s.offsetTop)}r[2]=r[0]/t.getWidth(),r[3]=r[1]/t.getHeight()}var hI=(function(){function r(t,e){if(this._show=!1,this._styleCoord=[0,0,0,0],this._enterable=!0,this._alwaysShowContent=!1,this._firstShow=!0,this._longHide=!0,nt.wxa)return null;var n=document.createElement("div");n.domBelongToZr=!0,this.el=n;var i=this._zr=t.getZr(),a=e.appendTo,o=a&&(W(a)?document.querySelector(a):Ia(a)?a:et(a)&&a(t.getDom()));vg(this._styleCoord,i,o,t.getWidth()/2,t.getHeight()/2),(o||t.getDom()).appendChild(n),this._api=t,this._container=o;var s=this;n.onmouseenter=function(){s._enterable&&(clearTimeout(s._hideTimeout),s._show=!0),s._inContent=!0},n.onmousemove=function(l){if(l=l||window.event,!s._enterable){var u=i.handler,f=i.painter.getViewportRoot();ye(f,l,!0),u.dispatch("mousemove",l)}},n.onmouseleave=function(){s._inContent=!1,s._enterable&&s._show&&s.hideLater(s._hideDelay)}}return r.prototype.update=function(t){if(!this._container){var e=this._api.getDom(),n=nI(e,"position"),i=e.style;i.position!=="absolute"&&n!=="absolute"&&(i.position="relative")}var a=t.get("alwaysShowContent");a&&this._moveIfResized(),this._alwaysShowContent=a,this._enableDisplayTransition=t.get("displayTransition")&&t.get("transitionDuration")>0,this.el.className=t.get("className")||""},r.prototype.show=function(t,e){clearTimeout(this._hideTimeout),clearTimeout(this._longHideTimeout);var n=this.el,i=n.style,a=this._styleCoord;n.innerHTML?i.cssText=aI+fI(t,!this._firstShow,this._longHide,this._enableDisplayTransition)+hg(a[0],a[1],!0)+("border-color:"+On(e)+";")+(t.get("extraCssText")||"")+(";pointer-events:"+(this._enterable?"auto":"none")):i.display="none",this._show=!0,this._firstShow=!1,this._longHide=!1},r.prototype.setContent=function(t,e,n,i,a){var o=this.el;if(t==null){o.innerHTML="";return}var s="";if(W(a)&&n.get("trigger")==="item"&&!j_(n)&&(s=sI(n,i,a)),W(t))o.innerHTML=t+s;else if(t){o.innerHTML="",H(t)||(t=[t]);for(var l=0;l<t.length;l++)Ia(t[l])&&t[l].parentNode!==o&&o.appendChild(t[l]);if(s&&o.childNodes.length){var u=document.createElement("div");u.innerHTML=s,o.appendChild(u)}}},r.prototype.setEnterable=function(t){this._enterable=t},r.prototype.getSize=function(){var t=this.el;return t?[t.offsetWidth,t.offsetHeight]:[0,0]},r.prototype.moveTo=function(t,e){if(this.el){var n=this._styleCoord;if(vg(n,this._zr,this._container,t,e),n[0]!=null&&n[1]!=null){var i=this.el.style,a=hg(n[0],n[1]);D(a,function(o){i[o[0]]=o[1]})}}},r.prototype._moveIfResized=function(){var t=this._styleCoord[2],e=this._styleCoord[3];this.moveTo(t*this._zr.getWidth(),e*this._zr.getHeight())},r.prototype.hide=function(){var t=this,e=this.el.style;this._enableDisplayTransition?(e.visibility="hidden",e.opacity="0"):e.display="none",nt.transform3dSupported&&(e.willChange=""),this._show=!1,this._longHideTimeout=setTimeout(function(){return t._longHide=!0},500)},r.prototype.hideLater=function(t){this._show&&!(this._inContent&&this._enterable)&&!this._alwaysShowContent&&(t?(this._hideDelay=t,this._show=!1,this._hideTimeout=setTimeout(Q(this.hide,this),t)):this.hide())},r.prototype.isShow=function(){return this._show},r.prototype.dispose=function(){clearTimeout(this._hideTimeout),clearTimeout(this._longHideTimeout);var t=this._zr;hT(t&&t.painter&&t.painter.getViewportRoot(),this._container);var e=this.el;if(e){e.onmouseenter=e.onmousemove=e.onmouseleave=null;var n=e.parentNode;n&&n.removeChild(e)}this.el=this._container=null},r})(),vI=(function(){function r(t){this._show=!1,this._styleCoord=[0,0,0,0],this._alwaysShowContent=!1,this._enterable=!0,this._zr=t.getZr(),dg(this._styleCoord,this._zr,t.getWidth()/2,t.getHeight()/2)}return r.prototype.update=function(t){var e=t.get("alwaysShowContent");e&&this._moveIfResized(),this._alwaysShowContent=e},r.prototype.show=function(){this._hideTimeout&&clearTimeout(this._hideTimeout),this.el.show(),this._show=!0},r.prototype.setContent=function(t,e,n,i,a){var o=this;X(t)&&ut(""),this.el&&this._zr.remove(this.el);var s=n.getModel("textStyle");this.el=new oe({style:{rich:e.richTextStyles,text:t,lineHeight:22,borderWidth:1,borderColor:i,textShadowColor:s.get("textShadowColor"),fill:n.get(["textStyle","color"]),padding:h0(n,"richText"),verticalAlign:"top",align:"left"},z:n.get("z")}),D(["backgroundColor","borderRadius","shadowColor","shadowBlur","shadowOffsetX","shadowOffsetY"],function(u){o.el.style[u]=n.get(u)}),D(["textShadowBlur","textShadowOffsetX","textShadowOffsetY"],function(u){o.el.style[u]=s.get(u)||0}),this._zr.add(this.el);var l=this;this.el.on("mouseover",function(){l._enterable&&(clearTimeout(l._hideTimeout),l._show=!0),l._inContent=!0}),this.el.on("mouseout",function(){l._enterable&&l._show&&l.hideLater(l._hideDelay),l._inContent=!1})},r.prototype.setEnterable=function(t){this._enterable=t},r.prototype.getSize=function(){var t=this.el,e=this.el.getBoundingRect(),n=cg(t.style);return[e.width+n.left+n.right,e.height+n.top+n.bottom]},r.prototype.moveTo=function(t,e){var n=this.el;if(n){var i=this._styleCoord;dg(i,this._zr,t,e),t=i[0],e=i[1];var a=n.style,o=Mr(a.borderWidth||0),s=cg(a);n.x=t+o+s.left,n.y=e+o+s.top,n.markRedraw()}},r.prototype._moveIfResized=function(){var t=this._styleCoord[2],e=this._styleCoord[3];this.moveTo(t*this._zr.getWidth(),e*this._zr.getHeight())},r.prototype.hide=function(){this.el&&this.el.hide(),this._show=!1},r.prototype.hideLater=function(t){this._show&&!(this._inContent&&this._enterable)&&!this._alwaysShowContent&&(t?(this._hideDelay=t,this._show=!1,this._hideTimeout=setTimeout(Q(this.hide,this),t)):this.hide())},r.prototype.isShow=function(){return this._show},r.prototype.dispose=function(){this._zr.remove(this.el)},r})();function Mr(r){return Math.max(0,r)}function cg(r){var t=Mr(r.shadowBlur||0),e=Mr(r.shadowOffsetX||0),n=Mr(r.shadowOffsetY||0);return{left:Mr(t-e),right:Mr(t+e),top:Mr(t-n),bottom:Mr(t+n)}}function dg(r,t,e,n){r[0]=e,r[1]=n,r[2]=r[0]/t.getWidth(),r[3]=r[1]/t.getHeight()}var cI=new Tt({shape:{x:-1,y:-1,width:2,height:2}}),dI=(function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.init=function(e,n){if(!(nt.node||!n.getDom())){var i=e.getComponent("tooltip"),a=this._renderMode=Gb(i.get("renderMode"));this._tooltipContent=a==="richText"?new vI(n):new hI(n,{appendTo:i.get("appendToBody",!0)?"body":i.get("appendTo",!0)})}},t.prototype.render=function(e,n,i){if(!(nt.node||!i.getDom())){this.group.removeAll(),this._tooltipModel=e,this._ecModel=n,this._api=i;var a=this._tooltipContent;a.update(e),a.setEnterable(e.get("enterable")),this._initGlobalListener(),this._keepShow(),this._renderMode!=="richText"&&e.get("transitionDuration")?_l(this,"_updatePosition",50,"fixRate"):ks(this,"_updatePosition")}},t.prototype._initGlobalListener=function(){var e=this._tooltipModel,n=e.get("triggerOn");Z_("itemTooltip",this._api,Q(function(i,a,o){n!=="none"&&(n.indexOf(i)>=0?this._tryShow(a,o):i==="leave"&&this._hide(o))},this))},t.prototype._keepShow=function(){var e=this._tooltipModel,n=this._ecModel,i=this._api,a=e.get("triggerOn");if(this._lastX!=null&&this._lastY!=null&&a!=="none"&&a!=="click"){var o=this;clearTimeout(this._refreshUpdateTimeout),this._refreshUpdateTimeout=setTimeout(function(){!i.isDisposed()&&o.manuallyShowTip(e,n,i,{x:o._lastX,y:o._lastY,dataByCoordSys:o._lastDataByCoordSys})})}},t.prototype.manuallyShowTip=function(e,n,i,a){if(!(a.from===this.uid||nt.node||!i.getDom())){var o=pg(a,i);this._ticket="";var s=a.dataByCoordSys,l=yI(a,n,i);if(l){var u=l.el.getBoundingRect().clone();u.applyTransform(l.el.transform),this._tryShow({offsetX:u.x+u.width/2,offsetY:u.y+u.height/2,target:l.el,position:a.position,positionDefault:"bottom"},o)}else if(a.tooltip&&a.x!=null&&a.y!=null){var f=cI;f.x=a.x,f.y=a.y,f.update(),pt(f).tooltipConfig={name:null,option:a.tooltip},this._tryShow({offsetX:a.x,offsetY:a.y,target:f},o)}else if(s)this._tryShow({offsetX:a.x,offsetY:a.y,position:a.position,dataByCoordSys:s,tooltipOption:a.tooltipOption},o);else if(a.seriesIndex!=null){if(this._manuallyAxisShowTip(e,n,i,a))return;var h=X_(a,n),c=h.point[0],v=h.point[1];c!=null&&v!=null&&this._tryShow({offsetX:c,offsetY:v,target:h.el,position:a.position,positionDefault:"bottom"},o)}else a.x!=null&&a.y!=null&&(i.dispatchAction({type:"updateAxisPointer",x:a.x,y:a.y}),this._tryShow({offsetX:a.x,offsetY:a.y,position:a.position,target:i.getZr().findHover(a.x,a.y).target},o))}},t.prototype.manuallyHideTip=function(e,n,i,a){var o=this._tooltipContent;this._tooltipModel&&o.hideLater(this._tooltipModel.get("hideDelay")),this._lastX=this._lastY=this._lastDataByCoordSys=null,a.from!==this.uid&&this._hide(pg(a,i))},t.prototype._manuallyAxisShowTip=function(e,n,i,a){var o=a.seriesIndex,s=a.dataIndex,l=n.getComponent("axisPointer").coordSysAxesInfo;if(!(o==null||s==null||l==null)){var u=n.getSeriesByIndex(o);if(u){var f=u.getData(),h=oa([f.getItemModel(s),u,(u.coordinateSystem||{}).model],this._tooltipModel);if(h.get("trigger")==="axis")return i.dispatchAction({type:"updateAxisPointer",seriesIndex:o,dataIndex:s,position:a.position}),!0}}},t.prototype._tryShow=function(e,n){var i=e.target,a=this._tooltipModel;if(a){this._lastX=e.offsetX,this._lastY=e.offsetY;var o=e.dataByCoordSys;if(o&&o.length)this._showAxisTooltip(o,e);else if(i){var s=pt(i);if(s.ssrType==="legend")return;this._lastDataByCoordSys=null;var l,u;pa(i,function(f){if(f.tooltipDisabled)return l=u=null,!0;l||u||(pt(f).dataIndex!=null?l=f:pt(f).tooltipConfig!=null&&(u=f))},!0),l?this._showSeriesItemTooltip(e,l,n):u?this._showComponentItemTooltip(e,u,n):this._hide(n)}else this._lastDataByCoordSys=null,this._hide(n)}},t.prototype._showOrMove=function(e,n){var i=e.get("showDelay");n=Q(n,this),clearTimeout(this._showTimout),i>0?this._showTimout=setTimeout(n,i):n()},t.prototype._showAxisTooltip=function(e,n){var i=this._ecModel,a=this._tooltipModel,o=[n.offsetX,n.offsetY],s=oa([n.tooltipOption],a),l=this._renderMode,u=[],f=Ga("section",{blocks:[],noHeader:!0}),h=[],c=new lu;D(e,function(y){D(y.dataByAxis,function(_){var S=i.getComponent(_.axisDim+"Axis",_.axisIndex),w=_.value;if(!(!S||w==null)){var b=U_(w,S.axis,i,_.seriesDataIndices,_.valueLabelOpt),T=Ga("section",{header:b,noHeader:!We(b),sortBlocks:!0,blocks:[]});f.blocks.push(T),D(_.seriesDataIndices,function(C){var x=i.getSeriesByIndex(C.seriesIndex),M=C.dataIndexInside,A=x.getDataParams(M);if(!(A.dataIndex<0)){A.axisDim=_.axisDim,A.axisIndex=_.axisIndex,A.axisType=_.axisType,A.axisId=_.axisId,A.axisValue=Us(S.axis,{value:w}),A.axisValueLabel=b,A.marker=c.makeTooltipMarker("item",On(A.color),l);var P=fd(x.formatTooltip(M,!0,null)),L=P.frag;if(L){var I=oa([x],a).get("valueFormatter");T.blocks.push(I?O({valueFormatter:I},L):L)}P.text&&h.push(P.text),u.push(A)}})}})}),f.blocks.reverse(),h.reverse();var v=n.position,d=s.get("order"),p=pd(f,c,l,d,i.get("useUTC"),s.get("textStyle"));p&&h.unshift(p);var g=l==="richText"?`

`:"<br/>",m=h.join(g);this._showOrMove(s,function(){this._updateContentNotChangedOnAxis(e,u)?this._updatePosition(s,v,o[0],o[1],this._tooltipContent,u):this._showTooltipContent(s,m,u,Math.random()+"",o[0],o[1],v,null,c)})},t.prototype._showSeriesItemTooltip=function(e,n,i){var a=this._ecModel,o=pt(n),s=o.seriesIndex,l=a.getSeriesByIndex(s),u=o.dataModel||l,f=o.dataIndex,h=o.dataType,c=u.getData(h),v=this._renderMode,d=e.positionDefault,p=oa([c.getItemModel(f),u,l&&(l.coordinateSystem||{}).model],this._tooltipModel,d?{position:d}:null),g=p.get("trigger");if(!(g!=null&&g!=="item")){var m=u.getDataParams(f,h),y=new lu;m.marker=y.makeTooltipMarker("item",On(m.color),v);var _=fd(u.formatTooltip(f,!1,h)),S=p.get("order"),w=p.get("valueFormatter"),b=_.frag,T=b?pd(w?O({valueFormatter:w},b):b,y,v,S,a.get("useUTC"),p.get("textStyle")):_.text,C="item_"+u.name+"_"+f;this._showOrMove(p,function(){this._showTooltipContent(p,T,m,C,e.offsetX,e.offsetY,e.position,e.target,y)}),i({type:"showTip",dataIndexInside:f,dataIndex:c.getRawIndex(f),seriesIndex:s,from:this.uid})}},t.prototype._showComponentItemTooltip=function(e,n,i){var a=this._renderMode==="html",o=pt(n),s=o.tooltipConfig,l=s.option||{},u=l.encodeHTMLContent;if(W(l)){var f=l;l={content:f,formatter:f},u=!0}u&&a&&l.content&&(l=st(l),l.content=re(l.content));var h=[l],c=this._ecModel.getComponent(o.componentMainType,o.componentIndex);c&&h.push(c),h.push({formatter:l.content});var v=e.positionDefault,d=oa(h,this._tooltipModel,v?{position:v}:null),p=d.get("content"),g=Math.random()+"",m=new lu;this._showOrMove(d,function(){var y=st(d.get("formatterParams")||{});this._showTooltipContent(d,p,y,g,e.offsetX,e.offsetY,e.position,n,m)}),i({type:"showTip",from:this.uid})},t.prototype._showTooltipContent=function(e,n,i,a,o,s,l,u,f){if(this._ticket="",!(!e.get("showContent")||!e.get("show"))){var h=this._tooltipContent;h.setEnterable(e.get("enterable"));var c=e.get("formatter");l=l||e.get("position");var v=n,d=this._getNearestPoint([o,s],i,e.get("trigger"),e.get("borderColor"),e.get("defaultBorderColor",!0)),p=d.color;if(c)if(W(c)){var g=e.ecModel.get("useUTC"),m=H(i)?i[0]:i,y=m&&m.axisType&&m.axisType.indexOf("time")>=0;v=c,y&&(v=yl(m.axisValue,v,g)),v=r0(v,i,!0)}else if(et(c)){var _=Q(function(S,w){S===this._ticket&&(h.setContent(w,f,e,p,l),this._updatePosition(e,l,o,s,h,i,u))},this);this._ticket=a,v=c(i,a,_)}else v=c;h.setContent(v,f,e,p,l),h.show(e,p),this._updatePosition(e,l,o,s,h,i,u)}},t.prototype._getNearestPoint=function(e,n,i,a,o){if(i==="axis"||H(n))return{color:a||o};if(!H(n))return{color:a||n.color||n.borderColor}},t.prototype._updatePosition=function(e,n,i,a,o,s,l){var u=this._api.getWidth(),f=this._api.getHeight();n=n||e.get("position");var h=o.getSize(),c=e.get("align"),v=e.get("verticalAlign"),d=l&&l.getBoundingRect().clone();if(l&&d.applyTransform(l.transform),et(n)&&(n=n([i,a],s,o.el,d,{viewSize:[u,f],contentSize:h.slice()})),H(n))i=It(n[0],u),a=It(n[1],f);else if(X(n)){var p=n;p.width=h[0],p.height=h[1];var g=ro(p,{width:u,height:f});i=g.x,a=g.y,c=null,v=null}else if(W(n)&&l){var m=mI(n,d,h,e.get("borderWidth"));i=m[0],a=m[1]}else{var m=pI(i,a,o,u,f,c?null:20,v?null:20);i=m[0],a=m[1]}if(c&&(i-=gg(c)?h[0]/2:c==="right"?h[0]:0),v&&(a-=gg(v)?h[1]/2:v==="bottom"?h[1]:0),j_(e)){var m=gI(i,a,o,u,f);i=m[0],a=m[1]}o.moveTo(i,a)},t.prototype._updateContentNotChangedOnAxis=function(e,n){var i=this._lastDataByCoordSys,a=this._cbParamsList,o=!!i&&i.length===e.length;return o&&D(i,function(s,l){var u=s.dataByAxis||[],f=e[l]||{},h=f.dataByAxis||[];o=o&&u.length===h.length,o&&D(u,function(c,v){var d=h[v]||{},p=c.seriesDataIndices||[],g=d.seriesDataIndices||[];o=o&&c.value===d.value&&c.axisType===d.axisType&&c.axisId===d.axisId&&p.length===g.length,o&&D(p,function(m,y){var _=g[y];o=o&&m.seriesIndex===_.seriesIndex&&m.dataIndex===_.dataIndex}),a&&D(c.seriesDataIndices,function(m){var y=m.seriesIndex,_=n[y],S=a[y];_&&S&&S.data!==_.data&&(o=!1)})})}),this._lastDataByCoordSys=e,this._cbParamsList=n,!!o},t.prototype._hide=function(e){this._lastDataByCoordSys=null,e({type:"hideTip",from:this.uid})},t.prototype.dispose=function(e,n){nt.node||!n.getDom()||(ks(this,"_updatePosition"),this._tooltipContent.dispose(),fh("itemTooltip",n))},t.type="tooltip",t})(Me);function oa(r,t,e){var n=t.ecModel,i;e?(i=new xt(e,n,n),i=new xt(t.option,i,n)):i=t;for(var a=r.length-1;a>=0;a--){var o=r[a];o&&(o instanceof xt&&(o=o.get("tooltip",!0)),W(o)&&(o={formatter:o}),o&&(i=new xt(o,i,n)))}return i}function pg(r,t){return r.dispatchAction||Q(t.dispatchAction,t)}function pI(r,t,e,n,i,a,o){var s=e.getSize(),l=s[0],u=s[1];return a!=null&&(r+l+a+2>n?r-=l+a:r+=a),o!=null&&(t+u+o>i?t-=u+o:t+=o),[r,t]}function gI(r,t,e,n,i){var a=e.getSize(),o=a[0],s=a[1];return r=Math.min(r+o,n)-o,t=Math.min(t+s,i)-s,r=Math.max(r,0),t=Math.max(t,0),[r,t]}function mI(r,t,e,n){var i=e[0],a=e[1],o=Math.ceil(Math.SQRT2*n)+8,s=0,l=0,u=t.width,f=t.height;switch(r){case"inside":s=t.x+u/2-i/2,l=t.y+f/2-a/2;break;case"top":s=t.x+u/2-i/2,l=t.y-a-o;break;case"bottom":s=t.x+u/2-i/2,l=t.y+f+o;break;case"left":s=t.x-i-o,l=t.y+f/2-a/2;break;case"right":s=t.x+u+o,l=t.y+f/2-a/2}return[s,l]}function gg(r){return r==="center"||r==="middle"}function yI(r,t,e){var n=Lh(r).queryOptionMap,i=n.keys()[0];if(!(!i||i==="series")){var a=Ja(t,i,n.get(i),{useDefault:!1,enableAll:!1,enableNone:!1}),o=a.models[0];if(o){var s=e.getViewOfComponentModel(o),l;if(s.group.traverse(function(u){var f=pt(u).tooltipConfig;if(f&&f.name===r.name)return l=u,!0}),l)return{componentMainType:i,componentIndex:o.componentIndex,el:l}}}}function _I(r){Fn($_),r.registerComponentModel(eI),r.registerComponentView(dI),r.registerAction({type:"showTip",event:"showTip",update:"tooltip:manuallyShowTip"},Kt),r.registerAction({type:"hideTip",event:"hideTip",update:"tooltip:manuallyHideTip"},Kt)}var SI=(function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.layoutMode={type:"box",ignoreSize:!0},e}return t.type="title",t.defaultOption={z:6,show:!0,text:"",target:"blank",subtext:"",subtarget:"blank",left:"center",top:Y.size.m,backgroundColor:Y.color.transparent,borderColor:Y.color.primary,borderWidth:0,padding:5,itemGap:10,textStyle:{fontSize:18,fontWeight:"bold",color:Y.color.primary},subtextStyle:{fontSize:12,color:Y.color.quaternary}},t})(dt),bI=(function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.render=function(e,n,i){if(this.group.removeAll(),!!e.get("show")){var a=this.group,o=e.getModel("textStyle"),s=e.getModel("subtextStyle"),l=e.get("textAlign"),u=q(e.get("textBaseline"),e.get("textVerticalAlign")),f=new oe({style:Hr(o,{text:e.get("text"),fill:o.getTextColor()},{disableBox:!0}),z2:10}),h=f.getBoundingRect(),c=e.get("subtext"),v=new oe({style:Hr(s,{text:c,fill:s.getTextColor(),y:h.height+e.get("itemGap"),verticalAlign:"top"},{disableBox:!0}),z2:10}),d=e.get("link"),p=e.get("sublink"),g=e.get("triggerEvent",!0);f.silent=!d&&!g,v.silent=!p&&!g,d&&f.on("click",function(){ld(d,"_"+e.get("target"))}),p&&v.on("click",function(){ld(p,"_"+e.get("subtarget"))}),pt(f).eventData=pt(v).eventData=g?{componentType:"title",componentIndex:e.componentIndex}:null,a.add(f),c&&a.add(v);var m=a.getBoundingRect(),y=e.getBoxLayoutParams();y.width=m.width,y.height=m.height;var _=ov(e,i),S=ro(y,_.refContainer,e.get("padding"));l||(l=e.get("left")||e.get("right"),l==="middle"&&(l="center"),l==="right"?S.x+=S.width:l==="center"&&(S.x+=S.width/2)),u||(u=e.get("top")||e.get("bottom"),u==="center"&&(u="middle"),u==="bottom"?S.y+=S.height:u==="middle"&&(S.y+=S.height/2),u=u||"top"),a.x=S.x,a.y=S.y,a.markRedraw();var w={align:l,verticalAlign:u};f.setStyle(w),v.setStyle(w),m=a.getBoundingRect();var b=S.margin,T=e.getItemStyle(["color","opacity"]);T.fill=e.get("backgroundColor");var C=new Tt({shape:{x:m.x-b[3],y:m.y-b[0],width:m.width+b[1]+b[3],height:m.height+b[0]+b[2],r:e.get("borderRadius")},style:T,subPixelOptimize:!0,silent:!0});a.add(C)}},t.type="title",t})(Me);function wI(r){r.registerComponentModel(SI),r.registerComponentView(bI)}var xI=(function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.type="dataZoom.inside",t.defaultOption=Wy(Xs.defaultOption,{disabled:!1,zoomLock:!1,zoomOnMouseWheel:!0,moveOnMouseMove:!0,moveOnMouseWheel:!1,preventDefaultMouseMove:!0}),t})(Xs),Mv=gt();function TI(r,t,e){Mv(r).coordSysRecordMap.each(function(n){var i=n.dataZoomInfoMap.get(t.uid);i&&(i.getRange=e)})}function MI(r,t){for(var e=Mv(r).coordSysRecordMap,n=e.keys(),i=0;i<n.length;i++){var a=n[i],o=e.get(a),s=o.dataZoomInfoMap;if(s){var l=t.uid,u=s.get(l);u&&(s.removeKey(l),s.keys().length||r1(e,o))}}}function r1(r,t){if(t){r.removeKey(t.model.uid);var e=t.controller;e&&e.dispose()}}function CI(r,t){var e={model:t,containsPoint:ie(AI,t),dispatchAction:ie(DI,r),dataZoomInfoMap:null,controller:null},n=e.controller=new _2(r.getZr());return D(["pan","zoom","scrollMove"],function(i){n.on(i,function(a){var o=[];e.dataZoomInfoMap.each(function(s){if(a.isAvailableBehavior(s.model.option)){var l=(s.getRange||{})[i],u=l&&l(s.dzReferCoordSysInfo,e.model.mainType,e.controller,a);!s.model.get("disabled",!0)&&u&&o.push({dataZoomId:s.model.id,start:u[0],end:u[1]})}}),o.length&&e.dispatchAction(o)})}),e}function DI(r,t){r.isDisposed()||r.dispatchAction({type:"dataZoom",animation:{easing:"cubicOut",duration:100},batch:t})}function AI(r,t,e,n){return r.coordinateSystem.containPoint([e,n])}function LI(r,t,e){var n,i="type_",a={type_true:2,type_move:1,type_false:0,type_undefined:-1},o=!0;return r.each(function(s){var l=s.model,u=l.get("disabled",!0)?!1:l.get("zoomLock",!0)?"move":!0;a[i+u]>a[i+n]&&(n=u),o=o&&l.get("preventDefaultMouseMove",!0)}),{controlType:n,opt:{zoomOnMouseWheel:!0,moveOnMouseMove:!0,moveOnMouseWheel:!0,preventDefaultMouseMove:!!o,api:e,zInfo:{component:t.model},triggerInfo:{roamTrigger:null,isInSelf:t.containsPoint}}}}function II(r){r.registerProcessor(r.PRIORITY.PROCESSOR.FILTER,function(t,e){var n=Mv(e),i=n.coordSysRecordMap||(n.coordSysRecordMap=K());i.each(function(a){a.dataZoomInfoMap=null}),t.eachComponent({mainType:"dataZoom",subType:"inside"},function(a){var o=q_(a);D(o.infoList,function(s){var l=s.model.uid,u=i.get(l)||i.set(l,CI(e,s.model)),f=u.dataZoomInfoMap||(u.dataZoomInfoMap=K());f.set(a.uid,{dzReferCoordSysInfo:s,model:a,getRange:null})})}),i.each(function(a){var o=a.controller,s,l=a.dataZoomInfoMap;if(l){var u=l.keys()[0];u!=null&&(s=l.get(u))}if(!s){r1(i,a);return}var f=LI(l,a,e);o.enable(f.controlType,f.opt),_l(a,"dispatchAction",s.model.get("throttle",!0),"fixRate")})})}var PI=(function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type="dataZoom.inside",e}return t.prototype.render=function(e,n,i){if(r.prototype.render.apply(this,arguments),e.noTarget()){this._clear();return}this.range=e.getPercentRange(),TI(i,e,{pan:Q(Hu.pan,this),zoom:Q(Hu.zoom,this),scrollMove:Q(Hu.scrollMove,this)})},t.prototype.dispose=function(){this._clear(),r.prototype.dispose.apply(this,arguments)},t.prototype._clear=function(){MI(this.api,this.dataZoomModel),this.range=null},t.type="dataZoom.inside",t})(K_),Hu={zoom:function(r,t,e,n){var i=this.range,a=i.slice(),o=r.axisModels[0];if(o){var s=Vu[t](null,[n.originX,n.originY],o,e,r),l=(s.signal>0?s.pixelStart+s.pixelLength-s.pixel:s.pixel-s.pixelStart)/s.pixelLength*(a[1]-a[0])+a[0],u=Math.max(1/n.scale,0);a[0]=(a[0]-l)*u+l,a[1]=(a[1]-l)*u+l;var f=this.dataZoomModel.findRepresentativeAxisProxy().getMinMaxSpan();if(Ka(0,a,[0,100],0,f.minSpan,f.maxSpan),this.range=a,i[0]!==a[0]||i[1]!==a[1])return a}},pan:mg(function(r,t,e,n,i,a){var o=Vu[n]([a.oldX,a.oldY],[a.newX,a.newY],t,i,e);return o.signal*(r[1]-r[0])*o.pixel/o.pixelLength}),scrollMove:mg(function(r,t,e,n,i,a){var o=Vu[n]([0,0],[a.scrollDelta,a.scrollDelta],t,i,e);return o.signal*(r[1]-r[0])*a.scrollDelta})};function mg(r){return function(t,e,n,i){var a=this.range,o=a.slice(),s=t.axisModels[0];if(s){var l=r(o,s,t,e,n,i);if(Ka(l,o,[0,100],"all"),this.range=o,a[0]!==o[0]||a[1]!==o[1])return o}}}var Vu={grid:function(r,t,e,n,i){var a=e.axis,o={},s=i.model.coordinateSystem.getRect();return r=r||[0,0],a.dim==="x"?(o.pixel=t[0]-r[0],o.pixelLength=s.width,o.pixelStart=s.x,o.signal=a.inverse?1:-1):(o.pixel=t[1]-r[1],o.pixelLength=s.height,o.pixelStart=s.y,o.signal=a.inverse?-1:1),o},polar:function(r,t,e,n,i){var a=e.axis,o={},s=i.model.coordinateSystem,l=s.getRadiusAxis().getExtent(),u=s.getAngleAxis().getExtent();return r=r?s.pointToCoord(r):[0,0],t=s.pointToCoord(t),e.mainType==="radiusAxis"?(o.pixel=t[0]-r[0],o.pixelLength=l[1]-l[0],o.pixelStart=l[0],o.signal=a.inverse?1:-1):(o.pixel=t[1]-r[1],o.pixelLength=u[1]-u[0],o.pixelStart=u[0],o.signal=a.inverse?-1:1),o},singleAxis:function(r,t,e,n,i){var a=e.axis,o=i.model.coordinateSystem.getRect(),s={};return r=r||[0,0],a.orient==="horizontal"?(s.pixel=t[0]-r[0],s.pixelLength=o.width,s.pixelStart=o.x,s.signal=a.inverse?1:-1):(s.pixel=t[1]-r[1],s.pixelLength=o.height,s.pixelStart=o.y,s.signal=a.inverse?-1:1),s}};function RI(r){Q_(r),r.registerComponentModel(xI),r.registerComponentView(PI),II(r)}var EI=(function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.type="dataZoom.slider",t.layoutMode="box",t.defaultOption=Wy(Xs.defaultOption,{show:!0,right:"ph",top:"ph",width:"ph",height:"ph",left:null,bottom:null,borderColor:Y.color.accent10,borderRadius:0,backgroundColor:Y.color.transparent,dataBackground:{lineStyle:{color:Y.color.accent30,width:.5},areaStyle:{color:Y.color.accent20,opacity:.2}},selectedDataBackground:{lineStyle:{color:Y.color.accent40,width:.5},areaStyle:{color:Y.color.accent20,opacity:.3}},fillerColor:"rgba(135,175,274,0.2)",handleIcon:"path://M-9.35,34.56V42m0-40V9.5m-2,0h4a2,2,0,0,1,2,2v21a2,2,0,0,1-2,2h-4a2,2,0,0,1-2-2v-21A2,2,0,0,1-11.35,9.5Z",handleSize:"100%",handleStyle:{color:Y.color.neutral00,borderColor:Y.color.accent20},moveHandleSize:7,moveHandleIcon:"path://M-320.9-50L-320.9-50c18.1,0,27.1,9,27.1,27.1V85.7c0,18.1-9,27.1-27.1,27.1l0,0c-18.1,0-27.1-9-27.1-27.1V-22.9C-348-41-339-50-320.9-50z M-212.3-50L-212.3-50c18.1,0,27.1,9,27.1,27.1V85.7c0,18.1-9,27.1-27.1,27.1l0,0c-18.1,0-27.1-9-27.1-27.1V-22.9C-239.4-41-230.4-50-212.3-50z M-103.7-50L-103.7-50c18.1,0,27.1,9,27.1,27.1V85.7c0,18.1-9,27.1-27.1,27.1l0,0c-18.1,0-27.1-9-27.1-27.1V-22.9C-130.9-41-121.8-50-103.7-50z",moveHandleStyle:{color:Y.color.accent40,opacity:.5},showDetail:!0,showDataShadow:"auto",realtime:!0,zoomLock:!1,textStyle:{color:Y.color.tertiary},brushSelect:!0,brushStyle:{color:Y.color.accent30,opacity:.3},emphasis:{handleLabel:{show:!0},handleStyle:{borderColor:Y.color.accent40},moveHandleStyle:{opacity:.8}},defaultLocationEdgeGap:15}),t})(Xs),sa=Tt,kI=1,Gu=30,OI=7,la="horizontal",yg="vertical",BI=5,NI=["line","bar","candlestick","scatter"],FI={easing:"cubicOut",duration:100,delay:0},zI=(function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e._displayables={},e}return t.prototype.init=function(e,n){this.api=n,this._onBrush=Q(this._onBrush,this),this._onBrushEnd=Q(this._onBrushEnd,this)},t.prototype.render=function(e,n,i,a){if(r.prototype.render.apply(this,arguments),_l(this,"_dispatchZoomAction",e.get("throttle"),"fixRate"),this._orient=e.getOrient(),e.get("show")===!1){this.group.removeAll();return}if(e.noTarget()){this._clear(),this.group.removeAll();return}(!a||a.type!=="dataZoom"||a.from!==this.uid)&&this._buildView(),this._updateView()},t.prototype.dispose=function(){this._clear(),r.prototype.dispose.apply(this,arguments)},t.prototype._clear=function(){ks(this,"_dispatchZoomAction");var e=this.api.getZr();e.off("mousemove",this._onBrush),e.off("mouseup",this._onBrushEnd)},t.prototype._buildView=function(){var e=this.group;e.removeAll(),this._brushing=!1,this._displayables.brushRect=null,this._resetLocation(),this._resetInterval();var n=this._displayables.sliderGroup=new Ft;this._renderBackground(),this._renderHandle(),this._renderDataShadow(),e.add(n),this._positionGroup()},t.prototype._resetLocation=function(){var e=this.dataZoomModel,n=this.api,i=e.get("brushSelect"),a=i?OI:0,o=ov(e,n).refContainer,s=this._findCoordRect(),l=e.get("defaultLocationEdgeGap",!0)||0,u=this._orient===la?{right:o.width-s.x-s.width,top:o.height-Gu-l-a,width:s.width,height:Gu}:{right:l,top:s.y,width:Gu,height:s.height},f=no(e.option);D(["right","top","width","height"],function(c){f[c]==="ph"&&(f[c]=u[c])});var h=ro(f,o);this._location={x:h.x,y:h.y},this._size=[h.width,h.height],this._orient===yg&&this._size.reverse()},t.prototype._positionGroup=function(){var e=this.group,n=this._location,i=this._orient,a=this.dataZoomModel.getFirstTargetAxisModel(),o=a&&a.get("inverse"),s=this._displayables.sliderGroup,l=(this._dataShadowInfo||{}).otherAxisInverse;s.attr(i===la&&!o?{scaleY:l?1:-1,scaleX:1}:i===la&&o?{scaleY:l?1:-1,scaleX:-1}:i===yg&&!o?{scaleY:l?-1:1,scaleX:1,rotation:Math.PI/2}:{scaleY:l?-1:1,scaleX:-1,rotation:Math.PI/2});var u=e.getBoundingRect([s]);e.x=n.x-u.x,e.y=n.y-u.y,e.markRedraw()},t.prototype._getViewExtent=function(){return[0,this._size[0]]},t.prototype._renderBackground=function(){var e=this.dataZoomModel,n=this._size,i=this._displayables.sliderGroup,a=e.get("brushSelect");i.add(new sa({silent:!0,shape:{x:0,y:0,width:n[0],height:n[1]},style:{fill:e.get("backgroundColor")},z2:-40}));var o=new sa({shape:{x:0,y:0,width:n[0],height:n[1]},style:{fill:"transparent"},z2:0,onclick:Q(this._onClickPanel,this)}),s=this.api.getZr();a?(o.on("mousedown",this._onBrushStart,this),o.cursor="crosshair",s.on("mousemove",this._onBrush),s.on("mouseup",this._onBrushEnd)):(s.off("mousemove",this._onBrush),s.off("mouseup",this._onBrushEnd)),i.add(o)},t.prototype._renderDataShadow=function(){var e=this._dataShadowInfo=this._prepareDataShadowInfo();if(this._displayables.dataShadowSegs=[],!e)return;var n=this._size,i=this._shadowSize||[],a=e.series,o=a.getRawData(),s=a.getShadowDim&&a.getShadowDim(),l=s&&o.getDimensionInfo(s)?a.getShadowDim():e.otherDim;if(l==null)return;var u=this._shadowPolygonPts,f=this._shadowPolylinePts;if(o!==this._shadowData||l!==this._shadowDim||n[0]!==i[0]||n[1]!==i[1]){var h=o.getDataExtent(e.thisDim),c=o.getDataExtent(l),v=(c[1]-c[0])*.3;c=[c[0]-v,c[1]+v];var d=[0,n[1]],p=[0,n[0]],g=[[n[0],0],[0,0]],m=[],y=p[1]/Math.max(1,o.count()-1),_=n[0]/(h[1]-h[0]),S=e.thisAxis.type==="time",w=-y,b=Math.round(o.count()/n[0]),T;o.each([e.thisDim,l],function(P,L,I){if(b>0&&I%b){S||(w+=y);return}w=S?(+P-h[0])*_:w+y;var R=L==null||isNaN(L)||L==="",E=R?0:Et(L,c,d,!0);R&&!T&&I?(g.push([g[g.length-1][0],0]),m.push([m[m.length-1][0],0])):!R&&T&&(g.push([w,0]),m.push([w,0])),R||(g.push([w,E]),m.push([w,E])),T=R}),u=this._shadowPolygonPts=g,f=this._shadowPolylinePts=m}this._shadowData=o,this._shadowDim=l,this._shadowSize=[n[0],n[1]];var C=this.dataZoomModel;function x(P){var L=C.getModel(P?"selectedDataBackground":"dataBackground"),I=new Ft,R=new to({shape:{points:u},segmentIgnoreThreshold:1,style:L.getModel("areaStyle").getAreaStyle(),silent:!0,z2:-20}),E=new eo({shape:{points:f},segmentIgnoreThreshold:1,style:L.getModel("lineStyle").getLineStyle(),silent:!0,z2:-19});return I.add(R),I.add(E),I}for(var M=0;M<3;M++){var A=x(M===1);this._displayables.sliderGroup.add(A),this._displayables.dataShadowSegs.push(A)}},t.prototype._prepareDataShadowInfo=function(){var e=this.dataZoomModel,n=e.get("showDataShadow");if(n!==!1){var i,a=this.ecModel;return e.eachTargetAxis(function(o,s){var l=e.getAxisProxy(o,s).getTargetSeriesModels();D(l,function(u){if(!i&&!(n!==!0&&ft(NI,u.get("type"))<0)){var f=a.getComponent(Pr(o),s).axis,h=HI(o),c,v=u.coordinateSystem;h!=null&&v.getOtherAxis&&(c=v.getOtherAxis(f).inverse),h=u.getData().mapDimension(h);var d=u.getData().mapDimension(o);i={thisAxis:f,series:u,thisDim:d,otherDim:h,otherAxisInverse:c}}},this)},this),i}},t.prototype._renderHandle=function(){var e=this.group,n=this._displayables,i=n.handles=[null,null],a=n.handleLabels=[null,null],o=this._displayables.sliderGroup,s=this._size,l=this.dataZoomModel,u=this.api,f=l.get("borderRadius")||0,h=l.get("brushSelect"),c=n.filler=new sa({silent:h,style:{fill:l.get("fillerColor")},textConfig:{position:"inside"}});o.add(c),o.add(new sa({silent:!0,subPixelOptimize:!0,shape:{x:0,y:0,width:s[0],height:s[1],r:f},style:{stroke:l.get("dataBackgroundColor")||l.get("borderColor"),lineWidth:kI,fill:Y.color.transparent}})),D([0,1],function(_){var S=l.get("handleIcon");!Rs[S]&&S.indexOf("path://")<0&&S.indexOf("image://")<0&&(S="path://"+S);var w=Nn(S,-1,0,2,2,null,!0);w.attr({cursor:VI(this._orient),draggable:!0,drift:Q(this._onDragMove,this,_),ondragend:Q(this._onDragEnd,this),onmouseover:Q(this._showDataInfo,this,!0),onmouseout:Q(this._showDataInfo,this,!1),z2:5});var b=w.getBoundingRect(),T=l.get("handleSize");this._handleHeight=It(T,this._size[1]),this._handleWidth=b.width/b.height*this._handleHeight,w.setStyle(l.getModel("handleStyle").getItemStyle()),w.style.strokeNoScale=!0,w.rectHover=!0,w.ensureState("emphasis").style=l.getModel(["emphasis","handleStyle"]).getItemStyle(),qm(w);var C=l.get("handleColor");C!=null&&(w.style.fill=C),o.add(i[_]=w);var x=l.getModel("textStyle"),M=l.get("handleLabel")||{},A=M.show||!1;e.add(a[_]=new oe({silent:!0,invisible:!A,style:Hr(x,{x:0,y:0,text:"",verticalAlign:"middle",align:"center",fill:x.getTextColor(),font:x.getFont()}),z2:10}))},this);var v=c;if(h){var d=It(l.get("moveHandleSize"),s[1]),p=n.moveHandle=new Tt({style:l.getModel("moveHandleStyle").getItemStyle(),silent:!0,shape:{r:[0,0,2,2],y:s[1]-.5,height:d}}),g=d*.8,m=n.moveHandleIcon=Nn(l.get("moveHandleIcon"),-g/2,-g/2,g,g,Y.color.neutral00,!0);m.silent=!0,m.y=s[1]+d/2-.5,p.ensureState("emphasis").style=l.getModel(["emphasis","moveHandleStyle"]).getItemStyle();var y=Math.min(s[1]/2,Math.max(d,10));v=n.moveZone=new Tt({invisible:!0,shape:{y:s[1]-y,height:d+y}}),v.on("mouseover",function(){u.enterEmphasis(p)}).on("mouseout",function(){u.leaveEmphasis(p)}),o.add(p),o.add(m),o.add(v)}v.attr({draggable:!0,cursor:"default",drift:Q(this._onDragMove,this,"all"),ondragstart:Q(this._showDataInfo,this,!0),ondragend:Q(this._onDragEnd,this),onmouseover:Q(this._showDataInfo,this,!0),onmouseout:Q(this._showDataInfo,this,!1)})},t.prototype._resetInterval=function(){var e=this._range=this.dataZoomModel.getPercentRange(),n=this._getViewExtent();this._handleEnds=[Et(e[0],[0,100],n,!0),Et(e[1],[0,100],n,!0)]},t.prototype._updateInterval=function(e,n){var i=this.dataZoomModel,a=this._handleEnds,o=this._getViewExtent(),s=i.findRepresentativeAxisProxy().getMinMaxSpan(),l=[0,100];Ka(n,a,o,i.get("zoomLock")?"all":e,s.minSpan!=null?Et(s.minSpan,l,o,!0):null,s.maxSpan!=null?Et(s.maxSpan,l,o,!0):null);var u=this._range,f=this._range=va([Et(a[0],o,l,!0),Et(a[1],o,l,!0)]);return!u||u[0]!==f[0]||u[1]!==f[1]},t.prototype._updateView=function(e){var n=this._displayables,i=this._handleEnds,a=va(i.slice()),o=this._size;D([0,1],function(v){var d=n.handles[v],p=this._handleHeight;d.attr({scaleX:p/2,scaleY:p/2,x:i[v]+(v?-1:1),y:o[1]/2-p/2})},this),n.filler.setShape({x:a[0],y:0,width:a[1]-a[0],height:o[1]});var s={x:a[0],width:a[1]-a[0]};n.moveHandle&&(n.moveHandle.setShape(s),n.moveZone.setShape(s),n.moveZone.getBoundingRect(),n.moveHandleIcon&&n.moveHandleIcon.attr("x",s.x+s.width/2));for(var l=n.dataShadowSegs,u=[0,a[0],a[1],o[0]],f=0;f<l.length;f++){var h=l[f],c=h.getClipPath();c||(c=new Tt,h.setClipPath(c)),c.setShape({x:u[f],y:0,width:u[f+1]-u[f],height:o[1]})}this._updateDataInfo(e)},t.prototype._updateDataInfo=function(e){var n=this.dataZoomModel,i=this._displayables,a=i.handleLabels,o=this._orient,s=["",""];if(n.get("showDetail")){var l=n.findRepresentativeAxisProxy();if(l){var u=l.getAxisModel().axis,f=this._range,h=e?l.calculateDataWindow({start:f[0],end:f[1]}).valueWindow:l.getDataValueWindow();s=[this._formatLabel(h[0],u),this._formatLabel(h[1],u)]}}var c=va(this._handleEnds.slice());v.call(this,0),v.call(this,1);function v(d){var p=fy(i.handles[d].parent,this.group),g=hy(d===0?"right":"left",p),m=this._handleWidth/2+BI,y=Na([c[d]+(d===0?-m:m),this._size[1]/2],p);a[d].setStyle({x:y[0],y:y[1],verticalAlign:o===la?"middle":g,align:o===la?g:"center",text:s[d]})}},t.prototype._formatLabel=function(e,n){var i=this.dataZoomModel,a=i.get("labelFormatter"),o=i.get("labelPrecision");(o==null||o==="auto")&&(o=n.getPixelPrecision());var s=e==null||isNaN(e)?"":n.type==="category"||n.type==="time"?n.scale.getLabel({value:Math.round(e)}):e.toFixed(Math.min(o,20));return et(a)?a(e,s):W(a)?a.replace("{value}",s):s},t.prototype._showDataInfo=function(e){var n=this.dataZoomModel.get("handleLabel")||{},i=n.show||!1,a=this.dataZoomModel.getModel(["emphasis","handleLabel"]),o=a.get("show")||!1,s=e||this._dragging?o:i,l=this._displayables,u=l.handleLabels;u[0].attr("invisible",!s),u[1].attr("invisible",!s),l.moveHandle&&this.api[s?"enterEmphasis":"leaveEmphasis"](l.moveHandle,1)},t.prototype._onDragMove=function(e,n,i,a){this._dragging=!0,Li(a.event);var o=this._displayables.sliderGroup.getLocalTransform(),s=Na([n,i],o,!0),l=this._updateInterval(e,s[0]),u=this.dataZoomModel.get("realtime");this._updateView(!u),l&&u&&this._dispatchZoomAction(!0)},t.prototype._onDragEnd=function(){this._dragging=!1,this._showDataInfo(!1);var e=this.dataZoomModel.get("realtime");!e&&this._dispatchZoomAction(!1)},t.prototype._onClickPanel=function(e){var n=this._size,i=this._displayables.sliderGroup.transformCoordToLocal(e.offsetX,e.offsetY);if(!(i[0]<0||i[0]>n[0]||i[1]<0||i[1]>n[1])){var a=this._handleEnds,o=(a[0]+a[1])/2,s=this._updateInterval("all",i[0]-o);this._updateView(),s&&this._dispatchZoomAction(!1)}},t.prototype._onBrushStart=function(e){var n=e.offsetX,i=e.offsetY;this._brushStart=new tt(n,i),this._brushing=!0,this._brushStartTime=+new Date},t.prototype._onBrushEnd=function(e){if(this._brushing){var n=this._displayables.brushRect;if(this._brushing=!1,!!n){n.attr("ignore",!0);var i=n.shape,a=+new Date;if(!(a-this._brushStartTime<200&&Math.abs(i.width)<5)){var o=this._getViewExtent(),s=[0,100],l=this._handleEnds=[i.x,i.x+i.width],u=this.dataZoomModel.findRepresentativeAxisProxy().getMinMaxSpan();Ka(0,l,o,0,u.minSpan!=null?Et(u.minSpan,s,o,!0):null,u.maxSpan!=null?Et(u.maxSpan,s,o,!0):null),this._range=va([Et(l[0],o,s,!0),Et(l[1],o,s,!0)]),this._updateView(),this._dispatchZoomAction(!1)}}}},t.prototype._onBrush=function(e){this._brushing&&(Li(e.event),this._updateBrushRect(e.offsetX,e.offsetY))},t.prototype._updateBrushRect=function(e,n){var i=this._displayables,a=this.dataZoomModel,o=i.brushRect;o||(o=i.brushRect=new sa({silent:!0,style:a.getModel("brushStyle").getItemStyle()}),i.sliderGroup.add(o)),o.attr("ignore",!1);var s=this._brushStart,l=this._displayables.sliderGroup,u=l.transformCoordToLocal(e,n),f=l.transformCoordToLocal(s.x,s.y),h=this._size;u[0]=Math.max(Math.min(h[0],u[0]),0),o.setShape({x:f[0],y:0,width:u[0]-f[0],height:h[1]})},t.prototype._dispatchZoomAction=function(e){var n=this._range;this.api.dispatchAction({type:"dataZoom",from:this.uid,dataZoomId:this.dataZoomModel.id,animation:e?FI:null,start:n[0],end:n[1]})},t.prototype._findCoordRect=function(){var e,n=q_(this.dataZoomModel).infoList;if(!e&&n.length){var i=n[0].model.coordinateSystem;e=i.getRect&&i.getRect()}if(!e){var a=this.api.getWidth(),o=this.api.getHeight();e={x:a*.2,y:o*.2,width:a*.6,height:o*.6}}return e},t.type="dataZoom.slider",t})(K_);function HI(r){var t={x:"y",y:"x",radius:"angle",angle:"radius"};return t[r]}function VI(r){return r==="vertical"?"ns-resize":"ew-resize"}function GI(r){r.registerComponentModel(EI),r.registerComponentView(zI),Q_(r)}function WI(r){Fn(RI),Fn(GI)}var _g={value:"eq","<":"lt","<=":"lte",">":"gt",">=":"gte","=":"eq","!=":"ne","<>":"ne"},UI=(function(){function r(t){var e=this._condVal=W(t)?new RegExp(t):P1(t)?t:null;if(e==null){var n="";ut(n)}}return r.prototype.evaluate=function(t){var e=typeof t;return W(e)?this._condVal.test(t):mt(e)?this._condVal.test(t+""):!1},r})(),YI=(function(){function r(){}return r.prototype.evaluate=function(){return this.value},r})(),ZI=(function(){function r(){}return r.prototype.evaluate=function(){for(var t=this.children,e=0;e<t.length;e++)if(!t[e].evaluate())return!1;return!0},r})(),XI=(function(){function r(){}return r.prototype.evaluate=function(){for(var t=this.children,e=0;e<t.length;e++)if(t[e].evaluate())return!0;return!1},r})(),$I=(function(){function r(){}return r.prototype.evaluate=function(){return!this.child.evaluate()},r})(),qI=(function(){function r(){}return r.prototype.evaluate=function(){for(var t=!!this.valueParser,e=this.getValue,n=e(this.valueGetterParam),i=t?this.valueParser(n):null,a=0;a<this.subCondList.length;a++)if(!this.subCondList[a].evaluate(t?i:n))return!1;return!0},r})();function Cv(r,t){if(r===!0||r===!1){var e=new YI;return e.value=r,e}var n="";return n1(r)||ut(n),r.and?Sg("and",r,t):r.or?Sg("or",r,t):r.not?KI(r,t):QI(r,t)}function Sg(r,t,e){var n=t[r],i="";H(n)||ut(i),n.length||ut(i);var a=r==="and"?new ZI:new XI;return a.children=$(n,function(o){return Cv(o,e)}),a.children.length||ut(i),a}function KI(r,t){var e=r.not,n="";n1(e)||ut(n);var i=new $I;return i.child=Cv(e,t),i.child||ut(n),i}function QI(r,t){for(var e="",n=t.prepareGetValue(r),i=[],a=St(r),o=r.parser,s=o?Ey(o):null,l=0;l<a.length;l++){var u=a[l];if(!(u==="parser"||t.valueGetterAttrMap.get(u))){var f=ve(_g,u)?_g[u]:u,h=r[u],c=s?s(h):h,v=Lx(f,c)||f==="reg"&&new UI(c);v||ut(e),i.push(v)}}i.length||ut(e);var d=new qI;return d.valueGetterParam=n,d.valueParser=s,d.getValue=t.getValue,d.subCondList=i,d}function n1(r){return X(r)&&!Qt(r)}var jI=(function(){function r(t,e){this._cond=Cv(t,e)}return r.prototype.evaluate=function(){return this._cond.evaluate()},r})();function JI(r,t){return new jI(r,t)}var tP={type:"echarts:filter",transform:function(r){for(var t=r.upstream,e,n=JI(r.config,{valueGetterAttrMap:K({dimension:!0}),prepareGetValue:function(s){var l="",u=s.dimension;ve(s,"dimension")||ut(l);var f=t.getDimensionInfo(u);return f||ut(l),{dimIdx:f.index}},getValue:function(s){return t.retrieveValueFromItem(e,s.dimIdx)}}),i=[],a=0,o=t.count();a<o;a++)e=t.getRawDataItem(a),n.evaluate()&&i.push(e);return{data:i}}},eP={type:"echarts:sort",transform:function(r){var t=r.upstream,e=r.config,n="",i=Ct(e);i.length||ut(n);var a=[];D(i,function(f){var h=f.dimension,c=f.order,v=f.parser,d=f.incomparable;if(h==null&&ut(n),c!=="asc"&&c!=="desc"&&ut(n),d&&d!=="min"&&d!=="max"){var p="";ut(p)}if(c!=="asc"&&c!=="desc"){var g="";ut(g)}var m=t.getDimensionInfo(h);m||ut(n);var y=v?Ey(v):null;v&&!y&&ut(n),a.push({dimIdx:m.index,parser:y,comparator:new Oy(c,d)})});var o=t.sourceFormat;o!==zt&&o!==Ce&&ut(n);for(var s=[],l=0,u=t.count();l<u;l++)s.push(t.getRawDataItem(l));return s.sort(function(f,h){for(var c=0;c<a.length;c++){var v=a[c],d=t.retrieveValueFromItem(f,v.dimIdx),p=t.retrieveValueFromItem(h,v.dimIdx);v.parser&&(d=v.parser(d),p=v.parser(p));var g=v.comparator.evaluate(d,p);if(g!==0)return g}return 0}),{data:s}}};function rP(r){r.registerTransform(tP),r.registerTransform(eP)}var nP=(function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type="dataset",e}return t.prototype.init=function(e,n,i){r.prototype.init.call(this,e,n,i),this._sourceManager=new a0(this),vd(this)},t.prototype.mergeOption=function(e,n){r.prototype.mergeOption.call(this,e,n),vd(this)},t.prototype.optionUpdated=function(){this._sourceManager.dirty()},t.prototype.getSourceManager=function(){return this._sourceManager},t.type="dataset",t.defaultOption={seriesLayoutBy:Re},t})(dt),iP=(function(r){z(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type="dataset",e}return t.type="dataset",t})(Me);function aP(r){r.registerComponentModel(nP),r.registerComponentView(iP)}function oP(r){if(r){for(var t=[],e=0;e<r.length;e++)t.push(r[e].slice());return t}}function sP(r,t){var e=r.label,n=t&&t.getTextGuideLine();return{dataIndex:r.dataIndex,dataType:r.dataType,seriesIndex:r.seriesModel.seriesIndex,text:r.label.style.text,rect:r.hostRect,labelRect:r.rect,align:e.style.align,verticalAlign:e.style.verticalAlign,labelLinePoints:oP(n&&n.shape.points)}}var bg=["align","verticalAlign","width","height","fontSize"],Xt=new Qa,Wu=gt(),lP=gt();function Yo(r,t,e){for(var n=0;n<e.length;n++){var i=e[n];t[i]!=null&&(r[i]=t[i])}}var Zo=["x","y","rotation"],uP=(function(){function r(){this._labelList=[],this._chartViewList=[]}return r.prototype.clearLabels=function(){this._labelList=[],this._chartViewList=[]},r.prototype._addLabel=function(t,e,n,i,a){var o=i.style,s=i.__hostTarget,l=s.textConfig||{},u=i.getComputedTransform(),f=i.getBoundingRect().plain();it.applyTransform(f,f,u),u?Xt.setLocalTransform(u):(Xt.x=Xt.y=Xt.rotation=Xt.originX=Xt.originY=0,Xt.scaleX=Xt.scaleY=1),Xt.rotation=ar(Xt.rotation);var h=i.__hostTarget,c;if(h){c=h.getBoundingRect().plain();var v=h.getComputedTransform();it.applyTransform(c,c,v)}var d=c&&h.getTextGuideLine();this._labelList.push({label:i,labelLine:d,seriesModel:n,dataIndex:t,dataType:e,layoutOptionOrCb:a,layoutOption:null,rect:f,hostRect:c,priority:c?c.width*c.height:0,defaultAttr:{ignore:i.ignore,labelGuideIgnore:d&&d.ignore,x:Xt.x,y:Xt.y,scaleX:Xt.scaleX,scaleY:Xt.scaleY,rotation:Xt.rotation,style:{x:o.x,y:o.y,align:o.align,verticalAlign:o.verticalAlign,width:o.width,height:o.height,fontSize:o.fontSize},cursor:i.cursor,attachedPos:l.position,attachedRot:l.rotation}})},r.prototype.addLabelsOfSeries=function(t){var e=this;this._chartViewList.push(t);var n=t.__model,i=n.get("labelLayout");(et(i)||St(i).length)&&t.group.traverse(function(a){if(a.ignore)return!0;var o=a.getTextContent(),s=pt(a);o&&!o.disableLabelLayout&&e._addLabel(s.dataIndex,s.dataType,n,o,i)})},r.prototype.updateLayoutConfig=function(t){var e=t.getWidth(),n=t.getHeight();function i(_,S){return function(){Ld(_,S)}}for(var a=0;a<this._labelList.length;a++){var o=this._labelList[a],s=o.label,l=s.__hostTarget,u=o.defaultAttr,f=void 0;et(o.layoutOptionOrCb)?f=o.layoutOptionOrCb(sP(o,l)):f=o.layoutOptionOrCb,f=f||{},o.layoutOption=f;var h=Math.PI/180;l&&l.setTextConfig({local:!1,position:f.x!=null||f.y!=null?null:u.attachedPos,rotation:f.rotate!=null?f.rotate*h:u.attachedRot,offset:[f.dx||0,f.dy||0]});var c=!1;if(f.x!=null?(s.x=It(f.x,e),s.setStyle("x",0),c=!0):(s.x=u.x,s.setStyle("x",u.style.x)),f.y!=null?(s.y=It(f.y,n),s.setStyle("y",0),c=!0):(s.y=u.y,s.setStyle("y",u.style.y)),f.labelLinePoints){var v=l.getTextGuideLine();v&&(v.setShape({points:f.labelLinePoints}),c=!1)}var d=Wu(s);d.needsUpdateLabelLine=c,s.rotation=f.rotate!=null?f.rotate*h:u.rotation,s.scaleX=u.scaleX,s.scaleY=u.scaleY;for(var p=0;p<bg.length;p++){var g=bg[p];s.setStyle(g,f[g]!=null?f[g]:u.style[g])}if(f.draggable){if(s.draggable=!0,s.cursor="move",l){var m=o.seriesModel;if(o.dataIndex!=null){var y=o.seriesModel.getData(o.dataType);m=y.getItemModel(o.dataIndex)}s.on("drag",i(l,m.getModel("labelLine")))}}else s.off("drag"),s.cursor=u.cursor}},r.prototype.layout=function(t){var e=t.getWidth(),n=t.getHeight(),i=[];D(this._labelList,function(l){l.defaultAttr.ignore||i.push(Gf({},l))});var a=wt(i,function(l){return l.layoutOption.moveOverlap==="shiftX"}),o=wt(i,function(l){return l.layoutOption.moveOverlap==="shiftY"});Ed(a,0,0,e),Ed(o,1,0,n);var s=wt(i,function(l){return l.layoutOption.hideOverlap});CC(s),C0(s)},r.prototype.processLabelsOverall=function(){var t=this;D(this._chartViewList,function(e){var n=e.__model,i=e.ignoreLabelLineUpdate,a=n.isAnimationEnabled();e.group.traverse(function(o){if(o.ignore&&!o.forceLabelAnimation)return!0;var s=!i,l=o.getTextContent();!s&&l&&(s=Wu(l).needsUpdateLabelLine),s&&t._updateLabelLine(o,n),a&&t._animateLabels(o,n)})})},r.prototype._updateLabelLine=function(t,e){var n=t.getTextContent(),i=pt(t),a=i.dataIndex;if(n&&a!=null){var o=e.getData(i.dataType),s=o.getItemModel(a),l={},u=o.getItemVisual(a,"style");if(u){var f=o.getVisual("drawType");l.stroke=u[f]}var h=s.getModel("labelLine");SC(t,bC(s),l),Ld(t,h)}},r.prototype._animateLabels=function(t,e){var n=t.getTextContent(),i=t.getTextGuideLine();if(n&&(t.forceLabelAnimation||!n.ignore&&!n.invisible&&!t.disableLabelAnimation&&!wi(t))){var a=Wu(n),o=a.oldLayout,s=pt(t),l=s.dataIndex,u={x:n.x,y:n.y,rotation:n.rotation},f=e.getData(s.dataType);if(o){n.attr(o);var c=t.prevStates;c&&(ft(c,"select")>=0&&n.attr(a.oldLayoutSelect),ft(c,"emphasis")>=0&&n.attr(a.oldLayoutEmphasis)),Ke(n,u,e,l)}else if(n.attr(u),!dl(n).valueAnimation){var h=q(n.style.opacity,1);n.style.opacity=0,cr(n,{style:{opacity:h}},e,l)}if(a.oldLayout=u,n.states.select){var v=a.oldLayoutSelect={};Yo(v,u,Zo),Yo(v,n.states.select,Zo)}if(n.states.emphasis){var d=a.oldLayoutEmphasis={};Yo(d,u,Zo),Yo(d,n.states.emphasis,Zo)}ix(n,l,f,e,e)}if(i&&!i.ignore&&!i.invisible){var a=lP(i),o=a.oldLayout,p={points:i.shape.points};o?(i.attr({shape:o}),Ke(i,{shape:p},e)):(i.setShape(p),i.style.strokePercent=0,cr(i,{style:{strokePercent:1}},e)),a.oldLayout=p}},r})(),Uu=gt();function fP(r){r.registerUpdateLifecycle("series:beforeupdate",function(t,e,n){var i=Uu(e).labelManager;i||(i=Uu(e).labelManager=new uP),i.clearLabels()}),r.registerUpdateLifecycle("series:layoutlabels",function(t,e,n){var i=Uu(e).labelManager;n.updatedSeries.forEach(function(a){i.addLabelsOfSeries(e.getViewOfSeriesModel(a))}),i.updateLayoutConfig(e),i.layout(e),i.processLabelsOverall()})}var Ve=vr.CMD;function yi(r,t){return Math.abs(r-t)<1e-5}function hh(r){var t=r.data,e=r.len(),n=[],i,a=0,o=0,s=0,l=0;function u(L,I){i&&i.length>2&&n.push(i),i=[L,I]}function f(L,I,R,E){yi(L,R)&&yi(I,E)||i.push(L,I,R,E,R,E)}function h(L,I,R,E,V,B){var k=Math.abs(I-L),G=Math.tan(k/4)*4/3,U=I<L?-1:1,Z=Math.cos(L),j=Math.sin(L),ot=Math.cos(I),yt=Math.sin(I),Ht=Z*V+R,de=j*B+E,pe=ot*V+R,Vt=yt*B+E,Dt=V*G*U,rt=B*G*U;i.push(Ht-Dt*j,de+rt*Z,pe+Dt*yt,Vt-rt*ot,pe,Vt)}for(var c,v,d,p,g=0;g<e;){var m=t[g++],y=g===1;switch(y&&(a=t[g],o=t[g+1],s=a,l=o,(m===Ve.L||m===Ve.C||m===Ve.Q)&&(i=[s,l])),m){case Ve.M:a=s=t[g++],o=l=t[g++],u(s,l);break;case Ve.L:c=t[g++],v=t[g++],f(a,o,c,v),a=c,o=v;break;case Ve.C:i.push(t[g++],t[g++],t[g++],t[g++],a=t[g++],o=t[g++]);break;case Ve.Q:c=t[g++],v=t[g++],d=t[g++],p=t[g++],i.push(a+2/3*(c-a),o+2/3*(v-o),d+2/3*(c-d),p+2/3*(v-p),d,p),a=d,o=p;break;case Ve.A:var _=t[g++],S=t[g++],w=t[g++],b=t[g++],T=t[g++],C=t[g++]+T;g+=1;var x=!t[g++];c=Math.cos(T)*w+_,v=Math.sin(T)*b+S,y?(s=c,l=v,u(s,l)):f(a,o,c,v),a=Math.cos(C)*w+_,o=Math.sin(C)*b+S;for(var M=(x?-1:1)*Math.PI/2,A=T;x?A>C:A<C;A+=M){var P=x?Math.max(A+M,C):Math.min(A+M,C);h(A,P,_,S,w,b)}break;case Ve.R:s=a=t[g++],l=o=t[g++],c=s+t[g++],v=l+t[g++],u(c,l),f(c,l,c,v),f(c,v,s,v),f(s,v,s,l),f(s,l,c,l);break;case Ve.Z:i&&f(a,o,s,l),a=s,o=l;break}}return i&&i.length>2&&n.push(i),n}function vh(r,t,e,n,i,a,o,s,l,u){if(yi(r,e)&&yi(t,n)&&yi(i,o)&&yi(a,s)){l.push(o,s);return}var f=2/u,h=f*f,c=o-r,v=s-t,d=Math.sqrt(c*c+v*v);c/=d,v/=d;var p=e-r,g=n-t,m=i-o,y=a-s,_=p*p+g*g,S=m*m+y*y;if(_<h&&S<h){l.push(o,s);return}var w=c*p+v*g,b=-c*m-v*y,T=_-w*w,C=S-b*b;if(T<h&&w>=0&&C<h&&b>=0){l.push(o,s);return}var x=[],M=[];Nr(r,e,i,o,.5,x),Nr(t,n,a,s,.5,M),vh(x[0],M[0],x[1],M[1],x[2],M[2],x[3],M[3],l,u),vh(x[4],M[4],x[5],M[5],x[6],M[6],x[7],M[7],l,u)}function hP(r,t){var e=hh(r),n=[];t=t||1;for(var i=0;i<e.length;i++){var a=e[i],o=[],s=a[0],l=a[1];o.push(s,l);for(var u=2;u<a.length;){var f=a[u++],h=a[u++],c=a[u++],v=a[u++],d=a[u++],p=a[u++];vh(s,l,f,h,c,v,d,p,o,t),s=d,l=p}n.push(o)}return n}function i1(r,t,e){var n=r[t],i=r[1-t],a=Math.abs(n/i),o=Math.ceil(Math.sqrt(a*e)),s=Math.floor(e/o);s===0&&(s=1,o=e);for(var l=[],u=0;u<o;u++)l.push(s);var f=o*s,h=e-f;if(h>0)for(var u=0;u<h;u++)l[u%o]+=1;return l}function wg(r,t,e){for(var n=r.r0,i=r.r,a=r.startAngle,o=r.endAngle,s=Math.abs(o-a),l=s*i,u=i-n,f=l>Math.abs(u),h=i1([l,u],f?0:1,t),c=(f?s:u)/h.length,v=0;v<h.length;v++)for(var d=(f?u:s)/h[v],p=0;p<h[v];p++){var g={};f?(g.startAngle=a+c*v,g.endAngle=a+c*(v+1),g.r0=n+d*p,g.r=n+d*(p+1)):(g.startAngle=a+d*p,g.endAngle=a+d*(p+1),g.r0=n+c*v,g.r=n+c*(v+1)),g.clockwise=r.clockwise,g.cx=r.cx,g.cy=r.cy,e.push(g)}}function vP(r,t,e){for(var n=r.width,i=r.height,a=n>i,o=i1([n,i],a?0:1,t),s=a?"width":"height",l=a?"height":"width",u=a?"x":"y",f=a?"y":"x",h=r[s]/o.length,c=0;c<o.length;c++)for(var v=r[l]/o[c],d=0;d<o[c];d++){var p={};p[u]=c*h,p[f]=d*v,p[s]=h,p[l]=v,p.x+=r.x,p.y+=r.y,e.push(p)}}function xg(r,t,e,n){return r*n-e*t}function cP(r,t,e,n,i,a,o,s){var l=e-r,u=n-t,f=o-i,h=s-a,c=xg(f,h,l,u);if(Math.abs(c)<1e-6)return null;var v=r-i,d=t-a,p=xg(v,d,f,h)/c;return p<0||p>1?null:new tt(p*l+r,p*u+t)}function dP(r,t,e){var n=new tt;tt.sub(n,e,t),n.normalize();var i=new tt;tt.sub(i,r,t);var a=i.dot(n);return a}function ai(r,t){var e=r[r.length-1];e&&e[0]===t[0]&&e[1]===t[1]||r.push(t)}function pP(r,t,e){for(var n=r.length,i=[],a=0;a<n;a++){var o=r[a],s=r[(a+1)%n],l=cP(o[0],o[1],s[0],s[1],t.x,t.y,e.x,e.y);l&&i.push({projPt:dP(l,t,e),pt:l,idx:a})}if(i.length<2)return[{points:r},{points:r}];i.sort(function(g,m){return g.projPt-m.projPt});var u=i[0],f=i[i.length-1];if(f.idx<u.idx){var h=u;u=f,f=h}for(var c=[u.pt.x,u.pt.y],v=[f.pt.x,f.pt.y],d=[c],p=[v],a=u.idx+1;a<=f.idx;a++)ai(d,r[a].slice());ai(d,v),ai(d,c);for(var a=f.idx+1;a<=u.idx+n;a++)ai(p,r[a%n].slice());return ai(p,c),ai(p,v),[{points:d},{points:p}]}function Tg(r){var t=r.points,e=[],n=[];xm(t,e,n);var i=new it(e[0],e[1],n[0]-e[0],n[1]-e[1]),a=i.width,o=i.height,s=i.x,l=i.y,u=new tt,f=new tt;return a>o?(u.x=f.x=s+a/2,u.y=l,f.y=l+o):(u.y=f.y=l+o/2,u.x=s,f.x=s+a),pP(t,u,f)}function $s(r,t,e,n){if(e===1)n.push(t);else{var i=Math.floor(e/2),a=r(t);$s(r,a[0],i,n),$s(r,a[1],e-i,n)}return n}function gP(r,t){for(var e=[],n=0;n<t;n++)e.push(Oh(r));return e}function mP(r,t){t.setStyle(r.style),t.z=r.z,t.z2=r.z2,t.zlevel=r.zlevel}function yP(r){for(var t=[],e=0;e<r.length;)t.push([r[e++],r[e++]]);return t}function _P(r,t){var e=[],n=r.shape,i;switch(r.type){case"rect":vP(n,t,e),i=Tt;break;case"sector":wg(n,t,e),i=Ci;break;case"circle":wg({r0:0,r:n.r,startAngle:0,endAngle:Math.PI*2,cx:n.cx,cy:n.cy},t,e),i=Ci;break;default:var a=r.getComputedTransform(),o=a?Math.sqrt(Math.max(a[0]*a[0]+a[1]*a[1],a[2]*a[2]+a[3]*a[3])):1,s=$(hP(r.getUpdatedPathProxy(),o),function(m){return yP(m)}),l=s.length;if(l===0)$s(Tg,{points:s[0]},t,e);else if(l===t)for(var u=0;u<l;u++)e.push({points:s[u]});else{var f=0,h=$(s,function(m){var y=[],_=[];xm(m,y,_);var S=(_[1]-y[1])*(_[0]-y[0]);return f+=S,{poly:m,area:S}});h.sort(function(m,y){return y.area-m.area});for(var c=t,u=0;u<l;u++){var v=h[u];if(c<=0)break;var d=u===l-1?c:Math.ceil(v.area/f*t);d<0||($s(Tg,{points:v.poly},d,e),c-=d)}}i=to;break}if(!i)return gP(r,t);for(var p=[],u=0;u<e.length;u++){var g=new i;g.setShape(e[u]),mP(r,g),p.push(g)}return p}function SP(r,t){var e=r.length,n=t.length;if(e===n)return[r,t];for(var i=[],a=[],o=e<n?r:t,s=Math.min(e,n),l=Math.abs(n-e)/6,u=(s-2)/6,f=Math.ceil(l/u)+1,h=[o[0],o[1]],c=l,v=2;v<s;){var d=o[v-2],p=o[v-1],g=o[v++],m=o[v++],y=o[v++],_=o[v++],S=o[v++],w=o[v++];if(c<=0){h.push(g,m,y,_,S,w);continue}for(var b=Math.min(c,f-1)+1,T=1;T<=b;T++){var C=T/b;Nr(d,g,y,S,C,i),Nr(p,m,_,w,C,a),d=i[3],p=a[3],h.push(i[1],a[1],i[2],a[2],d,p),g=i[5],m=a[5],y=i[6],_=a[6]}c-=b-1}return o===r?[h,t]:[r,h]}function Mg(r,t){for(var e=r.length,n=r[e-2],i=r[e-1],a=[],o=0;o<t.length;)a[o++]=n,a[o++]=i;return a}function bP(r,t){for(var e,n,i,a=[],o=[],s=0;s<Math.max(r.length,t.length);s++){var l=r[s],u=t[s],f=void 0,h=void 0;l?u?(e=SP(l,u),f=e[0],h=e[1],n=f,i=h):(h=Mg(i||l,l),f=l):(f=Mg(n||u,u),h=u),a.push(f),o.push(h)}return[a,o]}function Cg(r){for(var t=0,e=0,n=0,i=r.length,a=0,o=i-2;a<i;o=a,a+=2){var s=r[o],l=r[o+1],u=r[a],f=r[a+1],h=s*f-u*l;t+=h,e+=(s+u)*h,n+=(l+f)*h}return t===0?[r[0]||0,r[1]||0]:[e/t/3,n/t/3,t]}function wP(r,t,e,n){for(var i=(r.length-2)/6,a=1/0,o=0,s=r.length,l=s-2,u=0;u<i;u++){for(var f=u*6,h=0,c=0;c<s;c+=2){var v=c===0?f:(f+c-2)%l+2,d=r[v]-e[0],p=r[v+1]-e[1],g=t[c]-n[0],m=t[c+1]-n[1],y=g-d,_=m-p;h+=y*y+_*_}h<a&&(a=h,o=u)}return o}function xP(r){for(var t=[],e=r.length,n=0;n<e;n+=2)t[n]=r[e-n-2],t[n+1]=r[e-n-1];return t}function TP(r,t,e,n){for(var i=[],a,o=0;o<r.length;o++){var s=r[o],l=t[o],u=Cg(s),f=Cg(l);a==null&&(a=u[2]<0!=f[2]<0);var h=[],c=[],v=0,d=1/0,p=[],g=s.length;a&&(s=xP(s));for(var m=wP(s,l,u,f)*6,y=g-2,_=0;_<y;_+=2){var S=(m+_)%y+2;h[_+2]=s[S]-u[0],h[_+3]=s[S+1]-u[1]}h[0]=s[m]-u[0],h[1]=s[m+1]-u[1];for(var w=n/e,b=-n/2;b<=n/2;b+=w){for(var T=Math.sin(b),C=Math.cos(b),x=0,_=0;_<s.length;_+=2){var M=h[_],A=h[_+1],P=l[_]-f[0],L=l[_+1]-f[1],I=P*C-L*T,R=P*T+L*C;p[_]=I,p[_+1]=R;var E=I-M,V=R-A;x+=E*E+V*V}if(x<d){d=x,v=b;for(var B=0;B<p.length;B++)c[B]=p[B]}}i.push({from:h,to:c,fromCp:u,toCp:f,rotation:-v})}return i}function qs(r){return r.__isCombineMorphing}var a1="__mOriginal_";function Ks(r,t,e){var n=a1+t,i=r[n]||r[t];r[n]||(r[n]=r[t]);var a=e.replace,o=e.after,s=e.before;r[t]=function(){var l=arguments,u;return s&&s.apply(this,l),a?u=a.apply(this,l):u=i.apply(this,l),o&&o.apply(this,l),u}}function La(r,t){var e=a1+t;r[e]&&(r[t]=r[e],r[e]=null)}function Dg(r,t){for(var e=0;e<r.length;e++)for(var n=r[e],i=0;i<n.length;){var a=n[i],o=n[i+1];n[i++]=t[0]*a+t[2]*o+t[4],n[i++]=t[1]*a+t[3]*o+t[5]}}function o1(r,t){var e=r.getUpdatedPathProxy(),n=t.getUpdatedPathProxy(),i=bP(hh(e),hh(n)),a=i[0],o=i[1],s=r.getComputedTransform(),l=t.getComputedTransform();function u(){this.transform=null}s&&Dg(a,s),l&&Dg(o,l),Ks(t,"updateTransform",{replace:u}),t.transform=null;var f=TP(a,o,10,Math.PI),h=[];Ks(t,"buildPath",{replace:function(c){for(var v=t.__morphT,d=1-v,p=[],g=0;g<f.length;g++){var m=f[g],y=m.from,_=m.to,S=m.rotation*v,w=m.fromCp,b=m.toCp,T=Math.sin(S),C=Math.cos(S);$o(p,w,b,v);for(var x=0;x<y.length;x+=2){var M=y[x],A=y[x+1],P=_[x],L=_[x+1],I=M*d+P*v,R=A*d+L*v;h[x]=I*C-R*T+p[0],h[x+1]=I*T+R*C+p[1]}var E=h[0],V=h[1];c.moveTo(E,V);for(var x=2;x<y.length;){var P=h[x++],L=h[x++],B=h[x++],k=h[x++],G=h[x++],U=h[x++];E===P&&V===L&&B===G&&k===U?c.lineTo(G,U):c.bezierCurveTo(P,L,B,k,G,U),E=G,V=U}}}})}function Dv(r,t,e){if(!r||!t)return t;var n=e.done,i=e.during;o1(r,t),t.__morphT=0;function a(){La(t,"buildPath"),La(t,"updateTransform"),t.__morphT=-1,t.createPathProxy(),t.dirtyShape()}return t.animateTo({__morphT:1},at({during:function(o){t.dirtyShape(),i&&i(o)},done:function(){a(),n&&n()}},e)),t}function MP(r,t,e,n,i,a){var o=16;r=i===e?0:Math.round(32767*(r-e)/(i-e)),t=a===n?0:Math.round(32767*(t-n)/(a-n));for(var s=0,l,u=(1<<o)/2;u>0;u/=2){var f=0,h=0;(r&u)>0&&(f=1),(t&u)>0&&(h=1),s+=u*u*(3*f^h),h===0&&(f===1&&(r=u-1-r,t=u-1-t),l=r,r=t,t=l)}return s}function Qs(r){var t=1/0,e=1/0,n=-1/0,i=-1/0,a=$(r,function(s){var l=s.getBoundingRect(),u=s.getComputedTransform(),f=l.x+l.width/2+(u?u[4]:0),h=l.y+l.height/2+(u?u[5]:0);return t=Math.min(f,t),e=Math.min(h,e),n=Math.max(f,n),i=Math.max(h,i),[f,h]}),o=$(a,function(s,l){return{cp:s,z:MP(s[0],s[1],t,e,n,i),path:r[l]}});return o.sort(function(s,l){return s.z-l.z}).map(function(s){return s.path})}function s1(r){return _P(r.path,r.count)}function ch(){return{fromIndividuals:[],toIndividuals:[],count:0}}function CP(r,t,e){var n=[];function i(w){for(var b=0;b<w.length;b++){var T=w[b];qs(T)?i(T.childrenRef()):T instanceof ht&&n.push(T)}}i(r);var a=n.length;if(!a)return ch();var o=e.dividePath||s1,s=o({path:t,count:a});if(s.length!==a)return console.error("Invalid morphing: unmatched splitted path"),ch();n=Qs(n),s=Qs(s);for(var l=e.done,u=e.during,f=e.individualDelay,h=new Qa,c=0;c<a;c++){var v=n[c],d=s[c];d.parent=t,d.copyTransform(h),f||o1(v,d)}t.__isCombineMorphing=!0,t.childrenRef=function(){return s};function p(w){for(var b=0;b<s.length;b++)s[b].addSelfToZr(w)}Ks(t,"addSelfToZr",{after:function(w){p(w)}}),Ks(t,"removeSelfFromZr",{after:function(w){for(var b=0;b<s.length;b++)s[b].removeSelfFromZr(w)}});function g(){t.__isCombineMorphing=!1,t.__morphT=-1,t.childrenRef=null,La(t,"addSelfToZr"),La(t,"removeSelfFromZr")}var m=s.length;if(f)for(var y=m,_=function(){y--,y===0&&(g(),l&&l())},c=0;c<m;c++){var S=f?at({delay:(e.delay||0)+f(c,m,n[c],s[c]),done:_},e):e;Dv(n[c],s[c],S)}else t.__morphT=0,t.animateTo({__morphT:1},at({during:function(w){for(var b=0;b<m;b++){var T=s[b];T.__morphT=t.__morphT,T.dirtyShape()}u&&u(w)},done:function(){g();for(var w=0;w<r.length;w++)La(r[w],"updateTransform");l&&l()}},e));return t.__zr&&p(t.__zr),{fromIndividuals:n,toIndividuals:s,count:m}}function DP(r,t,e){var n=t.length,i=[],a=e.dividePath||s1;function o(v){for(var d=0;d<v.length;d++){var p=v[d];qs(p)?o(p.childrenRef()):p instanceof ht&&i.push(p)}}if(qs(r)){o(r.childrenRef());var s=i.length;if(s<n)for(var l=0,u=s;u<n;u++)i.push(Oh(i[l++%s]));i.length=n}else{i=a({path:r,count:n});for(var f=r.getComputedTransform(),u=0;u<i.length;u++)i[u].setLocalTransform(f);if(i.length!==n)return console.error("Invalid morphing: unmatched splitted path"),ch()}i=Qs(i),t=Qs(t);for(var h=e.individualDelay,u=0;u<n;u++){var c=h?at({delay:(e.delay||0)+h(u,n,i[u],t[u])},e):e;Dv(i[u],t[u],c)}return{fromIndividuals:i,toIndividuals:t,count:t.length}}function Ag(r){return H(r[0])}function Lg(r,t){for(var e=[],n=r.length,i=0;i<n;i++)e.push({one:r[i],many:[]});for(var i=0;i<t.length;i++){var a=t[i].length,o=void 0;for(o=0;o<a;o++)e[o%n].many.push(t[i][o])}for(var s=0,i=n-1;i>=0;i--)if(!e[i].many.length){var l=e[s].many;if(l.length<=1)if(s)s=0;else return e;var a=l.length,u=Math.ceil(a/2);e[i].many=l.slice(u,a),e[s].many=l.slice(0,u),s++}return e}var AP={clone:function(r){for(var t=[],e=1-Math.pow(1-r.path.style.opacity,1/r.count),n=0;n<r.count;n++){var i=Oh(r.path);i.setStyle("opacity",e),t.push(i)}return t},split:null};function Yu(r,t,e,n,i,a){if(!r.length||!t.length)return;var o=vl("update",n,i);if(!(o&&o.duration>0))return;var s=n.getModel("universalTransition").get("delay"),l=Object.assign({setToFinal:!0},o),u,f;Ag(r)&&(u=r,f=t),Ag(t)&&(u=t,f=r);function h(m,y,_,S,w){var b=m.many,T=m.one;if(b.length===1&&!w){var C=y?b[0]:T,x=y?T:b[0];if(qs(C))h({many:[C],one:x},!0,_,S,!0);else{var M=s?at({delay:s(_,S)},l):l;Dv(C,x,M),a(C,x,C,x,M)}}else for(var A=at({dividePath:AP[e],individualDelay:s&&function(V,B,k,G){return s(V+_,S)}},l),P=y?CP(b,T,A):DP(T,b,A),L=P.fromIndividuals,I=P.toIndividuals,R=L.length,E=0;E<R;E++){var M=s?at({delay:s(E,R)},l):l;a(L[E],I[E],y?b[E]:m.one,y?m.one:b[E],M)}}for(var c=u?u===r:r.length>t.length,v=u?Lg(f,u):Lg(c?t:r,[c?r:t]),d=0,p=0;p<v.length;p++)d+=v[p].many.length;for(var g=0,p=0;p<v.length;p++)h(v[p],c,g,d),g+=v[p].many.length}function _n(r){if(!r)return[];if(H(r)){for(var t=[],e=0;e<r.length;e++)t.push(_n(r[e]));return t}var n=[];return r.traverse(function(i){i instanceof ht&&!i.disableMorphing&&!i.invisible&&!i.ignore&&n.push(i)}),n}var l1=1e4,LP=0,Ig=1,Pg=2,IP=gt();function PP(r,t){for(var e=r.dimensions,n=0;n<e.length;n++){var i=r.getDimensionInfo(e[n]);if(i&&i.otherDims[t]===0)return e[n]}}function RP(r,t,e){var n=r.getDimensionInfo(e),i=n&&n.ordinalMeta;if(n){var a=r.get(n.name,t);return i&&i.categories[a]||a+""}}function Rg(r,t,e,n){var i=n?"itemChildGroupId":"itemGroupId",a=PP(r,i);if(a){var o=RP(r,t,a);return o}var s=r.getRawDataItem(t),l=n?"childGroupId":"groupId";if(s&&s[l])return s[l]+"";if(!n)return e||r.getId(t)}function Eg(r){var t=[];return D(r,function(e){var n=e.data,i=e.dataGroupId;if(!(n.count()>l1))for(var a=n.getIndices(),o=0;o<a.length;o++)t.push({data:n,groupId:Rg(n,o,i,!1),childGroupId:Rg(n,o,i,!0),divide:e.divide,dataIndex:o})}),t}function Zu(r,t,e){r.traverse(function(n){n instanceof ht&&cr(n,{style:{opacity:0}},t,{dataIndex:e,isFrom:!0})})}function Xu(r){if(r.parent){var t=r.getComputedTransform();r.setLocalTransform(t),r.parent.remove(r)}}function oi(r){r.stopAnimation(),r.isGroup&&r.traverse(function(t){t.stopAnimation()})}function EP(r,t,e){var n=vl("update",e,t);n&&r.traverse(function(i){if(i instanceof Bi){var a=Hw(i);a&&i.animateFrom({style:a},n)}})}function kP(r,t){var e=r.length;if(e!==t.length)return!1;for(var n=0;n<e;n++){var i=r[n],a=t[n];if(i.data.getId(i.dataIndex)!==a.data.getId(a.dataIndex))return!1}return!0}function u1(r,t,e){var n=Eg(r),i=Eg(t);function a(_,S,w,b,T){(w||_)&&S.animateFrom({style:w&&w!==_?O(O({},w.style),_.style):_.style},T)}var o=!1,s=LP,l=K(),u=K();n.forEach(function(_){_.groupId&&l.set(_.groupId,!0),_.childGroupId&&u.set(_.childGroupId,!0)});for(var f=0;f<i.length;f++){var h=i[f].groupId;if(u.get(h)){s=Ig;break}var c=i[f].childGroupId;if(c&&l.get(c)){s=Pg;break}}function v(_,S){return function(w){var b=w.data,T=w.dataIndex;return S?b.getId(T):_?s===Ig?w.childGroupId:w.groupId:s===Pg?w.childGroupId:w.groupId}}var d=kP(n,i),p={};if(!d)for(var f=0;f<i.length;f++){var g=i[f],m=g.data.getItemGraphicEl(g.dataIndex);m&&(p[m.id]=!0)}function y(_,S){var w=n[S],b=i[_],T=b.data.hostModel,C=w.data.getItemGraphicEl(w.dataIndex),x=b.data.getItemGraphicEl(b.dataIndex);if(C===x){x&&EP(x,b.dataIndex,T);return}C&&p[C.id]||x&&(oi(x),C?(oi(C),Xu(C),o=!0,Yu(_n(C),_n(x),b.divide,T,_,a)):Zu(x,T,_))}new If(n,i,v(!0,d),v(!1,d),null,"multiple").update(y).updateManyToOne(function(_,S){var w=i[_],b=w.data,T=b.hostModel,C=b.getItemGraphicEl(w.dataIndex),x=wt($(S,function(M){return n[M].data.getItemGraphicEl(n[M].dataIndex)}),function(M){return M&&M!==C&&!p[M.id]});C&&(oi(C),x.length?(D(x,function(M){oi(M),Xu(M)}),o=!0,Yu(_n(x),_n(C),w.divide,T,_,a)):Zu(C,T,w.dataIndex))}).updateOneToMany(function(_,S){var w=n[S],b=w.data.getItemGraphicEl(w.dataIndex);if(!(b&&p[b.id])){var T=wt($(_,function(x){return i[x].data.getItemGraphicEl(i[x].dataIndex)}),function(x){return x&&x!==b}),C=i[_[0]].data.hostModel;T.length&&(D(T,function(x){return oi(x)}),b?(oi(b),Xu(b),o=!0,Yu(_n(b),_n(T),w.divide,C,_[0],a)):D(T,function(x){return Zu(x,C,_[0])}))}}).updateManyToMany(function(_,S){new If(S,_,function(w){return n[w].data.getId(n[w].dataIndex)},function(w){return i[w].data.getId(i[w].dataIndex)}).update(function(w,b){y(_[w],S[b])}).execute()}).execute(),o&&D(t,function(_){var S=_.data,w=S.hostModel,b=w&&e.getViewOfSeriesModel(w),T=vl("update",w,0);b&&w.isAnimationEnabled()&&T&&T.duration>0&&b.group.traverse(function(C){C instanceof ht&&!C.animators.length&&C.animateFrom({style:{opacity:0}},T)})})}function kg(r){var t=r.getModel("universalTransition").get("seriesKey");return t||r.id}function Og(r){return H(r)?r.sort().join(","):r}function Cr(r){if(r.hostModel)return r.hostModel.getModel("universalTransition").get("divideShape")}function OP(r,t){var e=K(),n=K(),i=K();return D(r.oldSeries,function(a,o){var s=r.oldDataGroupIds[o],l=r.oldData[o],u=kg(a),f=Og(u);n.set(f,{dataGroupId:s,data:l}),H(u)&&D(u,function(h){i.set(h,{key:f,dataGroupId:s,data:l})})}),D(t.updatedSeries,function(a){if(a.isUniversalTransitionEnabled()&&a.isAnimationEnabled()){var o=a.get("dataGroupId"),s=a.getData(),l=kg(a),u=Og(l),f=n.get(u);if(f)e.set(u,{oldSeries:[{dataGroupId:f.dataGroupId,divide:Cr(f.data),data:f.data}],newSeries:[{dataGroupId:o,divide:Cr(s),data:s}]});else if(H(l)){var h=[];D(l,function(d){var p=n.get(d);p.data&&h.push({dataGroupId:p.dataGroupId,divide:Cr(p.data),data:p.data})}),h.length&&e.set(u,{oldSeries:h,newSeries:[{dataGroupId:o,data:s,divide:Cr(s)}]})}else{var c=i.get(l);if(c){var v=e.get(c.key);v||(v={oldSeries:[{dataGroupId:c.dataGroupId,data:c.data,divide:Cr(c.data)}],newSeries:[]},e.set(c.key,v)),v.newSeries.push({dataGroupId:o,data:s,divide:Cr(s)})}}}}),e}function Bg(r,t){for(var e=0;e<r.length;e++){var n=t.seriesIndex!=null&&t.seriesIndex===r[e].seriesIndex||t.seriesId!=null&&t.seriesId===r[e].id;if(n)return e}}function BP(r,t,e,n){var i=[],a=[];D(Ct(r.from),function(o){var s=Bg(t.oldSeries,o);s>=0&&i.push({dataGroupId:t.oldDataGroupIds[s],data:t.oldData[s],divide:Cr(t.oldData[s]),groupIdDim:o.dimension})}),D(Ct(r.to),function(o){var s=Bg(e.updatedSeries,o);if(s>=0){var l=e.updatedSeries[s].getData();a.push({dataGroupId:t.oldDataGroupIds[s],data:l,divide:Cr(l),groupIdDim:o.dimension})}}),i.length>0&&a.length>0&&u1(i,a,n)}function NP(r){r.registerUpdateLifecycle("series:beforeupdate",function(t,e,n){D(Ct(n.seriesTransition),function(i){D(Ct(i.to),function(a){for(var o=n.updatedSeries,s=0;s<o.length;s++)(a.seriesIndex!=null&&a.seriesIndex===o[s].seriesIndex||a.seriesId!=null&&a.seriesId===o[s].id)&&(o[s][as]=!0)})})}),r.registerUpdateLifecycle("series:transition",function(t,e,n){var i=IP(e);if(i.oldSeries&&n.updatedSeries&&n.optionChanged){var a=n.seriesTransition;if(a)D(Ct(a),function(v){BP(v,i,n,e)});else{var o=OP(i,n);D(o.keys(),function(v){var d=o.get(v);u1(d.oldSeries,d.newSeries,e)})}D(n.updatedSeries,function(v){v[as]&&(v[as]=!1)})}for(var s=t.getSeries(),l=i.oldSeries=[],u=i.oldDataGroupIds=[],f=i.oldData=[],h=0;h<s.length;h++){var c=s[h].getData();c.count()<l1&&(l.push(s[h]),u.push(s[h].get("dataGroupId")),f.push(c))}})}function Ng(r,t,e){var n=fr.createCanvas(),i=t.getWidth(),a=t.getHeight(),o=n.style;return o&&(o.position="absolute",o.left="0",o.top="0",o.width=i+"px",o.height=a+"px",n.setAttribute("data-zr-dom-id",r)),n.width=i*e,n.height=a*e,n}var $u=(function(r){z(t,r);function t(e,n,i){var a=r.call(this)||this;a.motionBlur=!1,a.lastFrameAlpha=.7,a.dpr=1,a.virtual=!1,a.config={},a.incremental=!1,a.zlevel=0,a.maxRepaintRectCount=5,a.__dirty=!0,a.__firstTimePaint=!0,a.__used=!1,a.__drawIndex=0,a.__startIndex=0,a.__endIndex=0,a.__prevStartIndex=null,a.__prevEndIndex=null;var o;i=i||ys,typeof e=="string"?o=Ng(e,n,i):X(e)&&(o=e,e=o.id),a.id=e,a.dom=o;var s=o.style;return s&&(jg(o),o.onselectstart=function(){return!1},s.padding="0",s.margin="0",s.borderWidth="0"),a.painter=n,a.dpr=i,a}return t.prototype.getElementCount=function(){return this.__endIndex-this.__startIndex},t.prototype.afterBrush=function(){this.__prevStartIndex=this.__startIndex,this.__prevEndIndex=this.__endIndex},t.prototype.initContext=function(){this.ctx=this.dom.getContext("2d"),this.ctx.dpr=this.dpr},t.prototype.setUnpainted=function(){this.__firstTimePaint=!0},t.prototype.createBackBuffer=function(){var e=this.dpr;this.domBack=Ng("back-"+this.id,this.painter,e),this.ctxBack=this.domBack.getContext("2d"),e!==1&&this.ctxBack.scale(e,e)},t.prototype.createRepaintRects=function(e,n,i,a){if(this.__firstTimePaint)return this.__firstTimePaint=!1,null;var o=[],s=this.maxRepaintRectCount,l=!1,u=new it(0,0,0,0);function f(y){if(!(!y.isFinite()||y.isZero()))if(o.length===0){var _=new it(0,0,0,0);_.copy(y),o.push(_)}else{for(var S=!1,w=1/0,b=0,T=0;T<o.length;++T){var C=o[T];if(C.intersect(y)){var x=new it(0,0,0,0);x.copy(C),x.union(y),o[T]=x,S=!0;break}else if(l){u.copy(y),u.union(C);var M=y.width*y.height,A=C.width*C.height,P=u.width*u.height,L=P-M-A;L<w&&(w=L,b=T)}}if(l&&(o[b].union(y),S=!0),!S){var _=new it(0,0,0,0);_.copy(y),o.push(_)}l||(l=o.length>=s)}}for(var h=this.__startIndex;h<this.__endIndex;++h){var c=e[h];if(c){var v=c.shouldBePainted(i,a,!0,!0),d=c.__isRendered&&(c.__dirty&fe||!v)?c.getPrevPaintRect():null;d&&f(d);var p=v&&(c.__dirty&fe||!c.__isRendered)?c.getPaintRect():null;p&&f(p)}}for(var h=this.__prevStartIndex;h<this.__prevEndIndex;++h){var c=n[h],v=c&&c.shouldBePainted(i,a,!0,!0);if(c&&(!v||!c.__zr)&&c.__isRendered){var d=c.getPrevPaintRect();d&&f(d)}}var g;do{g=!1;for(var h=0;h<o.length;){if(o[h].isZero()){o.splice(h,1);continue}for(var m=h+1;m<o.length;)o[h].intersect(o[m])?(g=!0,o[h].union(o[m]),o.splice(m,1)):m++;h++}}while(g);return this._paintRects=o,o},t.prototype.debugGetPaintRects=function(){return(this._paintRects||[]).slice()},t.prototype.resize=function(e,n){var i=this.dpr,a=this.dom,o=a.style,s=this.domBack;o&&(o.width=e+"px",o.height=n+"px"),a.width=e*i,a.height=n*i,s&&(s.width=e*i,s.height=n*i,i!==1&&this.ctxBack.scale(i,i))},t.prototype.clear=function(e,n,i){var a=this.dom,o=this.ctx,s=a.width,l=a.height;n=n||this.clearColor;var u=this.motionBlur&&!e,f=this.lastFrameAlpha,h=this.dpr,c=this;u&&(this.domBack||this.createBackBuffer(),this.ctxBack.globalCompositeOperation="copy",this.ctxBack.drawImage(a,0,0,s/h,l/h));var v=this.domBack;function d(p,g,m,y){if(o.clearRect(p,g,m,y),n&&n!=="transparent"){var _=void 0;if(Js(n)){var S=n.global||n.__width===m&&n.__height===y;_=S&&n.__canvasGradient||Xf(o,n,{x:0,y:0,width:m,height:y}),n.__canvasGradient=_,n.__width=m,n.__height=y}else I1(n)&&(n.scaleX=n.scaleX||h,n.scaleY=n.scaleY||h,_=$f(o,n,{dirty:function(){c.setUnpainted(),c.painter.refresh()}}));o.save(),o.fillStyle=_||n,o.fillRect(p,g,m,y),o.restore()}u&&(o.save(),o.globalAlpha=f,o.drawImage(v,p,g,m,y),o.restore())}!i||u?d(0,0,s,l):i.length&&D(i,function(p){d(p.x*h,p.y*h,p.width*h,p.height*h)})},t})(ke),Fg=1e5,yn=314159,Xo=.01,FP=.001;function zP(r){return r?r.__builtin__?!0:!(typeof r.resize!="function"||typeof r.refresh!="function"):!1}function HP(r,t){var e=document.createElement("div");return e.style.cssText=["position:relative","width:"+r+"px","height:"+t+"px","padding:0","margin:0","border-width:0"].join(";")+";",e}var VP=(function(){function r(t,e,n,i){this.type="canvas",this._zlevelList=[],this._prevDisplayList=[],this._layers={},this._layerConfig={},this._needsManuallyCompositing=!1,this.type="canvas";var a=!t.nodeName||t.nodeName.toUpperCase()==="CANVAS";this._opts=n=O({},n||{}),this.dpr=n.devicePixelRatio||ys,this._singleCanvas=a,this.root=t;var o=t.style;o&&(jg(t),t.innerHTML=""),this.storage=e;var s=this._zlevelList;this._prevDisplayList=[];var l=this._layers;if(a){var f=t,h=f.width,c=f.height;n.width!=null&&(h=n.width),n.height!=null&&(c=n.height),this.dpr=n.devicePixelRatio||1,f.width=h*this.dpr,f.height=c*this.dpr,this._width=h,this._height=c;var v=new $u(f,this,this.dpr);v.__builtin__=!0,v.initContext(),l[yn]=v,v.zlevel=yn,s.push(yn),this._domRoot=t}else{this._width=Oo(t,0,n),this._height=Oo(t,1,n);var u=this._domRoot=HP(this._width,this._height);t.appendChild(u)}}return r.prototype.getType=function(){return"canvas"},r.prototype.isSingleCanvas=function(){return this._singleCanvas},r.prototype.getViewportRoot=function(){return this._domRoot},r.prototype.getViewportRootOffset=function(){var t=this.getViewportRoot();if(t)return{offsetLeft:t.offsetLeft||0,offsetTop:t.offsetTop||0}},r.prototype.refresh=function(t){var e=this.storage.getDisplayList(!0),n=this._prevDisplayList,i=this._zlevelList;this._redrawId=Math.random(),this._paintList(e,n,t,this._redrawId);for(var a=0;a<i.length;a++){var o=i[a],s=this._layers[o];if(!s.__builtin__&&s.refresh){var l=a===0?this._backgroundColor:null;s.refresh(l)}}return this._opts.useDirtyRect&&(this._prevDisplayList=e.slice()),this},r.prototype.refreshHover=function(){this._paintHoverList(this.storage.getDisplayList(!1))},r.prototype._paintHoverList=function(t){var e=t.length,n=this._hoverlayer;if(n&&n.clear(),!!e){for(var i={inHover:!0,viewWidth:this._width,viewHeight:this._height},a,o=0;o<e;o++){var s=t[o];s.__inHover&&(n||(n=this._hoverlayer=this.getLayer(Fg)),a||(a=n.ctx,a.save()),Cn(a,s,i,o===e-1))}a&&a.restore()}},r.prototype.getHoverLayer=function(){return this.getLayer(Fg)},r.prototype.paintOne=function(t,e){$0(t,e)},r.prototype._paintList=function(t,e,n,i){if(this._redrawId===i){n=n||!1,this._updateLayerStatus(t);var a=this._doPaintList(t,e,n),o=a.finished,s=a.needsRefreshHover;if(this._needsManuallyCompositing&&this._compositeManually(),s&&this._paintHoverList(t),o)this.eachLayer(function(u){u.afterBrush&&u.afterBrush()});else{var l=this;Ns(function(){l._paintList(t,e,n,i)})}}},r.prototype._compositeManually=function(){var t=this.getLayer(yn).ctx,e=this._domRoot.width,n=this._domRoot.height;t.clearRect(0,0,e,n),this.eachBuiltinLayer(function(i){i.virtual&&t.drawImage(i.dom,0,0,e,n)})},r.prototype._doPaintList=function(t,e,n){for(var i=this,a=[],o=this._opts.useDirtyRect,s=0;s<this._zlevelList.length;s++){var l=this._zlevelList[s],u=this._layers[l];u.__builtin__&&u!==this._hoverlayer&&(u.__dirty||n)&&a.push(u)}for(var f=!0,h=!1,c=function(p){var g=a[p],m=g.ctx,y=o&&g.createRepaintRects(t,e,v._width,v._height),_=n?g.__startIndex:g.__drawIndex,S=!n&&g.incremental&&Date.now,w=S&&Date.now(),b=g.zlevel===v._zlevelList[0]?v._backgroundColor:null;if(g.__startIndex===g.__endIndex)g.clear(!1,b,y);else if(_===g.__startIndex){var T=t[_];(!T.incremental||!T.notClear||n)&&g.clear(!1,b,y)}_===-1&&(console.error("For some unknown reason. drawIndex is -1"),_=g.__startIndex);var C,x=function(L){var I={inHover:!1,allClipped:!1,prevEl:null,viewWidth:i._width,viewHeight:i._height};for(C=_;C<g.__endIndex;C++){var R=t[C];if(R.__inHover&&(h=!0),i._doPaintEl(R,g,o,L,I,C===g.__endIndex-1),S){var E=Date.now()-w;if(E>15)break}}I.prevElClipPaths&&m.restore()};if(y)if(y.length===0)C=g.__endIndex;else for(var M=v.dpr,A=0;A<y.length;++A){var P=y[A];m.save(),m.beginPath(),m.rect(P.x*M,P.y*M,P.width*M,P.height*M),m.clip(),x(P),m.restore()}else m.save(),x(),m.restore();g.__drawIndex=C,g.__drawIndex<g.__endIndex&&(f=!1)},v=this,d=0;d<a.length;d++)c(d);return nt.wxa&&D(this._layers,function(p){p&&p.ctx&&p.ctx.draw&&p.ctx.draw()}),{finished:f,needsRefreshHover:h}},r.prototype._doPaintEl=function(t,e,n,i,a,o){var s=e.ctx;if(n){var l=t.getPaintRect();(!i||l&&l.intersect(i))&&(Cn(s,t,a,o),t.setPrevPaintRect(l))}else Cn(s,t,a,o)},r.prototype.getLayer=function(t,e){this._singleCanvas&&!this._needsManuallyCompositing&&(t=yn);var n=this._layers[t];return n||(n=new $u("zr_"+t,this,this.dpr),n.zlevel=t,n.__builtin__=!0,this._layerConfig[t]?vt(n,this._layerConfig[t],!0):this._layerConfig[t-Xo]&&vt(n,this._layerConfig[t-Xo],!0),e&&(n.virtual=e),this.insertLayer(t,n),n.initContext()),n},r.prototype.insertLayer=function(t,e){var n=this._layers,i=this._zlevelList,a=i.length,o=this._domRoot,s=null,l=-1;if(!n[t]&&zP(e)){if(a>0&&t>i[0]){for(l=0;l<a-1&&!(i[l]<t&&i[l+1]>t);l++);s=n[i[l]]}if(i.splice(l+1,0,t),n[t]=e,!e.virtual)if(s){var u=s.dom;u.nextSibling?o.insertBefore(e.dom,u.nextSibling):o.appendChild(e.dom)}else o.firstChild?o.insertBefore(e.dom,o.firstChild):o.appendChild(e.dom);e.painter||(e.painter=this)}},r.prototype.eachLayer=function(t,e){for(var n=this._zlevelList,i=0;i<n.length;i++){var a=n[i];t.call(e,this._layers[a],a)}},r.prototype.eachBuiltinLayer=function(t,e){for(var n=this._zlevelList,i=0;i<n.length;i++){var a=n[i],o=this._layers[a];o.__builtin__&&t.call(e,o,a)}},r.prototype.eachOtherLayer=function(t,e){for(var n=this._zlevelList,i=0;i<n.length;i++){var a=n[i],o=this._layers[a];o.__builtin__||t.call(e,o,a)}},r.prototype.getLayers=function(){return this._layers},r.prototype._updateLayerStatus=function(t){this.eachBuiltinLayer(function(h,c){h.__dirty=h.__used=!1});function e(h){a&&(a.__endIndex!==h&&(a.__dirty=!0),a.__endIndex=h)}if(this._singleCanvas)for(var n=1;n<t.length;n++){var i=t[n];if(i.zlevel!==t[n-1].zlevel||i.incremental){this._needsManuallyCompositing=!0;break}}var a=null,o=0,s,l;for(l=0;l<t.length;l++){var i=t[l],u=i.zlevel,f=void 0;s!==u&&(s=u,o=0),i.incremental?(f=this.getLayer(u+FP,this._needsManuallyCompositing),f.incremental=!0,o=1):f=this.getLayer(u+(o>0?Xo:0),this._needsManuallyCompositing),f.__builtin__||Sh("ZLevel "+u+" has been used by unkown layer "+f.id),f!==a&&(f.__used=!0,f.__startIndex!==l&&(f.__dirty=!0),f.__startIndex=l,f.incremental?f.__drawIndex=-1:f.__drawIndex=l,e(l),a=f),i.__dirty&fe&&!i.__inHover&&(f.__dirty=!0,f.incremental&&f.__drawIndex<0&&(f.__drawIndex=l))}e(l),this.eachBuiltinLayer(function(h,c){!h.__used&&h.getElementCount()>0&&(h.__dirty=!0,h.__startIndex=h.__endIndex=h.__drawIndex=0),h.__dirty&&h.__drawIndex<0&&(h.__drawIndex=h.__startIndex)})},r.prototype.clear=function(){return this.eachBuiltinLayer(this._clearLayer),this},r.prototype._clearLayer=function(t){t.clear()},r.prototype.setBackgroundColor=function(t){this._backgroundColor=t,D(this._layers,function(e){e.setUnpainted()})},r.prototype.configLayer=function(t,e){if(e){var n=this._layerConfig;n[t]?vt(n[t],e,!0):n[t]=e;for(var i=0;i<this._zlevelList.length;i++){var a=this._zlevelList[i];if(a===t||a===t+Xo){var o=this._layers[a];vt(o,n[t],!0)}}}},r.prototype.delLayer=function(t){var e=this._layers,n=this._zlevelList,i=e[t];i&&(i.dom.parentNode.removeChild(i.dom),delete e[t],n.splice(ft(n,t),1))},r.prototype.resize=function(t,e){if(this._domRoot.style){var n=this._domRoot;n.style.display="none";var i=this._opts,a=this.root;if(t!=null&&(i.width=t),e!=null&&(i.height=e),t=Oo(a,0,i),e=Oo(a,1,i),n.style.display="",this._width!==t||e!==this._height){n.style.width=t+"px",n.style.height=e+"px";for(var o in this._layers)this._layers.hasOwnProperty(o)&&this._layers[o].resize(t,e);this.refresh(!0)}this._width=t,this._height=e}else{if(t==null||e==null)return;this._width=t,this._height=e,this.getLayer(yn).resize(t,e)}return this},r.prototype.clearLayer=function(t){var e=this._layers[t];e&&e.clear()},r.prototype.dispose=function(){this.root.innerHTML="",this.root=this.storage=this._domRoot=this._layers=null},r.prototype.getRenderedCanvas=function(t){if(t=t||{},this._singleCanvas&&!this._compositeManually)return this._layers[yn].dom;var e=new $u("image",this,t.pixelRatio||this.dpr);e.initContext(),e.clear(!1,t.backgroundColor||this._backgroundColor);var n=e.ctx;if(t.pixelRatio<=this.dpr){this.refresh();var i=e.dom.width,a=e.dom.height;this.eachLayer(function(h){h.__builtin__?n.drawImage(h.dom,0,0,i,a):h.renderToCanvas&&(n.save(),h.renderToCanvas(n),n.restore())})}else for(var o={inHover:!1,viewWidth:this._width,viewHeight:this._height},s=this.storage.getDisplayList(!0),l=0,u=s.length;l<u;l++){var f=s[l];Cn(n,f,o,l===u-1)}return e.dom},r.prototype.getWidth=function(){return this._width},r.prototype.getHeight=function(){return this._height},r})();function GP(r){r.registerPainter("canvas",VP)}const WP={class:"card-header"},UP={class:"statistics-content"},YP={class:"data-group"},ZP={class:"data-title"},XP={class:"data-text"},$P={class:"data-group"},qP={class:"data-title"},KP={class:"data-text"},QP={class:"data-group"},jP={class:"data-title"},JP={class:"card-header"},tR={key:0},eR={class:"proportion-bar"},rR=["title"],nR={class:"ranking-total-label"},iR={class:"ranking-label"},aR={__name:"AnalyticsCard",setup(r,{expose:t}){const{t:e}=zg(),n=Wt([]),i=Wt("1"),a=Wt(0),o=Wt(0),s=Wt(0),l=Wt([]),u=Wt(null),f=Wt(null),h=Wt(!1),c=new AbortController;let v=null;Fn([rC,wI,_I,X2,aP,rP,fP,NP,GP,WI]);const d=()=>getComputedStyle(document.documentElement).getPropertyValue("--el-color-primary").trim(),p=x=>new Date(x).toLocaleString([],{year:"numeric",month:"numeric",day:"numeric",hour:"2-digit",minute:"2-digit",hour12:!1}).replace(",",""),g=(x,M,A=30)=>{const P=M.getTime()-x.getTime(),L=Math.floor(P/(A*60*1e3));return new Date(M.getTime()-L*A*60*1e3)},m=(x,M,A)=>{const P={};return x.forEach(I=>{const R=new Date(I.timestamp),E=g(R,A,30),V=E.getTime();P[V]||(P[V]={date:E,count:0}),P[V].count+=1}),Object.values(P).sort((I,R)=>I.date-R.date)},y=(x,M,A)=>{const L=M*24*60/30,I=[],R=new Map(x.map(E=>[E.date.getTime(),E]));for(let E=L-1;E>=0;E--){const V=new Date(A.getTime()-E*30*60*1e3),B=g(V,A,30),k=B.getTime();R.has(k)?I.push(x.find(G=>G.date.getTime()===k)):I.push({date:B,count:0})}return I},_=(x,M)=>{const A=new Date,P=m(x.data,M,A);n.value=y(P,M,A).map(I=>({date:p(I.date),count:I.count})),a.value=P.reduce((I,R)=>I+R.count,0),o.value=Math.round(a.value/M),s.value=Math.floor(x.change_rate*100);const L={};x.data.forEach(I=>{const R=I.target_id?.split("|")[0]||e("unknown");L[R]=(L[R]||0)+1}),l.value=Object.entries(L).map(([I,R])=>({prefix:I,count:R})).sort((I,R)=>R.count-I.count)},S=async()=>{await qu(),u.value&&u.value.dispose();const x=f.value;if(!x||x.offsetWidth===0)return;const M=d(),A=AA(x);A.setOption({color:[M],tooltip:{trigger:"axis"},dataZoom:[{type:"slider",start:0,end:100},{type:"inside",start:0,end:100}],xAxis:{type:"category",data:n.value.map(P=>P.date)},yAxis:{type:"value"},series:[{name:e("dashboard.analytics.command.chart.command"),type:"line",smooth:!0,data:n.value.map(P=>P.count)}]}),u.value=A},w=async()=>{await qu(),u.value&&u.value.resize()},b=async x=>{h.value=!0;try{const M=await hs.get("/api/analytics",{signal:c.signal,params:{days:x}});_(M.data,x),S()}catch(M){hs.isCancel(M)?console.log("Request canceled"):Gg.error(e("message.error.fetch")+M.message)}finally{h.value=!1}},T=x=>{b(x)},C=x=>{const M=["#F56C6C","#E6A23C","#FAE384","#67C23A","#1ABC9C","#409EFF","#9B59B6","#E84393"];let A=0;for(let P=0;P<x.length;P++)A+=x.charCodeAt(P);return M[A%M.length]};return t({fetchAnalyticsData:b,selectedDays:i}),ph(()=>{b(i.value),v=new ResizeObserver(w),f.value&&v.observe(f.value)}),gh(()=>{c.abort(),v&&f.value&&(v.unobserve(f.value),v.disconnect()),u.value&&u.value.dispose()}),(x,M)=>{const A=d1,P=c1,L=Zg,I=Yg,R=p1,E=v1,V=Ug,B=Hg;return Jt(),Ar(V,{gutter:20},{default:Ot(()=>[Bt(I,{span:16,xs:24},{default:Ot(()=>[ma((Jt(),Ar(L,{"body-style":{height:"360px"},shadow:"never"},{default:Ot(()=>[N("div",WP,[N("h3",null,[M[1]||(M[1]=N("i",{class:"mdi mdi-chart-line"},null,-1)),Sn(" "+J(x.$t("dashboard.analytics.command.title")),1)]),Bt(P,{modelValue:i.value,"onUpdate:modelValue":M[0]||(M[0]=k=>i.value=k),onChange:T,class:"time-range-select"},{default:Ot(()=>[Bt(A,{label:x.$t("dashboard.analytics.command.select.1day"),value:"1"},null,8,["label"]),Bt(A,{label:x.$t("dashboard.analytics.command.select.3days"),value:"3"},null,8,["label"]),Bt(A,{label:x.$t("dashboard.analytics.command.select.7days"),value:"7"},null,8,["label"]),Bt(A,{label:x.$t("dashboard.analytics.command.select.30days"),value:"30"},null,8,["label"]),Bt(A,{label:x.$t("dashboard.analytics.command.select.365days"),value:"365"},null,8,["label"])]),_:1},8,["modelValue"])]),N("div",UP,[N("div",YP,[N("strong",ZP,J(x.$t("dashboard.analytics.command.label.total")),1),N("span",XP,J(a.value||0),1)]),N("div",$P,[N("strong",qP,J(x.$t("dashboard.analytics.command.label.average")),1),N("span",KP,J(o.value||0),1)]),N("div",QP,[N("strong",jP,J(x.$t("dashboard.analytics.command.label.change_rate")),1),N("span",{class:Vg({positive:s.value>0,negative:s.value<0,"data-text":s.value===0})},J(s.value>0?`+${s.value}%`:s.value===0?"0%":`${s.value}%`),3)])]),N("div",{ref_key:"chartContainer",ref:f,class:"chart-container"},null,512)]),_:1})),[[B,h.value]])]),_:1}),Bt(I,{span:8,xs:24},{default:Ot(()=>[ma((Jt(),Ar(L,{"body-style":{height:"360px"},shadow:"never"},{default:Ot(()=>[N("div",JP,[N("h3",null,[M[2]||(M[2]=N("i",{class:"mdi mdi-format-list-numbered"},null,-1)),Sn(" "+J(x.$t("dashboard.analytics.platform.title")),1)])]),l.value.length>0?(Jt(),si("div",tR,[N("div",eR,[(Jt(!0),si(Iv,null,Pv(l.value,k=>(Jt(),si("div",{key:k.prefix,class:"proportion-segment",style:Rv({width:Math.round(k.count/a.value*100*100)/100+"%",backgroundColor:C(k.prefix)}),title:`${k.prefix}: ${k.count} (${Math.round(k.count/a.value*100*100)/100}%)`},null,12,rR))),128))]),N("div",nR,[N("strong",null,J(x.$t("dashboard.analytics.command.label.total")),1),N("span",null,J(a.value||0),1)]),Bt(R,{height:"260px"},{default:Ot(()=>[(Jt(!0),si(Iv,null,Pv(l.value,(k,G)=>(Jt(),si("div",{key:k.prefix,class:"ranking-item"},[N("span",{style:Rv({backgroundColor:C(k.prefix),color:"#fff",borderRadius:"100%",padding:"6px 10px",display:"inline-block",marginRight:"8px"})},J(G+1),5),N("div",iR,[N("strong",null,J(k.prefix),1),N("span",null,J(k.count),1)])]))),128))]),_:1})])):(Jt(),Ar(E,{key:1}))]),_:1})),[[B,h.value]])]),_:1})]),_:1})}}},oR=dh(aR,[["__scopeId","data-v-0ad1536f"]]),sR={class:"data-title"},lR={class:"data-text"},uR={class:"data-title"},fR={class:"data-text"},hR={class:"data-title"},vR={class:"data-text"},cR={class:"data-title"},dR={class:"data-text"},pR={class:"data-title"},gR={class:"data-text"},mR={class:"data-title"},yR={class:"data-text"},_R={class:"data-title"},SR={class:"data-text"},bR={class:"data-title"},wR={class:"data-text"},xR={class:"data-text"},TR={class:"data-text"},MR={class:"percentage-value"},CR={class:"percentage-label"},DR={class:"percentage-value"},AR={class:"percentage-label"},LR={class:"percentage-value"},IR={class:"percentage-label"},PR={__name:"ServerInfoCard",setup(r,{expose:t}){const{t:e}=zg(),n=["#1989fa","#e6a23c","#f56c6c"],i=Fi({system:"",version:"",machine:"",boot_time:0}),a=Fi({running_time:0,python_version:"",version:"",web_render_status:!1}),o=Fi({cpu_brand:"",cpu_percent:0}),s=Fi({total:0,used:0,percent:0}),l=Fi({total:0,used:0,percent:0}),u=Wt(!1),f=Wt(!1),h=new AbortController;function c(y){const _=Math.floor(y/3600),S=Math.floor(y%3600/60),w=Math.floor(y%60);return e("dashboard.server_info.text.format_time",{hours:_,minutes:S,seconds:w})}function v(y){return y?y.startsWith("git:")?y.slice(4,11):y:"-"}function d(y){const _=new Date(y*1e3),S=(Wg.getItem("language")||"zh_cn").toLowerCase(),b={zh_cn:"zh-CN",zh_tw:"zh-TW",en_us:"en-US",ja_jp:"ja-JP"}[S]||"zh-CN";return b==="ja-JP"?new Intl.DateTimeFormat(b,{calendar:"japanese",era:"short",year:"numeric",month:"2-digit",day:"2-digit",hour:"2-digit",minute:"2-digit",second:"2-digit",hour12:!1}).format(_):new Intl.DateTimeFormat(b,{year:"numeric",month:"2-digit",day:"2-digit",hour:"2-digit",minute:"2-digit",second:"2-digit",hour12:!1}).format(_)}function p(y){return y>=90?n[2]:y>=60?n[1]:n[0]}function g(){qu(()=>{const y=document.querySelector(".memory-dashboards");y&&(f.value=y.scrollWidth>y.clientWidth)})}async function m(){u.value=!0;try{const _=(await hs.get("/api/server-info",{signal:h.signal})).data;Object.assign(i,_.os),Object.assign(a,_.bot),Object.assign(o,_.cpu),Object.assign(s,_.memory),Object.assign(l,_.disk)}catch(y){hs.isCancel(y)?console.log("Request canceled"):Gg.error(e("message.error.fetch")+y.message)}finally{u.value=!1}}return t({fetchServerInfoData:m}),ph(()=>{g(),window.addEventListener("resize",g),m()}),gh(()=>{window.removeEventListener("resize",g),h.abort()}),(y,_)=>{const S=Zg,w=Yg,b=g1,T=Ug,C=Hg;return Jt(),Ar(T,{gutter:20},{default:Ot(()=>[Bt(w,{span:10,xs:24},{default:Ot(()=>[ma((Jt(),Ar(S,{"body-style":{height:"190px"},shadow:"never"},{default:Ot(()=>[N("h3",null,[_[0]||(_[0]=N("i",{class:"mdi mdi-robot-outline"},null,-1)),Sn(" "+J(y.$t("dashboard.server_info.bot.title")),1)]),N("p",null,[N("strong",sR,J(y.$t("dashboard.server_info.bot.label.python_version")),1),N("span",lR,J(a.python_version||"-"),1)]),N("p",null,[N("strong",uR,J(y.$t("dashboard.server_info.bot.label.bot_version")),1),N("span",fR,J(v(a.version)),1)]),N("p",null,[N("strong",hR,J(y.$t("dashboard.server_info.bot.label.web_render_status")),1),N("span",vR,J(a.web_render_status?y.$t("true"):y.$t("false")),1)]),N("p",null,[N("strong",cR,J(y.$t("dashboard.server_info.bot.label.running_time")),1),N("span",dR,J(c(a.running_time||0)),1)])]),_:1})),[[C,u.value]]),ma((Jt(),Ar(S,{"body-style":{height:"190px"},shadow:"never"},{default:Ot(()=>[N("h3",null,[_[1]||(_[1]=N("i",{class:"mdi mdi-laptop"},null,-1)),Sn(" "+J(y.$t("dashboard.server_info.system.title")),1)]),N("p",null,[N("strong",pR,J(y.$t("dashboard.server_info.system.label.machine")),1),N("span",gR,J(i.system||"-")+" "+J(i.machine?"-":"")+" "+J(i.machine||""),1)]),N("p",null,[N("strong",mR,J(y.$t("dashboard.server_info.system.label.version")),1),N("span",yR,J(i.version||"-"),1)]),N("p",null,[N("strong",_R,J(y.$t("dashboard.server_info.system.label.boot_time")),1),N("span",SR,J(d(i.boot_time||0)),1)])]),_:1})),[[C,u.value]])]),_:1}),Bt(w,{span:14,xs:24},{default:Ot(()=>[ma((Jt(),Ar(S,{"body-style":{height:"440px"},shadow:"never"},{default:Ot(()=>[N("h3",null,[_[2]||(_[2]=N("i",{class:"mdi mdi-memory"},null,-1)),Sn(" "+J(y.$t("dashboard.server_info.cpu.title")),1)]),N("p",null,[N("strong",bR,J(y.$t("dashboard.server_info.cpu.label.brand")),1)]),N("p",null,[N("span",wR,J(o.cpu_brand||"-"),1)]),N("h3",null,[_[3]||(_[3]=N("i",{class:"mdi mdi-sd"},null,-1)),Sn(" "+J(y.$t("dashboard.server_info.memory.title")),1)]),N("p",null,[N("span",xR,J(s.used?s.used.toFixed():0)+" MB / "+J(s.total?s.total.toFixed():0)+" MB",1)]),N("h3",null,[_[4]||(_[4]=N("i",{class:"mdi mdi-server-outline"},null,-1)),Sn(" "+J(y.$t("dashboard.server_info.disk.title")),1)]),N("p",null,[N("span",TR,J(l.used?l.used.toFixed(1):0)+" GB / "+J(l.total?l.total.toFixed(1):0)+" GB",1)]),_[5]||(_[5]=N("br",null,null,-1)),N("div",{class:Vg(["memory-dashboards",{leftAlign:f.value,centerAlign:!f.value}])},[Bt(b,{type:"dashboard",percentage:o.cpu_percent?o.cpu_percent.toFixed(1):0,color:p(o.cpu_percent)},{default:Ot(({percentage:x})=>[N("span",MR,J(x)+"%",1),N("span",CR,J(y.$t("dashboard.server_info.cpu.title")),1)]),_:1},8,["percentage","color"]),Bt(b,{type:"dashboard",percentage:s.percent?s.percent.toFixed(1):0,color:p(s.percent)},{default:Ot(({percentage:x})=>[N("span",DR,J(x)+"%",1),N("span",AR,J(y.$t("dashboard.server_info.memory.title")),1)]),_:1},8,["percentage","color"]),Bt(b,{type:"dashboard",percentage:l.percent?l.percent.toFixed(1):0,color:p(l.percent)},{default:Ot(({percentage:x})=>[N("span",LR,J(x)+"%",1),N("span",IR,J(y.$t("dashboard.server_info.disk.title")),1)]),_:1},8,["percentage","color"])],2)]),_:1})),[[C,u.value]])]),_:1})]),_:1})}}},RR=dh(PR,[["__scopeId","data-v-5356f1c9"]]),ER={__name:"dashboard",setup(r){const t=Wt(!1),e=Wt(null),n=Wt(Math.floor(Date.now()/1e3)),i=Wt(null),a=Wt(null);async function o(){if(!t.value){t.value=!0;try{n.value=Math.floor(Date.now()/1e3);const h=[];if(i.value&&h.push(i.value.fetchServerInfoData()),a.value){const c=a.value.selectedDays;h.push(a.value.fetchAnalyticsData(c))}await Promise.all(h)}catch{}finally{t.value=!1,l()}}}function s(){e.value=setInterval(()=>{o()},36e5)}function l(){u(),s()}function u(){e.value&&(clearInterval(e.value),e.value=null)}function f(h){const c=new Date(h*1e3),v=(Wg.getItem("language")||"zh_cn").toLowerCase(),p={zh_cn:"zh-CN",zh_tw:"zh-TW",en_us:"en-US",ja_jp:"ja-JP"}[v]||"zh-CN";return p==="ja-JP"?new Intl.DateTimeFormat(p,{calendar:"japanese",era:"short",year:"numeric",month:"2-digit",day:"2-digit",hour:"2-digit",minute:"2-digit",second:"2-digit",hour12:!1}).format(c):new Intl.DateTimeFormat(p,{year:"numeric",month:"2-digit",day:"2-digit",hour:"2-digit",minute:"2-digit",second:"2-digit",hour12:!1}).format(c)}return ph(()=>{s()}),gh(()=>{u()}),(h,c)=>{const v=h1,d=f1;return Jt(),si("div",null,[Bt(RR,{ref_key:"serverInfoCard",ref:i,loading:t.value},null,8,["loading"]),Bt(oR,{ref_key:"analyticsCard",ref:a,loading:t.value},null,8,["loading"]),Bt(d,{content:h.$t("dashboard.update_time.title",{time:f(n.value)}),placement:"left"},{default:Ot(()=>[Bt(v,{class:"refresh-button",circle:"",size:"large",type:"primary",disabled:t.value,onClick:o},{default:Ot(()=>[...c[0]||(c[0]=[N("i",{class:"mdi mdi-refresh"},null,-1)])]),_:1},8,["disabled"])]),_:1},8,["content"])])}}},VR=dh(ER,[["__scopeId","data-v-05dd6b0c"]]);export{VR as default};
